// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=c236b3d006f55f2e69079b2f60e09f9a899b9d3a$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_DOWNLOAD_ITEM_CALLBACK_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_DOWNLOAD_ITEM_CALLBACK_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_download_handler_capi.h"
#include "include/cef_download_handler.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefDownloadItemCallbackCToCpp
    : public CefCToCppRefCounted<CefDownloadItemCallbackCToCpp,
                                 CefDownloadItemCallback,
                                 cef_download_item_callback_t> {
public:
  CefDownloadItemCallbackCToCpp();
  virtual ~CefDownloadItemCallbackCToCpp();

  // CefDownloadItemCallback methods.
  void Cancel() override;
  void Pause() override;
  void Resume() override;
};

constexpr auto CefDownloadItemCallbackCToCpp_Wrap =
    CefDownloadItemCallbackCToCpp::Wrap;
constexpr auto CefDownloadItemCallbackCToCpp_Unwrap =
    CefDownloadItemCallbackCToCpp::Unwrap;

#endif // CEF_LIBCEF_DLL_CTOCPP_DOWNLOAD_ITEM_CALLBACK_CTOCPP_H_
