// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=064d6de9f55d9547ed3788be1eededb0c3a91379$
//

#include "libcef_dll/ctocpp/views/panel_ctocpp.h"
#include "libcef_dll/cpptoc/views/panel_delegate_cpptoc.h"
#include "libcef_dll/cpptoc/views/view_delegate_cpptoc.h"
#include "libcef_dll/ctocpp/views/box_layout_ctocpp.h"
#include "libcef_dll/ctocpp/views/browser_view_ctocpp.h"
#include "libcef_dll/ctocpp/views/button_ctocpp.h"
#include "libcef_dll/ctocpp/views/fill_layout_ctocpp.h"
#include "libcef_dll/ctocpp/views/layout_ctocpp.h"
#include "libcef_dll/ctocpp/views/scroll_view_ctocpp.h"
#include "libcef_dll/ctocpp/views/textfield_ctocpp.h"
#include "libcef_dll/ctocpp/views/view_ctocpp.h"
#include "libcef_dll/ctocpp/views/window_ctocpp.h"
#include "libcef_dll/shutdown_checker.h"

// STATIC METHODS - Body may be edited by hand.

NO_SANITIZE("cfi-icall")
CefRefPtr<CefPanel> CefPanel::CreatePanel(
    CefRefPtr<CefPanelDelegate> delegate) {
  shutdown_checker::AssertNotShutdown();

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Unverified params: delegate

  // Execute
  auto *_retval = cef_panel_create(CefPanelDelegateCppToC_Wrap(delegate));

  // Return type: refptr_same
  return CefPanelCToCpp_Wrap(_retval);
}

// VIRTUAL METHODS - Body may be edited by hand.

NO_SANITIZE("cfi-icall") CefRefPtr<CefWindow> CefPanelCToCpp::AsWindow() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->as_window) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_window(_struct);

  // Return type: refptr_same
  return CefWindowCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefFillLayout> CefPanelCToCpp::SetToFillLayout() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->set_to_fill_layout) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->set_to_fill_layout(_struct);

  // Return type: refptr_same
  return CefFillLayoutCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefBoxLayout> CefPanelCToCpp::SetToBoxLayout(
    const CefBoxLayoutSettings &settings) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->set_to_box_layout) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->set_to_box_layout(_struct, &settings);

  // Return type: refptr_same
  return CefBoxLayoutCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefLayout> CefPanelCToCpp::GetLayout() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->get_layout) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->get_layout(_struct);

  // Return type: refptr_same
  return CefLayoutCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::Layout() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->layout) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->layout(_struct);
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::AddChildView(CefRefPtr<CefView> view) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->add_child_view) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return;
  }

  // Execute
  _struct->add_child_view(_struct, CefViewCToCpp_Unwrap(view));
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::AddChildViewAt(CefRefPtr<CefView> view, int index) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->add_child_view_at) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return;
  }
  // Verify param: index; type: simple_byval
  DCHECK_GE(index, 0);
  if (index < 0) {
    return;
  }

  // Execute
  _struct->add_child_view_at(_struct, CefViewCToCpp_Unwrap(view), index);
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::ReorderChildView(CefRefPtr<CefView> view, int index) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->reorder_child_view) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return;
  }

  // Execute
  _struct->reorder_child_view(_struct, CefViewCToCpp_Unwrap(view), index);
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::RemoveChildView(CefRefPtr<CefView> view) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->remove_child_view) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return;
  }

  // Execute
  _struct->remove_child_view(_struct, CefViewCToCpp_Unwrap(view));
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::RemoveAllChildViews() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->remove_all_child_views) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->remove_all_child_views(_struct);
}

NO_SANITIZE("cfi-icall") size_t CefPanelCToCpp::GetChildViewCount() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->get_child_view_count) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  size_t _retval = _struct->get_child_view_count(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefView> CefPanelCToCpp::GetChildViewAt(int index) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = GetStruct();
  if (!_struct->get_child_view_at) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: index; type: simple_byval
  DCHECK_GE(index, 0);
  if (index < 0) {
    return nullptr;
  }

  // Execute
  auto *_retval = _struct->get_child_view_at(_struct, index);

  // Return type: refptr_same
  return CefViewCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefBrowserView> CefPanelCToCpp::AsBrowserView() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->as_browser_view) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_browser_view(_struct);

  // Return type: refptr_same
  return CefBrowserViewCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefButton> CefPanelCToCpp::AsButton() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->as_button) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_button(_struct);

  // Return type: refptr_same
  return CefButtonCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefPanel> CefPanelCToCpp::AsPanel() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->as_panel) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_panel(_struct);

  // Return type: refptr_same
  return CefPanelCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefScrollView> CefPanelCToCpp::AsScrollView() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->as_scroll_view) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_scroll_view(_struct);

  // Return type: refptr_same
  return CefScrollViewCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefTextfield> CefPanelCToCpp::AsTextfield() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->as_textfield) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->as_textfield(_struct);

  // Return type: refptr_same
  return CefTextfieldCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") CefString CefPanelCToCpp::GetTypeString() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_type_string) {
    return CefString();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_string_userfree_t _retval = _struct->get_type_string(_struct);

  // Return type: string
  CefString _retvalStr;
  _retvalStr.AttachToUserFree(_retval);
  return _retvalStr;
}

NO_SANITIZE("cfi-icall")
CefString CefPanelCToCpp::ToString(bool include_children) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->to_string) {
    return CefString();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_string_userfree_t _retval = _struct->to_string(_struct, include_children);

  // Return type: string
  CefString _retvalStr;
  _retvalStr.AttachToUserFree(_retval);
  return _retvalStr;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsValid() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_valid) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_valid(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsAttached() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_attached) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_attached(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsSame(CefRefPtr<CefView> that) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_same) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: that; type: refptr_same
  DCHECK(that.get());
  if (!that.get()) {
    return false;
  }

  // Execute
  int _retval = _struct->is_same(_struct, CefViewCToCpp_Unwrap(that));

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefViewDelegate> CefPanelCToCpp::GetDelegate() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_delegate) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->get_delegate(_struct);

  // Return type: refptr_diff
  return CefViewDelegateCppToC_Unwrap(_retval);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefWindow> CefPanelCToCpp::GetWindow() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_window) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->get_window(_struct);

  // Return type: refptr_same
  return CefWindowCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") int CefPanelCToCpp::GetID() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_id) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->get_id(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetID(int id) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_id) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_id(_struct, id);
}

NO_SANITIZE("cfi-icall") int CefPanelCToCpp::GetGroupID() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_group_id) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->get_group_id(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetGroupID(int group_id) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_group_id) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_group_id(_struct, group_id);
}

NO_SANITIZE("cfi-icall") CefRefPtr<CefView> CefPanelCToCpp::GetParentView() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_parent_view) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->get_parent_view(_struct);

  // Return type: refptr_same
  return CefViewCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall")
CefRefPtr<CefView> CefPanelCToCpp::GetViewForID(int id) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_view_for_id) {
    return nullptr;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  auto *_retval = _struct->get_view_for_id(_struct, id);

  // Return type: refptr_same
  return CefViewCToCpp_Wrap(_retval);
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetBounds(const CefRect &bounds) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_bounds) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_bounds(_struct, &bounds);
}

NO_SANITIZE("cfi-icall") CefRect CefPanelCToCpp::GetBounds() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_bounds) {
    return CefRect();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_rect_t _retval = _struct->get_bounds(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") CefRect CefPanelCToCpp::GetBoundsInScreen() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_bounds_in_screen) {
    return CefRect();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_rect_t _retval = _struct->get_bounds_in_screen(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetSize(const CefSize &size) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_size) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_size(_struct, &size);
}

NO_SANITIZE("cfi-icall") CefSize CefPanelCToCpp::GetSize() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_size) {
    return CefSize();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_size_t _retval = _struct->get_size(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::SetPosition(const CefPoint &position) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_position) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_position(_struct, &position);
}

NO_SANITIZE("cfi-icall") CefPoint CefPanelCToCpp::GetPosition() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_position) {
    return CefPoint();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_point_t _retval = _struct->get_position(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::SetInsets(const CefInsets &insets) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_insets) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_insets(_struct, &insets);
}

NO_SANITIZE("cfi-icall") CefInsets CefPanelCToCpp::GetInsets() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_insets) {
    return CefInsets();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_insets_t _retval = _struct->get_insets(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") CefSize CefPanelCToCpp::GetPreferredSize() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_preferred_size) {
    return CefSize();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_size_t _retval = _struct->get_preferred_size(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SizeToPreferredSize() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->size_to_preferred_size) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->size_to_preferred_size(_struct);
}

NO_SANITIZE("cfi-icall") CefSize CefPanelCToCpp::GetMinimumSize() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_minimum_size) {
    return CefSize();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_size_t _retval = _struct->get_minimum_size(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") CefSize CefPanelCToCpp::GetMaximumSize() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_maximum_size) {
    return CefSize();
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_size_t _retval = _struct->get_maximum_size(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") int CefPanelCToCpp::GetHeightForWidth(int width) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_height_for_width) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->get_height_for_width(_struct, width);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::InvalidateLayout() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->invalidate_layout) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->invalidate_layout(_struct);
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetVisible(bool visible) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_visible) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_visible(_struct, visible);
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsVisible() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_visible) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_visible(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsDrawn() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_drawn) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_drawn(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetEnabled(bool enabled) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_enabled) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_enabled(_struct, enabled);
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsEnabled() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_enabled) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_enabled(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::SetFocusable(bool focusable) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_focusable) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_focusable(_struct, focusable);
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsFocusable() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_focusable) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_focusable(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::IsAccessibilityFocusable() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->is_accessibility_focusable) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->is_accessibility_focusable(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") bool CefPanelCToCpp::HasFocus() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->has_focus) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->has_focus(_struct);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall") void CefPanelCToCpp::RequestFocus() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->request_focus) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->request_focus(_struct);
}

NO_SANITIZE("cfi-icall")
void CefPanelCToCpp::SetBackgroundColor(cef_color_t color) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->set_background_color) {
    return;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  _struct->set_background_color(_struct, color);
}

NO_SANITIZE("cfi-icall") cef_color_t CefPanelCToCpp::GetBackgroundColor() {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_background_color) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_color_t _retval = _struct->get_background_color(_struct);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall")
cef_color_t CefPanelCToCpp::GetThemeColor(int color_id) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->get_theme_color) {
    return 0;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  cef_color_t _retval = _struct->get_theme_color(_struct, color_id);

  // Return type: simple
  return _retval;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointToScreen(CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_to_screen) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->convert_point_to_screen(_struct, &point);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointFromScreen(CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_from_screen) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->convert_point_from_screen(_struct, &point);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointToWindow(CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_to_window) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->convert_point_to_window(_struct, &point);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointFromWindow(CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_from_window) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Execute
  int _retval = _struct->convert_point_from_window(_struct, &point);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointToView(CefRefPtr<CefView> view,
                                        CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_to_view) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return false;
  }

  // Execute
  int _retval = _struct->convert_point_to_view(
      _struct, CefViewCToCpp_Unwrap(view), &point);

  // Return type: bool
  return _retval ? true : false;
}

NO_SANITIZE("cfi-icall")
bool CefPanelCToCpp::ConvertPointFromView(CefRefPtr<CefView> view,
                                          CefPoint &point) {
  shutdown_checker::AssertNotShutdown();

  auto *_struct = reinterpret_cast<cef_view_t *>(GetStruct());
  if (!_struct->convert_point_from_view) {
    return false;
  }

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  // Verify param: view; type: refptr_same
  DCHECK(view.get());
  if (!view.get()) {
    return false;
  }

  // Execute
  int _retval = _struct->convert_point_from_view(
      _struct, CefViewCToCpp_Unwrap(view), &point);

  // Return type: bool
  return _retval ? true : false;
}

// CONSTRUCTOR - Do not edit by hand.

CefPanelCToCpp::CefPanelCToCpp() {}

// DESTRUCTOR - Do not edit by hand.

CefPanelCToCpp::~CefPanelCToCpp() { shutdown_checker::AssertNotShutdown(); }

template <>
cef_panel_t *
CefCToCppRefCounted<CefPanelCToCpp, CefPanel, cef_panel_t>::UnwrapDerived(
    CefWrapperType type, CefPanel *c) {
  if (type == WT_WINDOW) {
    return reinterpret_cast<cef_panel_t *>(
        CefWindowCToCpp_Unwrap(reinterpret_cast<CefWindow *>(c)));
  }
  CHECK(false) << __func__ << " called with unexpected class type " << type;
  return nullptr;
}

template <>
CefWrapperType
    CefCToCppRefCounted<CefPanelCToCpp, CefPanel, cef_panel_t>::kWrapperType =
        WT_PANEL;
