// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=6010f28b1d9d8d5cb40a2d64964459a2ec049932$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_TEST_TEST_SERVER_CONNECTION_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_TEST_TEST_SERVER_CONNECTION_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/test/cef_test_server_capi.h"
#include "include/test/cef_test_server.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefTestServerConnectionCToCpp
    : public CefCToCppRefCounted<CefTestServerConnectionCToCpp,
                                 CefTestServerConnection,
                                 cef_test_server_connection_t> {
public:
  CefTestServerConnectionCToCpp();
  virtual ~CefTestServerConnectionCToCpp();

  // CefTestServerConnection methods.
  void SendHttp200Response(const CefString &content_type, const void *data,
                           size_t data_size) override;
  void SendHttp404Response() override;
  void SendHttp500Response(const CefString &error_message) override;
  void SendHttpResponse(int response_code, const CefString &content_type,
                        const void *data, size_t data_size,
                        const HeaderMap &extra_headers) override;
#if CEF_API_ADDED(15100)
  void SendHttpResponseWithRawHeaders(const void *header_data,
                                      size_t header_data_size,
                                      const void *response_data,
                                      size_t response_data_size) override;
#endif
};

constexpr auto CefTestServerConnectionCToCpp_Wrap =
    CefTestServerConnectionCToCpp::Wrap;
constexpr auto CefTestServerConnectionCToCpp_Unwrap =
    CefTestServerConnectionCToCpp::Unwrap;

#endif // CEF_LIBCEF_DLL_CTOCPP_TEST_TEST_SERVER_CONNECTION_CTOCPP_H_
