// Copyright (c) 2026 Marshall A. Greenblatt. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//    * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//    * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//    * Neither the name of Google Inc. nor the name Chromium Embedded
// Framework nor the names of its contributors may be used to endorse
// or promote products derived from this software without specific prior
// written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// ---------------------------------------------------------------------------
//
// This file is generated by the make_pack_header.py tool.
//

#ifndef CEF_INCLUDE_CEF_COMMAND_IDS_H_
#define CEF_INCLUDE_CEF_COMMAND_IDS_H_
#pragma once

// ---------------------------------------------------------------------------
// From chrome_command_ids.h:

#define IDC_MinimumLabelValue 4000
#define IDC_BACK 33000
#define IDC_FORWARD 33001
#define IDC_RELOAD 33002
#define IDC_HOME 33003
#define IDC_OPEN_CURRENT_URL 33004
#define IDC_STOP 33006
#define IDC_RELOAD_BYPASSING_CACHE 33007
#define IDC_RELOAD_CLEARING_CACHE 33009
#define IDC_NEW_WINDOW 34000
#define IDC_NEW_INCOGNITO_WINDOW 34001
#define IDC_CLOSE_WINDOW 34012
#define IDC_ALWAYS_ON_TOP 34013
#define IDC_NEW_TAB 34014
#define IDC_CLOSE_TAB 34015
#define IDC_SELECT_NEXT_TAB 34016
#define IDC_SELECT_PREVIOUS_TAB 34017
#define IDC_SELECT_TAB_0 34018
#define IDC_SELECT_TAB_1 34019
#define IDC_SELECT_TAB_2 34020
#define IDC_SELECT_TAB_3 34021
#define IDC_SELECT_TAB_4 34022
#define IDC_SELECT_TAB_5 34023
#define IDC_SELECT_TAB_6 34024
#define IDC_SELECT_TAB_7 34025
#define IDC_SELECT_LAST_TAB 34026
#define IDC_DUPLICATE_TAB 34027
#define IDC_RESTORE_TAB 34028
#define IDC_SHOW_AS_TAB 34029
#define IDC_FULLSCREEN 34030
#define IDC_EXIT 34031
#define IDC_MOVE_TAB_NEXT 34032
#define IDC_MOVE_TAB_PREVIOUS 34033
#define IDC_SEARCH 34035
#define IDC_WINDOW_MENU 34045
#define IDC_MINIMIZE_WINDOW 34046
#define IDC_MAXIMIZE_WINDOW 34047
#define IDC_ALL_WINDOWS_FRONT 34048
#define IDC_NAME_WINDOW 34049
#define IDC_TOGGLE_MULTITASK_MENU 34050
#define IDC_USE_SYSTEM_TITLE_BAR 34051
#define IDC_RESTORE_WINDOW 34052
#define IDC_MOVE_WINDOW 34053
#define IDC_SIZE_WINDOW 34054
#define IDC_OPEN_IN_PWA_WINDOW 34055
#define IDC_MOVE_TAB_TO_NEW_WINDOW 34056
#define IDC_NEW_SPLIT_TAB 34057
#define IDC_TOGGLE_VERTICAL_TABS 34058
#define IDC_VERTICAL_TABS_SEND_FEEDBACK 34059
#define IDC_TOGGLE_VERTICAL_TABS_EXPAND_ON_HOVER 34060
#define IDC_TOGGLE_VERTICAL_TABS_COLLAPSE 34061
#define IDC_COPY_URL 34071
#define IDC_OPEN_IN_CHROME 34072
#define IDC_WEB_APP_SETTINGS 34073
#define IDC_WEB_APP_MENU_APP_INFO 34074
#define IDC_WEB_APP_UPGRADE_DIALOG 34075
#define IDC_VISIT_DESKTOP_OF_LRU_USER_2 34080
#define IDC_VISIT_DESKTOP_OF_LRU_USER_3 34081
#define IDC_VISIT_DESKTOP_OF_LRU_USER_4 34082
#define IDC_VISIT_DESKTOP_OF_LRU_USER_5 34083
#define IDC_ADD_NEW_TAB_TO_GROUP 34100
#define IDC_CREATE_NEW_TAB_GROUP 34101
#define IDC_FOCUS_NEXT_TAB_GROUP 34102
#define IDC_FOCUS_PREV_TAB_GROUP 34103
#define IDC_CLOSE_TAB_GROUP 34104
#define IDC_GROUP_UNGROUPED_TABS 34105
#define IDC_CREATE_NEW_TAB_GROUP_TOP_LEVEL 34106
#define IDC_ADD_NEW_TAB_RECENT_GROUP 34107
#define IDC_UNFOCUS_TAB_GROUP 34108
#define IDC_BOOKMARK_THIS_TAB 35000
#define IDC_BOOKMARK_ALL_TABS 35001
#define IDC_VIEW_SOURCE 35002
#define IDC_PRINT 35003
#define IDC_SAVE_PAGE 35004
#define IDC_EMAIL_PAGE_LOCATION 35006
#define IDC_BASIC_PRINT 35007
#define IDC_SAVE_CREDIT_CARD_FOR_PAGE 35008
#define IDC_SHOW_TRANSLATE 35009
#define IDC_MANAGE_PASSWORDS_FOR_PAGE 35010
#define IDC_ROUTE_MEDIA 35011
#define IDC_WINDOW_MUTE_SITE 35012
#define IDC_WINDOW_PIN_TAB 35013
#define IDC_WINDOW_GROUP_TAB 35014
#define IDC_MIGRATE_LOCAL_CREDIT_CARD_FOR_PAGE 35015
#define IDC_SEND_TAB_TO_SELF 35016
#define IDC_FOCUS_THIS_TAB 35017
#define IDC_QRCODE_GENERATOR 35021
#define IDC_WINDOW_CLOSE_TABS_TO_RIGHT 35022
#define IDC_WINDOW_CLOSE_OTHER_TABS 35023
#define IDC_NEW_TAB_TO_RIGHT 35024
#define IDC_SAVE_AUTOFILL_ADDRESS 35025
#define IDC_OFFERS_AND_REWARDS_FOR_PAGE 35026
#define IDC_WEBAUTHN 35027
#define IDC_SHARING_HUB 35028
#define IDC_SHARING_HUB_MENU 35029
#define IDC_FILLED_CARD_INFORMATION 35030
#define IDC_SHARING_HUB_SCREENSHOT 35031
#define IDC_VIRTUAL_CARD_ENROLL 35032
#define IDC_SAVE_IBAN_FOR_PAGE 35035
#define IDC_AUTOFILL_MANDATORY_REAUTH 35036
#define IDC_PROFILE_MENU_IN_APP_MENU 35039
#define IDC_PASSWORDS_AND_AUTOFILL_MENU 35040
#define IDC_SHOW_PASSWORD_MANAGER 35041
#define IDC_SHOW_PAYMENT_METHODS 35042
#define IDC_SHOW_ADDRESSES 35043
#define IDC_ORGANIZE_TABS 35044
#define IDC_SEND_SHARED_TAB_GROUP_FEEDBACK 35046
#define IDC_SHOW_IDENTITY_DOCS 35047
#define IDC_SHOW_TRAVEL 35048
#define IDC_SHOW_CONTACT_INFO 35049
#define IDC_MUTE_TARGET_SITE 35050
#define IDC_PIN_TARGET_TAB 35051
#define IDC_GROUP_TARGET_TAB 35052
#define IDC_DUPLICATE_TARGET_TAB 35053
#define IDC_CUT 36000
#define IDC_COPY 36001
#define IDC_PASTE 36003
#define IDC_EDIT_MENU 36004
#define IDC_FIND 37000
#define IDC_FIND_NEXT 37001
#define IDC_FIND_PREVIOUS 37002
#define IDC_CLOSE_FIND_OR_STOP 37003
#define IDC_FIND_MENU 37100
#define IDC_FIND_AND_EDIT_MENU 37200
#define IDC_SAVE_AND_SHARE_MENU 37300
#define IDC_CUSTOMIZE_CHROME 37350
#define IDC_CLOSE_PROFILE 35351
#define IDC_MANAGE_GOOGLE_ACCOUNT 35352
#define IDC_SHOW_SYNC_SETTINGS 35353
#define IDC_TURN_ON_SYNC 35354
#define IDC_SHOW_SIGNIN_WHEN_PAUSED 35355
#define IDC_OPEN_GUEST_PROFILE 35356
#define IDC_ADD_NEW_PROFILE 35357
#define IDC_MANAGE_CHROME_PROFILES 35358
#define IDC_SHOW_SIGNIN 35359
#define IDC_SHOW_SYNC_PASSPHRASE_DIALOG 35360
#define IDC_ZOOM_MENU 38000
#define IDC_ZOOM_PLUS 38001
#define IDC_ZOOM_NORMAL 38002
#define IDC_ZOOM_MINUS 38003
#define IDC_FOCUS_TOOLBAR 39000
#define IDC_FOCUS_LOCATION 39001
#define IDC_FOCUS_SEARCH 39002
#define IDC_FOCUS_MENU_BAR 39003
#define IDC_FOCUS_NEXT_PANE 39004
#define IDC_FOCUS_PREVIOUS_PANE 39005
#define IDC_FOCUS_BOOKMARKS 39006
#define IDC_FOCUS_INACTIVE_POPUP_FOR_ACCESSIBILITY 39007
#define IDC_FOCUS_WEB_CONTENTS_PANE 39009
#define IDC_OPEN_FILE 40000
#define IDC_CREATE_SHORTCUT 40002
#define IDC_DEVELOPER_MENU 40003
#define IDC_DEV_TOOLS 40004
#define IDC_DEV_TOOLS_CONSOLE 40005
#define IDC_TASK_MANAGER 40006
#define IDC_DEV_TOOLS_DEVICES 40007
#define IDC_FEEDBACK 40008
#define IDC_SHOW_BOOKMARK_BAR 40009
#define IDC_SHOW_HISTORY 40010
#define IDC_SHOW_BOOKMARK_MANAGER 40011
#define IDC_SHOW_DOWNLOADS 40012
#define IDC_CLEAR_BROWSING_DATA 40013
#define IDC_IMPORT_SETTINGS 40014
#define IDC_OPTIONS 40015
#define IDC_EDIT_SEARCH_ENGINES 40016
#define IDC_VIEW_PASSWORDS 40017
#define IDC_ABOUT 40018
#define IDC_HELP_PAGE_VIA_KEYBOARD 40019
#define IDC_HELP_PAGE_VIA_MENU 40020
#define IDC_SHOW_APP_MENU 40021
#define IDC_MANAGE_EXTENSIONS 40022
#define IDC_DEV_TOOLS_INSPECT 40023
#define IDC_UPGRADE_DIALOG 40024
#define IDC_SHOW_HISTORY_CLUSTERS_SIDE_PANEL 40025
#define IDC_PROFILING_ENABLED 40028
#define IDC_BOOKMARKS_MENU 40029
#define IDC_SAVED_TAB_GROUPS_MENU 40030
#define IDC_EXTENSION_ERRORS 40031
#define IDC_SHOW_AVATAR_MENU 40134
#define IDC_EXTENSION_INSTALL_ERROR_FIRST 40135
#define IDC_EXTENSION_INSTALL_ERROR_LAST 40235
#define IDC_TOGGLE_REQUEST_TABLET_SITE 40236
#define IDC_DEV_TOOLS_TOGGLE 40237
#define IDC_RECENT_TABS_MENU 40239
#define IDC_RECENT_TABS_NO_DEVICE_TABS 40240
#define IDC_DISTILL_PAGE 40243
#define IDC_HELP_MENU 40244
#define IDC_TAKE_SCREENSHOT 40248
#define IDC_MORE_TOOLS_MENU 40249
#define IDC_TOGGLE_FULLSCREEN_TOOLBAR 40250
#define IDC_CUSTOMIZE_TOUCH_BAR 40251
#define IDC_SHOW_BETA_FORUM 40252
#define IDC_TOGGLE_JAVASCRIPT_APPLE_EVENTS 40253
#define IDC_INSTALL_PWA 40254
#define IDC_SHOW_MANAGEMENT_PAGE 40255
#define IDC_PASTE_AND_GO 40256
#define IDC_SHOW_FULL_URLS 40259
#define IDC_CARET_BROWSING_TOGGLE 40260
#define IDC_CHROME_TIPS 40263
#define IDC_CHROME_WHATS_NEW 40264
#define IDC_PERFORMANCE 40266
#define IDC_EXTENSIONS_SUBMENU 40267
#define IDC_EXTENSIONS_SUBMENU_MANAGE_EXTENSIONS 40268
#define IDC_EXTENSIONS_SUBMENU_VISIT_CHROME_WEB_STORE 40269
#define IDC_READING_LIST_MENU 40270
#define IDC_READING_LIST_MENU_ADD_TAB 40271
#define IDC_READING_LIST_MENU_SHOW_UI 40272
#define IDC_SHOW_READING_MODE_SIDE_PANEL 40273
#define IDC_SHOW_BOOKMARK_SIDE_PANEL 40274
#define IDC_SHOW_CHROME_LABS 40276
#define IDC_RECENT_TABS_LOGIN_FOR_DEVICE_TABS 40277
#define IDC_OPEN_RECENT_TAB 40278
#define IDC_OPEN_SAFETY_HUB 40279
#define IDC_SAFETY_HUB_SHOW_PASSWORD_CHECKUP 40280
#define IDC_SAFETY_HUB_MANAGE_EXTENSIONS 40281
#define IDC_SHOW_GOOGLE_LENS_SHORTCUT 40282
#define IDC_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL 40283
#define IDC_SHOW_CUSTOMIZE_CHROME_TOOLBAR 40284
#define IDC_TASK_MANAGER_APP_MENU 40285
#define IDC_TASK_MANAGER_SHORTCUT 40286
#define IDC_TASK_MANAGER_CONTEXT_MENU 40287
#define IDC_TASK_MANAGER_MAIN_MENU 40288
#define IDC_SHOW_HISTORY_SIDE_PANEL 40293
#define IDC_OPEN_GLIC 40294
#define IDC_FIND_EXTENSIONS 40295
#define IDC_SHOW_SEARCH_TOOLS 40296
#define IDC_SHOW_COMMENTS_SIDE_PANEL 40297
#define IDC_RECENT_TABS_SEE_DEVICE_TABS 40298
#define IDC_SHOW_AI_MODE_OMNIBOX_BUTTON 40299
#define IDC_CONTENT_CONTEXT_INSPECTELEMENT_WITH_GEMINI 40300
#define IDC_CONTENT_CONTEXT_INSPECTELEMENT_WITH_DEVTOOLS 40301
#define IDC_REPORT_UNSAFE_SITE 40302
#define IDC_SHOW_READING_MODE_KEYBOARD 40303
#define IDC_SHOW_TABS_FROM_OTHER_DEVICES_SIDE_PANEL 40304
#define IDC_CHROME_ENTERPRISE_RELEASE_NOTES 40305
#define IDC_SPELLCHECK_SUGGESTION_0 41000
#define IDC_SPELLCHECK_SUGGESTION_1 41001
#define IDC_SPELLCHECK_SUGGESTION_2 41002
#define IDC_SPELLCHECK_SUGGESTION_3 41003
#define IDC_SPELLCHECK_SUGGESTION_4 41004
#define IDC_SPELLCHECK_MENU 41005
#define IDC_SPELLCHECK_LANGUAGES_FIRST 41006
#define IDC_SPELLCHECK_LANGUAGES_LAST 41106
#define IDC_CHECK_SPELLING_WHILE_TYPING 41107
#define IDC_SPELLCHECK_ADD_TO_DICTIONARY 41110
#define IDC_SPELLCHECK_MULTI_LINGUAL 41111
#define IDC_SPELLCHECK_REMOVE_FROM_DICTIONARY 41112
#define IDC_WRITING_DIRECTION_MENU 41120
#define IDC_WRITING_DIRECTION_DEFAULT 41121
#define IDC_WRITING_DIRECTION_LTR 41122
#define IDC_WRITING_DIRECTION_RTL 41123
#define IDC_TRANSLATE_ORIGINAL_LANGUAGE_BASE 42100
#define IDC_TRANSLATE_TARGET_LANGUAGE_BASE 42400
#define IDC_VIEW_MENU 44000
#define IDC_FILE_MENU 44001
#define IDC_CHROME_MENU 44002
#define IDC_HIDE_APP 44003
#define IDC_HISTORY_MENU 46000
#define IDC_TAB_MENU 46001
#define IDC_PROFILE_MAIN_MENU 46100
#define IDC_INPUT_METHODS_MENU 46300
#define IDC_CONTENT_CONTEXT_CUSTOM_FIRST 47000
#define IDC_CONTENT_CONTEXT_CUSTOM_LAST 48000
#define IDC_EXTENSIONS_CONTEXT_CUSTOM_FIRST 49000
#define IDC_EXTENSIONS_CONTEXT_CUSTOM_LAST 50000
#define IDC_CONTENT_CONTEXT_OPENLINKNEWTAB 50100
#define IDC_CONTENT_CONTEXT_OPENLINKNEWWINDOW 50101
#define IDC_CONTENT_CONTEXT_OPENLINKOFFTHERECORD 50102
#define IDC_CONTENT_CONTEXT_SAVELINKAS 50103
#define IDC_CONTENT_CONTEXT_COPYLINKLOCATION 50104
#define IDC_CONTENT_CONTEXT_OPENLINKWITH 50106
#define IDC_CONTENT_CONTEXT_COPYLINKTEXT 50107
#define IDC_CONTENT_CONTEXT_OPENLINKINPROFILE 50108
#define IDC_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP 50109
#define IDC_CONTENT_CONTEXT_OPENLINKSPLITVIEW 50111
#define IDC_CONTENT_CONTEXT_ADD_LINK_TO_READING_LIST 50112
#define IDC_CONTENT_CONTEXT_SAVEIMAGEAS 50120
#define IDC_CONTENT_CONTEXT_COPYIMAGELOCATION 50121
#define IDC_CONTENT_CONTEXT_COPYIMAGE 50122
#define IDC_CONTENT_CONTEXT_OPENIMAGENEWTAB 50123
#define IDC_CONTENT_CONTEXT_SEARCHWEBFORIMAGE 50124
#define IDC_CONTENT_CONTEXT_OPEN_ORIGINAL_IMAGE_NEW_TAB 50125
#define IDC_CONTENT_CONTEXT_LOAD_IMAGE 50126
#define IDC_CONTENT_CONTEXT_SEARCHLENSFORIMAGE 50127
#define IDC_CONTENT_CONTEXT_GLICSHAREIMAGE 50128
#define IDC_CONTENT_CONTEXT_VIDEO_FRAME 50129
#define IDC_CONTENT_CONTEXT_SAVEVIDEOFRAMEAS 50130
#define IDC_CONTENT_CONTEXT_SAVEAVAS 50131
#define IDC_CONTENT_CONTEXT_COPYAVLOCATION 50132
#define IDC_CONTENT_CONTEXT_COPYVIDEOFRAME 50133
#define IDC_CONTENT_CONTEXT_SEARCHLENSFORVIDEOFRAME 50134
#define IDC_CONTENT_CONTEXT_SEARCHWEBFORVIDEOFRAME 50135
#define IDC_CONTENT_CONTEXT_OPENAVNEWTAB 50136
#define IDC_CONTENT_CONTEXT_PICTUREINPICTURE 50137
#define IDC_CONTENT_CONTEXT_LOOP 50140
#define IDC_CONTENT_CONTEXT_CONTROLS 50141
#define IDC_CONTENT_CONTEXT_ROTATECW 50142
#define IDC_CONTENT_CONTEXT_ROTATECCW 50143
#define IDC_CONTENT_CONTEXT_COPY 50150
#define IDC_CONTENT_CONTEXT_CUT 50151
#define IDC_CONTENT_CONTEXT_PASTE 50152
#define IDC_CONTENT_CONTEXT_DELETE 50153
#define IDC_CONTENT_CONTEXT_UNDO 50154
#define IDC_CONTENT_CONTEXT_REDO 50155
#define IDC_CONTENT_CONTEXT_SELECTALL 50156
#define IDC_CONTENT_CONTEXT_PASTE_AND_MATCH_STYLE 50157
#define IDC_CONTENT_CONTEXT_COPYLINKTOTEXT 50158
#define IDC_CONTENT_CONTEXT_RESHARELINKTOTEXT 50159
#define IDC_CONTENT_CONTEXT_REMOVELINKTOTEXT 50160
#define IDC_CONTENT_CONTEXT_TRANSLATE 50161
#define IDC_CONTENT_CONTEXT_INSPECTELEMENT 50162
#define IDC_CONTENT_CONTEXT_VIEWPAGEINFO 50163
#define IDC_CONTENT_CONTEXT_LANGUAGE_SETTINGS 50164
#define IDC_CONTENT_CONTEXT_LOOK_UP 50165
#define IDC_CONTENT_CONTEXT_NO_SPELLING_SUGGESTIONS 50166
#define IDC_CONTENT_CONTEXT_SPELLING_SUGGESTION 50167
#define IDC_CONTENT_CONTEXT_SPELLING_TOGGLE 50168
#define IDC_CONTENT_CONTEXT_OPEN_IN_READING_MODE 50169
#define IDC_CONTENT_CONTEXT_SAVEPLUGINAS 50170
#define IDC_CONTENT_CONTEXT_INSPECTBACKGROUNDPAGE 50171
#define IDC_CONTENT_CONTEXT_RELOAD_PACKAGED_APP 50172
#define IDC_CONTENT_CONTEXT_RESTART_PACKAGED_APP 50173
#define IDC_CONTENT_CONTEXT_LENS_REGION_SEARCH 50174
#define IDC_CONTENT_CONTEXT_WEB_REGION_SEARCH 50175
#define IDC_CONTENT_CONTEXT_GENERATEPASSWORD 50176
#define IDC_CONTENT_CONTEXT_EXIT_FULLSCREEN 50177
#define IDC_CONTENT_CONTEXT_SAVE_TO_MEMORY_BANKS 50183
#define IDC_CONTENT_CONTEXT_SHOWALLSAVEDPASSWORDS 50178
#define IDC_CONTENT_CONTEXT_PARTIAL_TRANSLATE 50179
#define IDC_CONTENT_CONTEXT_RELOADFRAME 50180
#define IDC_CONTENT_CONTEXT_VIEWFRAMESOURCE 50181
#define IDC_CONTENT_CONTEXT_VIEWFRAMEINFO 50182
#define IDC_CONTENT_CONTEXT_ADD_A_NOTE 50185
#define IDC_CONTENT_CONTEXT_GOTOURL 50190
#define IDC_CONTENT_CONTEXT_SEARCHWEBFOR 50191
#define IDC_CONTENT_CONTEXT_SEARCHWEBFORNEWTAB 50192
#define IDC_CONTENT_CONTEXT_LENS_OVERLAY 50193
#define IDC_CONTENT_CONTEXT_USE_PASSKEY_FROM_ANOTHER_DEVICE 50194
#define IDC_CONTENT_CONTEXT_LISTEN_TO_THIS_PAGE 50195
#define IDC_CONTENT_CONTEXT_OPEN_WITH1 50200
#define IDC_CONTENT_CONTEXT_OPEN_WITH2 50201
#define IDC_CONTENT_CONTEXT_OPEN_WITH3 50202
#define IDC_CONTENT_CONTEXT_OPEN_WITH4 50203
#define IDC_CONTENT_CONTEXT_OPEN_WITH5 50204
#define IDC_CONTENT_CONTEXT_OPEN_WITH6 50205
#define IDC_CONTENT_CONTEXT_OPEN_WITH7 50206
#define IDC_CONTENT_CONTEXT_OPEN_WITH8 50207
#define IDC_CONTENT_CONTEXT_OPEN_WITH9 50208
#define IDC_CONTENT_CONTEXT_OPEN_WITH10 50209
#define IDC_CONTENT_CONTEXT_OPEN_WITH11 50210
#define IDC_CONTENT_CONTEXT_OPEN_WITH12 50211
#define IDC_CONTENT_CONTEXT_OPEN_WITH13 50212
#define IDC_CONTENT_CONTEXT_OPEN_WITH14 50213
#define IDC_CONTENT_CONTEXT_EMOJI 50220
#define IDC_CONTENT_CONTEXT_DICTATION 50229
#define IDC_CONTEXT_COMPOSE 50230
#define IDC_CONTENT_CONTEXT_RELOAD_GLIC 50232
#define IDC_CONTENT_CONTEXT_ARCHIVE_GLIC 50233
#define IDC_CONTENT_CONTEXT_GLIC 50234
#define IDC_BOOKMARK_BAR_OPEN_ALL 51000
#define IDC_BOOKMARK_BAR_OPEN_ALL_NEW_WINDOW 51001
#define IDC_BOOKMARK_BAR_OPEN_ALL_INCOGNITO 51002
#define IDC_BOOKMARK_BAR_OPEN_INCOGNITO 51003
#define IDC_BOOKMARK_BAR_OPEN_ALL_NEW_TAB_GROUP 51004
#define IDC_BOOKMARK_BAR_RENAME_FOLDER 51005
#define IDC_BOOKMARK_BAR_EDIT 51006
#define IDC_BOOKMARK_BAR_REMOVE 51007
#define IDC_BOOKMARK_BAR_UNDO 51008
#define IDC_BOOKMARK_BAR_REDO 51009
#define IDC_BOOKMARK_BAR_ADD_NEW_BOOKMARK 51010
#define IDC_BOOKMARK_BAR_NEW_FOLDER 51011
#define IDC_BOOKMARK_MANAGER 51012
#define IDC_BOOKMARK_BAR_ALWAYS_SHOW 51013
#define IDC_BOOKMARK_BAR_SHOW_APPS_SHORTCUT 51014
#define IDC_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS 51016
#define IDC_BOOKMARK_BAR_TRACK_PRICE_FOR_SHOPPING_BOOKMARK 51017
#define IDC_BOOKMARK_BAR_UNTRACK_PRICE_FOR_SHOPPING_BOOKMARK 51018
#define IDC_BOOKMARK_BAR_ADD_TO_BOOKMARKS_BAR 51019
#define IDC_BOOKMARK_BAR_REMOVE_FROM_BOOKMARKS_BAR 51020
#define IDC_BOOKMARK_BAR_TOGGLE_SHOW_TAB_GROUPS 51021
#define IDC_BOOKMARK_BAR_MOVE 51022
#define IDC_BOOKMARK_BAR_OPEN_SPLIT_VIEW 51023
#define IDC_BOOKMARK_BAR_SUBMENU 51024
#define IDC_BOOKMARK_BAR_SUBMENU_ALWAYS_HIDE 51025
#define IDC_BOOKMARK_BAR_SUBMENU_ALWAYS_SHOW 51026
#define IDC_BOOKMARK_BAR_SUBMENU_ONLY_ON_NTP 51027
#define IDC_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_SINGLE_DEVICE 51030
#define IDC_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_MULTIPLE_DEVICES 51031
#define IDC_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_SINGLE_DEVICE 51032
#define IDC_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_MULTIPLE_DEVICES 51033
#define IDC_CONTENT_CONTEXT_GENERATE_QR_CODE 51034
#define IDC_CONTENT_CONTEXT_SHARING_SUBMENU 51035
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_DEVICE1 51040
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_DEVICE2 51041
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_DEVICE3 51042
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_DEVICE4 51043
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_DEVICE5 51044
#define IDC_CONTENT_CONTEXT_SEND_TAB_TO_SELF_MANAGE_DEVICES 51045
#define IDC_CONTENT_PASTE_FROM_CLIPBOARD 51037
#define IDC_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND 51100
#define IDC_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND_SETTING 51101
#define IDC_MEDIA_ROUTER_ABOUT 51200
#define IDC_MEDIA_ROUTER_HELP 51201
#define IDC_MEDIA_ROUTER_LEARN_MORE 51202
#define IDC_MEDIA_ROUTER_TOGGLE_MEDIA_REMOTING 51208
#define IDC_MEDIA_TOOLBAR_CONTEXT_REPORT_CAST_ISSUE 51209
#define IDC_MEDIA_TOOLBAR_CONTEXT_SHOW_OTHER_SESSIONS 51210
#define IDC_UPDATE_SIDE_PANEL_PIN_STATE 51211
#define IDC_MEDIA_CONTEXT_MEDIA_STREAM_CAPTURE_LIST_FIRST 51301
#define IDC_MEDIA_CONTEXT_MEDIA_STREAM_CAPTURE_LIST_LAST 51399
#define IDC_CONTENT_CONTEXT_PROTOCOL_HANDLER_FIRST 52000
#define IDC_CONTENT_CONTEXT_PROTOCOL_HANDLER_LAST 52199
#define IDC_CONTENT_CONTEXT_PROTOCOL_HANDLER_SETTINGS 52200
#define IDC_OPEN_LINK_IN_PROFILE_FIRST 52300
#define IDC_OPEN_LINK_IN_PROFILE_LAST 52399
#define IDC_CONTENT_CONTEXT_START_SMART_SELECTION_ACTION1 52400
#define IDC_CONTENT_CONTEXT_START_SMART_SELECTION_ACTION2 52401
#define IDC_CONTENT_CONTEXT_START_SMART_SELECTION_ACTION3 52402
#define IDC_CONTENT_CONTEXT_START_SMART_SELECTION_ACTION4 52403
#define IDC_CONTENT_CONTEXT_START_SMART_SELECTION_ACTION5 52404
#define IDC_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_TOGGLE 52410
#define IDC_CONTENT_CONTEXT_ACCESSIBILITY_LABELS 52411
#define IDC_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_TOGGLE_ONCE 52412
#define IDC_CONTENT_CONTEXT_QUICK_ANSWERS_INLINE_ANSWER 52413
#define IDC_CONTENT_CONTEXT_QUICK_ANSWERS_INLINE_QUERY 52414
#define IDC_TAB_SEARCH 52500
#define IDC_TAB_SEARCH_CLOSE 52501
#define IDC_DEBUG_TOGGLE_TABLET_MODE 52510
#define IDC_DEBUG_PRINT_VIEW_TREE 52511
#define IDC_DEBUG_PRINT_VIEW_TREE_DETAILS 52512
#define IDC_CONTENT_CONTEXT_AUTOFILL_FEEDBACK 52990
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PLUS_ADDRESS 52994
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SELECT_PASSWORD 52998
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_IMPORT_PASSWORDS 52999
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SUGGEST_PASSWORD 53000
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_USE_PASSKEY_FROM_ANOTHER_DEVICE 53002
#define IDC_CONTENT_CONTEXT_AUTOFILL_FALLBACK_AT_MEMORY 53003
#define IDC_LIVE_CAPTION 53251
#define IDC_DEVICE_SYSTEM_TRAY_ICON_FIRST 53260
#define IDC_DEVICE_SYSTEM_TRAY_ICON_LAST 53299
#define IDC_SET_BROWSER_AS_DEFAULT 53300
#define IDC_GLIC_STATUS_ICON_MENU_CUSTOMIZE_KEYBOARD_SHORTCUT 53311
#define IDC_GLIC_STATUS_ICON_MENU_REMOVE_ICON 53312
#define IDC_GLIC_STATUS_ICON_MENU_SETTINGS 53313
#define IDC_GLIC_STATUS_ICON_MENU_EXIT 53314
#define IDC_GLIC_STATUS_ICON_MENU_TOGGLE 53316
#define IDC_GLIC_TOGGLE_PIN 53320
#define IDC_TAB_SEARCH_TOGGLE_PIN 53321
#define IDC_PROJECTS_PANEL_TOGGLE_PIN 53322
#define IDC_EVERYTHING_MENU_TOGGLE_PIN 53323
#define IDC_SHOW_CONTEXTUAL_TASKS_SIDE_PANEL 54000
#define IDC_OMNIBOX_CONTEXT_ADD_IMAGE 54010
#define IDC_OMNIBOX_CONTEXT_ADD_FILE 54011
#define IDC_OMNIBOX_CONTEXT_CREATE_IMAGES 54012
#define IDC_OMNIBOX_CONTEXT_DEEP_RESEARCH 54013
#define IDC_OMNIBOX_CONTEXT_CANVAS 54014
#define IDC_OMNIBOX_CONTEXT_SET_MODEL_AUTO 54015
#define IDC_OMNIBOX_CONTEXT_SET_MODEL_THINKING 54016
#define IDC_OMNIBOX_CONTEXT_SET_MODEL_REGULAR 54017
#define IDC_OMNIBOX_CONTEXT_SET_MODEL_PRO_NO_GEN_UI 54018
#define IDC_OMNIBOX_CONTEXT_SHARED_TABS_SUBMENU 54019
#define IDC_OMNIBOX_CONTEXT_SMART_TAB_SHARING 54020

#endif  // CEF_INCLUDE_CEF_COMMAND_IDS_H_
