// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=39cd1fbe33c71915247f09cb6546edda85b1a8b1$
//

#include "libcef_dll/cpptoc/component_update_callback_cpptoc.h"
#include "libcef_dll/shutdown_checker.h"

#if CEF_API_ADDED(14600)

namespace {

// MEMBER FUNCTIONS - Body may be edited by hand.

void CEF_CALLBACK component_update_callback_on_complete(
    struct _cef_component_update_callback_t *self,
    const cef_string_t *component_id, cef_component_update_error_t error) {
  shutdown_checker::AssertNotShutdown();

  // AUTO-GENERATED CONTENT - DELETE THIS COMMENT BEFORE MODIFYING

  DCHECK(self);
  if (!self) {
    return;
  }
  // Verify param: component_id; type: string_byref_const
  DCHECK(component_id);
  if (!component_id) {
    return;
  }

  // Execute
  CefComponentUpdateCallbackCppToC::Get(self)->OnComplete(
      CefString(component_id), error);
}

} // namespace

// CONSTRUCTOR - Do not edit by hand.

CefComponentUpdateCallbackCppToC::CefComponentUpdateCallbackCppToC() {
  GetStruct()->on_complete = component_update_callback_on_complete;
}

// DESTRUCTOR - Do not edit by hand.

CefComponentUpdateCallbackCppToC::~CefComponentUpdateCallbackCppToC() {
  shutdown_checker::AssertNotShutdown();
}

template <>
CefRefPtr<CefComponentUpdateCallback>
CefCppToCRefCounted<CefComponentUpdateCallbackCppToC,
                    CefComponentUpdateCallback,
                    cef_component_update_callback_t>::
    UnwrapDerived(CefWrapperType type, cef_component_update_callback_t *s) {
  CHECK(false) << __func__ << " called with unexpected class type " << type;
  return nullptr;
}

template <>
CefWrapperType CefCppToCRefCounted<
    CefComponentUpdateCallbackCppToC, CefComponentUpdateCallback,
    cef_component_update_callback_t>::kWrapperType =
    WT_COMPONENT_UPDATE_CALLBACK;

#endif // CEF_API_ADDED(14600)
