// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=4717549858ebc6f64c6b0af46fd29c0e836f30cc$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_REGISTRATION_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_REGISTRATION_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_registration_capi.h"
#include "include/cef_registration.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefRegistrationCToCpp
    : public CefCToCppRefCounted<CefRegistrationCToCpp, CefRegistration,
                                 cef_registration_t> {
public:
  CefRegistrationCToCpp();
  virtual ~CefRegistrationCToCpp();

  // CefRegistration methods.
};

constexpr auto CefRegistrationCToCpp_Wrap = CefRegistrationCToCpp::Wrap;
constexpr auto CefRegistrationCToCpp_Unwrap = CefRegistrationCToCpp::Unwrap;

#endif // CEF_LIBCEF_DLL_CTOCPP_REGISTRATION_CTOCPP_H_
