// Copyright (c) 2026 Marshall A. Greenblatt. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//    * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//    * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//    * Neither the name of Google Inc. nor the name Chromium Embedded
// Framework nor the names of its contributors may be used to endorse
// or promote products derived from this software without specific prior
// written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// ---------------------------------------------------------------------------
//
// This file is generated by the make_pack_header.py tool.
//

#ifndef CEF_INCLUDE_CEF_PACK_STRINGS_H_
#define CEF_INCLUDE_CEF_PACK_STRINGS_H_
#pragma once

// ---------------------------------------------------------------------------
// From app_locale_settings.h:

#define IDS_WEB_FONT_FAMILY 50013
#define IDS_WEB_FONT_SIZE 50014

// ---------------------------------------------------------------------------
// From auto_image_annotation_strings.h:

#define IDS_AX_UNLABELED_IMAGE_ROLE_DESCRIPTION 50020
#define IDS_AX_IMAGE_ELIGIBLE_FOR_ANNOTATION 50022
#define IDS_AX_IMAGE_ANNOTATION_PENDING 50023
#define IDS_AX_IMAGE_ANNOTATION_ADULT 50024
#define IDS_AX_IMAGE_ANNOTATION_NO_DESCRIPTION 50025
#define IDS_AX_IMAGE_ANNOTATION_OCR_CONTEXT 50026
#define IDS_AX_IMAGE_ANNOTATION_DESCRIPTION_CONTEXT 50027
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLUS 50028
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_BACKWARD 50029
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_FORWARD 50030
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALL 50031
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHAT 50032
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHECK 50033
#define IDS_AX_IMAGE_ANNOTATION_ICON_X 50034
#define IDS_AX_IMAGE_ANNOTATION_ICON_DELETE 50035
#define IDS_AX_IMAGE_ANNOTATION_ICON_EDIT 50036
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI 50037
#define IDS_AX_IMAGE_ANNOTATION_ICON_END_CALL 50038
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_DOWNWARD 50039
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEART 50040
#define IDS_AX_IMAGE_ANNOTATION_ICON_HOME 50041
#define IDS_AX_IMAGE_ANNOTATION_ICON_INFO 50042
#define IDS_AX_IMAGE_ANNOTATION_ICON_LAUNCH_APPS 50043
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_UP 50044
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_BARS 50045
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_DOTS 50046
#define IDS_AX_IMAGE_ANNOTATION_ICON_NOTIFICATIONS 50047
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAUSE 50048
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLAY 50049
#define IDS_AX_IMAGE_ANNOTATION_ICON_REFRESH 50050
#define IDS_AX_IMAGE_ANNOTATION_ICON_MAGNIFYING_GLASS 50051
#define IDS_AX_IMAGE_ANNOTATION_ICON_SEND 50052
#define IDS_AX_IMAGE_ANNOTATION_ICON_SETTINGS 50053
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHARE 50054
#define IDS_AX_IMAGE_ANNOTATION_ICON_STAR 50055
#define IDS_AX_IMAGE_ANNOTATION_ICON_TAKE_PHOTO 50056
#define IDS_AX_IMAGE_ANNOTATION_ICON_TIME 50057
#define IDS_AX_IMAGE_ANNOTATION_ICON_VIDEOCAM 50058
#define IDS_AX_IMAGE_ANNOTATION_ICON_EXPAND 50059
#define IDS_AX_IMAGE_ANNOTATION_ICON_CONTRACT 50060
#define IDS_AX_IMAGE_ANNOTATION_ICON_GOOGLE 50061
#define IDS_AX_IMAGE_ANNOTATION_ICON_TWITTER 50062
#define IDS_AX_IMAGE_ANNOTATION_ICON_FACEBOOK 50063
#define IDS_AX_IMAGE_ANNOTATION_ICON_ASSISTANT 50064
#define IDS_AX_IMAGE_ANNOTATION_ICON_WEATHER 50065
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_CART 50066
#define IDS_AX_IMAGE_ANNOTATION_ICON_UPLOAD 50067
#define IDS_AX_IMAGE_ANNOTATION_ICON_QUESTION 50068
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC 50069
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC_MUTE 50070
#define IDS_AX_IMAGE_ANNOTATION_ICON_GALLERY 50071
#define IDS_AX_IMAGE_ANNOTATION_ICON_COMPASS 50072
#define IDS_AX_IMAGE_ANNOTATION_ICON_PEOPLE 50073
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_UPWARD 50074
#define IDS_AX_IMAGE_ANNOTATION_ICON_ENVELOPE 50075
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI_FACE 50076
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAPERCLIP 50077
#define IDS_AX_IMAGE_ANNOTATION_ICON_CAST 50078
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_UP 50079
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_DOWN 50080
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_STATE 50081
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_MUTE 50082
#define IDS_AX_IMAGE_ANNOTATION_ICON_STOP 50083
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_BAG 50084
#define IDS_AX_IMAGE_ANNOTATION_ICON_LIST 50085
#define IDS_AX_IMAGE_ANNOTATION_ICON_LOCATION 50086
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALENDAR 50087
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_DOWN 50088
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEADSET 50089
#define IDS_AX_IMAGE_ANNOTATION_ICON_REDO 50090
#define IDS_AX_IMAGE_ANNOTATION_ICON_UNDO 50091
#define IDS_AX_IMAGE_ANNOTATION_ICON_DOWNLOAD 50092
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_DOWNWARD 50093
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_UPWARD 50094
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_FORWARD 50095
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_BACKWARD 50096
#define IDS_AX_IMAGE_ANNOTATION_ICON_HISTORY 50097
#define IDS_AX_IMAGE_ANNOTATION_ICON_PERSON 50098
#define IDS_AX_IMAGE_ANNOTATION_ICON_HAPPY_FACE 50099
#define IDS_AX_IMAGE_ANNOTATION_ICON_SAD_FACE 50100
#define IDS_AX_IMAGE_ANNOTATION_ICON_MOON 50101
#define IDS_AX_IMAGE_ANNOTATION_ICON_CLOUD 50102
#define IDS_AX_IMAGE_ANNOTATION_ICON_SUN 50103

// ---------------------------------------------------------------------------
// From blink_strings.h:

#define IDS_DETAILS_WITHOUT_SUMMARY_LABEL 46450
#define IDS_FORM_CALENDAR_CLEAR 46451
#define IDS_FORM_CALENDAR_TODAY 46452
#define IDS_FORM_SUBMIT_LABEL 46453
#define IDS_FORM_INPUT_ALT 46454
#define IDS_FORM_RESET_LABEL 46455
#define IDS_FORM_FILE_BUTTON_LABEL 46456
#define IDS_FORM_MULTIPLE_FILES_BUTTON_LABEL 46457
#define IDS_FORM_FILE_NO_FILE_LABEL 46458
#define IDS_FORM_FILE_MULTIPLE_UPLOAD 46459
#define IDS_FORM_OTHER_COLOR_LABEL 46460
#define IDS_FORM_OTHER_DATE_LABEL 46461
#define IDS_FORM_OTHER_MONTH_LABEL 46462
#define IDS_FORM_OTHER_WEEK_LABEL 46463
#define IDS_FORM_PLACEHOLDER_FOR_DAY_OF_MONTH_FIELD 46464
#define IDS_FORM_PLACEHOLDER_FOR_MONTH_FIELD 46465
#define IDS_FORM_PLACEHOLDER_FOR_YEAR_FIELD 46466
#define IDS_FORM_SELECT_MENU_LIST_TEXT 46467
#define IDS_FORM_THIS_MONTH_LABEL 46468
#define IDS_FORM_THIS_WEEK_LABEL 46469
#define IDS_FORM_WEEK_NUMBER_LABEL 46470
#define IDS_DEBUGGER_PAUSED_IN_ANOTHER_TAB 46471
#define IDS_VIEW_SOURCE_LINE_WRAP 46472
#define IDS_FORM_INPUT_WEEK_TEMPLATE 46473
#define IDS_FORM_VALIDATION_VALUE_MISSING_MULTIPLE_FILE 46474
#define IDS_FORM_VALIDATION_TYPE_MISMATCH 46475
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY 46476
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_DOMAIN 46477
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_LOCAL 46478
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOMAIN 46479
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOTS 46480
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_LOCAL 46481
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_NO_AT_SIGN 46482
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_MULTIPLE_EMAIL 46483
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL 46484
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL_DATETIME 46485
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW 46486
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW_DATETIME 46487
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW 46488
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW_DATETIME 46489
#define IDS_FORM_VALIDATION_REVERSED_RANGE_OUT_OF_RANGE_TIME 46490
#define IDS_FORM_VALIDATION_RANGE_REVERSED 46491
#define IDS_FORM_VALIDATION_RANGE_INVALID_DATETIME 46492
#define IDS_FORM_VALIDATION_BAD_INPUT_DATETIME 46493
#define IDS_FORM_VALIDATION_BAD_INPUT_NUMBER 46494
#define IDS_PRETTY_PRINT_JSON 46495
#define IDS_FORM_VALIDATION_VALUE_MISSING 46496
#define IDS_FORM_VALIDATION_VALUE_MISSING_CHECKBOX 46497
#define IDS_FORM_VALIDATION_VALUE_MISSING_FILE 46498
#define IDS_FORM_VALIDATION_VALUE_MISSING_RADIO 46499
#define IDS_FORM_VALIDATION_VALUE_MISSING_SELECT 46500
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL 46501
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_URL 46502
#define IDS_FORM_VALIDATION_PATTERN_MISMATCH 46503
#define IDS_FORM_VALIDATION_STEP_MISMATCH 46504
#define IDS_FORM_VALIDATION_STEP_MISMATCH_CLOSE_TO_LIMIT 46505
#define IDS_FORM_VALIDATION_TOO_LONG 46506
#define IDS_FORM_VALIDATION_TOO_SHORT 46507
#define IDS_FORM_VALIDATION_TOO_SHORT_PLURAL 46508
#define IDS_MEDIA_SESSION_DATA_SOURCE 46509
#define IDS_MEDIA_SESSION_FILE_SOURCE 46510
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS 46511
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS_SUBMENU_TITLE 46512
#define IDS_MEDIA_TRACK_IDENTIFIER_VERBOSE_TITLE_NUMBERED 46513
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_AUDIO_TRACK_MENU_BUTTON 46514
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_VIDEO_TRACK_MENU_BUTTON 46515
#define IDS_MEDIA_OVERFLOW_MENU_TRACK_SELECTION_SUBMENU_TITLE 46516
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED 46517
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_SUBMENU_TITLE 46518
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_25X_TITLE 46519
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_5X_TITLE 46520
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_75X_TITLE 46521
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_NORMAL_TITLE 46522
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_25X_TITLE 46523
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_5X_TITLE 46524
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_75X_TITLE 46525
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_2X_TITLE 46526
#define IDS_MEDIA_OVERFLOW_MENU_CAST 46527
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_FULLSCREEN 46528
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_FULLSCREEN 46529
#define IDS_MEDIA_OVERFLOW_MENU_MUTE 46530
#define IDS_MEDIA_OVERFLOW_MENU_UNMUTE 46531
#define IDS_MEDIA_OVERFLOW_MENU_PLAY 46532
#define IDS_MEDIA_OVERFLOW_MENU_PAUSE 46533
#define IDS_MEDIA_OVERFLOW_MENU_DOWNLOAD 46534
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_PICTURE_IN_PICTURE 46535
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_PICTURE_IN_PICTURE 46536
#define IDS_MEDIA_PICTURE_IN_PICTURE_INTERSTITIAL_TEXT 46537
#define IDS_MEDIA_REMOTING_CAST_TEXT 46538
#define IDS_MEDIA_REMOTING_CAST_TO_UNKNOWN_DEVICE_TEXT 46539
#define IDS_MEDIA_REMOTING_STOP_TEXT 46540
#define IDS_MEDIA_REMOTING_STOP_BY_PLAYBACK_QUALITY_TEXT 46541
#define IDS_MEDIA_REMOTING_STOP_BY_ERROR_TEXT 46542
#define IDS_MEDIA_SCRUBBING_MESSAGE_TEXT 46543
#define IDS_MEDIA_TRACKS_NO_LABEL 46544
#define IDS_MEDIA_TRACKS_OFF 46545
#define IDS_PLUGIN_INITIALIZATION_ERROR 46546
#define IDS_MEDIA_PLAYBACK_ERROR 46547
#define IDS_UNITS_KIBIBYTES 46548
#define IDS_UNITS_MEBIBYTES 46549
#define IDS_UNITS_GIBIBYTES 46550
#define IDS_UNITS_TEBIBYTES 46551
#define IDS_UNITS_PEBIBYTES 46552

// ---------------------------------------------------------------------------
// From branded_strings.h:

#define IDS_RELAUNCH_CONFIRMATION_DIALOG_TITLE 800
#define IDS_SETTINGS_ABOUT_PROGRAM 801
#define IDS_SETTINGS_GET_HELP_USING_CHROME 802
#define IDS_SETTINGS_UPGRADE_UPDATING 803
#define IDS_SETTINGS_UPGRADE_UPDATING_PERCENT 804
#define IDS_SETTINGS_UPGRADE_SUCCESSFUL_RELAUNCH 805
#define IDS_SETTINGS_UPGRADE_UP_TO_DATE 806
#define IDS_SETTINGS_SIGNED_OUT_USER_LABEL 809
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_USE_TO_FILL 810
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT 811
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT_THANK_YOU 812
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT 813
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_USER_VALUE 814
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_AND_PIN 815
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_AND_PIN_USER_VALUE 816
#define IDS_SETTINGS_DEFAULT_BROWSER_ERROR 817
#define IDS_SETTINGS_DEFAULT_BROWSER_SECONDARY 818
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_TWO 819
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_TWO 820
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_THINGS_TO_CONSIDER_BULLET_TWO 821
#define IDS_SETTINGS_PRELOAD_PAGES_THINGS_TO_CONSIDER_BULLET_ONE 822
#define IDS_SETTINGS_SPELLING_PREF_DESC 823
#define IDS_SETTINGS_RESTART_TO_APPLY_CHANGES 824
#define IDS_SETTINGS_SIGNIN_ALLOWED 825
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC 826
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC_2 827
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_BLOCKED 828
#define IDS_SETTINGS_SITE_SITE_DETAILS_CAMERA_BLOCKED_BY_OS 829
#define IDS_SETTINGS_SITE_SITE_DETAILS_MICROPHONE_BLOCKED_BY_OS 830
#define IDS_SETTINGS_SITE_SITE_DETAILS_LOCATION_BLOCKED_BY_OS 831
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_BY_OS 832
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_BY_OS 833
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_BY_OS 834
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_WITH_EXCEPTION_RADIO_SUBLABEL 835
#define IDS_SETTINGS_SITE_DATA_PAGE_DELETE_ON_EXIT_EXCEPTIONS_SUB_HEADING 836
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_BODY 837
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION2 838
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_PRIVACY_DESCRIPTION1 839
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_SUB_LABEL 840
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION3 841
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION2 842
#define IDS_SETTINGS_PRIVACY_SANDBOX_AD_MEASUREMENT_DIALOG_DESCRIPTION 843
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_SUBLABEL 844
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_AND_NOTIFICATIONS_SETTING_SUBLABEL 845
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_TWO 846
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_TWO 847
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_ONE 848
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_LEARN_MORE_LABEL 849
#define IDS_SETTINGS_SECURE_DNS_DESCRIPTION 850
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_SINGULAR 851
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_PLURAL 852
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITHOUT_COUNTS 853
#define IDS_SETTINGS_CUSTOMIZE_YOUR_CHROME_PROFILE 854
#define IDS_SETTING_NAME_YOUR_PROFILE 855
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT_SECONDARY_WITH_ACCOUNT 856
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT 857
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT_WITH_BOOKMARKS 858
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_TITLE 859
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_TITLE 861
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_DESC 862
#define IDS_SETTINGS_PEOPLE_SIGNIN_SECTION_SIGNED_OUT_TITLE 863
#define IDS_SETTINGS_SYNC_DATA_ENCRYPTED_TEXT 864
#define IDS_SETTINGS_SYNC_DISCONNECT_TITLE 865
#define IDS_SETTINGS_SUGGEST_PREF_DESC 866
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF_DESC 867
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC 868
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC_WITH_LINKED_SERVICES 869
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_DESC 870
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION 871
#define IDS_SETTINGS_ERROR_TRUSTED_VAULT_USER_ERROR_DESCRIPTION 872
#define IDS_SETTINGS_ERROR_UPGRADE_CLIENT_USER_ERROR_DESCRIPTION 873
#define IDS_SETTINGS_PENDING_STATE_DESCRIPTION 874
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION_WITH_EMAIL 875
#define IDS_SETTINGS_SIGN_OUT 876
#define IDS_SETTINGS_ACCOUNT_DATA_DASHBOARD 877
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_LABEL 878
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_EXPLANATION_TEXT 879
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ACCOUNT_DATA_ENCRYPTION 880
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING_DESCRIPTION 881
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING_DESCRIPTION 882
#define IDS_SETTINGS_PERFORMANCE_PRELOAD_TOGGLE_SUMMARY 883
#define IDS_SETTINGS_SYSTEM_BACKGROUND_APPS_LABEL 886
#define IDS_SETTINGS_RESET_PROFILE_FEEDBACK 887
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_NOTHING_TO_DO 888
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_HEADER 889
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_SUBHEADER 890
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_UPPERCASE_NAME 891
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_LOWERCASE_NAME 892
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS 893
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_MODULE_HEADER 894
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_HEADER 895
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_SUBHEADER 896
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_HEADER 897
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_SUBHEADER 898
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_RESTART 899
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_UPDATED 900
#define IDS_SETTINGS_SAFETY_HUB_VERSION_NAVIGATION_ARIA_LABEL 901
#define IDS_SETTINGS_SAFETY_HUB_VERSION_RELAUNCH_ARIA_LABEL 902
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_ONE_PERMISSION_LABEL 903
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_TWO_PERMISSIONS_LABEL 904
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_THREE_PERMISSIONS_LABEL 905
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_FOUR_OR_MORE_PERMISSIONS_LABEL 906
#define IDS_SETTINGS_SAFETY_HUB_ABUSIVE_NOTIFICATION_PERMISSIONS_SETTING_SUBLABEL 907
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_DESC 908
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_CONTENT 909
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES_DESCRIPTION 910
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_ONE 911
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_DESCRIPTION 912
#define IDS_SETTINGS_HTTPS_FIRST_MODE_SUBTITLE 913
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_SUBLABEL 914
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_SUBLABEL 915
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_SUBLABEL 916
#define IDS_SETTINGS_SKILLS_SETTING_LABEL 917
#define IDS_SETTINGS_SKILLS_TOGGLE_LABEL 918
#define IDS_SETTINGS_SYNC_SKILLS_SEPARATE_INFORMATION 919
#define IDS_SETTINGS_SKILLS_WHEN_ON_BULLET_TWO 920
#define IDS_PRODUCT_NAME 921
#define IDS_SHORT_PRODUCT_NAME 922
#define IDS_FIRST_RUN_DIALOG_WINDOW_TITLE 928
#define IDS_TERMS_DIALOG_ACCEPT 929
#define IDS_TERMS_DIALOG_CANCEL 930
#define IDS_TERMS_DIALOG_TITLE 931
#define IDS_TERMS_DIALOG_ACCESSIBILITY_LABEL 932
#define IDS_PRODUCT_LOGO_ENTERPRISE_ALT_TEXT 936
#define IDS_TASK_MANAGER_TITLE 937
#define IDS_TASK_MANAGER_SEARCH_PLACEHOLDER 938
#define IDS_TASK_MANAGER_SEARCH_ACCESSIBILITY_NAME 939
#define IDS_TASK_MANAGER_CLEAR_SEARCH_BUTTON_ACCESSIBILITY_NAME 940
#define IDS_TASK_MANAGER_KILL_ACCESSIBILITY_NAME 941
#define IDS_TASK_MANAGER_TASK_KILL_SUCCESS_ACCESSIBILITY_MESSAGE 942
#define IDS_TASK_MANAGER_TASK_KILL_FAIL_ACCESSIBILITY_MESSAGE 943
#define IDS_TASK_MANAGER_CATEGORY_TABS_AND_EXTENSIONS_NAME 944
#define IDS_TASK_MANAGER_CATEGORY_SYSTEM_NAME 945
#define IDS_TASK_MANAGER_CATEGORY_BROWSER_NAME 946
#define IDS_TASK_MANAGER_CATEGORY_ALL_NAME 947
#define IDS_SESSION_CRASHED_VIEW_UMA_OPTIN 948
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TOO_MANY_BOOKMARKS_BODY 949
#define IDS_RESET_PROFILE_SETTINGS_EXPLANATION_IN_BULLET_POINTS 950
#define IDS_BROWSER_WINDOW_TITLE_FORMAT 951
#define IDS_CAPTIVE_PORTAL_BROWSER_WINDOW_TITLE_FORMAT 952
#define IDS_ACCESSIBLE_BROWSER_WINDOW_TITLE_FORMAT 953
#define IDS_ACCESSIBLE_BETA_BROWSER_WINDOW_TITLE_FORMAT 954
#define IDS_ACCESSIBLE_DEV_BROWSER_WINDOW_TITLE_FORMAT 955
#define IDS_ACCESSIBLE_CANARY_BROWSER_WINDOW_TITLE_FORMAT 956
#define IDS_ABOUT_VERSION_COMPANY_NAME 957
#define IDS_ABOUT_VERSION_COPYRIGHT 958
#define IDS_ABOUT_TERMS_OF_SERVICE 962
#define IDS_LINUX_OBSOLETE 968
#define IDS_ACCNAME_APP 969
#define IDS_COULDNT_STARTUP_PROFILE_ERROR 971
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES 972
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES_ORIGIN 973
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_NOT_FOUND 974
#define IDS_FR_CUSTOMIZE_DEFAULT_BROWSER 978
#define IDS_DEFAULT_BROWSER_CHANGED_MESSAGE 979
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND 985
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND_SETTING 986
#define IDS_CANT_WRITE_USER_DIRECTORY_SUMMARY 987
#define IDS_PROFILE_TOO_NEW_ERROR 989
#define IDS_PREFERENCES_UNREADABLE_ERROR 990
#define IDS_PREFERENCES_CORRUPT_ERROR 991
#define IDS_DESKTOP_SHORTCUT_COMMENT 992
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_C 993
#define IDS_PASSWORD_MANAGER_TITLE_BRAND 994
#define IDS_PASSWORD_MANAGER_BRAND_NAME 995
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 996
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 997
#define IDS_PASSWORD_MANAGER_IMPORT_DIALOG_TITLE 1018
#define IDS_PASSWORD_MANAGER_EXPORT_DIALOG_TITLE 1019
#define IDS_DEFAULT_BROWSER_INFOBAR_TEXT 1027
#define IDS_DEFAULT_BROWSER_PIN_INFOBAR_TEXT 1028
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITH_SETTINGS_ILLUSTRATION 1029
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION 1030
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION_UNPINNED 1031
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITHOUT_SETTINGS_ILLUSTRATION 1032
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION 1033
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION_UNPINNED 1034
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_TITLE 1035
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_BODY 1036
#define IDS_DEFAULT_BROWSER_SUCCESS_TOAST_BODY 1037
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_PINNED_COMBINED 1038
#define IDS_PDF_GLIC_SUMMARIZE_IPH_TEXT 1040
#define IDS_PDF_GLIC_SUMMARIZE_IPH_TEXT_NEW 1041
#define IDS_PDF_GLIC_SUMMARIZE_IPH_TEXT_NEW_SCREENREADER 1042
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_UNKNOWN_SOURCE 1043
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_BLOCKED_LEARN_MORE_LINK 1044
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_LOCAL_DECRYPTION 1045
#define IDS_DOWNLOAD_STATUS_CRX_INSTALL_RUNNING 1046
#define IDS_PROMPT_DOWNLOAD_CHANGES_SETTINGS 1047
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_URL 1048
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_CONTENT 1049
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING 1050
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_FILETYPE 1051
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS 1052
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_COOKIE_THEFT 1053
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON 1054
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON_SUSPICIOUS_ARCHIVE 1055
#define IDS_BLOCK_DOWNLOAD_REASON_POTENTIALLY_UNWANTED 1056
#define IDS_BLOCK_DOWNLOAD_REASON_INSECURE 1057
#define IDS_BLOCK_DOWNLOAD_REASON_UNVERIFIED_NO_SAFE_BROWSING 1058
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK 1059
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK_ACCESSIBLE 1060
#define IDS_ABANDON_DOWNLOAD_DIALOG_BROWSER_MESSAGE 1061
#define IDS_MISSING_GOOGLE_API_KEYS 1063
#define IDS_EXTENSION_INSTALLED_HEADING 1064
#define IDS_EXTENSION_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX 1066
#define IDS_EXTENSION_ALERT_ITEM_BLOCKLISTED_MALWARE 1067
#define IDS_EXTENSIONS_ALERT_ITEM_BLOCKLISTED_MALWARE_TITLE 1068
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_SUBTITLE 1069
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_SUBTITLE 1070
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_REMOVE_BUTTON_ACC_LABEL 1071
#define IDS_EXTENSIONS_MENU_ZERO_STATE_DESC 1072
#define IDS_OPEN_WEB_STORE_BUTTON_TEXT 1073
#define IDS_SAFETY_CHECK_EXTENSIONS_MALWARE 1074
#define IDS_SAFETY_CHECK_EXTENSIONS_POLICY_VIOLATION 1075
#define IDS_SAFETY_CHECK_EXTENSIONS_UNPUBLISHED 1076
#define IDS_EXTENSIONS_SAFETY_CHECK_PRIMARY_LABEL 1077
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE 1078
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_ON 1079
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_OFF 1080
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES 1081
#define IDS_EXTENSIONS_SC_DESCRIPTION 1082
#define IDS_EXTENSIONS_ITEM_SHOW_ACCESS_REQUESTS_IN_TOOLBAR 1083
#define IDS_EXTENSIONS_INCOGNITO_WARNING 1084
#define IDS_EXTENSIONS_UNINSTALL 1085
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_IN_CHROME 1086
#define IDS_PENDING_CHANGE_WARNING 1087
#define IDS_EXTENSIONS_MULTIPLE_UNSUPPORTED_DISABLED_BODY 1088
#define IDS_EXTENSIONS_SINGLE_UNSUPPORTED_DISABLED_BODY 1089
#define IDS_ANCHORED_MESSAGE_MENU_TOOLTIP 1090
#define IDS_APPMENU_TOOLTIP 1091
#define IDS_APPMENU_TOOLTIP_UPDATE_AVAILABLE 1092
#define IDS_APPMENU_TOOLTIP_ALERT 1093
#define IDS_OPEN_IN_CHROME 1094
#define IDS_ABOUT 1095
#define IDS_RELAUNCH_TO_UPDATE 1096
#define IDS_CUSTOMIZE_CHROME 1100
#define IDS_OTHER_CHROME_PROFILES_TITLE 1101
#define IDS_MANAGE_CHROME_PROFILES 1102
#define IDS_VIEW_PASSWORDS 1103
#define IDS_CHROME_SIGNIN_TITLE 1104
#define IDS_PROFILES_DICE_SYNC_PROMO 1105
#define IDS_SYNC_WRONG_EMAIL 1106
#define IDS_SYNC_USED_PROFILE_ERROR 1107
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_SESSION 1108
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_RESTART 1109
#define IDS_SESSION_RESTORE_TURN_ON 1110
#define IDS_SESSION_RESTORE_LINK 1111
#define IDS_SESSION_RESTORE_LINK_ARIA_LABEL 1112
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_TITLE 1113
#define IDS_AI_SIGNIN_PROMO_SUBTITLE 1114
#define IDS_AI_SIGNIN_PROMO_AVATAR_PILL_TEXT 1115
#define IDS_ENTERPRISE_SIGNIN_TITLE 1116
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITHOUT_PROFILE_CREATION 1117
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITH_PROFILE_CREATION 1118
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_KNOWN_DOMAIN_TITLE 1119
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_SUGGESTED_TITLE 1120
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED 1121
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY 1122
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY_MULTIPLE_ORGANIZATIONS 1123
#define IDS_MANAGED_PROFILE_INTERSTITIAL_PRIMARY_PARAGRAPH 1124
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE 1125
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_1 1126
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE_FALLBACK 1127
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_UNKNOWN_BROWSER 1128
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_KNOWN_BROWSER 1129
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_YOUR_CHROME 1130
#define IDS_NTP_CUSTOMIZE_BUTTON_LABEL 1131
#define IDS_NTP_MODULES_SETUP_LIST_TITLE 1132
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_LABEL 1133
#define IDS_NTP_CUSTOMIZATION_PROMO 1134
#define IDS_NTP_MOBILE_PROMO_TITLE 1135
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_TITLE 1136
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_BODY 1137
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_SCREENREADER 1138
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT 1139
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT_SCREENREADER 1140
#define IDS_SIGNIN_EMAIL_CONFIRMATION_TITLE 1141
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_TEXT 1142
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE 1143
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_DECLINE_TEXT 1144
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_TITLE_V2 1145
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_TITLE 1146
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2 1147
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2_SUPERVISED 1148
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CONSUMER_BUBBLE_DESC 1149
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC 1150
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE 1151
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_WITH_BOOKMARKS 1152
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_SUPERVISED 1153
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER 1154
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER_SCREENREADER 1155
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_TITLE 1156
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_BODY 1157
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_DATA_BODY 1158
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY 1159
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY_WITH_COUNT 1160
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY 1161
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY_WITH_COUNT 1162
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT 1163
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCESSIBILITY_LABEL 1164
#define IDS_AVATAR_BUTTON_SIGNIN_PENDING_ACCESSIBILITY_LABEL 1165
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_PASSWORD 1166
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_ADDRESS 1167
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER 1168
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK_ACC 1169
#define IDS_SYNC_PASSPHRASE_DIALOG_BODY 1170
#define IDS_PROFILE_CUSTOMIZATION_TEXT 1171
#define IDS_PROFILE_CUSTOMIZATION_TITLE_V2 1172
#define IDS_PROFILE_MENU_SIGNIN_PROMO_BUTTON 1182
#define IDS_PROFILE_MENU_PLACEHOLDER_PROFILE_NAME 1183
#define IDS_PROFILE_MENU_SIGN_OUT_WHEN_SIGNIN_PENDING 1184
#define IDS_PROFILE_MENU_PROFILES_LIST_TITLE 1185
#define IDS_PROFILE_MENU_MANAGE_PROFILES 1186
#define IDS_PROFILE_MENU_SIGN_OUT 1187
#define IDS_PROFILE_MENU_ADD_PROFILE 1188
#define IDS_QR_CODE_BUBBLE_SIGNIN_ON_PHONE_TITLE 1189
#define IDS_APP_ALSO_DELETE_APPS_DATA 1191
#define IDS_APP_SHORTCUTS_SUBDIR_NAME 1192
#define IDS_APP_SHORTCUTS_SUBDIR_NAME_CANARY 1193
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_AND_VIDEO 1196
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_ONLY 1197
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_VIDEO_ONLY 1198
#define IDS_WEBHID_SYSTEM_TRAY_ICON_TITLE 1199
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_TITLE 1200
#define IDS_PROFILE_IN_USE_POSIX 1201
#define IDS_LOGIN_POD_USER_REMOVE_WARNING_SYNC 1203
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TITLE 1204
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TEXT 1205
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TITLE 1206
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TEXT 1207
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_GUEST_TEXT 1208
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_FRIENDS_TEXT 1209
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_TEXT 1210
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_ADD_USER 1211
#define IDS_TUTORIAL_PASSWORD_MANAGER_OPEN_APP_MENU 1212
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORD_MANAGER 1213
#define IDS_TUTORIAL_PASSWORD_MANAGER_SUCCESS_BODY 1214
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_BODY 1215
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_PAGES 1216
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_AND_SEARCH 1217
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS_EXPLANATION 1218
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS_EXPLANATION 1219
#define IDS_WEBSTORE_APP_DESCRIPTION 1220
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT 1229
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT_ONCE 1230
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TEXT 1231
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB_INAPP 1232
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD_INAPP 1233
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD_INAPP_V2 1234
#define IDS_AVATAR_BUTTON_MAKING_CHROME_YOURS 1235
#define IDS_AVATAR_BUTTON_SIGNIN_PROMO 1236
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE 1237
#define IDS_UPDATE_RECOMMENDED 1238
#define IDS_RELAUNCH_AND_UPDATE 1239
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE_ALT 1240
#define IDS_UPDATE_RECOMMENDED_ALT 1241
#define IDS_REINSTALL_APP 1242
#define IDS_UPGRADE_BUBBLE_MENU_ITEM 1243
#define IDS_UPGRADE_BUBBLE_TITLE 1244
#define IDS_UPGRADE_BUBBLE_TEXT 1245
#define IDS_SYNC_ERROR_USER_MENU_UPGRADE_BUTTON 1246
#define IDS_SYNC_ERROR_PASSPHRASE_USER_MENU_ERROR_DESCRIPTION 1247
#define IDS_SYNC_ERROR_TRUSTED_VAULT_USER_MENU_ERROR_DESCRIPTION 1248
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_TITLE 1249
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_ERROR_DESCRIPTION 1250
#define IDS_SYNC_UPGRADE_CLIENT 1251
#define IDS_SYNC_UPGRADE_CLIENT_BUTTON 1252
#define IDS_RECOVERY_BUBBLE_TITLE 1253
#define IDS_RUN_RECOVERY 1254
#define IDS_RECOVERY_BUBBLE_TEXT 1255
#define IDS_CRITICAL_NOTIFICATION_TITLE 1256
#define IDS_CRITICAL_NOTIFICATION_TITLE_ALTERNATE 1257
#define IDS_CRITICAL_NOTIFICATION_TEXT 1258
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_TAB 1259
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_MAC 1260
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_PERIOD_MAC 1261
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_MAC 1262
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_PERIOD_MAC 1263
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_RESTART_TEXT_MAC 1264
#define IDS_DESKTOP_MEDIA_PICKER_SYSTEM_AUDIO_PERMISSION_TEXT_MAC 1265
#define IDS_SIDE_PANEL_CUSTOMIZE_CHROME_TITLE 1283
#define IDS_HISTORY_HISTORY_MENU_ITEM 1284
#define IDS_LENS_SEND_FEEDBACK 1285
#define IDS_LENS_SEND_FEEDBACK_PLACEHOLDER 1286
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH 1287
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH_SCREENREADER 1288
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH 1289
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH_SCREENREADER 1290
#define IDS_SIDE_PANEL_CONTEXTUAL_TASKS_PINNABLE_IPH 1291
#define IDS_TUTORIAL_CONTEXTUAL_TASKS_STEP1 1292
#define IDS_TUTORIAL_CONTEXTUAL_TASKS_STEP2 1293
#define IDS_TUTORIAL_CONTEXTUAL_TASKS_STEP3 1294
#define IDS_LENS_OVERLAY_COPY 1295
#define IDS_LENS_OVERLAY_COPY_TEXT 1296
#define IDS_LENS_OVERLAY_COPY_TOAST_MESSAGE 1297
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE_TOAST_MESSAGE 1298
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE 1299
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE_ALT 1300
#define IDS_LENS_OVERLAY_SEND_FEEDBACK_BUTTON_LABEL 1301
#define IDS_LENS_OVERLAY_CLOSE_FEEDBACK_TOAST_ACCESSIBILITY_LABEL 1302
#define IDS_LENS_OVERLAY_MORE_OPTIONS_BUTTON_LABEL 1303
#define IDS_LENS_OVERLAY_MY_ACTIVITY 1304
#define IDS_LENS_OVERLAY_TOAST_PAGE_CONTENT_NOT_FOUND_MESSAGE 1305
#define IDS_LENS_OVERLAY_TOAST_DISMISS_MESSAGE 1306
#define IDS_LENS_OVERLAY_TRANSLATE 1307
#define IDS_LENS_OVERLAY_SELECT_TEXT 1308
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE 1309
#define IDS_LENS_OVERLAY_SAVE_AS_IMAGE 1310
#define IDS_LENS_OVERLAY_LEARN_MORE 1311
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL 1312
#define IDS_LENS_OVERLAY_COBROWSE_INITIAL_TOAST_LABEL 1313
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE 1314
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL_SIMPLIFIED 1315
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SIMPLIFIED 1316
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SELECT_TEXT 1317
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_MESSAGE 1318
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_EXIT_BUTTON_TEXT 1319
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_DRAG_MESSAGE 1320
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_TEXT_HIGHLIGHT_MESSAGE 1321
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_CLICK_MESSAGE 1322
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_LIVE_PAGE_MESSAGE 1323
#define IDS_LENS_OVERLAY_AUTO_DETECT_LANGUAGE_LABEL 1324
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_LABEL 1325
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_PICKER_MENU_TITLE 1326
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_PICKER_MENU_TITLE 1327
#define IDS_LENS_OVERLAY_RECENT_LANGUAGES_LABEL 1328
#define IDS_LENS_OVERLAY_ALL_LANGUAGES_LABEL 1329
#define IDS_LENS_OVERLAY_DETECTED_LABEL 1330
#define IDS_LENS_OVERLAY_DETECT_LANGUAGE_LABEL 1331
#define IDS_LENS_OVERLAY_RENDERER_LABEL 1332
#define IDS_LENS_OVERLAY_CLOSE_TRANSLATE_SCREEN_LABEL 1333
#define IDS_LENS_OVERLAY_LANGUAGE_PICKER_LABEL 1334
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_ACCESSIBILITY_LABEL 1335
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_ACCESSIBILITY_LABEL 1336
#define IDS_LENS_OVERLAY_SEARCH_LANGUAGE_PICKER_LABEL 1337
#define IDS_LENS_OVERLAY_TOP_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1338
#define IDS_LENS_OVERLAY_TOP_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1339
#define IDS_LENS_OVERLAY_BOTTOM_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1340
#define IDS_LENS_OVERLAY_BOTTOM_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1341
#define IDS_LENS_OVERLAY_SEARCH_SCREENSHOT_ACCESSIBILITY_LABEL 1342
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH 1343
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH_SCREENREADER 1344
#define IDS_CONTENT_CONTEXT_LENS_OVERLAY 1345
#define IDS_CONTENT_LENS_OVERLAY_ENTRYPOINT_LABEL 1346
#define IDS_CONTENT_LENS_OVERLAY_HOMEWORK_ENTRYPOINT_LABEL 1347
#define IDS_CONTENT_LENS_OVERLAY_ASK_GOOGLE_ENTRYPOINT_LABEL 1348
#define IDS_SIDE_PANEL_LENS_OVERLAY_TOOLBAR_TOOLTIP 1349
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT1 1350
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT2 1351
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT3 1352
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT1 1353
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT2 1354
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT3 1355
#define IDS_LENS_OVERLAY_TAB_ENTRYPOINT_LABEL 1356
#define IDS_LENS_OVERLAY_TAB_ENTRYPOINT_LABEL_V2 1357
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT1 1358
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT2 1359
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT3 1360
#define IDS_AI_MODE_ENTRYPOINT_LABEL 1361
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_FIRST_LINE 1362
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_SECOND_LINE 1363
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_FIRST_LINE 1364
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_SECOND_LINE 1365
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CANCEL_BUTTON 1366
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CONTINUE_BUTTON 1367
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CSB_DESCRIPTION 1368
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_NON_BLOCKING_DESCRIPTION 1369
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_DESCRIPTION 1370
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_LINK 1371
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_ABOUT_GOOGLE_LENS_LINK 1372
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TITLE 1373
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TAB_TO_CONTINUE 1374
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_GOT_IT 1375
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_REMIND_ME_LATER 1376
#define IDS_SHOW_LENS_OVERLAY 1378
#define IDS_CONTEXT_MENU_SHOW_GOOGLE_LENS_SHORTCUT 1377
#define IDS_LENS_CONTEXTUAL_SEARCH_DEFAULT_QUERY 1379
#define IDS_LENS_CONTEXTUAL_SEARCH_ZERO_STATE_QUERY 1380
#define IDS_LENS_COMPOSEBOX_HINT_TEXT 1381
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SEARCH_PAGE 1382
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SELECT_PAGE 1383
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_ASK_ANYTHING 1384
#define IDS_AI_MODE_ASK_ABOUT_THIS_TAB 1385
#define IDS_AI_MODE_NEW_SEARCH 1386
#define IDS_CONTEXT_MENU_SHOW_AI_MODE_OMNIBOX_BUTTON 1387
#define IDS_RELAUNCH_RECOMMENDED_TITLE 1391
#define IDS_RELAUNCH_RECOMMENDED_BODY 1392
#define IDS_RELAUNCH_REQUIRED_TITLE_DAYS 1393
#define IDS_RELAUNCH_REQUIRED_TITLE_HOURS 1394
#define IDS_RELAUNCH_REQUIRED_TITLE_MINUTES 1395
#define IDS_RELAUNCH_REQUIRED_TITLE_SECONDS 1396
#define IDS_RELAUNCH_REQUIRED_BODY 1397
#define IDS_ADVANCED_PROTECTION_RELAUNCH_REQUIRED_BODY 1398
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_TOOLTIP 1399
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_ERROR 1400
#define IDS_ENTERPRISE_STARTUP_RELAUNCH_BUTTON 1401
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WEB_CONTENTS_ONLY 1402
#define IDS_IDLE_BUBBLE_TITLE_CLOSE 1403
#define IDS_IDLE_BUBBLE_BODY_CLOSE_AND_CLEAR 1404
#define IDS_IDLE_BUBBLE_BODY_CLEAR 1405
#define IDS_IDLE_BUBBLE_BODY_CLOSE 1406
#define IDS_IDLE_TIMEOUT_CLOSE_TITLE 1407
#define IDS_IDLE_TIMEOUT_CLEAR_TITLE 1408
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_TITLE 1409
#define IDS_IDLE_TIMEOUT_CLOSE_BODY 1410
#define IDS_IDLE_TIMEOUT_CLEAR_BODY 1411
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_BODY 1412
#define IDS_IDLE_DISMISS_BUTTON 1413
#define IDS_HATS_BUBBLE_TITLE 1414
#define IDS_EXTENSION_PERMISSIONS_BLOCKED_BY_PARENT_PROMPT_MESSAGE 1416
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_APP 1417
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_EXTENSION 1418
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_THEME 1419
#define IDS_EXTENSION_EXTERNAL_INITIAL_INSTALL_PROMPT_TITLE_EXTENSION 1420
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ABORT_BUTTON 1421
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_DETAILS 1422
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE 1423
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_V2 1424
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE 1425
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_TITLE 1426
#define IDS_PROFILE_PICKER_IPH_FOR_PROFILES_TEXT 1427
#define IDS_PROFILE_PICKER_IPH_FOR_ADD_PROFILE_TEXT 1428
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_TITLE 1429
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SUBTITLE 1430
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_BODY 1431
#define IDS_FRE_SIGN_IN_TITLE_0 1432
#define IDS_FRE_GET_YOUR_BROWSER_READY_TITLE 1433
#define IDS_FRE_DEFAULT_BROWSER_TITLE 1434
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_TITLE 1435
#define IDS_FRE_DEFAULT_BROWSER_SUBTITLE_NEW 1436
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_SUBTITLE 1437
#define IDS_FRE_DEFAULT_BROWSER_ILLUSTRATION_ALT_TEXT 1438
#define IDS_APP_MENU_TOOLTIP_DEFAULT_PROMPT 1439
#define IDS_APP_MENU_BUTTON_DEFAULT_PROMPT 1440
#define IDS_SET_BROWSER_AS_DEFAULT_MENU_ITEM 1441
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_TITLE 1442
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SUBTITLE 1443
#define IDS_PROFILE_SWITCH_PROMO 1444
#define IDS_PROFILE_SWITCH_PROMO_SCREENREADER 1445
#define IDS_PASSWORD_MANAGER_IPH_BODY_WEB_APP_PROFILE_SWITCH 1446
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT 1447
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT_SCREENREADER 1448
#define IDS_FEATURE_SHOWCASE_PASSWORD_MANAGER_TITLE 1449
#define IDS_FEATURE_SHOWCASE_PASSWORD_MANAGER_SUBTITLE 1450
#define IDS_FEATURE_SHOWCASE_LENS_OVERLAY_TITLE 1451
#define IDS_FEATURE_SHOWCASE_LENS_OVERLAY_DISCLOSURE 1452
#define IDS_FEATURE_SHOWCASE_THEMES_TITLE 1453
#define IDS_QUIET_NOTIFICATION_IPH_TEXT 1454
#define IDS_QUIET_NOTIFICATION_IPH_TEXT_SCREENREADER 1455
#define IDS_CHROMELABS_RELAUNCH_FOOTER_MESSAGE 1456
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 1457
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_TITLE 1458
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_TITLE 1459
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION 1460
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION_UPDATED 1461
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_ACCEPT 1462
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_ENABLED 1467
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_DISABLED 1468
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_DESCRIPTION 1469
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_SUB_LABEL 1470
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_SUB_LABEL 1471
#define IDS_MEMORY_SAVER_DIALOG_BODY 1537
#define IDS_MEMORY_SAVER_MODE_PROMO_TITLE 1538
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_V1 1539
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_SINGULAR_V1 1540
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V3 1541
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SIGNED_IN 1542
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_SUBTITLE 1543
#define IDS_CLEAR_BROWSING_DATA_TOAST_BODY 1545
#define IDS_SKILL_SAVED_TOAST_BUTTON 1546
#define IDS_GLIC_PROMO_TITLE 1547
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP 1548
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP_CLOSE 1549
#define IDS_GLIC_THREE_DOT_MENU_ITEM 1550
#define IDS_GLIC_STATUS_ICON_TOOLTIP 1551
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CANARY 1552
#define IDS_GLIC_STATUS_ICON_TOOLTIP_DEV 1553
#define IDS_GLIC_STATUS_ICON_TOOLTIP_BETA 1554
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE 1555
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_CANARY 1556
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_DEV 1557
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_BETA 1558
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE 1559
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_CANARY 1560
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_DEV 1561
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_BETA 1562
#define IDS_GLIC_STATUS_ICON_MENU_SHOW 1563
#define IDS_GLIC_STATUS_ICON_MENU_CLOSE 1564
#define IDS_GLIC_STATUS_ICON_MENU_TOGGLE 1565
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE 1566
#define IDS_SETTINGS_GLIC_PAGE_TITLE 1567
#define IDS_SETTINGS_GLIC_SECTION_TITLE 1568
#define IDS_SETTINGS_GLIC_ROW_LABEL 1569
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE_SUBLABEL 1570
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE 1571
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE_SUBLABEL 1572
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_SUBLABEL 1573
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_SUBLABEL 1574
#define IDS_SETTINGS_GLIC_KEEP_SIDEPANEL_OPEN_ON_NEW_TABS_SUBLABEL 1575
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_SUBLABEL 1576
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC 1577
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC_NO_PROFILE 1578
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC 1579
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC_NO_PROFILE 1580
#define IDS_PROFILE_PICKER_ADD_PROFILE_HELPER_GLIC 1581
#define IDS_GLIC_CONTEXTUAL_CUEING_ANNOUNCEMENT 1582
#define IDS_EXTENSION_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1583
#define IDS_BOOKMARK_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1584
#define IDS_BOOKMARK_INSTALLED_BUBBLE_PROMO_EXPLICIT_SIGNIN_MESSAGE 1585
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_MESSAGE 1586
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_BUTTON 1587
#define IDS_PROFILE_MENU_ACCOUNT_SETTINGS_BUTTON 1588
#define IDS_DICTATION_CONTEXT_MENU_STRING 1589
#define IDS_DICTATION_ONBOARDING_TITLE 1590
#define IDS_DICTATION_ONBOARDING_BULLET_MICROPHONE 1591
#define IDS_DICTATION_ONBOARDING_BULLET_DISCLAIMER 1592
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_REMINDER 1593
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_QR 1594
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_REMINDER 1595
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE 1596
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_QR 1597
#define IDS_IOS_DESKTOP_PROMO_QR_CODE_ALT_TEXT 1598
#define IDS_IOS_DESKTOP_PROMO_REMINDER_CONFIRMATION 1599
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_REMINDER_CONFIRMATION 1600
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_REMINDER 1601
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_QR 1602
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 1603
#define IDS_IOS_DESKTOP_PRICE_TRACKING_DESCRIPTION_QR 1604
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_QR 1605
#define IDS_IOS_DESKTOP_PRICE_TRACKING_REMINDER_CONFIRMATION 1606
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_QR 1607
#define IDS_IOS_DESKTOP_TAB_GROUPS_REMINDER_CONFIRMATION 1608
#define IDS_IOS_DESKTOP_AI_PROMO_BUBBLE_DESCRIPTION_QR 1609
#define IDS_IOS_DESKTOP_AI_PROMO_BUBBLE_TITLE_QR 1610
#define IDS_IOS_DESKTOP_AI_PROMO_BUBBLE_DESCRIPTION_REMINDER 1611
#define IDS_IOS_DESKTOP_AI_PROMO_BUBBLE_TITLE_REMINDER 1612
#define IDS_IOS_DESKTOP_AI_PROMO_NOTIFICATION_BODY 1613
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_BUBBLE_DESCRIPTION_QR 1614
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_BUBBLE_TITLE_QR 1615
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_BUBBLE_DESCRIPTION_REMINDER 1616
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_BUBBLE_TITLE_REMINDER 1617
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_NOTIFICATION_BODY 1618
#define IDS_IOS_DESKTOP_BEST_OF_GOOGLE_PROMO_NOTIFICATION_TITLE 1619
#define IDS_IOS_DESKTOP_SAFETY_PROMO_BUBBLE_DESCRIPTION_QR 1620
#define IDS_IOS_DESKTOP_SAFETY_PROMO_BUBBLE_TITLE_QR 1621
#define IDS_IOS_DESKTOP_SAFETY_PROMO_BUBBLE_DESCRIPTION_REMINDER 1622
#define IDS_IOS_DESKTOP_SAFETY_PROMO_BUBBLE_TITLE_REMINDER 1623
#define IDS_IOS_DESKTOP_SAFETY_PROMO_NOTIFICATION_BODY 1624
#define IDS_IOS_DESKTOP_SAFETY_PROMO_NOTIFICATION_TITLE 1625
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_BUBBLE_DESCRIPTION_QR 1626
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_BUBBLE_TITLE_QR 1627
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_BUBBLE_DESCRIPTION_REMINDER 1628
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_BUBBLE_TITLE_REMINDER 1629
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_NOTIFICATION_BODY 1630
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_BUBBLE_DESCRIPTION_QR 1631
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_BUBBLE_TITLE_QR 1632
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_BUBBLE_DESCRIPTION_REMINDER 1633
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_BUBBLE_TITLE_REMINDER 1634
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_NOTIFICATION_BODY 1635
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_TITLE 1636
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_BODY 1637
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_GOT_IT_BUTTON 1638
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_LEARN_MORE_BUTTON 1639
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_SEARCH_SETTINGS_BUTTON 1640
#define IDS_REPORT_UNSAFE_SITE_DIALOG_TITLE 1641
#define IDS_REPORT_UNSAFE_SITE_DIALOG_DESCRIPTION 1642
#define IDS_REPORT_UNSAFE_SITE_DIALOG_FOOTER 1643
#define IDS_JS_OPTIMIZATION_BUBBLE_BODY_NON_POLICY_BODY 1644
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_TITLE 1645
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_BUTTON_LABEL 1646
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_TITLE 1647
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_SUBTITLE 1648

// ---------------------------------------------------------------------------
// From cef_strings.h:

#define IDS_TEXT_FILES 59100
#define IDS_CONTENT_CONTEXT_NO_SPELLING_SUGGESTIONS 59101

// ---------------------------------------------------------------------------
// From components_branded_strings.h:

#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_BODY 34390
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_HEADER 34391
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_CLIENT 34392
#define IDS_ERRORPAGES_SUGGESTION_PROXY_DISABLE_PLATFORM 34393
#define IDS_FLAGS_UI_RELAUNCH_NOTICE 34396
#define IDS_CRASH_DISABLED_MESSAGE 34397
#define IDS_SHORT_PRODUCT_LOGO_ALT_TEXT 34398
#define IDS_VERSION_UI_LICENSE 34399
#define IDS_PAGE_INFO_INTERNAL_PAGE 34402
#define IDS_SESSION_CRASHED_VIEW_MESSAGE 34403
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 34404
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_BODY 34405
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_TITLE 34406
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_TITLE 34407
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_TITLE 34408

// ---------------------------------------------------------------------------
// From components_strings.h:

#define IDS_ASH_ARC_APP_COMPAT_DISABLED_COMPAT_MODE_BUTTON_TOOLTIP_PHONE 34420
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_TITLE 34421
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_BODY 34422
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_ACCEPT 34423
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_DONT_ASK_ME 34424
#define IDS_ASH_ARC_NEARBY_SHARE_FILE_PREPARATION_PROGRESS 34425
#define IDS_ASH_ARC_NEARBY_SHARE_FILES_PREPARATION_PROGRESS 34426
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE 34427
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE_PH 34428
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_TITLE 34429
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE 34430
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE_PH 34431
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_STORAGE_BUTTON 34432
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_RESIZE_SETTINGS 34433
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_TITLE 34434
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_TITLE 34435
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY 34436
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY_UNRESIZABLE 34437
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_CLOSE 34438
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_LINK 34439
#define IDS_ARC_COMPAT_MODE_DISABLE_RESIZE_LOCK_TOAST 34440
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_ICON 34441
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_THROBBER 34442
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_MESSAGE 34443
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_AOD_MESSAGE 34444
#define IDS_ARC_GHOST_WINDOW_APP_FIXUP_MESSAGE 34445
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_TITLE 34446
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY 34447
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY_WITH_LEARN_MORE 34448
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_SUBSCRIPTION_BODY_WITH_LEARN_MORE 34449
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_LEARN_MORE_LABEL 34450
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_ALLOW_BUTTON 34451
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_DONT_ALLOW_BUTTON 34452
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_TITLE 34453
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_DAYS_UNTIL_DEADLINE 34454
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_ACCEPT_BUTTON_LABEL 34455
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_TITLE 34456
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SAVE_WORK_MESSAGE 34457
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_DAYS_UNTIL_DEADLINE 34458
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_NOW_BUTTON_LABEL 34459
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SKIP_BUTTON_LABEL 34460
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_BUTTON_LABEL 34461
#define IDS_ARC_VM_DATA_MIGRATION_LOADING_SCREEN_MESSAGE 34462
#define IDS_ARC_VM_DATA_MIGRATION_WELCOME_SCREEN_TITLE 34463
#define IDS_ARC_VM_DATA_MIGRATION_WHAT_TO_EXPECT_TITLE 34464
#define IDS_ARC_VM_DATA_MIGRATION_UPDATE_DESCRIPTION 34465
#define IDS_ARC_VM_DATA_MIGRATION_BLOCKING_BEHAVIOR_DESCRIPTION 34466
#define IDS_ARC_VM_DATA_MIGRATION_CONNECT_TO_CHARGER_MESSAGE 34467
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_FREE_DISK_SPACE_MESSAGE 34468
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_BATTERY_MESSAGE 34469
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_UPDATE_BUTTON_LABEL 34470
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_SKIP_BUTTON_LABEL 34471
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_SCREEN_TITLE 34472
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_DESCRIPTION 34473
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_RESUME_BUTTON_LABEL 34474
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_SCREEN_TITLE 34475
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_DESCRIPTION 34476
#define IDS_ARC_VM_DATA_MIGRATION_SUCCESS_SCREEN_TITLE 34477
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_FINISH_BUTTON_LABEL 34478
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_SCREEN_TITLE 34479
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_DESCRIPTION 34480
#define IDS_ARC_VM_DATA_MIGRATION_SEND_FEEDBACK_MESSAGE 34481
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_REPORT_BUTTON_LABEL 34482
#define IDS_ARC_VM_PRELOAD_NOTIFICATION_TITLE 34483
#define IDS_ARC_VM_PRELOAD_STARTED_MESSAGE 34484
#define IDS_ARC_VM_PRELOAD_SUCCEEDED_MESSAGE 34485
#define IDS_ARC_VM_PRELOAD_FAILED_MESSAGE 34486
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_LOCAL_SAVE 34487
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_UPLOAD_SAVE 34488
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_NO_THANKS 34489
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_NO_THANKS 34490
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_ACCEPT 34491
#define IDS_AUTOFILL_GOOGLE_PAY_LOGO_ACCESSIBLE_NAME 34494
#define IDS_AUTOFILL_GOOGLE_WALLET_LOGO_ACCESSIBLE_NAME 34495
#define IDS_AUTOFILL_CHROME_LOGO_ACCESSIBLE_NAME 34496
#define IDS_AUTOFILL_FIELD_LABEL_PHONE 34497
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_LOCAL_SAVE_ACCEPT 34499
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_UPLOAD_SAVE_ACCEPT 34500
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CONTINUE 34502
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_LOCAL 34503
#define IDS_AUTOFILL_SAVE_CARD_ONLY_PROMPT_EXPLANATION_LOCAL 34505
#define IDS_AUTOFILL_SAVE_CARD_WITH_CVC_PROMPT_EXPLANATION_LOCAL 34506
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_LOCAL 34507
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_LOCAL 34508
#define IDS_AUTOFILL_FIX_FLOW_PROMPT_SAVE_CARD_LABEL 34509
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD 34510
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_SECURITY 34512
#define IDS_AUTOFILL_SAVE_CARD_IN_GOOGLE_WALLET_PROMPT_TITLE 34513
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_TO_CLOUD 34514
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION 34515
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION_WITH_NICKNAME 34516
#define IDS_AUTOFILL_CARD_SAVED 34520
#define IDS_AUTOFILL_CVC_SAVED 34521
#define IDS_AUTOFILL_DONE 34522
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION 34524
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_UPLOAD 34525
#define IDS_AUTOFILL_SAVE_CVC_TO_WALLET_PROMPT_EXPLANATION_UPLOAD 34526
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_SECURITY 34527
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION_SECURITY 34528
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_V2_EXPLANATION 34529
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME 34534
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME_TOOLTIP 34535
#define IDS_AUTOFILL_SAVE_CARD_CARDHOLDER_NAME_FIX_FLOW_HEADER 34536
#define IDS_AUTOFILL_SAVE_CARD_UPDATE_EXPIRATION_DATE_TITLE 34537
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_TOOLTIP 34540
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_AND_CARDHOLDER_NAME_TOOLTIP 34541
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 34542
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 34543
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_TITLE 34544
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_LOCAL 34545
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_UPLOAD 34546
#define IDS_AUTOFILL_SAVE_AND_FILL_TO_WALLET_DIALOG_EXPLANATION_UPLOAD 34547
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CARD_NUMBER_LABEL 34548
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_LABEL 34549
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_PLACEHOLDER 34550
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_LABEL 34551
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_PLACEHOLDER 34552
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_NAME_ON_CARD_LABEL 34553
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_ACCEPT 34554
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CARD_NUMBER 34555
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CVC 34556
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_EXPIRATION_DATE 34557
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_NAME_ON_CARD 34558
#define IDS_AUTOFILL_PENDING_DIALOG_LOADING_ACCESSIBILITY_DESCRIPTION 34559
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASKING_ERROR_TITLE 34560
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_TITLE 34561
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_TITLE 34562
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_DESCRIPTION 34563
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_DESCRIPTION 34564
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_TITLE 34565
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_DESCRIPTION 34566
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_TITLE 34567
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_TITLE 34568
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_DESCRIPTION 34569
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_DESCRIPTION 34570
#define IDS_AUTOFILL_ERROR_DIALOG_NEGATIVE_BUTTON_LABEL 34571
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_CVC 34572
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_SECURITY_CODE 34573
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_PERMANENT 34574
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_NETWORK 34575
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_BACK_OF_CARD 34576
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_FRONT_OF_CARD 34577
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION 34578
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION_FOR_AMEX 34579
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_DEFAULT 34580
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_EXPIRED_CARD 34581
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_VIRTUAL_CARD 34582
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_TITLE 34583
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE 34587
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE_SECURITY_CODE 34588
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_EXPIRED_TITLE 34589
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRM_BUTTON 34603
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_MONTH 34604
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_YEAR 34605
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_IN_PROGRESS 34606
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_SUCCESS 34607
#define IDS_AUTOFILL_CARD_UNMASK_INVALID_EXPIRATION_DATE 34608
#define IDS_AUTOFILL_EXPIRATION_DATE_SEPARATOR 34609
#define IDS_AUTOFILL_CARD_UNMASK_NEW_CARD_LINK 34610
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_CVC 34611
#define IDS_AUTOFILL_DIALOG_ACCESSIBLE_NAME_SECURITY_CODE 34612
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_BAR_MESSAGE 34613
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASK_PROGRESS_BAR_MESSAGE 34614
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_DIALOG_TITLE 34615
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_DIALOG_TITLE 34616
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_BAR_MESSAGE 34617
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_DIALOG_TITLE 34618
#define IDS_AUTOFILL_CARD_UNMASK_CANCEL_BUTTON_LABEL 34619
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_MESSAGE 34620
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_LOADING_MESSAGE 34622
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 34623
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_TITLE 34624
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_MESSAGE 34625
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE 34635
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE_ERROR 34636
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION 34637
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_OK_BUTTON_LABEL 34638
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION_ERROR 34639
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL 34640
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL_ERROR 34641
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_TITLE 34642
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_CANCEL_BUTTON_LABEL 34643
#define IDS_AUTOFILL_WALLET_MANAGEMENT_LINK_TEXT 34644
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT_LONG 34645
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_LOCAL 34646
#define IDS_AUTOFILL_SAVE_IBAN_LABEL 34647
#define IDS_AUTOFILL_IBANS_TITLE 34648
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_ACCEPT 34649
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_NICKNAME 34650
#define IDS_AUTOFILL_SAVE_IBAN_PLACEHOLDER 34651
#define IDS_IBAN_NICKNAME_COUNT_BY 34652
#define IDS_AUTOFILL_IBAN_SAVED 34653
#define IDS_AUTOFILL_MANAGE_SAVED_PAYMENT_METHODS 34654
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_SERVER 34655
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_PROMPT_TITLE 34656
#define IDS_AUTOFILL_UPLOAD_IBAN_PROMPT_EXPLANATION 34657
#define IDS_AUTOFILL_UPLOAD_IBAN_TO_WALLET_PROMPT_EXPLANATION 34658
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_TITLE 34664
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_EXPLANATION 34665
#define IDS_AUTOFILL_MANDATORY_REAUTH_ICON_TOOLTIP 34666
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_TITLE 34667
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_EXPLANATION 34668
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_SETTINGS_LINK 34669
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 34673
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 34674
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL 34675
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL 34676
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_ENROLLED_CARD_UNMASK_PROGRESS_DIALOG_TITLE 34677
#define IDS_AUTOFILL_VIRTUAL_CARD_ENTRY_PREFIX 34678
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_FALLBACK_ICON_TOOLTIP 34679
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE_VIRTUAL_CARD 34680
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL_VIRTUAL_CARD 34681
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL_VIRTUAL_CARD 34682
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD 34683
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD 34684
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARDHOLDER_NAME_LABEL_VIRTUAL_CARD 34685
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD 34686
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_VIRTUAL_CARD_LABEL 34687
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_ICON_TOOLTIP_VIRTUAL_CARD 34688
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_NORMAL_VIRTUAL_CARD 34689
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_CLICKED_VIRTUAL_CARD 34690
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL 34691
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_ACCEPT_BUTTON_LABEL 34692
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_TITLE_LABEL 34693
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_TITLE_LABEL_V2 34694
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_CONTENT_LABEL 34695
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_CONTENT_LABEL_V2 34696
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_SKIP 34697
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_NO_THANKS 34698
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_LEARN_MORE_LINK_LABEL 34699
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_CARD_IMAGE_TOOLTIP 34700
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_OPTION_VALUE 34701
#define IDS_AUTOFILL_IBAN_SUGGESTION_OPTION_VALUE 34702
#define IDS_AUTOFILL_VIRTUAL_CARD_NUMBER_SWITCH_LABEL 34703
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_LOADING_THROBBER_ACCESSIBLE_NAME 34704
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL 34716
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 34717
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_TITLE 34718
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD_IOS 34719
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD_IOS 34720
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_NAME_ON_CARD_LABEL_VIRTUAL_CARD_IOS 34721
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD_IOS 34722
#define IDS_AUTOFILL_VIRTUAL_CARD_DISABLED_SUGGESTION_OPTION_VALUE 34723
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL 34724
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 34725
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 34726
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 34727
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 34728
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 34729
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP 34730
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 34731
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 34732
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_ZIP 34733
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_KLARNA 34734
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 34735
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_ZIP 34736
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_KLARNA 34737
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_CLEAR_FORM_TO_ENABLE 34738
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_NOT_AVAILABLE_RIGHT_NOW 34739
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CURRENCY_NOT_SUPPORTED 34740
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_NOT_AVAILABLE_FOR_MERCHANT 34741
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_NOT_SUPPORTED_BY_MERCHANT 34742
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_LOW 34743
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_HIGH 34744
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_LOW 34745
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_HIGH 34746
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_AI_FOOTNOTE 34747
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_OPTIONS_AI_FOOTNOTE 34748
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_FOR_AI_AMOUNT_EXTRACTION_NOTE 34749
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION 34750
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION_PAYMENT_SETTINGS_LINK_TEXT 34751
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_TITLE 34752
#define IDS_AUTOFILL_BNPL_SELECT_PROVIDER_TITLE_DESCRIPTION 34753
#define IDS_AUTOFILL_CARD_BNPL_LINKED_ISSUER_PILL_LABEL 34754
#define IDS_AUTOFILL_PAY_NOW 34755
#define IDS_AUTOFILL_PAY_LATER 34756
#define IDS_AUTOFILL_PAY_NOW_PAY_LATER_TAB_ACCESSIBILITY_ANNOUNCEMENT 34757
#define IDS_AUTOFILL_A11Y_ANNOUNCEMENT_CONCATENATE_TWO_STRINGS 34758
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_FALLBACK_LABEL 34759
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 34760
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 34761
#define IDS_AUTOFILL_DOWNSTREAM_CARD_AWARENESS_IPH_BUBBLE_LABEL 34762
#define IDS_AUTOFILL_DOWNSTREAM_CARD_AWARENESS_IPH_BUBBLE_LABEL_SCREENREADER 34763
#define IDS_AUTOFILL_CARD_AUTH_SELECTION_DIALOG_TITLE_MULTIPLE_OPTIONS 34764
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_ISSUER_CONFIRMATION_TEXT 34765
#define IDS_AUTOFILL_AUTHENTICATION_MODE_SECURITY_CODE 34766
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_TEXT_MESSAGE 34767
#define IDS_AUTOFILL_AUTHENTICATION_MODE_TEXT_MESSAGE 34768
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_EMAIL 34769
#define IDS_AUTOFILL_AUTHENTICATION_MODE_THREE_DOMAIN_SECURE 34770
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CURRENT_INFO_NOT_SEEN_TEXT 34771
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_CONTINUE 34772
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_SEND 34773
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CVC_CHALLENGE_INFO 34774
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_THREE_DOMAIN_SECURE_CHALLENGE_INFO 34775
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TITLE 34776
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_FOOTER_MESSAGE 34777
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_NEW_CODE_MESSAGE 34778
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TEXTFIELD_PLACEHOLDER_MESSAGE 34779
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_PENDING_MESSAGE 34780
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_VERIFICATION_CODE_EXPIRED_LABEL 34781
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_ENTER_CORRECT_CODE_LABEL 34782
#define IDS_AUTOFILL_LOADING_AND_CONSENT_DIALOG_TITLE_VCN_3DS 34783
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_DESCRIPTION_VCN_3DS 34784
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_OK_BUTTON_LABEL_VCN_3DS 34785
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_ACCEPTANCE_ACCESSIBILITY_ANNOUNCEMENT 34786
#define IDS_AUTOFILL_REGULAR_CARD_MANUAL_FALLBACK_BUBBLE_CARD_NUMBER_LABEL_IOS 34787
#define IDS_AUTOFILL_BNPL_PAY_LATER_OPTIONS_TEXT 34788
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL 34789
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_TWO_ISSUERS 34790
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_THREE_ISSUERS 34791
#define IDS_AUTOFILL_BNPL_SUGGESTION_LABEL_FOR_UNAVAILABLE_PURCHASE 34792
#define IDS_AUTOFILL_BNPL_SETTINGS_LABEL 34793
#define IDS_AUTOFILL_BNPL_SETTINGS_SUBLABEL 34794
#define IDS_AUTOFILL_BNPL_AFFIRM 34795
#define IDS_AUTOFILL_BNPL_ZIP 34796
#define IDS_AUTOFILL_BNPL_AFTER_PAY 34797
#define IDS_AUTOFILL_BNPL_KLARNA 34798
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFFIRM_LOGO_ACCESSIBLE_NAME 34799
#define IDS_AUTOFILL_GOOGLE_PAY_AND_ZIP_LOGO_ACCESSIBLE_NAME 34800
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFTERPAY_LOGO_ACCESSIBLE_NAME 34801
#define IDS_AUTOFILL_GOOGLE_PAY_AND_KLARNA_LOGO_ACCESSIBLE_NAME 34802
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 34803
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 34804
#define IDS_AUTOFILL_BNPL_FILLED_CARD_SNACKBAR_MESSAGE_TEXT 34805
#define IDS_AUTOFILL_BNPL_TOS_OK_BUTTON_LABEL 34806
#define IDS_AUTOFILL_BNPL_TOS_CANCEL_BUTTON_LABEL 34807
#define IDS_AUTOFILL_BNPL_TOS_TITLE_DESCRIPTION 34808
#define IDS_AUTOFILL_BNPL_TOS_UNLINKED_TITLE 34810
#define IDS_AUTOFILL_BNPL_TOS_LINKED_TITLE 34811
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT 34812
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT_WALLET_BRANDING 34813
#define IDS_AUTOFILL_BNPL_TOS_APPROVE_TEXT 34814
#define IDS_AUTOFILL_BNPL_TOS_LINK_TEXT 34815
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_TITLE 34816
#define IDS_AUTOFILL_BNPL_PROGRESS_DIALOG_LOADING_MESSAGE 34817
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 34818
#define IDS_AUTOFILL_BNPL_ERROR_DIALOG_TITLE 34819
#define IDS_AUTOFILL_BNPL_TEMPORARY_ERROR_DESCRIPTION 34820
#define IDS_AUTOFILL_BNPL_PERMANENT_ERROR_DESCRIPTION 34821
#define IDS_AUTOFILL_BNPL_ERROR_OK_BUTTON 34822
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DIALOG_TITLE 34824
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DESCRIPTION 34825
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_TEXT_FOR_SUGGESTIONS 34826
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL 34827
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL_SCREENREADER 34828
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_LABEL 34829
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_LEARN_LINK 34830
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_ISSUER_TERMS_APPLY_TEXT_AND_LEARN_LINK 34831
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_TAG_FOR_CREDIT_CARD_LIST_ENTRY 34832
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_ARIA_LABEL 34833
#define IDS_AUTOFILL_CARD_LINKED_OFFER_REMINDER_TITLE 34840
#define IDS_AUTOFILL_OFFERS_REMINDER_POSITIVE_BUTTON_LABEL 34841
#define IDS_AUTOFILL_PROMO_CODE_SUGGESTIONS_FOOTER_TEXT 34842
#define IDS_AUTOFILL_OFFERS_REMINDER_ICON_TOOLTIP_TEXT 34843
#define IDS_AUTOFILL_OFFERS_REMINDER_DESCRIPTION_TEXT 34844
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_TITLE 34847
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_NORMAL 34848
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_CLICKED 34849
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_VALUE_PROP_TEXT 34850
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_CANT_FIND_CODE_MESSAGE 34851
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_OTP_INPUT_HINT 34852
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_POSITIVE_BUTTON_LABEL 34853
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_NEGATIVE_BUTTON_LABEL 34854
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_LABEL 34910
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_SUBLABEL 34911
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_LABEL 34914
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_ARIA_LABEL_FOR_NO_CVC_SAVED 34915
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_SUBLABEL 34916
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_WITH_DELETE_LINK_SUBLABEL 34917
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_TITLE 34918
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_DESCRIPTION 34919
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_FROM_WALLET_DESCRIPTION 34920
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_TAG_FOR_CREDIT_CARD_LIST_ENTRY 34921
#define IDS_AUTOFILL_CVC_SUGGESTION_MAIN_TEXT 34924
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_SAVED_LABEL 34925
#define IDS_AUTOFILL_SETTINGS_PAGE_SUMMARY_SEPARATED_BY_PIPE 34926
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_TITLE_TEXT 34930
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_TITLE_TEXT 34931
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_TITLE_TEXT 34932
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_TITLE_TEXT 34933
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_TITLE_TEXT 34934
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_TITLE_TEXT 34935
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 34936
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 34937
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT_V2 34938
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 34939
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 34940
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 34941
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 34942
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 34943
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 34944
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 34945
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 34946
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 34947
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 34948
#define IDS_AUTOFILL_SAVE_CARD_AND_VIRTUAL_CARD_ENROLL_CONFIRMATION_BUTTON_TEXT 34949
#define IDS_AUTOFILL_PAYMENT_TEXT 34951
#define IDS_AUTOFILL_IPH_OMNIBOX_PAYMENT_CHIP_LABEL 34952
#define IDS_AUTOFILL_IPH_OMNIBOX_PAYMENT_CHIP_LABEL_SCREENREADER 34953
#define IDS_AUTOFILL_OMNIBOX_BUBBLE_TITLE 34954
#define IDS_AUTOFILL_CLEAR_FORM_MENU_ITEM 34955
#define IDS_AUTOFILL_UNDO_MENU_ITEM 34956
#define IDS_AUTOFILL_WARNING_INSECURE_CONNECTION 34957
#define IDS_AUTOFILL_WARNING_MIXED_FORM 34958
#define IDS_AUTOFILL_AI_FETCHING_AMBIENT_DATA 34959
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_CONFIRMATION_BODY 34963
#define IDS_AUTOFILL_DELETE_CREDIT_CARD_SUGGESTION_CONFIRMATION_BODY 34964
#define IDS_AUTOFILL_DELETE_PROFILE_SUGGESTION_CONFIRMATION_BODY 34965
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_TITLE 34966
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_BODY 34967
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_TITLE 34968
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_BODY 34969
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_TITLE 34970
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_BODY 34971
#define IDS_AUTOFILL_REMOVE_SUGGESTION_BUTTON 34972
#define IDS_AUTOFILL_DELETE_SUGGESTION_BUTTON 34973
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_TOOLTIP 34974
#define IDS_AUTOFILL_AUTOCOMPLETE_ENTRY_DELETED_A11Y_HINT 34975
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_A11Y_HINT 34976
#define IDS_HOME_SUGGESTION_VOICE_OVER 34977
#define IDS_WORK_SUGGESTION_VOICE_OVER 34978
#define IDS_AUTOFILL_CC_AMEX 34979
#define IDS_AUTOFILL_CC_AMEX_SHORT 34980
#define IDS_AUTOFILL_CC_DINERS 34981
#define IDS_AUTOFILL_CC_DISCOVER 34982
#define IDS_AUTOFILL_CC_ELO 34983
#define IDS_AUTOFILL_CC_JCB 34984
#define IDS_AUTOFILL_CC_MASTERCARD 34985
#define IDS_AUTOFILL_CC_MIR 34986
#define IDS_AUTOFILL_CC_TROY 34987
#define IDS_AUTOFILL_CC_UNION_PAY 34988
#define IDS_AUTOFILL_CC_VERVE 34989
#define IDS_AUTOFILL_CC_VISA 34990
#define IDS_AUTOFILL_CC_GENERIC 34991
#define IDS_AUTOFILL_IBAN_GENERIC 34992
#define IDS_AUTOFILL_LOYALTY_CARD_GENERIC 34993
#define IDS_AUTOFILL_LOYALTY_CARDS_SUBMENU_TITLE 34994
#define IDS_AUTOFILL_LOYALTY_CARDS_ALL_YOUR_CARDS_SUBMENU_TITLE 34995
#define IDS_AUTOFILL_ADDRESS_SUMMARY_SEPARATOR 34996
#define IDS_AUTOFILL_DEVELOPER_TOOLS 34997
#define IDS_AUTOFILL_TEST_ADDRESS_BY_COUNTRY 34998
#define IDS_AUTOFILL_TEST_ADDRESS_SELECTED_A11Y_HINT 34999
#define IDS_AUTOFILL_EMAIL_VERIFIER_PROMPT_TITLE 35000
#define IDS_AUTOFILL_EMAIL_VERIFIER_PROMPT_BODY 35001
#define IDS_AUTOFILL_EMAIL_VERIFIER_PROMPT_VERIFY 35002
#define IDS_AUTOFILL_EMAIL_VERIFIER_PROMPT_NOT_NOW 35003
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_FORM 35004
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_CARD_INFORMATION_ENTRY 35005
#define IDS_AUTOFILL_A11Y_ANNOUNCE_CLEARED_FORM 35006
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_PROVIDED_MINOR_TEXT 35007
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_MINOR_TEXT 35008
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_EMAIL_LABEL 35009
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_LABEL_TEXT 35010
#define IDS_AUTOFILL_MANAGE_ADDRESSES 35011
#define IDS_AUTOFILL_MANAGE_PAYMENT_METHODS 35012
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS 35013
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS_A11Y_HINT 35014
#define IDS_AUTOFILL_SCAN_CREDIT_CARD 35015
#define IDS_AUTOFILL_SAVE_AND_FILL_SUGGESTION_TITLE 35016
#define IDS_AUTOFILL_LOCAL_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 35017
#define IDS_AUTOFILL_SERVER_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 35018
#define IDS_AUTOFILL_POPUP_ACCESSIBLE_NODE_DATA 35019
#define IDS_AUTOFILL_IPH_EXTERNAL_ACCOUNT_PROFILE_SUGGESTION 35020
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION 35021
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_SCREENREADER 35022
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_TITLE 35023
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION 35024
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_SCREENREADER 35025
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_TITLE 35026
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR 35027
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR_V2 35028
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_NAME 35029
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_CARD_NUMBER 35030
#define IDS_AUTOFILL_LOADING_REGIONS 35031
#define IDS_AUTOFILL_ADDRESSES 35032
#define IDS_AUTOFILL_ADDRESSES_TABLE_ARIA_LABEL 35033
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_SUBLABEL 35034
#define IDS_AUTOFILL_LOCAL_PROFILE_ICON_ACCESSIBILITY_LABEL 35035
#define IDS_AUTOFILL_HOME_PROFILE_ICON_ACCESSIBILITY_LABEL 35036
#define IDS_AUTOFILL_WORK_PROFILE_ICON_ACCESSIBILITY_LABEL 35037
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_SUBLABEL 35038
#define IDS_AUTOFILL_DELETE_ACCOUNT_ADDRESS_RECORD_TYPE_NOTICE 35039
#define IDS_AUTOFILL_DELETE_SYNC_ADDRESS_RECORD_TYPE_NOTICE 35040
#define IDS_AUTOFILL_DELETE_LOCAL_ADDRESS_RECORD_TYPE_NOTICE 35041
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_RECORD_TYPE_NOTICE 35042
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_MIGRATION_RECORD_TYPE_NOTICE 35043
#define IDS_AUTOFILL_ADDRESS_ALREADY_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 35044
#define IDS_AUTOFILL_ADDRESS_WILL_BE_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 35045
#define IDS_AUTOFILL_ADDRESS_HOME_RECORD_TYPE_NOTICE 35046
#define IDS_AUTOFILL_ADDRESS_WORK_RECORD_TYPE_NOTICE 35047
#define IDS_AUTOFILL_ADDRESS_HOME_AND_WORK_RECORD_TYPE_NOTICE 35048
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELD_FORM_ERROR 35049
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELDS_FORM_ERROR 35050
#define IDS_AUTOFILL_LOCAL_ADDRESS_ICON_A11Y_LABEL 35051
#define IDS_AUTOFILL_HOME_ADDRESS_ICON_A11Y_LABEL 35052
#define IDS_AUTOFILL_WORK_ADDRESS_ICON_A11Y_LABEL 35053
#define IDS_AUTOFILL_HOME_WORK_ADDRESS_EDIT_A11Y_LABEL 35054
#define IDS_AUTOFILL_SYNC_TOGGLE_LABEL 35055
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_TITLE 35056
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_SUBLABEL 35057
#define IDS_AUTOFILL_SETTINGS_EMAIL_VERIFICATION_LABEL 35058
#define IDS_AUTOFILL_SETTINGS_EMAIL_VERIFICATION_SECTION_TITLE 35059
#define IDS_AUTOFILL_SETTINGS_EMAIL_VERIFICATION_EMPTY_LABEL 35060
#define IDS_AUTOFILL_PAYMENT_METHODS 35061
#define IDS_AUTOFILL_PAYMENT_METHODS_KEYWORDS 35062
#define IDS_AUTOFILL_PAYMENT_METHODS_TABLE_ARIA_LABEL 35063
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_LABEL 35064
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION_TITLE 35065
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION 35066
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION_V2 35067
#define IDS_AUTOFILL_DISABLE_SETTINGS_BUTTON_LABEL 35068
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_LABEL 35069
#define IDS_AUTOFILL_DELETE_ADDRESS_CONFIRMATION_DIALOG_TITLE 35070
#define IDS_SYNC_DATATYPE_PAYMENTS_AND_INFO 35081
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_OK_BUTTON_LABEL 35090
#define IDS_AUTOFILL_SAVE_ADDRESS_WITH_MORE_INFO_ADDRESS_PROMPT_TITLE 35091
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_MIGRATION_OK_BUTTON_LABEL 35092
#define IDS_AUTOFILL_ACCOUNT_MIGRATE_ADDRESS_PROMPT_TITLE 35093
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OK_BUTTON_LABEL 35094
#define IDS_AUTOFILL_ADD_NEW_INFO_ADDRESS_PROMPT_TITLE 35095
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_OK_BUTTON_LABEL 35096
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_OK_BUTTON_LABEL 35097
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_CANCEL_BUTTON_LABEL 35098
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_NEW_VALUES_SECTION_LABEL 35099
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OLD_VALUES_SECTION_LABEL 35100
#define IDS_AUTOFILL_MIGRATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 35101
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_PROMPT_ADDRESS_SOURCE_NOTICE 35102
#define IDS_AUTOFILL_UPDATE_PROMPT_ACCOUNT_ADDRESS_SOURCE_NOTICE 35103
#define IDS_AUTOFILL_SYNCABLE_PROFILE_MIGRATION_PROMPT_NOTICE 35104
#define IDS_AUTOFILL_LOCAL_PROFILE_MIGRATION_PROMPT_NOTICE 35105
#define IDS_AUTOFILL_SAVE_PROMPT_ADDRESS_SECTION_A11Y_LABEL 35106
#define IDS_AUTOFILL_SAVE_PROMPT_PHONE_SECTION_A11Y_LABEL 35107
#define IDS_AUTOFILL_SAVE_PROMPT_EMAIL_SECTION_A11Y_LABEL 35108
#define IDS_AUTOFILL_CONTACT_INFO_TITLE 35129
#define IDS_AUTOFILL_PAYMENTS_TITLE 35130
#define IDS_AUTOFILL_IDENTITY_DOCS_TITLE 35131
#define IDS_AUTOFILL_SHOPPING_TITLE 35132
#define IDS_AUTOFILL_TRAVEL_TITLE 35133
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_LABEL 35134
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_SUB_LABEL 35135
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_LABEL 35136
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_SUB_LABEL 35137
#define IDS_AUTOFILL_SHOPPING_OPT_IN_TOGGLE_LABEL 35138
#define IDS_AUTOFILL_SHOPPING_OPT_IN_TOGGLE_SUB_LABEL 35139
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_TITLE 35109
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 35147
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_EDIT_BUTTON_TOOLTIP 35112
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_TITLE 35110
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_CANCEL_BUTTON_LABEL 35148
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 35149
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_PROMPT_TITLE 35150
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_OK_BUTTON_LABEL 35151
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_CANCEL_BUTTON_LABEL 35152
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_TITLE 35113
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 35153
#define IDS_AUTOFILL_MIGRATE_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 35154
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_UPDATE 35155
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_CANCEL_BUTTON_LABEL 35156
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_FILL_ADDRESS_A11Y_ADDON 35157
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT 35158
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT_RTL 35159
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_SUBMENU_HINT 35160
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_PASSWORD 35161
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_PASSWORD 35162
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_CLEAR_SEARCH_BUTTON_A11Y_NAME 35163
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_INPUT_PLACEHOLDER 35164
#define IDS_AUTOFILL_AT_MEMORY_POPUP_SEARCH_BAR_PLACEHOLDER 35165
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_NOT_FOUND 35166
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_ADDRESS 35167
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_ADDRESS 35168
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_TITLE 35169
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_BODY 35170
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_SCREENREADER 35171
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_RECOVERY_SHOWN_A11Y_ANNOUNCEMENT 35172
#define IDS_AUTOFILL_AI_SAVE_OR_UPDATE_LOCAL_ENTITY_SOURCE_NOTICE 35173
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_ATTRIBUTION_TITLE 35174
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_ATTRIBUTION_DESCRIPTION 35175
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_GMAIL 35176
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_CALENDAR 35177
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_PHOTOS 35178
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_AMBIENT 35179
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_LIVETABS 35180
#define IDS_AUTOFILL_AT_MEMORY_NO_DATA 35181
#define IDS_AUTOFILL_AT_MEMORY_NO_CONNECTION 35182
#define IDS_AUTOFILL_AT_MEMORY_GENERIC_ERROR 35183
#define IDS_AUTOFILL_AT_MEMORY_SEARCH_AFFORDANCE_SUBTITLE 35184
#define IDS_AUTOFILL_AT_MEMORY_UNSUPPORTED_QUERY_TITLE 35185
#define IDS_AUTOFILL_AT_MEMORY_UNSUPPORTED_QUERY_DESCRIPTION 35186
#define IDS_AUTOFILL_AT_MEMORY_MANAGE_SUGGESTION_MAIN_TEXT 35195
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_HISPANIC_MUNICIPIO 35196
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_FRENCH_LOCALITY_2 35197
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_JAPANESE_ALTERNATIVE_NAME 35198
#define IDS_SETTINGS_AUTOFILL_AI_ENTERPRISE_LOGGING_MANAGED_DISABLED 35201
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ENTITY_NAME 35202
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ENTITY_NAME 35203
#define IDS_AUTOFILL_AI_ID_CARD_ENTITY_NAME 35204
#define IDS_AUTOFILL_AI_PASSPORT_ENTITY_NAME 35205
#define IDS_AUTOFILL_AI_VEHICLE_ENTITY_NAME 35206
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ENTITY_NAME 35207
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ENTITY_NAME 35208
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATION_ENTITY_NAME 35209
#define IDS_AUTOFILL_AI_ORDER_ENTITY_NAME 35210
#define IDS_AUTOFILL_AI_SHIPMENT_ENTITY_NAME 35211
#define IDS_AUTOFILL_AI_DRIVERS_LICENSES_TITLE 35212
#define IDS_AUTOFILL_AI_NATIONAL_IDS_TITLE 35213
#define IDS_AUTOFILL_AI_NATIONAL_IDS_SHORT_TITLE 35214
#define IDS_AUTOFILL_AI_PASSPORTS_TITLE 35215
#define IDS_AUTOFILL_AI_VEHICLES_TITLE 35216
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_TITLE 35217
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_TITLE 35218
#define IDS_AUTOFILL_AI_TRAVEL_INFO_TITLE 35219
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATIONS_TITLE 35220
#define IDS_AUTOFILL_AI_ORDERS_TITLE 35221
#define IDS_AUTOFILL_AI_SHIPMENTS_TITLE 35222
#define IDS_AUTOFILL_AI_ADD_DRIVERS_LICENSE_ENTITY 35223
#define IDS_AUTOFILL_AI_ADD_NATIONAL_ID_CARD_ENTITY 35224
#define IDS_AUTOFILL_AI_ADD_PASSPORT_ENTITY 35225
#define IDS_AUTOFILL_AI_ADD_VEHICLE_ENTITY 35226
#define IDS_AUTOFILL_AI_ADD_KNOWN_TRAVELER_NUMBER_ENTITY 35227
#define IDS_AUTOFILL_AI_ADD_REDRESS_NUMBER_ENTITY 35228
#define IDS_AUTOFILL_AI_EDIT_DRIVERS_LICENSE_ENTITY 35229
#define IDS_AUTOFILL_AI_EDIT_NATIONAL_ID_CARD_ENTITY 35230
#define IDS_AUTOFILL_AI_EDIT_PASSPORT_ENTITY 35231
#define IDS_AUTOFILL_AI_EDIT_VEHICLE_ENTITY 35232
#define IDS_AUTOFILL_AI_EDIT_KNOWN_TRAVELER_NUMBER_ENTITY 35233
#define IDS_AUTOFILL_AI_EDIT_REDRESS_NUMBER_ENTITY 35234
#define IDS_AUTOFILL_AI_DELETE_DRIVERS_LICENSE_ENTITY 35235
#define IDS_AUTOFILL_AI_DELETE_NATIONAL_ID_CARD_ENTITY 35236
#define IDS_AUTOFILL_AI_DELETE_PASSPORT_ENTITY 35237
#define IDS_AUTOFILL_AI_DELETE_VEHICLE_ENTITY 35238
#define IDS_AUTOFILL_AI_DELETE_KNOWN_TRAVELER_NUMBER_ENTITY 35239
#define IDS_AUTOFILL_AI_DELETE_REDRESS_NUMBER_ENTITY 35240
#define IDS_AUTOFILL_AI_ORDER_ID_ATTRIBUTE_NAME 35241
#define IDS_AUTOFILL_AI_ORDER_ACCOUNT_ATTRIBUTE_NAME 35242
#define IDS_AUTOFILL_AI_ORDER_DATE_ATTRIBUTE_NAME 35243
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_NAME_ATTRIBUTE_NAME 35244
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_DOMAIN_ATTRIBUTE_NAME 35245
#define IDS_AUTOFILL_AI_ORDER_PRODUCT_NAMES_ATTRIBUTE_NAME 35246
#define IDS_AUTOFILL_AI_SHIPMENT_TRACKING_NUMBER_ATTRIBUTE_NAME 35247
#define IDS_AUTOFILL_AI_SHIPMENT_DELIVERY_ZIP_CODE_ATTRIBUTE_NAME 35248
#define IDS_AUTOFILL_AI_SHIPMENT_CARRIER_NAME_ATTRIBUTE_NAME 35249
#define IDS_AUTOFILL_AI_SHIPMENT_CARRIER_DOMAIN_ATTRIBUTE_NAME 35250
#define IDS_AUTOFILL_AI_SHIPMENT_SHIPPED_DATE_ATTRIBUTE_NAME 35251
#define IDS_AUTOFILL_AI_SHIPMENT_ORDER_IDS_ATTRIBUTE_NAME 35252
#define IDS_AUTOFILL_AI_SHIPMENT_ORDER_DATES_ATTRIBUTE_NAME 35253
#define IDS_AUTOFILL_AI_SHIPMENT_MERCHANT_NAME_ATTRIBUTE_NAME 35254
#define IDS_AUTOFILL_AI_SHIPMENT_PRODUCT_NAMES_ATTRIBUTE_NAME 35255
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NAME_ATTRIBUTE_NAME 35256
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_STATE_ATTRIBUTE_NAME 35257
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME 35258
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME_NEW 35259
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_EXPIRATION_DATE_ATTRIBUTE_NAME 35260
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ISSUE_DATE_ATTRIBUTE_NAME 35261
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NAME_ATTRIBUTE_NAME 35262
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NUMBER_ATTRIBUTE_NAME 35263
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME 35264
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME_NEW 35265
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_EXPIRATION_DATE_ATTRIBUTE_NAME 35266
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME 35267
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME_NEW 35268
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_NAME_ATTRIBUTE_NAME 35269
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ATTRIBUTE_NAME 35270
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_EXPIRATION_DATE_ATTRIBUTE_NAME 35271
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_NAME_ATTRIBUTE_NAME 35272
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ATTRIBUTE_NAME 35273
#define IDS_AUTOFILL_AI_PASSPORT_NAME_ATTRIBUTE_NAME 35274
#define IDS_AUTOFILL_AI_PASSPORT_NUMBER_ATTRIBUTE_NAME 35275
#define IDS_AUTOFILL_AI_PASSPORT_COUNTRY_ATTRIBUTE_NAME 35276
#define IDS_AUTOFILL_AI_PASSPORT_EXPIRATION_DATE_ATTRIBUTE_NAME 35277
#define IDS_AUTOFILL_AI_PASSPORT_ISSUE_DATE_ATTRIBUTE_NAME 35278
#define IDS_AUTOFILL_AI_VEHICLE_MAKE_ATTRIBUTE_NAME 35279
#define IDS_AUTOFILL_AI_VEHICLE_MODEL_ATTRIBUTE_NAME 35280
#define IDS_AUTOFILL_AI_VEHICLE_YEAR_ATTRIBUTE_NAME 35281
#define IDS_AUTOFILL_AI_VEHICLE_OWNER_ATTRIBUTE_NAME 35282
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_NUMBER_ATTRIBUTE_NAME 35283
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_STATE_ATTRIBUTE_NAME 35284
#define IDS_AUTOFILL_AI_VEHICLE_VEHICLE_IDENTIFICATION_NUMBER_ATTRIBUTE_NAME 35285
#define IDS_AUTOFILL_AI_MANAGE_SUGGESTION_MAIN_TEXT 35286
#define IDS_AUTOFILL_AI_MANAGE_IDENTITY_DOCS_SUGGESTION_MAIN_TEXT 35287
#define IDS_AUTOFILL_AI_MANAGE_TRAVEL_SUGGESTION_MAIN_TEXT 35288
#define IDS_AUTOFILL_AI_MANAGE_SHOPPING_SUGGESTION_MAIN_TEXT 35289
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_NO_THANKS_BUTTON 35290
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_SAVE_BUTTON 35291
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_UPDATE_DIALOG_UPDATE_BUTTON 35292
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TITLE 35293
#define IDS_AUTOFILL_AI_OPT_IN_IPH_BODY 35294
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TURN_ON 35295
#define IDS_AUTOFILL_AI_OPT_IN_IPH_MAYBE_LATER 35296
#define IDS_AUTOFILL_AI_VALUABLES_IPH_TITLE 35297
#define IDS_AUTOFILL_AI_VALUABLES_IPH_BODY 35298
#define IDS_AUTOFILL_GOOGLE_WALLET_TITLE 35299
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 35300
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE_NEW 35301
#define IDS_AUTOFILL_AI_SAVE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 35302
#define IDS_AUTOFILL_AI_SAVE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 35303
#define IDS_AUTOFILL_AI_SAVE_ID_CARD_ENTITY_DIALOG_TITLE 35304
#define IDS_AUTOFILL_AI_SAVE_PASSPORT_ENTITY_DIALOG_TITLE 35305
#define IDS_AUTOFILL_AI_SAVE_VEHICLE_ENTITY_DIALOG_TITLE 35306
#define IDS_AUTOFILL_AI_SAVE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 35307
#define IDS_AUTOFILL_AI_SAVE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 35308
#define IDS_AUTOFILL_AI_SAVE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE_BRANDED 35309
#define IDS_AUTOFILL_AI_SAVE_ID_CARD_ENTITY_DIALOG_TITLE_BRANDED 35310
#define IDS_AUTOFILL_AI_SAVE_PASSPORT_ENTITY_DIALOG_TITLE_BRANDED 35311
#define IDS_AUTOFILL_AI_SAVE_VEHICLE_ENTITY_DIALOG_TITLE_BRANDED 35312
#define IDS_AUTOFILL_AI_SAVE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE_BRANDED 35313
#define IDS_AUTOFILL_AI_SAVE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE_BRANDED 35314
#define IDS_AUTOFILL_AI_UPDATE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 35315
#define IDS_AUTOFILL_AI_UPDATE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 35316
#define IDS_AUTOFILL_AI_UPDATE_ID_CARD_ENTITY_DIALOG_TITLE 35317
#define IDS_AUTOFILL_AI_UPDATE_PASSPORT_ENTITY_DIALOG_TITLE 35318
#define IDS_AUTOFILL_AI_UPDATE_VEHICLE_ENTITY_DIALOG_TITLE 35319
#define IDS_AUTOFILL_AI_UPDATE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 35320
#define IDS_AUTOFILL_AI_UPDATE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 35321
#define IDS_AUTOFILL_AI_UPDATE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE_BRANDED 35322
#define IDS_AUTOFILL_AI_UPDATE_ID_CARD_ENTITY_DIALOG_TITLE_BRANDED 35323
#define IDS_AUTOFILL_AI_UPDATE_PASSPORT_ENTITY_DIALOG_TITLE_BRANDED 35324
#define IDS_AUTOFILL_AI_UPDATE_VEHICLE_ENTITY_DIALOG_TITLE_BRANDED 35325
#define IDS_AUTOFILL_AI_UPDATE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE_BRANDED 35326
#define IDS_AUTOFILL_AI_UPDATE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE_BRANDED 35327
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_SUBTITLE 35328
#define IDS_AUTOFILL_AI_SAVE_ENTITY_DIALOG_SUBTITLE 35329
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 35330
#define IDS_AUTOFILL_MANAGE_YOUR_INFO_LINK 35331
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME 35332
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME 35333
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME_V2 35334
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME_V2 35335
#define IDS_AUTOFILL_AI_WALLET_UPLOAD_THROBBER_ACCESSIBLE_NAME 35336
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_TITLE 35337
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DESCRIPTION 35338
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DISMISS_BUTTON_LABEL 35339
#define IDS_AUTOFILL_AI_WALLET_UPDATE_OR_MIGRATE_FAILURE_NOTIFICATION 35340
#define IDS_AUTOFILL_AI_WALLET_FETCH_FAILURE_NOTIFICATION 35341
#define IDS_AUTOFILL_AI_PRE_FETCH_ERROR_MESSAGE 35342
#define IDS_AUTOFILL_AI_PRE_FETCH_ERROR_MESSAGE_BUTTON_TEXT 35343
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_TITLE 35390
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_DESCRIPTION 35391
#define IDS_AUTOFILL_AI_FFR_CONSIDER_DESCRIPTION 35392
#define IDS_AUTOFILL_AI_FFR_CONSIDER_LEARN_MORE 35393
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_TITLE 35394
#define IDS_AT_MEMORY_PROMO_TITLE 35395
#define IDS_AT_MEMORY_PROMO_DESCRIPTION 35396
#define IDS_AT_MEMORY_PROMO_LEARN_MORE_BUTTON 35397
#define IDS_AT_MEMORY_PROMO_GOT_IT_BUTTON 35398
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_SUBTITLE 35399
#define IDS_SETTINGS_AUTOFILL_AI_PAGE_TITLE 35400
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON 35401
#define IDS_SETTINGS_AUTOFILL_AI_THINGS_TO_CONSIDER 35402
#define IDS_SETTINGS_AUTOFILL_SERVICE_PROVIDER 35403
#define IDS_SETTINGS_AUTOFILL_AI_TO_CONSIDER_DATA_USAGE 35404
#define IDS_SETTINGS_AUTOFILL_AI_DESCRIPTION 35405
#define IDS_SETTINGS_AUTOFILL_AI_TOGGLE_SUB_LABEL 35406
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_CAN_FILL_DIFFICULT_FIELDS 35407
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_TITLE 35408
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_SUBTITLE 35409
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_BUTTON_LABEL 35410
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_QUALITY_LOGGING_TITLE 35411
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_WHEN_USED_1 35412
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_WHEN_USED_2 35413
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_CONSIDER_1 35414
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_CONSIDER_2 35415
#define IDS_SETTINGS_SUGGESTIONS_FROM_GEMINI_CONSIDER_3 35416
#define IDS_BOOKMARK_BAR_FOLDER_NAME 35419
#define IDS_BOOKMARK_BAR_MOBILE_FOLDER_NAME 35420
#define IDS_BOOKMARK_BAR_OTHER_FOLDER_NAME 35421
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DOMAIN_NAME 35422
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DEFAULT_NAME 35423
#define IDS_BOOKMARK_EDITOR_TITLE 35424
#define IDS_BOOKMARK_MOVE_DIALOG_TITLE 35425
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_NAME 35426
#define IDS_BOOKMARK_BUBBLE_REMOVE_BOOKMARK 35427
#define IDS_BOOKMARK_MANAGER_NAME_INPUT_PLACE_HOLDER 35428
#define IDS_BOOKMARK_MANAGER_URL_INPUT_PLACE_HOLDER 35429
#define IDS_TOOLTIP_STAR 35430
#define IDS_CLEAR_BROWSING_DATA_CALCULATING 35431
#define IDS_DEL_BROWSING_HISTORY_COUNTER 35432
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SYNCED 35433
#define IDS_DEL_NO_BROWSING_HISTORY_TEXT 35434
#define IDS_DEL_NO_BROWSING_HISTORY_SYNC_TEXT 35435
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_TEXT 35436
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_SYNC_TEXT 35437
#define IDS_DEL_BROWSING_HISTORY_COUNTER_MULTIPLE_DOMAINS_TEXT 35438
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_TEXT 35439
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_SYNC_TEXT 35440
#define IDS_DEL_CACHE_COUNTER_UPPER_ESTIMATE 35441
#define IDS_DEL_CACHE_COUNTER_ALMOST_EMPTY 35442
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED 35443
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_UPPER_ESTIMATE 35444
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_ALMOST_EMPTY 35445
#define IDS_DEL_PASSWORDS_COUNTER 35446
#define IDS_DEL_PASSWORDS_COUNTER_SYNCED 35447
#define IDS_DEL_ACCOUNT_PASSWORDS_COUNTER 35448
#define IDS_DEL_PASSWORDS_DOMAINS_DISPLAY 35449
#define IDS_DEL_PASSWORDS_COUNTER_AND_X_MORE 35450
#define IDS_DEL_SIGNIN_DATA_COUNTER 35451
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_NONE 35452
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_COMBINATION 35453
#define IDS_DEL_SITE_SETTINGS_COUNTER 35454
#define IDS_DEL_AUTOFILL_COUNTER_EMPTY 35455
#define IDS_DEL_AUTOFILL_COUNTER_PAYMENT_METHODS 35456
#define IDS_DEL_AUTOFILL_COUNTER_ADDRESSES 35457
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS 35458
#define IDS_DEL_AUTOFILL_COUNTER_USER_ANNOTATION_ENTRIES 35459
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_LONG 35460
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_SHORT 35461
#define IDS_DEL_AUTOFILL_COUNTER_ONE_TYPE_SYNCED 35462
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES 35463
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES_SYNCED 35464
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES 35465
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES_SYNCED 35466
#define IDS_DEL_AUTOFILL_SYNCABLE_NON_SYNCABLE_COMBINATION 35467
#define IDS_DEL_COOKIES_COUNTER 35468
#define IDS_DEL_COOKIES_COUNTER_ADVANCED 35469
#define IDS_DEL_COOKIES_COUNTER_ADVANCED_WITH_SIGNED_IN_EXCEPTION 35470
#define IDS_ANDROID_DEL_COOKIES_COUNTER_ADVANCED 35471
#define IDS_DEL_DOWNLOADS_COUNTER 35472
#define IDS_DEL_HOSTED_APPS_COUNTER 35473
#define IDS_DEL_HOSTED_APPS_COUNTER_AND_X_MORE 35474
#define IDS_DEL_TABS_COUNTER 35475
#define IDS_TABS_COUNT 35476
#define IDS_WINDOWS_COUNT 35477
#define IDS_DEL_TABS_MULTIWINDOW_COUNTER 35478
#define IDS_DEL_GOOGLE_COOKIES_SIGNOUT_LINK 35479
#define IDS_SETTINGS_MANAGE_IN_GOOGLE_PASSWORD_MANAGER 35480
#define IDS_SETTINGS_MANAGE_IN_YOUR_GOOGLE_ACCOUNT 35481
#define IDS_SETTINGS_MANAGE_OTHER_DATA_LABEL 35482
#define IDS_SETTINGS_MANAGE_OTHER_GOOGLE_DATA_LABEL 35483
#define IDS_SETTINGS_MY_ACTIVITY 35484
#define IDS_SETTINGS_OTHER_DATA_TITLE 35485
#define IDS_SETTINGS_OTHER_GOOGLE_DATA_TITLE 35486
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS 35487
#define IDS_SETTINGS_MANAGE_PASSWORDS_SUB_LABEL 35488
#define IDS_SETTINGS_SEARCH_HISTORY 35489
#define IDS_SETTINGS_MANAGE_OTHER_DATA_SUB_LABEL 35490
#define IDS_SETTINGS_OTHER_DATA_DESCRIPTION 35491
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_NON_PREPOPULATED_DSE 35492
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_PREPOPULATED_DSE 35493
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE 35494
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ACTION_BUTTON 35495
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ERROR_DESCRIPTION 35496
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE_FIRST_RUN 35497
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_DESCRIPTION_FIRST_RUN 35498
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_CANCEL_BUTTON 35499
#define IDS_PRICE_TRACKING_SAVE_DESCRIPTION 35500
#define IDS_PRICE_TRACKING_SAVE_LOCATION 35501
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_BODY 35502
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_TITLE 35503
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_LEARN_MORE_LINK_TEXT 35504
#define IDS_PRICE_TRACKING_NOT_NOW 35505
#define IDS_PRICE_TRACKING_YES_IM_IN 35506
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_TITLE 35507
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_ACTION_BUTTON 35508
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_UNTRACK_BUTTON 35509
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION 35510
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION_EMAIL_OFF 35511
#define IDS_PRICE_TRACKING_SIDE_PANEL_IPH 35512
#define IDS_SIDE_PANEL_TRACKED_PRODUCTS 35513
#define IDS_SIDE_PANEL_UNTRACK_BUTTON 35514
#define IDS_SIDE_PANEL_TRACK_BUTTON 35515
#define IDS_PRICE_TRACKING_UNTRACK_PRODUCT_ACCESSIBILITY 35516
#define IDS_PRICE_TRACKING_TRACK_PRODUCT_ACCESSIBILITY 35517
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_BUTTON 35518
#define IDS_PRICE_TRACKING_SETTINGS_TITLE 35519
#define IDS_PRICE_TRACKING_SETTINGS_EMAIL_DESCRIPTION 35520
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_MESSAGE 35521
#define IDS_SHOPPING_COLLECTION_IPH_TITLE 35522
#define IDS_SHOPPING_COLLECTION_IPH_BODY 35523
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TITLE 35524
#define IDS_PRICE_HISTORY_TITLE 35525
#define IDS_PRICE_HISTORY_TITLE_MULTIPLE_OPTIONS 35526
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_LOW_PRICE 35527
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_HIGH_PRICE 35528
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_TYPICAL_PRICE 35529
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_TITLE 35530
#define IDS_SHOPPING_INSIGHTS_ICON_TOOLTIP_TEXT 35531
#define IDS_SHOPPING_INSIGHTS_BUYING_OPTIONS 35532
#define IDS_PRICE_HISTORY_YESTERDAY_PRICE 35533
#define IDS_PRICE_HISTORY_DESCRIPTION 35534
#define IDS_PRICE_HISTORY_GRAPH_ACCESSIBILITY 35535
#define IDS_SHOPPING_INSIGHTS_COLLECT_FEEDBACK 35536
#define IDS_SHOPPING_INSIGHTS_FEEDBACK_FORM_TITLE 35537
#define IDS_PRICE_HISTORY_SINGLE_OPTION_LOW_PRICE 35538
#define IDS_PRICE_HISTORY_SINGLE_OPTION_HIGH_PRICE 35539
#define IDS_PRICE_HISTORY_SINGLE_OPTION_TYPICAL_PRICE 35540
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_DESCRIPTION 35541
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_ERROR 35542
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT_WITH_EXPIRATION_DATE 35543
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT 35544
#define IDS_TWO_STRINGS_CONNECTOR_WITH_SPACE 35545
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_TITLE 35546
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_FOOTER 35547
#define IDS_SEE_SELLER_TERMS_AND_CONDITIONS 35548
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP 35549
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP_CLICKED 35550
#define IDS_PRICE_DROP_POPUP_CONTENT_TITLE 35561
#define IDS_PRICE_DROP_POPUP_CONTENT_TEXT 35562
#define IDS_PRICE_DROP_POPUP_ACTION_BUTTON 35563
#define IDS_PRICE_DROP_POPUP_UNTRACK_BUTTON 35564
#define IDS_PRICE_RANGE_ALL_OPTIONS 35565
#define IDS_PRICE_RANGE_ALL_OPTIONS_ONE_TYPICAL_PRICE 35566
#define IDS_PRICE_RANGE_SINGLE_OPTION 35567
#define IDS_PRICE_RANGE_SINGLE_OPTION_ONE_TYPICAL_PRICE 35568
#define IDS_PRICE_TRACKING_DESCRIPTION 35569
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_TITLE 35570
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_SUBTITLE 35571
#define IDS_PRICE_INSIGHTS_TRACK_BUTTON_TITLE 35572
#define IDS_PRICE_INSIGHTS_TRACKING_BUTTON_TITLE 35573
#define IDS_INSIGHTS_ICON_EXPANDED_TEXT_GOOD_DEAL 35574
#define IDS_INSIGHTS_RICH_IPH_TEXT 35575
#define IDS_PRICE_INSIGHTS_ACCESSIBILITY 35576
#define IDS_PRICE_INSIGHTS_GRAPH_ACCESSIBILITY_LABEL 35577
#define IDS_PRICE_INSIGHTS_SNACKBAR_BUTTON_TITLE 35578
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_DISABLED 35579
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_ENABLED 35580
#define IDS_BUYING_OPTIONS_ACCESSIBILITY_DESCRIPTION 35581
#define IDS_PRICE_TRACKING_DESCRIPTION_TRACKED 35582
#define IDS_PRICE_HISTORY_TITLE_WITH_VARIANTS 35583
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_TITLE 35584
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_MESSAGE 35585
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_CLOSE 35586
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_REDIRECT 35587
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_MESSAGE 35588
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_BUTTON_TITLE 35589
#define IDS_PRICE_HISTORY_TITLE_SINGLE_OPTION 35590
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_LOW_PRICE 35591
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_HIGH_PRICE 35592
#define IDS_SHOPPING_COLLECTION_FOLDER_NAME 35593
#define IDS_DISCOUNT_ICON_EXPANDED_TEXT 35594
#define IDS_DISCOUNT_CODE_COPY_BUTTON_TEXT 35595
#define IDS_SETTINGS_TITLE 35603
#define IDS_SETTINGS_HIDE_ADVANCED_SETTINGS 35604
#define IDS_SETTINGS_SHOW_ADVANCED_SETTINGS 35605
#define IDS_NETWORK_PREDICTION_ENABLED_DESCRIPTION 35606
#define IDS_SYSTEM_TITLE 35607
#define IDS_OPTIONS_PROXIES_CONFIGURE_BUTTON 35608
#define IDS_COMPOSE_SUGGESTION_MAIN_TEXT 35609
#define IDS_COMPOSE_CONTEXT_MENU_TEXT 35610
#define IDS_COMPOSE_SUGGESTION_LABEL 35611
#define IDS_COMPOSE_SUGGESTION_SAVED_TEXT 35612
#define IDS_COMPOSE_SUGGESTION_SAVED_LABEL 35613
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_PROACTIVE 35614
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_RESUME 35615
#define IDS_COMPOSE_DONT_SHOW_ON_THIS_SITE_CHILD_SUGGESTION_TEXT 35616
#define IDS_COMPOSE_DISABLE_HELP_ME_WRITE_CHILD_SUGGESTION_TEXT 35617
#define IDS_COMPOSE_GO_TO_SETTINGS_CHILD_SUGGESTION_TEXT 35618
#define IDS_COMPOSE_FRE_TITLE 35619
#define IDS_COMPOSE_FRE_MAIN_TOP 35620
#define IDS_COMPOSE_FRE_MAIN_MID 35621
#define IDS_COMPOSE_FRE_MAIN_MID_ENTERPRISE 35622
#define IDS_COMPOSE_FRE_OK_BUTTON 35623
#define IDS_COMPOSE_FRE_MSBB_TITLE 35624
#define IDS_COMPOSE_FRE_MSBB_MAIN 35625
#define IDS_COMPOSE_FRE_MSBB_SETTINGS_BUTTON 35626
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT 35627
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT_SCREENREADER 35628
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_CLOSE_BUTTON_LABEL_TEXT 35629
#define IDS_COMPOSE_DIALOG_TITLE 35630
#define IDS_COMPOSE_INPUT_PLACEHOLDER_TITLE 35631
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_1 35632
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_2 35633
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_3 35634
#define IDS_COMPOSE_INPUT_FOOTER 35635
#define IDS_COMPOSE_INPUT_FOOTER_ENTERPRISE 35636
#define IDS_COMPOSE_INPUT_MODE_POLISH 35637
#define IDS_COMPOSE_INPUT_MODE_ELABORATE 35638
#define IDS_COMPOSE_INPUT_MODE_FORMALIZE 35639
#define IDS_COMPOSE_SUBMIT_BUTTON 35640
#define IDS_COMPOSE_EDIT_UPDATE_BUTTON 35641
#define IDS_COMPOSE_EDIT 35642
#define IDS_COMPOSE_MODIFIERS_MENU_TITLE 35643
#define IDS_COMPOSE_MODIFIERS_MENU_LABEL 35644
#define IDS_COMPOSE_MENU_RETRY_OPTION 35645
#define IDS_COMPOSE_MENU_LENGTH_TITLE 35646
#define IDS_COMPOSE_MENU_SHORTER_OPTION 35647
#define IDS_COMPOSE_MENU_LONGER_OPTION 35648
#define IDS_COMPOSE_MENU_TONE_TITLE 35649
#define IDS_COMPOSE_MENU_CASUAL_OPTION 35650
#define IDS_COMPOSE_MENU_FORMAL_OPTION 35651
#define IDS_COMPOSE_UNDO_BUTTON_TEXT 35652
#define IDS_COMPOSE_UNDO_LABEL 35653
#define IDS_COMPOSE_REDO_BUTTON_TEXT 35654
#define IDS_COMPOSE_REDO_LABEL 35655
#define IDS_COMPOSE_RESUBMIT 35656
#define IDS_COMPOSE_INSERT_BUTTON 35657
#define IDS_COMPOSE_REPLACE_BUTTON 35658
#define IDS_COMPOSE_THUMBS_DOWN 35659
#define IDS_COMPOSE_THUMBS_UP 35660
#define IDS_COMPOSE_RESULT_TEXT_LABEL 35661
#define IDS_COMPOSE_RESULT_LOADING_A11Y_MESSAGE 35662
#define IDS_COMPOSE_RESULT_UPDATED_A11Y_MESSAGE 35663
#define IDS_COMPOSE_UNDO_RESULT_A11Y_MESSAGE 35664
#define IDS_COMPOSE_REDO_RESULT_A11Y_MESSAGE 35665
#define IDS_COMPOSE_ERROR_TOO_SHORT 35666
#define IDS_COMPOSE_ERROR_TOO_LONG 35667
#define IDS_COMPOSE_ERROR_TRY_AGAIN 35668
#define IDS_COMPOSE_ERROR_TRY_AGAIN_LATER 35669
#define IDS_COMPOSE_ERROR_FILTERED 35670
#define IDS_COMPOSE_ERROR_FILTERED_BACK_BUTTON 35671
#define IDS_COMPOSE_ERROR_UNSUPPORTED_LANGUAGE 35672
#define IDS_COMPOSE_ERROR_PERMISSION_DENIED 35673
#define IDS_COMPOSE_ERROR_REQUEST_THROTTLED 35674
#define IDS_COMPOSE_ERROR_OFFLINE 35675
#define IDS_COMPOSE_FOOTER_FISHFOOD 35676
#define IDS_COMPOSE_EXPERIMENTAL_DISCLAIMER_FOOTER 35677
#define IDS_COMPOSE_REFINEMENTS_EXPERIMENTAL_DISCLAIMER_FOOTER 35678
#define IDS_COMPOSE_FOOTER_FISHFOOD_ON_DEVICE_USED 35679
#define IDS_COMPOSE_FEEDBACK_PLACEHOLDER 35680
#define IDS_CRASH_TITLE 35681
#define IDS_CRASH_CRASH_COUNT_BANNER_FORMAT 35682
#define IDS_CRASH_SHOW_DEVELOPER_DETAILS 35683
#define IDS_CRASH_CAPTURE_TIME_FORMAT 35684
#define IDS_CRASH_REPORT_STATUS 35685
#define IDS_CRASH_REPORT_STATUS_NOT_UPLOADED 35686
#define IDS_CRASH_REPORT_STATUS_PENDING 35687
#define IDS_CRASH_REPORT_STATUS_PENDING_USER_REQUESTED 35688
#define IDS_CRASH_REPORT_STATUS_UPLOADED 35689
#define IDS_CRASH_REPORT_UPLOADED_ID 35690
#define IDS_CRASH_REPORT_UPLOADED_TIME 35691
#define IDS_CRASH_REPORT_LOCAL_ID 35692
#define IDS_CRASH_REPORT_FILE_SIZE 35693
#define IDS_CRASH_BUG_LINK_LABEL 35694
#define IDS_CRASH_NO_CRASHES_MESSAGE 35695
#define IDS_CRASH_DISABLED_HEADER 35696
#define IDS_CRASH_UPLOAD_MESSAGE 35697
#define IDS_CRASH_UPLOAD_NOW_LINK_TEXT 35698
#define IDS_HTTP_POST_WARNING_TITLE 35699
#define IDS_HTTP_POST_WARNING 35700
#define IDS_HTTP_POST_WARNING_RESEND 35701
#define IDS_DOM_DISTILLER_JAVASCRIPT_DISABLED_CONTENT 35702
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_URL 35703
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD 35704
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD_FAILED 35705
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL 35706
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL_FAILED 35707
#define IDS_DOM_DISTILLER_WEBUI_REFRESH 35708
#define IDS_DOM_DISTILLER_WEBUI_FETCHING_ENTRIES 35709
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_TITLE 35710
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_CONTENT 35711
#define IDS_DOM_DISTILLER_VIEWER_LOADING_TITLE 35712
#define IDS_DOM_DISTILLER_VIEWER_CUSTOMIZE_APPEARANCE 35713
#define IDS_DOM_DISTILLER_VIEWER_FONT_STYLE 35714
#define IDS_DOM_DISTILLER_VIEWER_SANS_SERIF_FONT 35715
#define IDS_DOM_DISTILLER_VIEWER_SERIF_FONT 35716
#define IDS_DOM_DISTILLER_VIEWER_MONOSPACE_FONT 35717
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR 35718
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_LIGHT 35719
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_SEPIA 35720
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_DARK 35721
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE 35722
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_SMALL 35723
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_LARGE 35724
#define IDS_DOM_DISTILLER_VIEWER_CLOSE 35725
#define IDS_DOM_DISTILLER_VIEWER_NO_DATA_CONTENT 35726
#define IDS_DOM_DISTILLER_WEBUI_TITLE 35727
#define IDS_DOM_DISTILLER_VIEWER_TITLE_SUFFIX 35728
#define IDS_ENTERPRISE_COPY_PREVENTION_MISSING_LIST_ERROR 35729
#define IDS_ENTERPRISE_COPY_PREVENTION_DISABLE_CONTAINS_WILDCARD_ERROR 35730
#define IDS_ENTERPRISE_COPY_PREVENTION_WARNING_MESSAGE 35731
#define IDS_ENTERPRISE_DATA_CONTROLS_COPY_PREVENTION_WARNING_MESSAGE 35732
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_BLOCK_TITLE 35733
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_WARN_TITLE 35734
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_BLOCK_TITLE 35735
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_WARN_TITLE 35736
#define IDS_DATA_CONTROLS_CLIPBOARD_DRAG_BLOCK_TITLE 35737
#define IDS_DATA_CONTROLS_CLIPBOARD_SHARE_WARN_TITLE 35738
#define IDS_DATA_CONTROLS_CLIPBOARD_ACTION_WARN_TITLE 35739
#define IDS_DATA_CONTROLS_BLOCKED_LABEL 35740
#define IDS_DATA_CONTROLS_WARNED_LABEL 35741
#define IDS_DATA_CONTROLS_WARNED_LABEL_WITH_DOMAIN 35742
#define IDS_DATA_CONTROLS_PASTE_WARN_CONTINUE_BUTTON 35743
#define IDS_DATA_CONTROLS_COPY_WARN_CONTINUE_BUTTON 35744
#define IDS_DATA_CONTROLS_SHARE_WARN_CONTINUE_BUTTON 35745
#define IDS_DATA_CONTROLS_PASTE_WARN_CANCEL_BUTTON 35746
#define IDS_DATA_CONTROLS_COPY_WARN_CANCEL_BUTTON 35747
#define IDS_DATA_CONTROLS_SHARE_WARN_CANCEL_BUTTON 35748
#define IDS_DATA_CONTROLS_BLOCKED_LABEL_WITH_DOMAIN 35749
#define IDS_ERRORPAGE_NET_BUTTON_DETAILS 35750
#define IDS_ERRORPAGE_NET_BUTTON_HIDE_DETAILS 35751
#define IDS_ERRORPAGES_BUTTON_RELOAD 35752
#define IDS_ERRORPAGES_BUTTON_SHOW_SAVED_COPY 35753
#define IDS_ERRORPAGE_FUN_DISABLED 35754
#define IDS_ERRORPAGES_SUGGESTION_RELOAD_REPOST_SUMMARY 35759
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_HEADER 35760
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_BODY 35761
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_HEADER 35762
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_BODY 35763
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_HEADER 35764
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_BODY 35765
#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_HEADER 35766
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_BODY 35767
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_HEADER 35768
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_BODY 35769
#define IDS_ERRORPAGES_SUGGESTION_CAPTIVE_PORTAL_SIGNIN 35770
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_HEADER 35772
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_BODY 35773
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_HEADER 35774
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_BODY 35775
#define IDS_ERRORPAGES_SUGGESTION_NAVIGATE_TO_ORIGIN 35776
#define IDS_ERRORPAGES_HEADING_NOT_AVAILABLE 35777
#define IDS_ERRORPAGES_HEADING_NETWORK_ACCESS_DENIED 35778
#define IDS_ERRORPAGES_HEADING_INTERNET_DISCONNECTED 35779
#define IDS_ERRORPAGES_HEADING_YOU_ARE_OFFLINE 35780
#define IDS_ERRORPAGES_MESSAGE_IWA_INVALID_WEB_BUNDLE 35781
#define IDS_ERRORPAGES_MESSAGE_IWA_CONNECTION_REFUSED 35782
#define IDS_ERRORPAGES_MESSAGE_IWA_INSTALLED_IN_DEV_MODE 35783
#define IDS_ERRORPAGES_MESSAGE_IWA_PAGE_NOT_FOUND 35784
#define IDS_ERRORPAGES_HEADING_CACHE_READ_FAILURE 35785
#define IDS_ERRORPAGES_HEADING_CONNECTION_INTERRUPTED 35786
#define IDS_ERRORPAGES_HEADING_NOT_FOUND 35787
#define IDS_ERRORPAGES_HEADING_FILE_NOT_FOUND 35788
#define IDS_ERRORPAGES_HEADING_BLOCKED 35789
#define IDS_ERRORPAGES_HEADING_BLOCKED_BY_ADMINISTRATOR 35790
#define IDS_ERRORPAGES_SUMMARY_NOT_AVAILABLE 35791
#define IDS_ERRORPAGES_SUMMARY_TIMED_OUT 35792
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_RESET 35793
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_CLOSED 35794
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_FAILED 35795
#define IDS_ERRORPAGES_SUMMARY_NETWORK_CHANGED 35796
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_REFUSED 35797
#define IDS_ERRORPAGES_SUMMARY_NAME_NOT_RESOLVED 35798
#define IDS_ERRORPAGES_SUMMARY_ICANN_NAME_COLLISION 35799
#define IDS_ERRORPAGES_SUMMARY_ADDRESS_UNREACHABLE 35800
#define IDS_ERRORPAGES_SUMMARY_FILE_ACCESS_DENIED 35801
#define IDS_ERRORPAGES_SUMMARY_NETWORK_ACCESS_DENIED 35802
#define IDS_ERRORPAGES_SUMMARY_PROXY_CONNECTION_FAILED 35803
#define IDS_ERRORPAGES_SUMMARY_CACHE_READ_FAILURE 35804
#define IDS_ERRORPAGES_SUMMARY_NETWORK_IO_SUSPENDED 35805
#define IDS_ERRORPAGES_SUMMARY_NOT_FOUND 35806
#define IDS_ERRORPAGES_SUMMARY_FILE_NOT_FOUND 35807
#define IDS_ERRORPAGES_SUMMARY_TOO_MANY_REDIRECTS 35808
#define IDS_ERRORPAGES_SUMMARY_EMPTY_RESPONSE 35809
#define IDS_ERRORPAGES_SUMMARY_INVALID_RESPONSE 35810
#define IDS_ERRORPAGES_SUMMARY_DNS_PROBE_RUNNING 35811
#define IDS_ERRORPAGES_HEADING_ACCESS_DENIED 35812
#define IDS_ERRORPAGES_HEADING_FILE_ACCESS_DENIED 35813
#define IDS_ERRORPAGES_SUMMARY_FORBIDDEN 35814
#define IDS_ERRORPAGES_SUMMARY_GONE 35815
#define IDS_ERRORPAGES_HEADING_PAGE_NOT_WORKING 35816
#define IDS_ERRORPAGES_SUMMARY_CONTACT_SITE_OWNER 35817
#define IDS_ERRORPAGES_SUMMARY_WEBSITE_CANNOT_HANDLE_REQUEST 35818
#define IDS_ERRORPAGES_SUMMARY_GATEWAY_TIMEOUT 35819
#define IDS_ERRORPAGES_SUMMARY_SSL_SECURITY_ERROR 35820
#define IDS_ERRORPAGES_SUMMARY_SSL_VERSION_OR_CIPHER_MISMATCH 35821
#define IDS_ERRORPAGES_HEADING_INSECURE_CONNECTION 35822
#define IDS_ERRORPAGES_SUMMARY_BAD_SSL_CLIENT_AUTH_CERT 35823
#define IDS_ERRORPAGES_SUMMARY_SSL_CLIENT_AUTH_SIGNATURE_FAILED 35824
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_EXTENSION 35825
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_ADMINISTRATOR 35826
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_SECURITY 35827
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_LOCAL_NETWORK_ACCESS_CHECKS 35828
#define IDS_ERRORPAGES_HTTP_POST_WARNING 35829
#define IDS_ERRORPAGES_SUGGESTION_LIST_HEADER 35830
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_SUMMARY 35831
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_DNS_SUMMARY 35833
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SECURE_DNS_SUMMARY 35834
#define IDS_ERRORPAGES_SUGGESTION_CHECK_FIREWALL_ANTIVIRUS_SUMMARY 35835
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SUMMARY 35836
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_ADDRESS_SUMMARY 35837
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY 35838
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY_STANDALONE 35839
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY 35840
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY_STANDALONE 35841
#define IDS_ERRORPAGES_SUGGESTION_DELETE_COOKIES_SUMMARY 35842
#define IDS_ERRORPAGES_SUGGESTION_CHECK_HARDWARE_SUMMARY 35846
#define IDS_ERRORPAGES_SUGGESTION_CHECK_WIFI_SUMMARY 35847
#define IDS_ERRORPAGES_SUGGESTION_DISABLE_EXTENSION_SUMMARY 35848
#define IDS_ERRORPAGES_CHECK_TYPO_SUMMARY 35849
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS 35853
#define IDS_ERRORPAGE_DINO_GAME_DESCRIPTION 35854
#define IDS_ERRORPAGE_DINO_ARIA_LABEL 35855
#define IDS_ERRORPAGE_DINO_GAME_START 35856
#define IDS_ERRORPAGE_DINO_GAME_OVER 35857
#define IDS_ERRORPAGE_DINO_HIGH_SCORE 35858
#define IDS_ERRORPAGE_DINO_JUMP 35859
#define IDS_ERRORPAGE_DINO_SLOW_SPEED_TOGGLE 35860
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_TOUCH 35861
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_KEYBOARD 35862
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_HYBRID 35863
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_TOUCH 35864
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_KEYBOARD 35865
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_HYBRID 35866
#define IDS_ERRORPAGES_HEADING_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 35867
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 35868
#define IDS_FIND_IN_PAGE_ACCESSIBLE_TITLE 35869
#define IDS_FIND_IN_PAGE_COUNT 35870
#define IDS_ACCESSIBLE_FIND_IN_PAGE_COUNT 35871
#define IDS_ACCESSIBLE_FIND_IN_PAGE_NO_RESULTS 35872
#define IDS_FIND_IN_PAGE_PREVIOUS_TOOLTIP 35873
#define IDS_FIND_IN_PAGE_NEXT_TOOLTIP 35874
#define IDS_FIND_IN_PAGE_CLOSE_TOOLTIP 35875
#define IDS_FLAGS_UI_SEARCH_PLACEHOLDER 35876
#define IDS_FLAGS_UI_SEARCH_LABEL 35877
#define IDS_FLAGS_UI_TITLE 35878
#define IDS_FLAGS_UI_PAGE_RESET 35879
#define IDS_FLAGS_UI_PAGE_WARNING 35880
#define IDS_FLAGS_UI_PAGE_WARNING_EXPLANATION 35881
#define IDS_FLAGS_UI_OWNER_WARNING 35882
#define IDS_FLAGS_UI_AVAILABLE_FEATURE 35883
#define IDS_FLAGS_UI_UNAVAILABLE_FEATURE 35884
#define IDS_FLAGS_UI_ENABLED_FEATURE 35885
#define IDS_FLAGS_UI_DISABLED_FEATURE 35886
#define IDS_FLAGS_UI_NO_RESULTS 35887
#define IDS_FLAGS_UI_NOT_AVAILABLE_ON_PLATFORM 35888
#define IDS_FLAGS_UI_RELAUNCH 35889
#define IDS_FLAGS_UI_CLEAR_SEARCH 35890
#define IDS_FLAGS_UI_RESET_ACKNOWLEDGED 35891
#define IDS_FLAGS_UI_EXPERIMENT_ENABLED 35892
#define IDS_FLAGS_UI_SEARCH_RESULTS_SINGULAR 35893
#define IDS_FLAGS_UI_SEARCH_RESULTS_PLURAL 35894
#define IDS_DEPRECATED_FEATURES_SEARCH_PLACEHOLDER 35895
#define IDS_DEPRECATED_FEATURES_TITLE 35896
#define IDS_DEPRECATED_FEATURES_HEADING 35897
#define IDS_DEPRECATED_FEATURES_PAGE_WARNING_EXPLANATION 35898
#define IDS_DEPRECATED_FEATURES_NO_RESULTS 35899
#define IDS_EXIT_FULLSCREEN_MODE 35900
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN 35901
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN_WITH_ORIGIN 35902
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN 35903
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_WITH_ORIGIN 35904
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_TWO_KEYS 35905
#define IDS_PRESS_TO_EXIT_MOUSELOCK 35906
#define IDS_PRESS_TO_EXIT_MOUSELOCK_WITH_ORIGIN 35907
#define IDS_PRESS_TO_EXIT_MOUSELOCK_TWO_KEYS 35908
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS 35909
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS 35910
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS_AND_EXIT 35911
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS_AND_EXIT 35912
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN_WITH_ORIGIN 35913
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN 35914
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK_WITH_ORIGIN 35915
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK 35916
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS 35917
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS_AND_EXIT 35918
#define IDS_GLOBAL_MEDIA_CONTROLS_BACK_TO_TAB 35919
#define IDS_GLOBAL_MEDIA_CONTROLS_DISMISS_ICON_TOOLTIP_TEXT 35920
#define IDS_GLOBAL_MEDIA_CONTROLS_CAST_HEADER_TEXT 35921
#define IDS_GLOBAL_MEDIA_CONTROLS_CLOSE_DEVICE_LIST_TEXT 35922
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_SOURCE_TEXT 35923
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_DEVICE_TEXT 35924
#define IDS_GLOBAL_MEDIA_CONTROLS_MEDIA_LIVE_TEXT 35925
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_DETAILS 35926
#define IDS_HEAVY_AD_INTERVENTION_HEADING 35927
#define IDS_HEAVY_AD_INTERVENTION_SUMMARY 35928
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_RELOAD 35929
#define IDS_HISTORY_CLUSTERS_ACTION_MENU_DESCRIPTION 35930
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 35931
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_WARNING 35932
#define IDS_HISTORY_CLUSTERS_BY_GROUP_TAB_LABEL 35933
#define IDS_HISTORY_CLUSTERS_BY_DATE_TAB_LABEL 35934
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_SEARCH_TERMS 35935
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_MULTIPLE_HOSTNAMES 35936
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_OTHER_MATCHING_VISITS 35937
#define IDS_HISTORY_CLUSTERS_HIDE_PAGE 35938
#define IDS_HISTORY_CLUSTERS_HIDE_VISITS 35939
#define IDS_HISTORY_CLUSTERS_LOAD_MORE_BUTTON_LABEL 35940
#define IDS_HISTORY_CLUSTERS_NO_RESULTS 35941
#define IDS_HISTORY_CLUSTERS_NO_SEARCH_RESULTS 35942
#define IDS_HISTORY_CLUSTERS_SHOW_SIDE_PANEL 35943
#define IDS_HISTORY_CLUSTERS_OPEN_ALL_IN_TABGROUP 35944
#define IDS_HISTORY_CLUSTERS_OPEN_INCOGNITO 35945
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_TAB 35946
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_WINDOW 35947
#define IDS_HISTORY_CLUSTERS_RELATED_SEARCHES_HEADER 35948
#define IDS_HISTORY_CLUSTERS_REMOVE_ALL_ITEMS 35949
#define IDS_HISTORY_CLUSTERS_REMOVE_PAGE 35950
#define IDS_HISTORY_CLUSTERS_REMOVE_ITEM_TOAST 35951
#define IDS_HISTORY_CLUSTERS_REMOVE_SELECTED_ITEMS 35952
#define IDS_HISTORY_CLUSTERS_SAVED_IN_TABGROUP_LABEL 35953
#define IDS_HISTORY_CLUSTERS_CUT 35954
#define IDS_HISTORY_CLUSTERS_COPY 35955
#define IDS_HISTORY_CLUSTERS_PASTE 35956
#define IDS_HISTORY_CLUSTERS_COPY_LINK 35957
#define IDS_HISTORY_CLUSTERS_SHOW_LESS_BUTTON_LABEL 35958
#define IDS_HISTORY_CLUSTERS_SHOW_MORE_BUTTON_LABEL 35959
#define IDS_HISTORY_ACTION_MENU_DESCRIPTION 35960
#define IDS_HISTORY_ACTOR_TASK_TOOLTIP 35961
#define IDS_HISTORY_ARIA_ROLE_DESCRIPTION 35962
#define IDS_HISTORY_CANCEL_EDITING_BUTTON 35963
#define IDS_HISTORY_DATE_WITH_RELATIVE_TIME 35964
#define IDS_HISTORY_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 35965
#define IDS_HISTORY_DELETE_PRIOR_VISITS_WARNING 35966
#define IDS_HISTORY_DELETE_SELECTED_ENTRIES_BUTTON 35967
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_DELETE 35968
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_LABEL 35969
#define IDS_HISTORY_ENTRY_BOOKMARKED 35970
#define IDS_HISTORY_ENTRY_SUMMARY 35971
#define IDS_HISTORY_FOUND_SEARCH_RESULTS 35972
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_ONLY 35973
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GAA_ONLY 35974
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_AND_GAA 35975
#define IDS_HISTORY_LOADING 35976
#define IDS_HISTORY_MORE_FROM_SITE 35977
#define IDS_HISTORY_NO_RESULTS 35978
#define IDS_HISTORY_NO_SEARCH_RESULTS 35979
#define IDS_HISTORY_OPEN_CLEAR_BROWSING_DATA_DIALOG 35980
#define IDS_HISTORY_OTHER_SESSIONS_COLLAPSE_SESSION 35981
#define IDS_HISTORY_OTHER_SESSIONS_EXPAND_SESSION 35982
#define IDS_HISTORY_OTHER_SESSIONS_HIDE_FOR_NOW 35983
#define IDS_HISTORY_OTHER_SESSIONS_OPEN_ALL 35984
#define IDS_HISTORY_REMOVE_BOOKMARK 35985
#define IDS_HISTORY_REMOVE_PAGE 35986
#define IDS_HISTORY_REMOVE_PAGE_SUCCESS 35987
#define IDS_HISTORY_REMOVE_SELECTED_ITEMS 35988
#define IDS_HISTORY_SEARCH_BUTTON 35989
#define IDS_HISTORY_SEARCH_RESULT 35990
#define IDS_HISTORY_SEARCH_RESULTS 35991
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULT 35992
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULTS 35993
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULT 35994
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULTS 35995
#define IDS_HISTORY_SHOW_HISTORY 35996
#define IDS_HISTORY_SHOW_SIDE_PANEL 35997
#define IDS_HISTORY_SHOWFULLHISTORY_LINK 35998
#define IDS_HISTORY_SOURCE_FILTER_CHIPS_ARIA_LABEL 35999
#define IDS_HISTORY_SOURCE_FILTER_CHIP_ACTOR 36000
#define IDS_HISTORY_SOURCE_FILTER_CHIP_USER 36001
#define IDS_HISTORY_CLOSE_AND_RETURN_TO_PREFIX 36002
#define IDS_HISTORY_START_EDITING_BUTTON 36003
#define IDS_HISTORY_TITLE 36004
#define IDS_HISTORY_UNKNOWN_DEVICE 36005
#define IDS_HISTORY_SYNC_PROMO_TITLE 36006
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_OUT 36007
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING 36008
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING_SYNC_HISTORY_ON 36009
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_IN 36010
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER 36011
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER_LOGGING_OFF 36012
#define IDS_HISTORY_EMBEDDINGS_PROMO_LABEL 36013
#define IDS_HISTORY_EMBEDDINGS_PROMO_CLOSE 36014
#define IDS_HISTORY_EMBEDDINGS_PROMO_HEADING 36015
#define IDS_HISTORY_EMBEDDINGS_PROMO_BODY 36016
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_HEADING 36017
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_BODY 36018
#define IDS_HISTORY_EMBEDDIGNS_PROMO_SETTINGS_LINK_TEXT 36019
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_ARIA_LABEL 36020
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_DATE 36021
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_GROUP 36022
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1 36023
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2 36024
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3 36025
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1_ARIA_LABEL 36026
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2_ARIA_LABEL 36027
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3_ARIA_LABEL 36028
#define IDS_HISTORY_EMBEDDINGS_HEADING 36029
#define IDS_HISTORY_EMBEDDINGS_HEADING_LOADING 36030
#define IDS_HISTORY_EMBEDDINGS_WITH_ANSWERS_RESULTS_HEADING 36031
#define IDS_HISTORY_EMBEDDINGS_FOOTER 36032
#define IDS_HISTORY_EMBEDDINGS_FEEDBACK_PLACEHOLDER 36033
#define IDS_HISTORY_EMBEDDINGS_IPH_BODY 36034
#define IDS_HISTORY_EMBEDDINGS_IPH_ACTION 36035
#define IDS_HISTORY_EMBEDDINGS_SEARCH_PROMPT 36036
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_1 36037
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_2 36038
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_3 36039
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_4 36040
#define IDS_HISTORY_EMBEDDINGS_ANSWER_HEADING 36041
#define IDS_HISTORY_EMBEDDINGS_ANSWER_LOADING_HEADING 36042
#define IDS_HISTORY_EMBEDDINGS_ANSWER_SOURCE_VISIT_DATE_LABEL 36043
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_UNANSWERABLE 36044
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_MODEL_UNAVAILABLE 36045
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_TRY_AGAIN 36046
#define IDS_COMPARE_HISTORY_EMPTY 36047
#define IDS_COMPARE_HISTORY_HEADER 36048
#define IDS_COMPARE_HISTORY_INFO 36049
#define IDS_COMPARE_HISTORY_MENU_ARIA_LABEL 36050
#define IDS_COMPARE_HISTORY_MENU_ITEM 36051
#define IDS_COMPARE_HISTORY_REMOVE 36052
#define IDS_COMPARE_HISTORY_ROW 36053
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE 36054
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_IFRAME 36055
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL 36056
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL_IFRAME 36057
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_EXTENSION 36058
#define IDS_JAVASCRIPT_MESSAGEBOX_SUPPRESS_OPTION 36059
#define IDS_BEFOREUNLOAD_MESSAGEBOX_TITLE 36060
#define IDS_BEFOREUNLOAD_APP_MESSAGEBOX_TITLE 36061
#define IDS_BEFOREUNLOAD_MESSAGEBOX_OK_BUTTON_LABEL 36062
#define IDS_BEFOREUNLOAD_MESSAGEBOX_MESSAGE 36063
#define IDS_BEFORERELOAD_MESSAGEBOX_TITLE 36064
#define IDS_BEFORERELOAD_APP_MESSAGEBOX_TITLE 36065
#define IDS_BEFORERELOAD_MESSAGEBOX_OK_BUTTON_LABEL 36066
#define IDS_LIVE_CAPTION_BUBBLE_TITLE 36067
#define IDS_LIVE_CAPTION_BUBBLE_CLOSE 36068
#define IDS_LIVE_CAPTION_BUBBLE_EXPAND 36069
#define IDS_LIVE_CAPTION_BUBBLE_COLLAPSE 36070
#define IDS_LIVE_CAPTION_BUBBLE_BACK_TO_TAB 36071
#define IDS_LIVE_CAPTION_BUBBLE_ERROR 36072
#define IDS_LIVE_CAPTION_BUBBLE_CONTENT_SETTINGS 36073
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR 36074
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR_CHECKBOX 36075
#define IDS_LIVE_CAPTION_BUBBLE_APPEAR_SCREENREADER_ANNOUNCEMENT 36076
#define IDS_LIVE_CAPTION_CAPTION_LANGUAGE_AUTODETECTED 36077
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_SCROLLING 36078
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_LOCKED 36079
#define IDS_LIVE_CAPTION_DOWNLOAD_PROGRESS 36080
#define IDS_LIVE_CAPTION_TRANSLATION_DOWNLOADING_LANGUAGE_PACKAGES_WITH_PROGRESS 36081
#define IDS_LIVE_CAPTION_INSTALLING 36082
#define IDS_LIVE_CAPTION_INSTALLING_LANGUAGE_PACKAGES 36083
#define IDS_LIVE_CAPTION_LANGUAGE_DOWNLOAD_FAILED 36084
#define IDS_LIVE_CAPTION_TRANSLATING 36085
#define IDS_LOGIN_DIALOG_TITLE 36086
#define IDS_LOGIN_DIALOG_OK_BUTTON_LABEL 36087
#define IDS_LOGIN_DIALOG_AUTHORITY 36088
#define IDS_LOGIN_DIALOG_PROXY_AUTHORITY 36089
#define IDS_LOGIN_DIALOG_NOT_PRIVATE 36090
#define IDS_LOGIN_DIALOG_USERNAME_FIELD 36091
#define IDS_LOGIN_DIALOG_PASSWORD_FIELD 36092
#define IDS_MANAGEMENT_TITLE 36093
#define IDS_MANAGEMENT_TOOLBAR_TITLE 36094
#define IDS_MANAGEMENT_SEARCH_PROMPT 36095
#define IDS_MANAGEMENT_SUBTITLE_MANAGED_BY 36097
#define IDS_MANAGEMENT_NOT_MANAGED_SUBTITLE 36098
#define IDS_MANAGEMENT_SUBTITLE 36099
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY 36100
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY 36101
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_SAME_MANAGED_BY 36102
#define IDS_MANAGEMENT_SUBTITLE_PROFILE_MANAGED_BY 36103
#define IDS_MANAGEMENT_BROWSER_NOTICE 36104
#define IDS_MANAGEMENT_NOT_MANAGED_NOTICE 36105
#define IDS_MANAGEMENT_PROFILE_NOTICE 36106
#define IDS_MANAGEMENT_LEARN_MORE_ACCCESSIBILITY_TEXT 36107
#define IDS_MANAGEMENT_EXTENSION_REPORTING 36163
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED 36164
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED_BY 36165
#define IDS_MANAGEMENT_EXTENSIONS_NAME 36166
#define IDS_MANAGEMENT_EXTENSIONS_PERMISSIONS 36167
#define IDS_MANAGEMENT_APPLICATION_REPORTING 36168
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED 36169
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED_BY 36170
#define IDS_MANAGEMENT_APPLICATIONS_NAME 36171
#define IDS_MANAGEMENT_APPLICATIONS_PERMISSIONS 36172
#define IDS_MANAGEMENT_APPLICATIONS_RUN_ON_OS_LOGIN 36173
#define IDS_MANAGEMENT_MANAGED_WEBSITES 36174
#define IDS_MANAGEMENT_MANAGED_WEBSITES_EXPLANATION 36175
#define IDS_MANAGEMENT_MANAGED_WEBSITES_BY_EXPLANATION 36176
#define IDS_MANAGEMENT_BROWSER_REPORTING_EXPLANATION 36177
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME 36178
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME_ADDRESS 36179
#define IDS_MANAGEMENT_EXTENSION_REPORT_USERNAME 36180
#define IDS_MANAGEMENT_EXTENSION_REPORT_VERSION 36181
#define IDS_MANAGEMENT_EXTENSION_REPORT_EXTENSIONS_PLUGINS 36182
#define IDS_MANAGEMENT_EXTENSION_REPORT_USER_BROWSING_DATA 36183
#define IDS_MANAGEMENT_EXTENSION_REPORT_PERF_CRASH 36184
#define IDS_MANAGEMENT_EXTENSION_REPORT_VISITED_URL 36185
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT 36186
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT_NO_LINK 36187
#define IDS_MANAGEMENT_THREAT_PROTECTION_MORE 36188
#define IDS_MANAGEMENT_FILE_ATTACHED_EVENT 36189
#define IDS_MANAGEMENT_TEXT_ENTERED_EVENT 36190
#define IDS_MANAGEMENT_PAGE_PRINTED_EVENT 36191
#define IDS_MANAGEMENT_FILE_TRANSFER_EVENT 36192
#define IDS_MANAGEMENT_SCREEN_CAPTURE_EVENT 36193
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_EVENT 36194
#define IDS_MANAGEMENT_FILE_ATTACHED_VISIBLE_DATA 36195
#define IDS_MANAGEMENT_TEXT_ENTERED_VISIBLE_DATA 36196
#define IDS_MANAGEMENT_PAGE_PRINTED_VISIBLE_DATA 36197
#define IDS_MANAGEMENT_FILE_TRANSFER_VISIBLE_DATA 36198
#define IDS_MANAGEMENT_SCREEN_CAPTURE_DATA 36199
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_VISIBLE_DATA 36200
#define IDS_MANAGEMENT_BROWSER_REPORTING 36201
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXPLANATION 36209
#define IDS_MANAGEMENT_PROFILE_REPORTING_OVERVIEW 36210
#define IDS_MANAGEMENT_PROFILE_REPORTING_USERNAME 36211
#define IDS_MANAGEMENT_PROFILE_REPORTING_BROWSER 36212
#define IDS_MANAGEMENT_PROFILE_REPORTING_POLICY 36213
#define IDS_MANAGEMENT_PROFILE_REPORTING_LEARN_MORE 36214
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXTENSION 36215
#define IDS_MANAGEMENT_DEVICE_SIGNALS_DISCLOSURE 36220
#define IDS_MANAGEMENT_THREAT_PROTECTION 36221
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION 36222
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION_BY 36223
#define IDS_MANAGEMENT_CONNECTORS_EVENT 36224
#define IDS_MANAGEMENT_CONNECTORS_VISIBLE_DATA 36225
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_EVENT 36226
#define IDS_MANAGEMENT_FILE_DOWNLOADED_EVENT 36227
#define IDS_MANAGEMENT_FILE_DOWNLOADED_VISIBLE_DATA 36228
#define IDS_MANAGEMENT_PAGE_VISITED_EVENT 36229
#define IDS_MANAGEMENT_PAGE_VISITED_VISIBLE_DATA 36230
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_VISIBLE_DATA 36231
#define IDS_MANAGEMENT_DIALOG_BROWSING_DATA_MANAGEMENT 36232
#define IDS_MANAGEMENT_DIALOG_DEVICE_SIGNALS 36233
#define IDS_MANAGEMENT_DIALOG_PROFILE_MANAGED_BY 36234
#define IDS_MANAGEMENT_DIALOG_THINGS_TO_CONSIDER_SUBTITLE 36235
#define IDS_MANAGED_PROFILE_INTERSTITIAL_TAB_TITLE 36236
#define IDS_MANAGEMENT_BANNER_PROMOTION_TITLE 36237
#define IDS_MANAGEMENT_BANNER_PROMOTION_DESC 36238
#define IDS_MANAGEMENT_BANNER_PROMOTION_BTN 36239
#define IDS_MANAGEMENT_BANNER_ARIA_LABEL 36240
#define IDS_MANAGEMENT_BANNER_NEW_TAB_ARIA_DESCRIPTION 36241
#define IDS_MANAGEMENT_BANNER_DISMISS_ARIA_LABEL 36242
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PREVIOUS_TRACK 36243
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_BACKWARD 36244
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_REPLAY_10 36245
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PLAY 36246
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PAUSE 36247
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_FORWARD_10 36248
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_FORWARD 36249
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_NEXT_TRACK 36250
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_ENTER_PIP 36251
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_EXIT_PIP 36252
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_MUTE 36253
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_UNMUTE 36254
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SHOW_DEVICE_LIST 36255
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_HIDE_DEVICE_LIST 36256
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_STOP_CASTING 36257
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_TIME_SCRUBBER 36258
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACCESSIBLE_NAME 36259
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_LABEL 36260
#define IDS_DEFAULT_TAB_TITLE 36261
#define IDS_DOWNLOAD_TAB_TITLE 36262
#define IDS_SAD_TAB_TITLE 36263
#define IDS_SAD_TAB_MESSAGE 36264
#define IDS_SAD_TAB_HELP_MESSAGE 36265
#define IDS_SAD_TAB_HELP_LINK 36266
#define IDS_SAD_TAB_RELOAD_LABEL 36267
#define IDS_SAD_TAB_RELOAD_TITLE 36270
#define IDS_SAD_TAB_OOM_MESSAGE_TABS 36271
#define IDS_SAD_TAB_OOM_MESSAGE_NOTABS 36272
#define IDS_SAD_TAB_RELOAD_TRY 36273
#define IDS_SAD_TAB_RELOAD_INCOGNITO 36274
#define IDS_SAD_TAB_RELOAD_CLOSE_TABS 36275
#define IDS_SAD_TAB_RELOAD_CLOSE_NOTABS 36276
#define IDS_SAD_TAB_RELOAD_RESTART_BROWSER 36277
#define IDS_SAD_TAB_RELOAD_RESTART_DEVICE 36278
#define IDS_SAD_TAB_ERROR_CODE 36280
#define IDS_NEW_TAB_TITLE 36281
#define IDS_NEW_INCOGNITO_TAB_TITLE 36282
#define IDS_INCOGNITO_TAB_LEARN_MORE_ACCESSIBILITY_LABEL 36283
#define IDS_NEW_TAB_OTR_HEADING 36284
#define IDS_NEW_TAB_OTR_DESCRIPTION 36285
#define IDS_NEW_TAB_OTR_LEARN_MORE_LINK 36286
#define IDS_NEW_TAB_OTR_MESSAGE_WARNING 36287
#define IDS_NEW_TAB_UNDO_THUMBNAIL_REMOVE 36288
#define IDS_NEW_TAB_OTR_TITLE 36289
#define IDS_NEW_TAB_OTR_SUBTITLE 36290
#define IDS_NEW_TAB_OTR_SUBTITLE_WITH_READING_LIST 36291
#define IDS_NEW_TAB_OTR_NOT_SAVED 36292
#define IDS_NEW_TAB_OTR_VISIBLE 36293
#define IDS_NEW_TAB_OPENS_HC_ARTICLE_IN_NEW_TAB 36294
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 36295
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUGGESTION_CONTENTS 36296
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUFFIX 36297
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA 36298
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 36299
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUGGESTION_CONTENTS 36300
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUFFIX 36301
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS 36302
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 36303
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUGGESTION_CONTENTS 36304
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUFFIX 36305
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD 36306
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 36307
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 36308
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 36309
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 36310
#define IDS_OMNIBOX_PEDAL_TRANSLATE_HINT 36311
#define IDS_OMNIBOX_PEDAL_TRANSLATE_SUGGESTION_CONTENTS 36312
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE_SUFFIX 36313
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE 36314
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_HINT 36315
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_SUGGESTION_CONTENTS 36316
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME_SUFFIX 36317
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME 36318
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUGGESTION_CONTENTS 36319
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUFFIX 36320
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK 36321
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_HINT 36322
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUGGESTION_CONTENTS 36323
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUFFIX 36324
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2 36325
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_HINT 36326
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUGGESTION_CONTENTS 36327
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUFFIX 36328
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS 36329
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_HINT 36330
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_SUGGESTION_CONTENTS 36331
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES_SUFFIX 36332
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES 36333
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_HINT 36334
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUGGESTION_CONTENTS 36335
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUFFIX 36336
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES 36337
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT 36338
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS 36339
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX 36340
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC 36341
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT_UPDATED 36342
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS_UPDATED 36343
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX_UPDATED 36344
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_UPDATED 36345
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_HINT 36346
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUGGESTION_CONTENTS 36347
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUFFIX 36348
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS 36349
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_HINT 36350
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUGGESTION_CONTENTS 36351
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUFFIX 36352
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC 36353
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_HINT 36354
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUGGESTION_CONTENTS 36355
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUFFIX 36356
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET 36357
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_HINT 36358
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUGGESTION_CONTENTS 36359
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUFFIX 36360
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE 36361
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_HINT 36362
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUGGESTION_CONTENTS 36363
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUFFIX 36364
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT 36365
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_HINT 36366
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUGGESTION_CONTENTS 36367
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUFFIX 36368
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE 36369
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_HINT 36370
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUGGESTION_CONTENTS 36371
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUFFIX 36372
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE 36373
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_HINT 36374
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUGGESTION_CONTENTS 36375
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUFFIX 36376
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM 36377
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_HINT 36378
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUGGESTION_CONTENTS 36379
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUFFIX 36380
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS 36381
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_HINT 36382
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUGGESTION_CONTENTS 36383
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUFFIX 36384
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT 36385
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_HINT 36386
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUGGESTION_CONTENTS 36387
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUFFIX 36388
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD 36389
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_HINT 36390
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUGGESTION_CONTENTS 36391
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUFFIX 36392
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS 36393
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 36394
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUGGESTION_CONTENTS 36395
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUFFIX 36396
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME 36397
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_HINT 36398
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_SUGGESTION_CONTENTS 36399
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE_SUFFIX 36400
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE 36401
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_HINT 36402
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUGGESTION_CONTENTS 36403
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUFFIX 36404
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY 36405
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 36406
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUGGESTION_CONTENTS 36407
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUFFIX 36408
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS 36409
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_HINT 36410
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUGGESTION_CONTENTS 36411
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUFFIX 36412
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS 36413
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 36414
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUGGESTION_CONTENTS 36415
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUFFIX 36416
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY 36417
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_HINT 36418
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUGGESTION_CONTENTS 36419
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUFFIX 36420
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE 36421
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_HINT 36422
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUGGESTION_CONTENTS 36423
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUFFIX 36424
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY 36425
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_HINT 36426
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUGGESTION_CONTENTS 36427
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUFFIX 36428
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS 36429
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_HINT 36430
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUGGESTION_CONTENTS 36431
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUFFIX 36432
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES 36433
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_HINT 36434
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUGGESTION_CONTENTS 36435
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUFFIX 36436
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES 36437
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_HINT 36438
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUGGESTION_CONTENTS 36439
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUFFIX 36440
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY 36441
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 36442
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 36443
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 36444
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 36445
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 36446
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 36447
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 36448
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 36449
#define IDS_IOS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 36450
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 36451
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 36452
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 36453
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 36454
#define IDS_IOS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 36455
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 36456
#define IDS_IOS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_HINT 36457
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 36458
#define IDS_IOS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 36459
#define IDS_IOS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 36460
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 36461
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 36462
#define IDS_AUTOCOMPLETE_SEARCH_DESCRIPTION 36463
#define IDS_OMNIBOX_ILLS_USE_APPROXIMATE_LOCATION 36464
#define IDS_OMNIBOX_ILLS_USE_LOCATION 36465
#define IDS_OMNIBOX_ILLS_USE_PRECISE_LOCATION 36466
#define IDS_AUTOCOMPLETE_ASK_DESCRIPTION 36467
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL 36468
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT 36469
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT2 36470
#define IDS_OMNIBOX_TOOLBELT_LABEL 36471
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_HINT 36472
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUGGESTION_CONTENTS 36473
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUFFIX 36474
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION 36475
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_HINT 36476
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_SUGGESTION_CONTENTS 36477
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION_SUFFIX 36478
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION 36479
#define IDS_STARTER_PACK_HISTORY_ACTION_HINT 36480
#define IDS_STARTER_PACK_HISTORY_ACTION_SUGGESTION_CONTENTS 36481
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION_SUFFIX 36482
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION 36483
#define IDS_STARTER_PACK_TABS_ACTION_HINT 36484
#define IDS_STARTER_PACK_TABS_ACTION_SUGGESTION_CONTENTS 36485
#define IDS_ACC_STARTER_PACK_TABS_ACTION_SUFFIX 36486
#define IDS_ACC_STARTER_PACK_TABS_ACTION 36487
#define IDS_STARTER_PACK_AI_MODE_ACTION_HINT 36488
#define IDS_STARTER_PACK_AI_MODE_ACTION_SUGGESTION_CONTENTS 36489
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION_SUFFIX 36490
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION 36491
#define IDS_EMPTY_KEYWORD_VALUE 36492
#define IDS_EMPTY_STARTER_PACK_AI_MODE_VALUE 36493
#define IDS_LINK_FROM_CLIPBOARD 36494
#define IDS_TEXT_FROM_CLIPBOARD 36495
#define IDS_IMAGE_FROM_CLIPBOARD 36496
#define IDS_SECURE_VERBOSE_STATE 36497
#define IDS_NOT_SECURE_VERBOSE_STATE 36498
#define IDS_DANGEROUS_VERBOSE_STATE 36499
#define IDS_OFFLINE_VERBOSE_STATE 36500
#define IDS_OMNIBOX_EMPTY_HINT 36501
#define IDS_OMNIBOX_EMPTY_HINT_WITH_DSE_NAME 36502
#define IDS_OMNIBOX_EMPTY_ASK_HINT_WITH_DSE_NAME 36503
#define IDS_OMNIBOX_NAVATTACH_GALLERY 36504
#define IDS_OMNIBOX_NAVATTACH_FILES 36505
#define IDS_OMNIBOX_NAVATTACH_TABS 36506
#define IDS_FUSEBOX_ADD_CURRENT_TAB 36507
#define IDS_FUSEBOX_ADD_TAB 36508
#define IDS_FUSEBOX_UPLOAD_FAILED 36509
#define IDS_OMNIBOX_CREATE_IMAGE 36510
#define IDS_OMNIBOX_EMPTY_HINT_FOR_IMAGE_GENERATION 36511
#define IDS_FUSEBOX_RECENT_TABS_HEADER 36512
#define IDS_OMNIBOX_ADDITIONAL_TEXT_DASH_TEMPLATE 36514
#define IDS_OMNIBOX_TAB_SUGGEST_HINT 36515
#define IDS_OMNIBOX_HISTORY_EMBEDDING_HINT 36516
#define IDS_OMNIBOX_FILE 36517
#define IDS_OMNIBOX_READER_MODE 36518
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_BUGANIZER 36519
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_COMMA_SEPARATED_VALUES 36520
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_APPS_SCRIPT 36521
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DOCS 36522
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRAWINGS 36523
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE 36524
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE_FOLDER 36525
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_FORMS 36526
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_JAMBOARD 36527
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_PHOTOS 36528
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SITES 36529
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SHEETS 36530
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SLIDES 36531
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_JPEG 36532
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_PNG 36533
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_SVG 36534
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JIRA 36535
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JSON 36536
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MARKDOWN 36537
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_EXCEL 36538
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_POWERPOINT 36539
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_WORD 36540
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_PRESENTATION 36541
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_SPREADSHEET 36542
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_TEXT 36543
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PDF 36544
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PLAIN_TEXT 36545
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_RICH_TEXT_FORMAT 36546
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SALESFORCE 36547
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SLACK 36548
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_MP4 36549
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_QUICKTIME 36550
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_WEBM 36551
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_ZIP_FILE 36552
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE 36553
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_DATE 36554
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_OWNER 36555
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_FILE_TYPE_DESCRIPTION 36556
#define IDS_PERSON_SUGGESTION_DESCRIPTION 36557
#define IDS_ACC_OMNIBOX_SUGGESTION_TYPE_SEARCH 36558
#define IDS_ACC_OMNIBOX_SUGGESTION_TYPE_NAVIGATION 36559
#define IDS_ACC_OMNIBOX_SUGGESTION_TYPE_CONVERSATION 36560
#define IDS_ACC_OMNIBOX_SUGGESTION_IN_GROUP_WITH_TYPE 36561
#define IDS_ACC_OMNIBOX_SUGGESTION_IN_GROUP_WITH_TYPE_AND_DESCRIPTION 36562
#define IDS_OMNIBOX_ACTION_CROSS_DEVICE_TAB_HINT 36563
#define IDS_OMNIBOX_ACTION_CROSS_DEVICE_TAB_SUGGESTION_CONTENTS 36564
#define IDS_ACC_OMNIBOX_ACTION_CROSS_DEVICE_TAB_SUFFIX 36565
#define IDS_ACC_OMNIBOX_ACTION_CROSS_DEVICE_TAB 36566
#define IDS_OMNIBOX_HISTORY_CLUSTERS_SEARCH_HINT 36567
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_HINT 36568
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUGGESTION_CONTENTS 36569
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUFFIX 36570
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH 36571
#define IDS_ACC_OMNIBOX_ACTION_IN_SUGGEST_SUFFIX 36572
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_HINT 36573
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_CONTENTS 36574
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_HINT 36575
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_CONTENTS 36576
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_HINT 36577
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_CONTENTS 36578
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_HINT 36579
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_CONTENTS 36580
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_HINT 36581
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_CONTENTS 36582
#define IDS_ACC_OMNIBOX_ACTION_IN_EXTENSION_SUGGEST_SUFFIX 36583
#define IDS_ACC_SEND_BUTTON_SEARCH_OR_NAVIGATE 36584
#define IDS_ACC_SEND_BUTTON_SEND_TO_AI 36585
#define IDS_ACC_SEND_BUTTON_CREATE_IMAGE 36586
#define IDS_ACC_REMOVE_IMAGE_ATTACHMENT 36587
#define IDS_ACC_REMOVE_ATTACHMENT 36588
#define IDS_ACC_FUSEBOX_POPUP_BUTTON_SELECTED 36589
#define IDS_ACC_AUTOCOMPLETE_HISTORY 36590
#define IDS_ACC_AUTOCOMPLETE_SEARCH_HISTORY 36591
#define IDS_ACC_AUTOCOMPLETE_SEARCH 36592
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH 36593
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH_ENTITY 36594
#define IDS_ACC_AUTOCOMPLETE_QUICK_ANSWER 36595
#define IDS_ACC_AUTOCOMPLETE_BOOKMARK 36596
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_IMAGE 36597
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_TEXT 36598
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_URL 36599
#define IDS_ACC_SEARCH_ICON 36600
#define IDS_ACC_AUTOCOMPLETE_N_OF_M 36601
#define IDS_ACC_TAB_SWITCH_SUFFIX 36602
#define IDS_ACC_TAB_SWITCH_BUTTON 36603
#define IDS_ACC_MULTIPLE_ACTIONS_SUFFIX 36604
#define IDS_ACC_KEYWORD_SUFFIX 36605
#define IDS_ACC_KEYWORD_MODE 36606
#define IDS_ACC_ASK_KEYWORD_MODE 36607
#define IDS_ACC_KEYWORD_MODE_WITH_SHORTCUT 36608
#define IDS_ACC_ASK_KEYWORD_MODE_WITH_SHORTCUT 36609
#define IDS_OMNIBOX_KEYWORD_TEXT_MD 36610
#define IDS_ACC_THUMBS_UP_SUGGESTION_FOCUSED_PREFIX 36611
#define IDS_ACC_THUMBS_UP_SUGGESTION_BUTTON 36612
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_FOCUSED_PREFIX 36613
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_BUTTON 36614
#define IDS_ACC_REMOVE_SUGGESTION_SUFFIX 36615
#define IDS_ACC_REMOVE_SUGGESTION_FOCUSED_PREFIX 36616
#define IDS_ACC_REMOVE_SUGGESTION_BUTTON 36617
#define IDS_ACC_AI_MODE_PLACEHOLDER_TEXT 36618
#define IDS_ACC_AI_MODE_BUTTON_FOCUSED 36619
#define IDS_ACC_CHROME_TIP 36620
#define IDS_ACC_DISMISS_CHROME_TIP_SUFFIX 36621
#define IDS_ACC_DISMISS_CHROME_TIP_FOCUSED_PREFIX 36622
#define IDS_ACC_DISMISS_CHROME_TIP_BUTTON 36623
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_NAME 36624
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_KEYWORD 36625
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_NAME 36626
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_KEYWORD 36627
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_NAME 36628
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_KEYWORD 36629
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_NAME 36630
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_KEYWORD 36631
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_NAME 36632
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_KEYWORD 36633
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_NAME 36634
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_KEYWORD 36635
#define IDS_STARTER_PACK_PAGE_KEYWORD_TEXT 36636
#define IDS_STARTER_PACK_PAGE_EMPTY_QUERY_MATCH_TEXT 36637
#define IDS_OMNIBOX_INSTANT_KEYWORD_ASK_TEXT 36638
#define IDS_OMNIBOX_INSTANT_KEYWORD_SEARCH_TEXT 36639
#define IDS_OMNIBOX_SELECTED_KEYWORD_ASK_TEXT 36640
#define IDS_OMNIBOX_TAB_SEARCH_NO_RESULTS_FOUND 36641
#define IDS_OMNIBOX_GEMINI_IPH 36642
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SITE_SEARCH_IPH 36643
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SEARCH_AGGREGATOR_IPH 36644
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH 36645
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH_LINK_TEXT 36646
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH 36647
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH_LINK_TEXT 36648
#define IDS_ACC_OMNIBOX_IPH_LINK_SELECTED 36649
#define IDS_ACC_OMNIBOX_TOOLBELT_NEXT_SUFFIX 36650
#define IDS_OMNIBOX_HISTORY_SCOPE_PROMO_IPH 36651
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PROMO_IPH 36652
#define IDS_OMNIBOX_ONE_LINE_CALCULATOR_SUGGESTION_TEMPLATE 36653
#define IDS_OMNIBOX_BOOKMARKS_SCOPE_PLACEHOLDER_TEXT 36654
#define IDS_OMNIBOX_HISTORY_SCOPE_PLACEHOLDER_TEXT 36655
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PLACEHOLDER_TEXT 36656
#define IDS_OMNIBOX_TABS_SCOPE_PLACEHOLDER_TEXT 36657
#define IDS_OMNIBOX_GEMINI_SCOPE_PLACEHOLDER_TEXT 36658
#define IDS_OMNIBOX_PAGE_SCOPE_PLACEHOLDER_TEXT 36659
#define IDS_OMNIBOX_AI_MODE_SCOPE_PLACEHOLDER_TEXT 36660
#define IDS_OMNIBOX_HUB_OPEN_TABS_HEADER 36661
#define IDS_OMNIBOX_HUB_SEARCH_HEADER 36662
#define IDS_OMNIBOX_HUB_HISTORY_HEADER 36663
#define IDS_OMNIBOX_HUB_TYPED_MATCH_HEADER 36664
#define IDS_PAGE_INFO_SECURE_SUMMARY 36665
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY 36666
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY_SHORT 36667
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY 36668
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY_SHORT 36669
#define IDS_PAGE_INFO_SAFE_BROWSING_SUMMARY 36670
#define IDS_PAGE_INFO_EXTENSION_PAGE 36671
#define IDS_PAGE_INFO_VIEW_SOURCE_PAGE 36672
#define IDS_PAGE_INFO_DEVTOOLS_PAGE 36673
#define IDS_PAGE_INFO_READER_MODE_PAGE_SECURE 36674
#define IDS_PAGE_INFO_READER_MODE_PAGE 36675
#define IDS_PAGE_INFO_SAFETY_TIP_MORE_INFO_LINK 36676
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_LEAVE_BUTTON 36677
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_TITLE 36678
#define IDS_PAGE_INFO_SAFETY_TIP_DESCRIPTION 36679
#define IDS_PAGE_INFO_FILE_PAGE 36680
#define IDS_PAGE_INFO_SECURE_DETAILS 36681
#define IDS_PAGE_INFO_MIXED_CONTENT_DETAILS 36682
#define IDS_PAGE_INFO_NOT_SECURE_DETAILS 36683
#define IDS_PAGE_INFO_MALWARE_DETAILS 36684
#define IDS_PAGE_INFO_SOCIAL_ENGINEERING_DETAILS 36685
#define IDS_PAGE_INFO_UNWANTED_SOFTWARE_DETAILS 36686
#define IDS_PAGE_INFO_SECURITY_TAB_INSECURE_IDENTITY 36687
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SUMMARY 36688
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SAVED_PASSWORD_SUMMARY 36689
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SAVED 36690
#define IDS_PAGE_INFO_CHECK_PASSWORDS_BUTTON 36691
#define IDS_PAGE_INFO_INVALID_CERTIFICATE_DESCRIPTION 36692
#define IDS_PAGE_INFO_RESET_INVALID_CERTIFICATE_DECISIONS_BUTTON 36693
#define IDS_PAGE_INFO_HELP_CENTER_LINK 36694
#define IDS_PAGE_INFO_SECURITY_TAB_DEPRECATED_SIGNATURE_ALGORITHM 36695
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_CONNECTION_TEXT 36696
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_ERROR 36697
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_WARNING 36698
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_FORM_WARNING 36699
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_SENTENCE_LINK 36700
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS 36701
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS_AEAD 36702
#define IDS_PAGE_INFO_SECURITY_TAB_NOT_ENCRYPTED_CONNECTION_TEXT 36703
#define IDS_PAGE_INFO_SECURITY_TAB_SSL_VERSION 36704
#define IDS_PAGE_INFO_SECURITY_TAB_UNKNOWN_PARTY 36705
#define IDS_PAGE_INFO_SECURITY_TAB_WEAK_ENCRYPTION_CONNECTION_TEXT 36706
#define IDS_PAGE_INFO_CERT_INFO_BUTTON 36707
#define IDS_PAGE_INFO_SECURITY_TAB_SECURE_IDENTITY_EV_VERIFIED 36708
#define IDS_PAGE_INFO_CERTIFICATE_IS_VALID 36709
#define IDS_PAGE_INFO_CERTIFICATE_DETAILS 36710
#define IDS_PAGE_INFO_CERTIFICATE_VALID_LINK_TOOLTIP 36711
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_LINK_TOOLTIP 36712
#define IDS_PAGE_INFO_QWAC_STATUS_TITLE 36713
#define IDS_PAGE_INFO_COOKIES 36715
#define IDS_PAGE_INFO_COOKIES_TOOLTIP 36716
#define IDS_PAGE_INFO_BUTTON_TEXT_AUTOMATIC_BY_DEFAULT 36717
#define IDS_PAGE_INFO_BUTTON_TEXT_MUTED_BY_DEFAULT 36718
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED 36719
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_ONCE 36720
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED 36721
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_INCOGNITO 36722
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_GUEST 36723
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_INSECURE 36724
#define IDS_PAGE_INFO_STATE_TEXT_MUTED 36725
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_BY_DEFAULT 36726
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_BY_DEFAULT 36727
#define IDS_PAGE_INFO_SELECTOR_TOOLTIP 36728
#define IDS_PAGE_INFO_SELECTOR_STORAGE_ACCESS_TOOLTIP 36729
#define IDS_PAGE_INFO_STATE_TEXT_AR_ASK 36730
#define IDS_PAGE_INFO_STATE_TEXT_AUTO_PICTURE_IN_PICTURE_ASK 36731
#define IDS_PAGE_INFO_STATE_TEXT_AUTOMATIC_DOWNLOADS_ASK 36732
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_DEVICES_ASK 36733
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_ASK 36734
#define IDS_PAGE_INFO_STATE_TEXT_CAPTURED_SURFACE_CONTROL_ASK 36735
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_PAN_TILT_ZOOM_ASK 36736
#define IDS_PAGE_INFO_STATE_TEXT_CLIPBOARD_ASK 36737
#define IDS_PAGE_INFO_STATE_TEXT_FILE_SYSTEM_WRITE_ASK 36738
#define IDS_PAGE_INFO_STATE_TEXT_HAND_TRACKING_ASK 36739
#define IDS_PAGE_INFO_STATE_TEXT_HID_DEVICES_ASK 36740
#define IDS_PAGE_INFO_STATE_TEXT_KEYBOARD_LOCK_ASK 36741
#define IDS_PAGE_INFO_STATE_TEXT_LOCATION_ASK 36742
#define IDS_PAGE_INFO_STATE_TEXT_MIC_ASK 36743
#define IDS_PAGE_INFO_STATE_TEXT_MIDI_SYSEX_ASK 36744
#define IDS_PAGE_INFO_STATE_TEXT_NOTIFICATIONS_ASK 36745
#define IDS_PAGE_INFO_STATE_TEXT_POINTER_LOCK_ASK 36746
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_AND_LIGHT_SENSORS_ASK 36747
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_SENSORS_ASK 36748
#define IDS_PAGE_INFO_STATE_TEXT_USB_ASK 36749
#define IDS_PAGE_INFO_STATE_TEXT_VR_ASK 36750
#define IDS_PAGE_INFO_STATE_TEXT_FONT_ACCESS_ASK 36751
#define IDS_PAGE_INFO_STATE_TEXT_SERIAL_ASK 36752
#define IDS_PAGE_INFO_STATE_TEXT_IDLE_DETECTION_ASK 36753
#define IDS_PAGE_INFO_STATE_TEXT_WINDOW_MANAGEMENT_ASK 36754
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_SCANNING_ASK 36755
#define IDS_PAGE_INFO_STATE_TEXT_STORAGE_ACCESS_ASK 36756
#define IDS_PAGE_INFO_STATE_TEXT_WEB_APP_INSTALLATION_ASK 36757
#define IDS_PAGE_INFO_STATE_TEXT_WEB_PRINTING_ASK 36758
#define IDS_PAGE_INFO_STATE_TEXT_LOCAL_NETWORK_ASK 36759
#define IDS_PAGE_INFO_STATE_TEXT_LOOPBACK_NETWORK_ASK 36760
#define IDS_PAGE_INFO_USB_DEVICE_SECONDARY_LABEL 36761
#define IDS_PAGE_INFO_USB_DEVICE_ALLOWED_BY_POLICY_LABEL 36762
#define IDS_PAGE_INFO_DELETE_USB_DEVICE_WITH_NAME 36763
#define IDS_PAGE_INFO_SERIAL_PORT_SECONDARY_LABEL 36764
#define IDS_PAGE_INFO_SERIAL_PORT_ALLOWED_BY_POLICY_LABEL 36765
#define IDS_PAGE_INFO_DELETE_SERIAL_PORT_WITH_NAME 36766
#define IDS_PAGE_INFO_BLUETOOTH_DEVICE_SECONDARY_LABEL 36767
#define IDS_PAGE_INFO_DELETE_BLUETOOTH_DEVICE_WITH_NAME 36768
#define IDS_PAGE_INFO_HID_DEVICE_SECONDARY_LABEL 36769
#define IDS_PAGE_INFO_HID_DEVICE_ALLOWED_BY_POLICY_LABEL 36770
#define IDS_PAGE_INFO_DELETE_HID_DEVICE_WITH_NAME 36771
#define IDS_PAGE_INFO_SMART_CARD_READER_ALLOWED_BY_POLICY_LABEL 36772
#define IDS_PAGE_INFO_SMART_CARD_READER_SECONDARY_LABEL 36773
#define IDS_PAGE_INFO_DELETE_SMART_CARD_READER_WITH_NAME 36774
#define IDS_PAGE_INFO_SITE_SETTINGS_LINK 36775
#define IDS_PAGE_INFO_SITE_SETTINGS_TOOLTIP 36776
#define IDS_PAGE_INFO_CAMERA_SYSTEM_SETTINGS_DESCRIPTION 36779
#define IDS_PAGE_INFO_MICROPHONE_SYSTEM_SETTINGS_DESCRIPTION 36780
#define IDS_PAGE_INFO_LOCATION_SYSTEM_SETTINGS_DESCRIPTION 36781
#define IDS_PAGE_INFO_CLIPBOARD_SYSTEM_SETTINGS_DESCRIPTION 36782
#define IDS_PAGE_INFO_SETTINGS_OF_A_SYSTEM_LINK 36783
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_POLICY 36784
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_POLICY 36785
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_POLICY 36786
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_EXTENSION 36787
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_EXTENSION 36788
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_EXTENSION 36789
#define IDS_PAGE_INFO_PERMISSION_AUTOMATICALLY_BLOCKED 36790
#define IDS_PAGE_INFO_PERMISSION_ADS_SUBTITLE 36791
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_POLICY 36792
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_EXTENSION 36793
#define IDS_PAGE_INFO_INFOBAR_TEXT 36794
#define IDS_PAGE_INFO_INFOBAR_BUTTON 36795
#define IDS_PAGE_INFO_PERMISSION_USING_NOW 36796
#define IDS_PAGE_INFO_PERMISSION_RECENTLY_USED 36797
#define IDS_PAGE_INFO_PERMISSION_USED_TIME_AGO 36798
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS 36799
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SYNC 36800
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SIGNED_IN_NON_SYNC 36801
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE 36802
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE_WITH_ORG_NAME 36803
#define IDS_PAGE_INFO_CHANGE_PASSWORD_BUTTON 36804
#define IDS_PAGE_INFO_PROTECT_ACCOUNT_BUTTON 36805
#define IDS_PAGE_INFO_IGNORE_PASSWORD_WARNING_BUTTON 36806
#define IDS_PAGE_INFO_ALLOWLIST_PASSWORD_REUSE_BUTTON 36807
#define IDS_PAGE_INFO_BILLING_SUMMARY 36808
#define IDS_PAGE_INFO_BILLING_DETAILS 36809
#define IDS_PAGE_INFO_VR_PRESENTING_TEXT 36810
#define IDS_PAGE_INFO_VR_TURN_OFF_BUTTON_TEXT 36811
#define IDS_CERT_INFO_SUBJECT_GROUP 36812
#define IDS_CERT_INFO_ISSUER_GROUP 36813
#define IDS_CERT_INFO_COMMON_NAME_LABEL 36814
#define IDS_CERT_INFO_ORGANIZATION_LABEL 36815
#define IDS_CERT_INFO_ORGANIZATIONAL_UNIT_LABEL 36816
#define IDS_CERT_INFO_SERIAL_NUMBER_LABEL 36817
#define IDS_CERT_INFO_VALIDITY_GROUP 36818
#define IDS_CERT_INFO_ISSUED_ON_LABEL 36819
#define IDS_CERT_INFO_EXPIRES_ON_LABEL 36820
#define IDS_CERT_INFO_FINGERPRINTS_GROUP 36821
#define IDS_CERT_INFO_SHA256_FINGERPRINT_LABEL 36822
#define IDS_CERT_INFO_SHA256_SPKI_FINGERPRINT_LABEL 36823
#define IDS_CERT_DETAILS_EXTENSIONS 36824
#define IDS_CERT_X509_SUBJECT_ALT_NAME 36825
#define IDS_CERT_DETAILS_VERSION 36826
#define IDS_CERT_DETAILS_SERIAL_NUMBER 36827
#define IDS_CERT_DETAILS_ISSUER 36828
#define IDS_CERT_DETAILS_VALIDITY 36829
#define IDS_CERT_DETAILS_NOT_BEFORE 36830
#define IDS_CERT_DETAILS_NOT_AFTER 36831
#define IDS_CERT_DETAILS_SUBJECT 36832
#define IDS_CERT_DETAILS_SUBJECT_KEY_INFO 36833
#define IDS_CERT_GENERAL_NAME_RFC822_NAME 36834
#define IDS_CERT_GENERAL_NAME_DNS_NAME 36835
#define IDS_CERT_GENERAL_NAME_X400_ADDRESS 36836
#define IDS_CERT_GENERAL_NAME_DIRECTORY_NAME 36837
#define IDS_CERT_GENERAL_NAME_EDI_PARTY_NAME 36838
#define IDS_CERT_GENERAL_NAME_URI 36839
#define IDS_CERT_GENERAL_NAME_IP_ADDRESS 36840
#define IDS_CERT_GENERAL_NAME_REGISTERED_ID 36841
#define IDS_CERT_EXTENSION_CRITICAL 36842
#define IDS_CERT_EXTENSION_NON_CRITICAL 36843
#define IDS_CERT_X509_SUBJECT_KEYID 36844
#define IDS_CERT_X509_AUTH_KEYID 36845
#define IDS_CERT_X509_AUTH_INFO_ACCESS 36846
#define IDS_CERT_X509_KEY_USAGE 36847
#define IDS_CERT_X509_ISSUER_ALT_NAME 36848
#define IDS_CERT_X509_BASIC_CONSTRAINTS 36849
#define IDS_CERT_X509_CRL_DIST_POINTS 36850
#define IDS_CERT_X509_CERT_POLICIES 36851
#define IDS_CERT_X509_SCT_LIST 36852
#define IDS_CERT_X509_EXT_KEY_USAGE 36853
#define IDS_CERT_QC_STATEMENTS 36854
#define IDS_CERT_OID_PKCS1_RSA_ENCRYPTION 36855
#define IDS_CERT_OID_PKCS1_MD2_WITH_RSA_ENCRYPTION 36856
#define IDS_CERT_OID_PKCS1_MD4_WITH_RSA_ENCRYPTION 36857
#define IDS_CERT_OID_PKCS1_MD5_WITH_RSA_ENCRYPTION 36858
#define IDS_CERT_OID_PKCS1_SHA1_WITH_RSA_ENCRYPTION 36859
#define IDS_CERT_OID_PKCS1_SHA256_WITH_RSA_ENCRYPTION 36860
#define IDS_CERT_OID_PKCS1_SHA384_WITH_RSA_ENCRYPTION 36861
#define IDS_CERT_OID_PKCS1_SHA512_WITH_RSA_ENCRYPTION 36862
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA1_SIGNATURE 36863
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA256_SIGNATURE 36864
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA384_SIGNATURE 36865
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA512_SIGNATURE 36866
#define IDS_CERT_OID_ANSIX962_EC_PUBLIC_KEY 36867
#define IDS_CERT_OID_SECG_EC_SECP256R1 36868
#define IDS_CERT_OID_SECG_EC_SECP384R1 36869
#define IDS_CERT_OID_SECG_EC_SECP521R1 36870
#define IDS_CERT_OID_ML_DSA_44 36871
#define IDS_CERT_OID_ML_DSA_65 36872
#define IDS_CERT_OID_ML_DSA_87 36873
#define IDS_CERT_EKU_ANY_EKU 36874
#define IDS_CERT_EKU_CODE_SIGNING 36875
#define IDS_CERT_EKU_EMAIL_PROTECTION 36876
#define IDS_CERT_EKU_TIME_STAMPING 36877
#define IDS_CERT_EKU_TLS_WEB_SERVER_AUTHENTICATION 36878
#define IDS_CERT_EKU_TLS_WEB_CLIENT_AUTHENTICATION 36879
#define IDS_CERT_EKU_OCSP_SIGNING 36880
#define IDS_CERT_X509_KEY_USAGE_SIGNING 36881
#define IDS_CERT_X509_KEY_USAGE_NONREP 36882
#define IDS_CERT_X509_KEY_USAGE_ENCIPHERMENT 36883
#define IDS_CERT_X509_KEY_USAGE_DATA_ENCIPHERMENT 36884
#define IDS_CERT_X509_KEY_USAGE_KEY_AGREEMENT 36885
#define IDS_CERT_X509_KEY_USAGE_CERT_SIGNER 36886
#define IDS_CERT_X509_KEY_USAGE_CRL_SIGNER 36887
#define IDS_CERT_X509_KEY_USAGE_ENCIPHER_ONLY 36888
#define IDS_CERT_X509_KEY_USAGE_DECIPHER_ONLY 36889
#define IDS_CERT_PKIX_CPS_POINTER_QUALIFIER 36890
#define IDS_CERT_PKIX_USER_NOTICE_QUALIFIER 36891
#define IDS_CERT_QC_ETSI_QCS_QCCOMPLIANCE 36892
#define IDS_CERT_QC_ETSI_QCS_QCTYPE 36893
#define IDS_CERT_QC_ETSI_QCT_WEB 36894
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_BUTTON 36895
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_HEADER 36896
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_BUTTON_TOOLTIP 36897
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON 36898
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON_TOOLTIP 36899
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_REMEMBER_THIS_SETTING 36900
#define IDS_PAGE_INFO_RESET_PERMISSIONS 36901
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TITLE 36902
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_DESCRIPTION_PLACEHOLDER 36903
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TOOLTIP 36904
#define IDS_PAGE_INFO_COOKIES_HEADER 36905
#define IDS_PAGE_INFO_COOKIES_DESCRIPTION 36906
#define IDS_PAGE_INFO_COOKIES_SETTINGS_LINK 36907
#define IDS_PAGE_INFO_BLOCK_THIRD_PARTY_COOKIES_MANAGED_BY_SETTINGS_TOOLTIP 36908
#define IDS_PAGE_INFO_COOKIES_ALLOWED_SITES_COUNT 36909
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TITLE 36910
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TOOLTIP 36911
#define IDS_PAGE_INFO_RWS_BUTTON_TOOLTIP 36912
#define IDS_PAGE_INFO_RWS_BUTTON_TITLE 36913
#define IDS_PAGE_INFO_RWS_BUTTON_SUBTITLE 36914
#define IDS_PAGE_INFO_COOKIES_SITE_NOT_WORKING_TITLE 36915
#define IDS_PAGE_INFO_TRACKING_PROTECTION_SITE_NOT_WORKING_DESCRIPTION_TEMPORARY 36916
#define IDS_PAGE_INFO_COOKIES_SITE_NOT_WORKING_DESCRIPTION_PERMANENT 36917
#define IDS_PAGE_INFO_COOKIES_THIRD_PARTY_COOKIES_LABEL 36918
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_BLOCKED_RESTART_TITLE 36919
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_RESTART_DESCRIPTION 36920
#define IDS_PAGE_INFO_TRACKING_PROTECTION_PERMANENT_ALLOWED_TITLE 36921
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_PERMANENT_ALLOWED_DESCRIPTION 36922
#define IDS_PAGE_INFO_COOKIE_SYNC_DESCRIPTION 36923
#define IDS_PAGE_INFO_SYNC_SETTINGS_LINK 36924
#define IDS_MERCHANT_TRUST_SIDE_PANEL_TITLE 36925
#define IDS_PAGE_INFO_MERCHANT_TRUST_HEADER 36926
#define IDS_PAGE_INFO_MERCHANT_TRUST_DESCRIPTION 36927
#define IDS_PAGE_INFO_MERCHANT_TRUST_VIEW_ALL_REVIEWS 36928
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_AND_COUNT_A11Y_DESCRIPTION 36929
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_A11Y_DESCRIPTION 36930
#define IDS_PAGE_INFO_MERCHANT_TRUST_REVIEWS_SUMMARY_TITLE 36931
#define IDS_PAGE_INFO_HISTORY 36932
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_TODAY 36933
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_YESTERDAY 36934
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DAYS 36935
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DATE 36936
#define IDS_PAGE_INFO_ENTERPRISE_WARN_SUMMARY 36937
#define IDS_PAGE_INFO_ENTERPRISE_WARN_DETAILS 36938
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_SUMMARY 36939
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_DETAILS 36940
#define IDS_PAGE_INFO_AD_PRIVACY_HEADER 36941
#define IDS_PAGE_INFO_AD_PRIVACY_TOOLTIP 36942
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_DESCRIPTION 36943
#define IDS_PAGE_INFO_AD_PRIVACY_FLEDGE_DESCRIPTION 36944
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_AND_FLEDGE_DESCRIPTION 36945
#define IDS_PAGE_INFO_AD_PRIVACY_SUBPAGE_MANAGE_BUTTON 36946
#define IDS_PAINT_PREVIEW_COMPOSITOR_SERVICE_DISPLAY_NAME 36947
#define IDS_LEAK_CHECK_CREDENTIALS 36948
#define IDS_CREDENTIAL_LEAK_TITLE_CHANGE 36949
#define IDS_CREDENTIAL_LEAK_TITLE_CHECK_GPM 36950
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 36951
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_BRANDED 36952
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 36953
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 36954
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_NON_BRANDED 36955
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 36956
#define IDS_PASSWORD_MANAGER_LEAK_HELP_MESSAGE 36959
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE 36960
#define IDS_PASSWORD_MANAGER_EMPTY_LOGIN 36961
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS 36962
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_AND_PASSKEYS 36963
#define IDS_PASSWORD_MANAGER_GENERATE_PASSWORD 36964
#define IDS_PASSWORD_MANAGER_SHOW_PASSWORDS_TAB_TITLE 36965
#define IDS_PASSWORD_MANAGER_DEFAULT_EXPORT_FILENAME 36966
#define IDS_PASSWORD_MANAGER_PASSWORD_FOR_ACCOUNT 36967
#define IDS_PASSWORD_MANAGER_USE_SCREEN_LOCK 36968
#define IDS_PASSWORD_MANAGER_PASSKEY 36969
#define IDS_PASSWORD_MANAGER_USE_GENERIC_DEVICE 36970
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_CHROME_PROFILE 36971
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_ICLOUD_KEYCHAIN 36972
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_GOOGLE_PASSWORD_MANAGER 36973
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_WINDOWS_HELLO 36974
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_PROVIDER 36975
#define IDS_PASSWORD_MANAGER_PASSWORD_FROM_GOOGLE_PASSWORD_MANAGER 36976
#define IDS_PASSWORD_MANAGER_USE_DIFFERENT_PASSKEY 36977
#define IDS_PASSWORD_MANAGER_USE_PASSKEY_OTHER_DEVICE 36978
#define IDS_PASSWORD_MANAGER_PASSKEY_QR_CODE_TITLE 36979
#define IDS_PASSWORD_MANAGER_USE_PASSKEY 36980
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_BRANDED 37005
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_BRANDED 37006
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_NON_BRANDED 37007
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_NON_BRANDED 37008
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_BRANDED 37012
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_NON_BRANDED 37013
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_CANCEL_BUTTON 37014
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_NEVER_BUTTON 37015
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_FOOTER_MOVE_PASSWORD 37016
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LINK_TEXT_MOVE_PASSWORD 37017
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_SUGGESTED_PASSWORDS_SECTION_TITLE 37018
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_ALL_PASSWORDS_SECTION_TITLE 37019
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_FILL_PASSWORD_ENTRY 37020
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_VIEW_DETAILS_ENTRY 37021
#define IDS_PASSWORD_MANAGER_PENDING_STATE 37022
#define IDS_PASSWORD_MANAGER_UI_TROUBLE_SIGNING_IN 37023
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_SUGGESTION 37024
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_BRANDED 37025
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_NON_BRANDED 37026
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_TAG 37027
#define IDS_PAYMENTS_TITLE 37028
#define IDS_PAYMENTS_ERROR_MESSAGE_DIALOG_TITLE 37029
#define IDS_PAYMENTS_METHOD_OF_PAYMENT_LABEL 37030
#define IDS_PAYMENTS_CONTACT_DETAILS_LABEL 37031
#define IDS_PAYMENTS_ADD_CONTACT_DETAILS_LABEL 37032
#define IDS_PAYMENTS_EDIT_CONTACT_DETAILS_LABEL 37033
#define IDS_PAYMENTS_ADD_MORE_INFORMATION 37034
#define IDS_PAYMENTS_ADD_PHONE_NUMBER 37035
#define IDS_PAYMENTS_ADD_RECIPIENT 37036
#define IDS_PAYMENTS_ADD_VALID_ADDRESS 37037
#define IDS_PAYMENTS_ADD_EMAIL 37038
#define IDS_PAYMENTS_ADD_NAME 37039
#define IDS_PAYMENTS_ORDER_SUMMARY_LABEL 37040
#define IDS_PAYMENT_REQUEST_PAYMENT_METHOD_SECTION_NAME 37041
#define IDS_PAYMENT_REQUEST_CONTACT_INFO_SECTION_NAME 37042
#define IDS_PAYMENTS_SHIPPING_SUMMARY_LABEL 37043
#define IDS_PAYMENTS_SHIPPING_ADDRESS_LABEL 37044
#define IDS_PAYMENTS_SHIPPING_OPTION_LABEL 37045
#define IDS_PAYMENTS_DELIVERY_SUMMARY_LABEL 37046
#define IDS_PAYMENTS_DELIVERY_ADDRESS_LABEL 37047
#define IDS_PAYMENTS_DELIVERY_OPTION_LABEL 37048
#define IDS_PAYMENTS_PICKUP_SUMMARY_LABEL 37049
#define IDS_PAYMENTS_PICKUP_ADDRESS_LABEL 37050
#define IDS_PAYMENTS_PICKUP_OPTION_LABEL 37051
#define IDS_PAYMENTS_EDIT_BUTTON 37052
#define IDS_PAYMENTS_PAY_BUTTON 37053
#define IDS_PAYMENTS_CONTINUE_BUTTON 37054
#define IDS_PAYMENTS_ADD_CONTACT 37055
#define IDS_PAYMENTS_ADD_CARD 37056
#define IDS_PAYMENTS_ADD_ADDRESS 37057
#define IDS_PAYMENTS_EDIT_ADDRESS 37058
#define IDS_PAYMENTS_CANCEL_PAYMENT 37059
#define IDS_PAYMENTS_CONFIRM_BUTTON 37060
#define IDS_PAYMENTS_NAME_FIELD_IN_CONTACT_DETAILS 37061
#define IDS_PAYMENTS_PHONE_FIELD_IN_CONTACT_DETAILS 37062
#define IDS_PAYMENTS_EMAIL_FIELD_IN_CONTACT_DETAILS 37063
#define IDS_PAYMENTS_LOADING_MESSAGE 37064
#define IDS_PAYMENTS_PROCESSING_MESSAGE 37065
#define IDS_PAYMENTS_CHECKING_OPTION 37066
#define IDS_PAYMENTS_UPDATED_LABEL 37067
#define IDS_PAYMENTS_ERROR_MESSAGE 37068
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS 37069
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_IN 37070
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_OUT 37071
#define IDS_SETTINGS_CAN_MAKE_PAYMENT_TOGGLE_LABEL 37072
#define IDS_PAYMENTS_REQUIRED_FIELD_MESSAGE 37073
#define IDS_PAYMENTS_VALIDATION_INVALID_CREDIT_CARD_EXPIRED 37074
#define IDS_PAYMENTS_VALIDATION_UNSUPPORTED_CREDIT_CARD_TYPE 37075
#define IDS_PAYMENTS_PHONE_INVALID_VALIDATION_MESSAGE 37076
#define IDS_PAYMENTS_EMAIL_INVALID_VALIDATION_MESSAGE 37077
#define IDS_PAYMENTS_CARD_NUMBER_INVALID_VALIDATION_MESSAGE 37078
#define IDS_PAYMENTS_INVALID_ADDRESS 37079
#define IDS_PAYMENTS_BILLING_ADDRESS_REQUIRED 37080
#define IDS_PAYMENTS_MORE_INFORMATION_REQUIRED 37081
#define IDS_PAYMENTS_PHONE_NUMBER_REQUIRED 37082
#define IDS_PAYMENTS_RECIPIENT_REQUIRED 37083
#define IDS_PAYMENTS_EMAIL_REQUIRED 37084
#define IDS_PAYMENTS_NAME_REQUIRED 37085
#define IDS_PREF_EDIT_DIALOG_FIELD_REQUIRED_VALIDATION_MESSAGE 37086
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SECTION_TOTAL_FORMAT 37087
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SHEET_TOTAL_FORMAT 37088
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MORE_ITEMS 37089
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MULTIPLE_CURRENCY_INDICATOR 37090
#define IDS_PAYMENTS_SELECT_SHIPPING_ADDRESS_FOR_SHIPPING_METHODS 37091
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_ADDRESS 37092
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_OPTION 37093
#define IDS_PAYMENTS_SELECT_DELIVERY_ADDRESS_FOR_DELIVERY_METHODS 37094
#define IDS_PAYMENTS_UNSUPPORTED_DELIVERY_ADDRESS 37095
#define IDS_PAYMENTS_SELECT_PICKUP_ADDRESS_FOR_PICKUP_METHODS 37096
#define IDS_PAYMENTS_UNSUPPORTED_PICKUP_ADDRESS 37097
#define IDS_PAYMENTS_ANDROID_APP_ERROR 37098
#define IDS_PAYMENT_REQUEST_PAYMENT_METHODS_PREVIEW 37100
#define IDS_PAYMENT_REQUEST_SHIPPING_ADDRESSES_PREVIEW 37101
#define IDS_PAYMENT_REQUEST_SHIPPING_OPTIONS_PREVIEW 37102
#define IDS_PAYMENT_REQUEST_CONTACTS_PREVIEW 37103
#define IDS_PAYMENTS_BACK 37104
#define IDS_PAYMENTS_CLOSE 37105
#define IDS_PAYMENTS_EDIT 37106
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_FORMAT 37107
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_SELECTED_FORMAT 37108
#define IDS_PAYMENTS_PROFILE_LABELS_ACCESSIBLE_FORMAT 37109
#define IDS_PAYMENTS_ACCESSIBLE_LABEL_WITH_ERROR 37110
#define IDS_PAYMENTS_ORDER_SUMMARY_ACCESSIBLE_LABEL 37111
#define IDS_PAYMENT_INSTRUMENT_ICON 37112
#define IDS_PAYMENT_HANDLER_SHEET_DESCRIPTION 37113
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_HALF 37114
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_FULL 37115
#define IDS_PAYMENT_HANDLER_SHEET_CLOSED 37116
#define IDS_PAYMENT_HANDLER_ICON 37117
#define IDS_SECURE_PAYMENT_CONFIRMATION_TITLE 37118
#define IDS_SECURE_PAYMENT_CONFIRMATION_INFORM_ONLY_TITLE 37119
#define IDS_SECURE_PAYMENT_CONFIRMATION_VERIFY_BUTTON_LABEL 37120
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_TEXT 37125
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_LINK_TEXT 37126
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_TEXT 37127
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_LINK_TEXT 37128
#define IDS_SECURE_PAYMENT_CONFIRMATION_CONFIRM_BUTTON_LABEL 37129
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_AUTHENTICATOR_TEXT 37130
#define IDS_PDF_DOWNLOAD_ORIGINAL 37138
#define IDS_PDF_DOWNLOAD_EDITED 37139
#define IDS_PDF_PRESENT 37140
#define IDS_PDF_NEED_PASSWORD 37141
#define IDS_PDF_PASSWORD_DIALOG_TITLE 37142
#define IDS_PDF_PASSWORD_SUBMIT 37143
#define IDS_PDF_PASSWORD_INVALID 37144
#define IDS_PDF_SIDEBAR_LABEL 37145
#define IDS_PDF_PAGE_LOADING 37146
#define IDS_PDF_ERROR_DIALOG_TITLE 37147
#define IDS_PDF_PAGE_LOAD_FAILED 37148
#define IDS_PDF_PAGE_RELOAD_BUTTON 37149
#define IDS_PDF_BOOKMARKS 37150
#define IDS_PDF_BOOKMARK_EXPAND_ICON_ARIA_LABEL 37151
#define IDS_PDF_PROPERTIES_DIALOG_TITLE 37152
#define IDS_PDF_PROPERTIES_FILE_NAME 37153
#define IDS_PDF_PROPERTIES_FILE_SIZE 37154
#define IDS_PDF_PROPERTIES_TITLE 37155
#define IDS_PDF_PROPERTIES_AUTHOR 37156
#define IDS_PDF_PROPERTIES_SUBJECT 37157
#define IDS_PDF_PROPERTIES_KEYWORDS 37158
#define IDS_PDF_PROPERTIES_CREATED 37159
#define IDS_PDF_PROPERTIES_MODIFIED 37160
#define IDS_PDF_PROPERTIES_APPLICATION 37161
#define IDS_PDF_PROPERTIES_PDF_PRODUCER 37162
#define IDS_PDF_PROPERTIES_PDF_VERSION 37163
#define IDS_PDF_PROPERTIES_PAGE_COUNT 37164
#define IDS_PDF_PROPERTIES_PAGE_SIZE 37165
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_INCH 37166
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_MM 37167
#define IDS_PDF_PROPERTIES_PAGE_SIZE_PORTRAIT 37168
#define IDS_PDF_PROPERTIES_PAGE_SIZE_LANDSCAPE 37169
#define IDS_PDF_PROPERTIES_PAGE_SIZE_SQUARE 37170
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VARIABLE 37171
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW 37172
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_NO 37173
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_YES 37174
#define IDS_PDF_TOOLTIP_ROTATE_CCW 37175
#define IDS_PDF_ROTATION_STATE_LABEL_0 37176
#define IDS_PDF_ROTATION_STATE_LABEL_90 37177
#define IDS_PDF_ROTATION_STATE_LABEL_180 37178
#define IDS_PDF_ROTATION_STATE_LABEL_270 37179
#define IDS_PDF_TOOLTIP_DOWNLOAD 37180
#define IDS_PDF_TOOLTIP_PRINT 37181
#define IDS_PDF_TOOLTIP_FIT_PAGE 37182
#define IDS_PDF_TOOLTIP_FIT_WIDTH 37183
#define IDS_PDF_TWO_UP_VIEW_ENABLE 37184
#define IDS_PDF_ANNOTATIONS_SHOW_TOGGLE 37185
#define IDS_PDF_ZOOM_TEXT_INPUT_ARIA_LABEL 37186
#define IDS_PDF_TOOLTIP_ZOOM_IN 37187
#define IDS_PDF_TOOLTIP_ZOOM_OUT 37188
#define IDS_PDF_TOOLTIP_THUMBNAILS 37189
#define IDS_PDF_TOOLTIP_DOCUMENT_OUTLINE 37190
#define IDS_PDF_TOOLTIP_ATTACHMENTS 37191
#define IDS_PDF_TOOLTIP_DOWNLOAD_ATTACHMENT 37192
#define IDS_PDF_LABEL_PAGE_NUMBER 37193
#define IDS_PDF_LOADING_TO_A11Y_TREE 37194
#define IDS_PDF_LOADED_TO_A11Y_TREE 37195
#define IDS_PDF_OVERSIZE_ATTACHMENT_WARNING 37196
#define IDS_PDF_PAGE_INDEX 37197
#define IDS_PDF_DOCUMENT_PAGE_COUNT 37198
#define IDS_PDF_THUMBNAIL_PAGE_ARIA_LABEL 37199
#define IDS_PDF_ANNOTATION_PEN 37200
#define IDS_PDF_ANNOTATION_HIGHLIGHTER 37201
#define IDS_PDF_ANNOTATION_ERASER 37202
#define IDS_PDF_ANNOTATION_UNDO 37203
#define IDS_PDF_ANNOTATION_REDO 37204
#define IDS_PDF_ANNOTATION_COLOR_BLACK 37205
#define IDS_PDF_ANNOTATION_COLOR_RED 37206
#define IDS_PDF_ANNOTATION_COLOR_YELLOW 37207
#define IDS_PDF_ANNOTATION_COLOR_GREEN 37208
#define IDS_PDF_ANNOTATION_COLOR_WHITE 37209
#define IDS_PDF_ANNOTATION_COLOR_ORANGE 37210
#define IDS_PDF_ANNOTATION_COLOR_BLUE 37211
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREY 37212
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_ORANGE 37213
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREEN 37214
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_BLUE 37215
#define IDS_PDF_INK2_DRAW 37216
#define IDS_PDF_INK2_ANNOTATION_TOOL 37217
#define IDS_PDF_INK2_ANNOTATION_SIZE 37218
#define IDS_PDF_INK2_ANNOTATION_COLOR 37219
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THIN 37220
#define IDS_PDF_INK2_ANNOTATION_SIZE_THIN 37221
#define IDS_PDF_INK2_ANNOTATION_SIZE_MEDIUM 37222
#define IDS_PDF_INK2_ANNOTATION_SIZE_THICK 37223
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THICK 37224
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_RED 37225
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_YELLOW 37226
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_1 37227
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_2 37228
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_1 37229
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_1 37230
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_1 37231
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_1 37232
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_1 37233
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_1 37234
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_2 37235
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_2 37236
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_2 37237
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_2 37238
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_2 37239
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_2 37240
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_3 37241
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_3 37242
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_3 37243
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_3 37244
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_3 37245
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_3 37246
#define IDS_PDF_INK2_TEXT_ANNOTATION 37247
#define IDS_PDF_INK2_TEXT_ANNOTATIONS_AX_LABEL 37248
#define IDS_PDF_INK2_TEXT_FONT 37249
#define IDS_PDF_INK2_TEXT_FONT_SANS_SERIF 37250
#define IDS_PDF_INK2_TEXT_FONT_SERIF 37251
#define IDS_PDF_INK2_TEXT_FONT_MONOSPACE 37252
#define IDS_PDF_INK2_TEXT_FONT_SIZE 37253
#define IDS_PDF_INK2_TEXT_STYLES 37254
#define IDS_PDF_INK2_TEXT_STYLE_BOLD 37255
#define IDS_PDF_INK2_TEXT_STYLE_ITALIC 37256
#define IDS_PDF_INK2_TEXT_ALIGNMENT 37257
#define IDS_PDF_INK2_TEXT_ALIGN_LEFT 37258
#define IDS_PDF_INK2_TEXT_ALIGN_CENTER 37259
#define IDS_PDF_INK2_TEXT_ALIGN_RIGHT 37260
#define IDS_PDF_INK2_TEXT_COLOR 37261
#define IDS_AX_ROLE_DESCRIPTION_PDF_HIGHLIGHT 37262
#define IDS_AX_ROLE_DESCRIPTION_PDF_POPUP_NOTE 37263
#define IDS_PDF_TOOLTIP_SAVE_TO_DRIVE 37264
#define IDS_SAVE_TO_DRIVE_DIALOG_CANCEL_UPLOAD_BUTTON_LABEL 37265
#define IDS_SAVE_TO_DRIVE_DIALOG_CONNECTION_ERROR_MESSAGE 37266
#define IDS_SAVE_TO_DRIVE_DIALOG_ERROR_TITLE 37267
#define IDS_SAVE_TO_DRIVE_DIALOG_MANAGE_STORAGE_BUTTON_LABEL 37268
#define IDS_SAVE_TO_DRIVE_DIALOG_OPEN_IN_DRIVE_BUTTON_LABEL 37269
#define IDS_SAVE_TO_DRIVE_DIALOG_RETRY_BUTTON_LABEL 37270
#define IDS_SAVE_TO_DRIVE_DIALOG_SESSION_TIMEOUT_ERROR_MESSAGE 37271
#define IDS_SAVE_TO_DRIVE_DIALOG_STORAGE_FULL_ERROR_MESSAGE 37272
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_MESSAGE 37273
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_TITLE 37274
#define IDS_SAVE_TO_DRIVE_DIALOG_UNKNOWN_ERROR_MESSAGE 37275
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_DONE 37276
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_WITH_SEPARATOR 37277
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOADING_TITLE 37278
#define IDS_PDF_OCR_FEATURE_ALERT 37279
#define IDS_PDF_OCR_IN_PROGRESS 37280
#define IDS_PDF_OCR_COMPLETED 37281
#define IDS_PDF_OCR_NO_RESULT 37282
#define IDS_PDF_OCR_POSTAMBLE_PAGE 37283
#define IDS_PDF_SEARCHIFY_IN_PROGRESS 37284
#define IDS_GEOLOCATION_INFOBAR_TEXT 37285
#define IDS_GEOLOCATION_INFOBAR_PERMISSION_FRAGMENT 37325
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_FRAGMENT 37326
#define IDS_MOTION_SENSORS_PERMISSION_FRAGMENT 37327
#define IDS_NOTIFICATION_PERMISSIONS_FRAGMENT 37328
#define IDS_MIDI_SYSEX_PERMISSION_FRAGMENT 37329
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT 37330
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 37331
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT 37332
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 37333
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT 37334
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT_WITH_COUNT 37335
#define IDS_ACCESSIBILITY_EVENTS_PERMISSION_FRAGMENT 37336
#define IDS_CLIPBOARD_PERMISSION_FRAGMENT 37337
#define IDS_VR_PERMISSION_FRAGMENT 37338
#define IDS_AR_PERMISSION_FRAGMENT 37339
#define IDS_HAND_TRACKING_PERMISSION_FRAGMENT 37340
#define IDS_KEYBOARD_LOCK_PERMISSIONS_FRAGMENT 37341
#define IDS_POINTER_LOCK_PERMISSIONS_FRAGMENT 37342
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_PROMPT_TITLE 37343
#define IDS_STORAGE_ACCESS_PERMISSION_FRAGMENT 37344
#define IDS_STORAGE_ACCESS_PERMISSION_EXPLANATION 37345
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_EXPLANATION 37346
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_LINK 37347
#define IDS_WINDOW_MANAGEMENT_PERMISSION_FRAGMENT 37348
#define IDS_FONT_ACCESS_PERMISSION_FRAGMENT 37349
#define IDS_IDLE_DETECTION_PERMISSION_FRAGMENT 37350
#define IDS_IDENTITY_PROVIDER_PERMISSION_FRAGMENT 37351
#define IDS_MULTI_DOWNLOAD_PERMISSION_FRAGMENT 37352
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_FRAGMENT 37353
#define IDS_WEB_APP_INSTALLATION_PERMISSION_FRAGMENT 37354
#define IDS_LOCAL_NETWORK_PERMISSION_FRAGMENT 37355
#define IDS_LOOPBACK_NETWORK_PERMISSION_FRAGMENT 37356
#define IDS_PERMISSION_ALLOW 37357
#define IDS_PERMISSION_DENY 37358
#define IDS_PERMISSION_ALLOW_THIS_TIME 37359
#define IDS_PERMISSION_ALLOW_EVERY_VISIT 37360
#define IDS_PERMISSION_ALLOW_WHILE_VISITING 37361
#define IDS_PERMISSION_DONT_ALLOW 37362
#define IDS_PERMISSION_NEVER_ALLOW 37363
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO 37364
#define IDS_PERMISSION_ALLOW_PRECISE_GEO 37365
#define IDS_PERMISSION_ALLOW_PRECISE_GEO_DESCRIPTION 37366
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO_DESCRIPTION 37367
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PROMPT 37368
#define IDS_BLUETOOTH_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 37369
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PAIR_BUTTON_TEXT 37370
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL 37371
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL_TOOLTIP 37372
#define IDS_BLUETOOTH_DEVICE_CHOOSER_ADAPTER_OFF 37373
#define IDS_BLUETOOTH_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 37374
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 37375
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_WITH_ID 37376
#define IDS_BLUETOOTH_SCANNING_PROMPT 37377
#define IDS_BLUETOOTH_SCANNING_DEVICE_UNKNOWN 37378
#define IDS_BLUETOOTH_SCANNING_PROMPT_NO_DEVICES_FOUND_PROMPT 37379
#define IDS_BLUETOOTH_SCANNING_PROMPT_ALLOW_BUTTON_TEXT 37380
#define IDS_BLUETOOTH_SCANNING_PROMPT_BLOCK_BUTTON_TEXT 37381
#define IDS_DEVICE_CHOOSER_CANCEL_BUTTON_TEXT 37382
#define IDS_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 37383
#define IDS_USB_DEVICE_CHOOSER_PROMPT 37384
#define IDS_USB_DEVICE_CHOOSER_CONNECT_BUTTON_TEXT 37385
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL 37386
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL_TOOLTIP 37387
#define IDS_GEOLOCATION_PERMISSION_CHIP 37388
#define IDS_NOTIFICATION_PERMISSIONS_CHIP 37389
#define IDS_MIDI_SYSEX_PERMISSION_CHIP 37390
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_CHIP 37391
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_CHIP 37392
#define IDS_MEDIA_CAPTURE_VIDEO_AND_AUDIO_PERMISSION_CHIP 37393
#define IDS_CLIPBOARD_PERMISSION_CHIP 37394
#define IDS_SAA_PERMISSION_CHIP 37395
#define IDS_IDLE_DETECTION_PERMISSION_CHIP 37396
#define IDS_KEYBOARD_LOCK_PERMISSION_CHIP 37397
#define IDS_KEYBOARD_AND_POINTER_LOCK_PERMISSION_CHIP 37398
#define IDS_POINTER_LOCK_PERMISSION_CHIP 37399
#define IDS_WEB_APP_INSTALLATION_PERMISSION_CHIP 37400
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_CHIP 37401
#define IDS_MOTION_SENSORS_PERMISSION_CHIP 37402
#define IDS_AR_PERMISSION_CHIP 37403
#define IDS_PERMISSIONS_AR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37404
#define IDS_PERMISSIONS_AR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37405
#define IDS_PERMISSIONS_AR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37406
#define IDS_VR_PERMISSION_CHIP 37407
#define IDS_PERMISSIONS_VR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37408
#define IDS_PERMISSIONS_VR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37409
#define IDS_PERMISSIONS_VR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37410
#define IDS_HAND_TRACKING_PERMISSION_CHIP 37411
#define IDS_HAND_TRACKING_PERMISSION_BLOCKED_CHIP 37412
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37413
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37414
#define IDS_PERMISSIONS_HAND_TRACKING_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37415
#define IDS_GEOLOCATION_PERMISSION_BLOCKED_CHIP 37416
#define IDS_NOTIFICATION_PERMISSIONS_BLOCKED_CHIP 37417
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_CHIP 37418
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_BLOCKED_CHIP 37419
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37420
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37421
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_CONFIRMATION 37422
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_ONCE_CONFIRMATION 37423
#define IDS_PERMISSIONS_PERMISSION_NOT_ALLOWED_CONFIRMATION 37424
#define IDS_PERMISSIONS_NOTIFICATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37425
#define IDS_PERMISSIONS_NOTIFICATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37426
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37427
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37428
#define IDS_PERMISSIONS_GEOLOCATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37429
#define IDS_PERMISSIONS_CAMERA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37430
#define IDS_PERMISSIONS_CAMERA_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37431
#define IDS_PERMISSIONS_CAMERA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37432
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37433
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37434
#define IDS_PERMISSIONS_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37435
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37436
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37437
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37438
#define IDS_PERMISSIONS_SAA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37439
#define IDS_PERMISSIONS_SAA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37440
#define IDS_PERMISSIONS_KEYBOARD_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37441
#define IDS_PERMISSIONS_KEYBOARD_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37442
#define IDS_PERMISSIONS_POINTER_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37443
#define IDS_PERMISSIONS_POINTER_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37444
#define IDS_PERMISSIONS_WEB_INSTALL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37445
#define IDS_PERMISSIONS_WEB_INSTALL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37446
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37447
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37448
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37449
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37450
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37451
#define IDS_PERMISSIONS_MOTION_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 37452
#define IDS_REQUEST_QUOTA_INFOBAR_TEXT 37456
#define IDS_REQUEST_LARGE_QUOTA_INFOBAR_TEXT 37457
#define IDS_REQUEST_QUOTA_PERMISSION_FRAGMENT 37458
#define IDS_EMBEDDED_PROMPT_ADMIN_BLOCKED 37459
#define IDS_EMBEDDED_PROMPT_ADMIN_ALLOWED 37460
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_ALLOWED 37461
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_NOT_ALLOWED 37462
#define IDS_PERMISSION_OFF_FOR_CHROME 37463
#define IDS_PERMISSION_CHROME_NEEDS_PERMISSION 37464
#define IDS_GEOLOCATION_NAME_FRAGMENT 37465
#define IDS_CAMERA_PERMISSION_NAME_FRAGMENT 37466
#define IDS_MICROPHONE_PERMISSION_NAME_FRAGMENT 37467
#define IDS_CAMERA_AND_MICROPHONE_PERMISSION_NAME_FRAGMENT 37468
#define IDS_MACOS_NAME_FRAGMENT 37469
#define IDS_WINDOWS_NAME_FRAGMENT 37470
#define IDS_CHROMEOS_NAME_FRAGMENT 37471
#define IDS_EMBEDDED_PROMPT_OK_LABEL 37473
#define IDS_EMBEDDED_PROMPT_CONTINUE_ALLOWING 37474
#define IDS_EMBEDDED_PROMPT_STOP_ALLOWING 37475
#define IDS_EMBEDDED_PROMPT_OPEN_SYSTEM_SETTINGS 37477
#define IDS_EMBEDDED_PROMPT_CONTINUE_NOT_ALLOWING 37478
#define IDS_PERMISSION_PROMPT_SURVEY_CUSTOM_INVITATION 37479
#define IDS_PERSONAL_CONTEXT_NOTICE_TITLE 37483
#define IDS_PERSONAL_CONTEXT_NOTICE_DESCRIPTION_ANDROID 37484
#define IDS_PERSONAL_CONTEXT_NOTICE_CARD_1_ANDROID 37485
#define IDS_PERSONAL_CONTEXT_NOTICE_CARD_2_ANDROID 37486
#define IDS_PERSONAL_CONTEXT_NOTICE_LEARN_MORE_ANDROID 37487
#define IDS_PERSONAL_CONTEXT_NOTICE_DESCRIPTION_DESKTOP 37488
#define IDS_PERSONAL_CONTEXT_NOTICE_CARD_1_DESKTOP 37489
#define IDS_PERSONAL_CONTEXT_NOTICE_CARD_2_DESKTOP 37490
#define IDS_PERSONAL_CONTEXT_NOTICE_LEARN_MORE_DESKTOP 37491
#define IDS_PERSONAL_CONTEXT_NOTICE_PRIMARY_BUTTON 37492
#define IDS_PERSONAL_CONTEXT_NOTICE_SECONDARY_BUTTON 37493
#define IDS_PERSONAL_CONTEXT_SETTINGS_TITLE 37494
#define IDS_PERSONAL_CONTEXT_SETTINGS_DESCRIPTION_DESKTOP 37495
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_TITLE_ANDROID 37496
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_SUMMARY_ANDROID 37497
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_SWITCH_TITLE_ANDROID 37498
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_SWITCH_SUMMARY_ANDROID 37499
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_MANAGE_CONNECTED_APPS_TITLE_ANDROID 37500
#define IDS_PERSONAL_CONTEXT_AUTOFILL_SETTINGS_MANAGE_CONNECTED_APPS_SUMMARY_ANDROID 37501
#define IDS_POLICY_DM_STATUS_SUCCESS 37502
#define IDS_POLICY_DM_STATUS_REQUEST_INVALID 37503
#define IDS_POLICY_DM_STATUS_REQUEST_FAILED 37504
#define IDS_POLICY_DM_STATUS_TEMPORARY_UNAVAILABLE 37505
#define IDS_POLICY_DM_STATUS_HTTP_STATUS_ERROR 37506
#define IDS_POLICY_DM_STATUS_RESPONSE_DECODING_ERROR 37507
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_NOT_SUPPORTED 37508
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NOT_FOUND 37509
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_TOKEN_INVALID 37510
#define IDS_POLICY_DM_STATUS_SERVICE_ACTIVATION_PENDING 37511
#define IDS_POLICY_DM_STATUS_SERVICE_INVALID_SERIAL_NUMBER 37512
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_ID_CONFLICT 37513
#define IDS_POLICY_DM_STATUS_SERVICE_MISSING_LICENSES 37514
#define IDS_POLICY_DM_STATUS_SERVICE_DEPROVISIONED 37515
#define IDS_POLICY_DM_STATUS_SERVICE_POLICY_NOT_FOUND 37516
#define IDS_POLICY_DM_STATUS_UNKNOWN_ERROR 37517
#define IDS_POLICY_DM_STATUS_INVALID_PACKAGED_DEVICE_FOR_KIOSK 37518
#define IDS_POLICY_DM_STATUS_ORG_UNIT_ENROLLMENT_LIMIT_EXCEEDED 37519
#define IDS_POLICY_DM_STATUS_SERVICE_DOMAIN_MISMATCH 37520
#define IDS_POLICY_DM_STATUS_CANNOT_SIGN_REQUEST 37521
#define IDS_POLICY_DM_STATUS_REQUEST_TOO_LARGE 37522
#define IDS_POLICY_DM_STATUS_SERVICE_TOO_MANY_REQUESTS 37523
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NEEDS_RESET 37524
#define IDS_POLICY_DM_STATUS_CONSUMER_ACCOUNT_WITH_PACKAGED_LICENSE 37525
#define IDS_POLICY_DM_STATUS_ENTERPRISE_ACCOUNT_IS_NOT_ELIGIBLE_TO_ENROLL 37526
#define IDS_POLICY_ACTION_BLOCKED_BY_ORGANIZATION 37527
#define IDS_POLICY_ACTION_FORCED_SAVE_TO_CLOUD 37528
#define IDS_POLICY_VALIDATION_OK 37529
#define IDS_POLICY_VALIDATION_BAD_INITIAL_SIGNATURE 37530
#define IDS_POLICY_VALIDATION_BAD_SIGNATURE 37531
#define IDS_POLICY_VALIDATION_ERROR_CODE_PRESENT 37532
#define IDS_POLICY_VALIDATION_PAYLOAD_PARSE_ERROR 37533
#define IDS_POLICY_VALIDATION_WRONG_POLICY_TYPE 37534
#define IDS_POLICY_VALIDATION_WRONG_SETTINGS_ENTITY_ID 37535
#define IDS_POLICY_VALIDATION_BAD_TIMESTAMP 37536
#define IDS_POLICY_VALIDATION_BAD_DM_TOKEN 37537
#define IDS_POLICY_VALIDATION_BAD_DEVICE_ID 37538
#define IDS_POLICY_VALIDATION_BAD_USER 37539
#define IDS_POLICY_VALIDATION_POLICY_PARSE_ERROR 37540
#define IDS_POLICY_VALIDATION_BAD_KEY_VERIFICATION_SIGNATURE 37541
#define IDS_POLICY_VALIDATION_VALUE_WARNING 37542
#define IDS_POLICY_VALIDATION_VALUE_ERROR 37543
#define IDS_POLICY_VALIDATION_UNKNOWN_ERROR 37544
#define IDS_POLICY_STORE_STATUS_OK 37545
#define IDS_POLICY_STORE_STATUS_LOAD_ERROR 37546
#define IDS_POLICY_STORE_STATUS_STORE_ERROR 37547
#define IDS_POLICY_STORE_STATUS_PARSE_ERROR 37548
#define IDS_POLICY_STORE_STATUS_SERIALIZE_ERROR 37549
#define IDS_POLICY_STORE_STATUS_VALIDATION_ERROR 37550
#define IDS_POLICY_STORE_STATUS_BAD_STATE 37551
#define IDS_POLICY_STORE_STATUS_UNKNOWN_ERROR 37552
#define IDS_POLICY_ASSOCIATION_STATE_ACTIVE 37553
#define IDS_POLICY_ASSOCIATION_STATE_UNMANAGED 37554
#define IDS_POLICY_ASSOCIATION_STATE_DEPROVISIONED 37555
#define IDS_POLICY_TYPE_ERROR 37556
#define IDS_POLICY_OUT_OF_RANGE_ERROR 37557
#define IDS_POLICY_VALUE_FORMAT_ERROR 37558
#define IDS_POLICY_INVALID_FILE_EXTENSION_ERROR 37559
#define IDS_POLICY_INVALID_HASH_ERROR 37560
#define IDS_POLICY_INVALID_SELECTION_ERROR 37561
#define IDS_POLICY_PAPER_SIZE_CUSTOM_NO_SIZE_ERROR 37562
#define IDS_POLICY_PAPER_SIZE_NOT_CUSTOM_ERROR 37563
#define IDS_POLICY_INVALID_ACCOUNT_PATTERN_FORMAT_ERROR 37564
#define IDS_POLICY_INVALID_PROTOCOL_ERROR 37565
#define IDS_POLICY_INVALID_ORIGIN_ERROR 37566
#define IDS_POLICY_EMPTY_ORIGIN_LIST_ERROR 37567
#define IDS_POLICY_INVALID_EXTENSION_ID_ERROR 37569
#define IDS_POLICY_INVALID_UPDATE_URL_ERROR 37570
#define IDS_POLICY_URL_PATH_SPECIFIED_ERROR 37571
#define IDS_POLICY_MISSING_VENDOR_ID_ERROR 37572
#define IDS_POLICY_INVALID_NUMBER_OF_URLS_ERROR 37573
#define IDS_POLICY_BRUSCHETTA_UNINSTALLABLE_ERROR 37574
#define IDS_POLICY_CLOUD_SOURCE_ONLY_ERROR 37575
#define IDS_POLICY_CLOUD_USER_ONLY_ERROR 37576
#define IDS_POLICY_CLOUD_MANAGEMENT_ENROLLMENT_ONLY_ERROR 37577
#define IDS_POLICY_DEFAULT_SEARCH_DISABLED 37578
#define IDS_POLICY_NOT_SPECIFIED_ERROR 37579
#define IDS_POLICY_EXTENSION_SETTINGS_ORIGIN_LIMIT_WARNING 37580
#define IDS_POLICY_URL_ALLOW_BLOCK_LIST_MAX_FILTERS_LIMIT_WARNING 37581
#define IDS_POLICY_ERROR_WITH_PATH 37582
#define IDS_POLICY_SCHEMA_VALIDATION_ERROR 37583
#define IDS_POLICY_INVALID_JSON_ERROR 37584
#define IDS_POLICY_INVALID_URL_ERROR 37585
#define IDS_POLICY_URL_NOT_HTTPS_ERROR 37586
#define IDS_POLICY_INVALID_SEARCH_URL_ERROR 37587
#define IDS_POLICY_INVALID_SECURE_DNS_MODE_ERROR 37588
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_ERROR 37589
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_ERROR 37590
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_SIZE_ERROR 37591
#define IDS_POLICY_SECURE_DNS_TEMPLATES_IRRELEVANT_MODE_ERROR 37592
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_MODE_ERROR 37593
#define IDS_POLICY_SECURE_DNS_TEMPLATES_UNSET_MODE_ERROR 37594
#define IDS_POLICY_SECURE_DNS_TEMPLATES_NOT_SPECIFIED_ERROR 37595
#define IDS_POLICY_INVALID_PROXY_MODE_ERROR 37596
#define IDS_POLICY_OFF_CWS_URL_ERROR 37598
#define IDS_POLICY_HOMEPAGE_LOCATION_ERROR 37599
#define IDS_POLICY_PROXY_MODE_DISABLED_ERROR 37600
#define IDS_POLICY_PROXY_MODE_AUTO_DETECT_ERROR 37601
#define IDS_POLICY_PROXY_MODE_PAC_URL_ERROR 37602
#define IDS_POLICY_PROXY_MODE_FIXED_SERVERS_ERROR 37603
#define IDS_POLICY_PROXY_MODE_SYSTEM_ERROR 37604
#define IDS_POLICY_PROXY_BOTH_SPECIFIED_ERROR 37605
#define IDS_POLICY_PROXY_NEITHER_SPECIFIED_ERROR 37606
#define IDS_POLICY_PROXY_UNKNOWN_CONDITION 37607
#define IDS_POLICY_PROXY_INVALID_SCHEME_HOST_PORT 37608
#define IDS_POLICY_PROXY_INVALID_PROXY 37609
#define IDS_POLICY_PROXY_INVALID_DESTINATION 37610
#define IDS_POLICY_UNAFFILIATED_USER_ERROR 37611
#define IDS_POLICY_DEVELOPER_TOOLS_EXTENSIONS_CONFLICT_MESSAGE 37612
#define IDS_POLICY_OVERRIDDEN 37613
#define IDS_POLICY_VALUE_DEPRECATED 37614
#define IDS_POLICY_DEPENDENCY_ERROR 37615
#define IDS_POLICY_DEPENDENCY_ERROR_ANY_VALUE 37616
#define IDS_POLICY_IDLE_TIMEOUT_ACTIONS_DEPENDENCY_ERROR 37617
#define IDS_POLICY_USER_IS_NOT_AFFILIATED_ERROR 37618
#define IDS_POLICY_LEVEL_ERROR 37623
#define IDS_POLICY_OK 37624
#define IDS_POLICY_RESTART_REQUIRED 37625
#define IDS_POLICY_UNSET 37626
#define IDS_POLICY_UNKNOWN 37627
#define IDS_POLICY_PROTO_PARSING_ERROR 37628
#define IDS_POLICY_HEX_COLOR_ERROR 37629
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_PROVIDERS_LIMIT_ERROR 37630
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_FEATURED_PROVIDERS_LIMIT_ERROR 37631
#define IDS_POLICY_SITE_SEARCH_SETTINGS_DUPLICATED_SHORTCUT 37632
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_CONTAINS_SPACE 37633
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_STARTS_WITH_AT 37634
#define IDS_SEARCH_POLICY_SETTINGS_NO_VALID_PROVIDER 37635
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_IS_EMPTY 37636
#define IDS_SEARCH_POLICY_SETTINGS_NAME_IS_EMPTY 37637
#define IDS_SEARCH_POLICY_SETTINGS_URL_IS_EMPTY 37638
#define IDS_SEARCH_POLICY_SETTINGS_URL_DOESNT_SUPPORT_REPLACEMENT 37639
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_EQUALS_DSP_KEYWORD 37640
#define IDS_POLICY_SITE_SEARCH_SETTINGS_SHORTCUT_EQUALS_SEARCH_AGGREGATOR_KEYWORD 37641
#define IDS_SEARCH_POLICY_SETTINGS_URL_NOT_HTTPS 37642
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEYS 37643
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEY_SETS 37644
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_CONDITION 37645
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_RESTRICTION 37646
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_LEVEL 37647
#define IDS_POLICY_NTP_SHORTCUTS_MAX_SHORTCUTS_LIMIT_ERROR 37648
#define IDS_POLICY_NTP_SHORTCUTS_NO_VALID_PROVIDER 37649
#define IDS_POLICY_NTP_SHORTCUTS_DUPLICATED_URL 37650
#define IDS_POLICY_NTP_SHORTCUTS_NAME_TOO_LONG 37651
#define IDS_POLICY_NTP_SHORTCUTS_URL_TOO_LONG 37652
#define IDS_POLICY_HTTP_HEADER_INJECTION_MAX_URL_PATTERNS_LIMIT_ERROR 37653
#define IDS_POLICY_HTTP_HEADER_INJECTION_MAX_HEADERS_PER_RULE_LIMIT_ERROR 37654
#define IDS_POLICY_HTTP_HEADER_INJECTION_MAX_HEADER_SIZE_LIMIT_ERROR 37655
#define IDS_POLICY_TITLE 37656
#define IDS_POLICY_FILTER_PLACEHOLDER 37657
#define IDS_POLICY_RELOAD_POLICIES 37658
#define IDS_POLICY_RELOADING_POLICIES 37659
#define IDS_POLICY_RELOAD_POLICIES_DONE 37660
#define IDS_EXPORT_POLICIES_JSON 37661
#define IDS_EXPORT_POLICIES_JSON_DONE 37662
#define IDS_UPLOAD_REPORT 37663
#define IDS_REPORT_UPLOADING 37664
#define IDS_REPORT_UPLOADED 37665
#define IDS_POLICY_STATUS 37666
#define IDS_POLICY_STATUS_DEVICE 37667
#define IDS_POLICY_STATUS_USER 37668
#define IDS_POLICY_STATUS_MACHINE 37669
#define IDS_POLICY_STATUS_UPDATER 37670
#define IDS_POLICY_STATUS_ERROR_MANAGED_NO_POLICY 37671
#define IDS_POLICY_STATUS_FLEX_ORG_NO_POLICY 37672
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DOMAIN 37673
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_TOKEN 37674
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DEVICE_ID 37675
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_MACHINE_NAME 37676
#define IDS_POLICY_LABEL_USERNAME 37677
#define IDS_POLICY_LABEL_GAIA_ID 37678
#define IDS_POLICY_LABEL_CLIENT_ID 37679
#define IDS_POLICY_LABEL_PROFILE_ID 37680
#define IDS_POLICY_LABEL_ASSET_ID 37681
#define IDS_POLICY_LABEL_LOCATION 37682
#define IDS_POLICY_LABEL_DIRECTORY_API_ID 37683
#define IDS_POLICY_LABEL_MANAGED_BY 37684
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_FETCH_ATTEMPT 37685
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_REFRESH 37686
#define IDS_POLICY_LABEL_POLICY_FETCH 37687
#define IDS_POLICY_LABEL_EXTENSION_INSTALL_POLICY_FETCH 37688
#define IDS_POLICY_LABEL_LAST_CLOUD_REPORT_SENT_TIMESTAMP 37689
#define IDS_POLICY_NOT_SPECIFIED 37690
#define IDS_POLICY_LABEL_PUSH_POLICIES 37691
#define IDS_POLICY_PUSH_POLICIES_ON 37692
#define IDS_POLICY_PUSH_POLICIES_OFF 37693
#define IDS_POLICY_NEVER_FETCHED 37694
#define IDS_POLICY_LABEL_REFRESH_INTERVAL 37695
#define IDS_POLICY_LABEL_CONFLICT 37696
#define IDS_POLICY_LABEL_SUPERSEDING 37697
#define IDS_POLICY_LABEL_CONFLICT_VALUE 37698
#define IDS_POLICY_LABEL_SUPERSEDED_VALUE 37699
#define IDS_POLICY_LABEL_ERROR 37700
#define IDS_POLICY_LABEL_DEPRECATED 37701
#define IDS_POLICY_LABEL_FUTURE 37702
#define IDS_POLICY_LABEL_IGNORED 37703
#define IDS_POLICY_LABEL_VALUE 37704
#define IDS_POLICY_LABEL_VERSION 37705
#define IDS_POLICY_LABEL_STATUS 37706
#define IDS_POLICY_LABEL_INFO 37707
#define IDS_POLICY_LABEL_PRECEDENCE 37708
#define IDS_POLICY_SHOW_UNSET 37709
#define IDS_POLICY_NO_POLICIES_SET 37710
#define IDS_POLICY_HEADER_SCOPE 37711
#define IDS_POLICY_HEADER_LEVEL 37712
#define IDS_POLICY_HEADER_NAMESPACE 37713
#define IDS_POLICY_HEADER_NAME 37714
#define IDS_POLICY_HEADER_VALUE 37715
#define IDS_POLICY_HEADER_STATUS 37716
#define IDS_POLICY_HEADER_SOURCE 37717
#define IDS_POLICY_HEADER_WARNING 37718
#define IDS_POLICY_SHOW_MORE 37719
#define IDS_POLICY_SHOW_LESS 37720
#define IDS_POLICY_LEARN_MORE 37721
#define IDS_POLICY_SCOPE_USER 37722
#define IDS_POLICY_SCOPE_ALL_USERS 37723
#define IDS_POLICY_SCOPE_DEVICE 37724
#define IDS_POLICY_LEVEL_RECOMMENDED 37725
#define IDS_POLICY_LEVEL_MANDATORY 37726
#define IDS_POLICY_SOURCE_ENTERPRISE_DEFAULT 37727
#define IDS_POLICY_SOURCE_DEFAULT 37728
#define IDS_POLICY_SOURCE_COMMAND_LINE 37729
#define IDS_POLICY_SOURCE_CLOUD 37730
#define IDS_POLICY_SOURCE_MERGED 37731
#define IDS_POLICY_SOURCE_CLOUD_FROM_ASH 37732
#define IDS_POLICY_SOURCE_RESTRICTED_MANAGED_GUEST_SESSION_OVERRIDE 37733
#define IDS_POLICY_SOURCE_ACTIVE_DIRECTORY 37734
#define IDS_POLICY_SOURCE_PLATFORM 37735
#define IDS_POLICY_SOURCE_DEVICE_LOCAL_ACCOUNT_OVERRIDE 37736
#define IDS_POLICY_RISK_TAG_FULL_ADMIN_ACCESS 37737
#define IDS_POLICY_RISK_TAG_SYSTEM_SECURITY 37738
#define IDS_POLICY_RISK_TAG_WEBSITE_SHARING 37739
#define IDS_POLICY_RISK_TAG_ADMIN_SHARING 37740
#define IDS_POLICY_RISK_TAG_FILTERING 37741
#define IDS_POLICY_RISK_TAG_LOCAL_DATA_ACCESS 37742
#define IDS_POLICY_RISK_TAG_GOOGLE_SHARING 37743
#define IDS_POLICY_SHOW_EXPANDED_STATUS 37744
#define IDS_POLICY_HIDE_EXPANDED_STATUS 37745
#define IDS_POLICY_LIST_MERGING_WRONG_POLICY_TYPE_SPECIFIED 37746
#define IDS_POLICY_DICTIONARY_MERGING_WRONG_POLICY_TYPE_SPECIFIED 37747
#define IDS_POLICY_DICTIONARY_MERGING_POLICY_NOT_ALLOWED 37748
#define IDS_POLICY_CONFLICT_SAME_VALUE 37749
#define IDS_POLICY_CONFLICT_DIFF_VALUE 37750
#define IDS_POLICY_USES_SAME_LOCAL_STATE_AND_PROFILE_PREFS 37751
#define IDS_POLICY_USES_LOCAL_STATE_AND_PROFILE_PREFS 37752
#define IDS_POLICY_MIGRATED_OLD_POLICY 37753
#define IDS_POLICY_MIGRATED_NEW_POLICY 37754
#define IDS_POLICY_BLOCKED 37755
#define IDS_POLICY_INVALID 37756
#define IDS_POLICY_IGNORED_BY_GROUP_MERGING 37757
#define IDS_POLICY_INVALID_VALUE 37758
#define IDS_POLICY_IGNORED_MANDATORY_REPORTING_POLICY 37759
#define IDS_POLICY_IGNORED_CHROME_PROFILE 37760
#define IDS_POLICY_IGNORED_UNAFFILIATED 37761
#define IDS_POLICY_IGNORED_EXTENSION 37762
#define IDS_POLICY_EXTENSION_INSTALL_IGNORED_BY_INSTALLATION_MODE 37763
#define IDS_POLICY_PRECEDENCE_PLATFORM_MACHINE 37764
#define IDS_POLICY_PRECEDENCE_PLATFORM_USER 37765
#define IDS_POLICY_PRECEDENCE_CLOUD_MACHINE 37766
#define IDS_POLICY_PRECEDENCE_CLOUD_USER 37767
#define IDS_POLICY_SPELLCHECK_UNKNOWN_LANGUAGE 37768
#define IDS_POLICY_SPELLCHECK_BLOCKLIST_IGNORE 37769
#define IDS_POLICY_DEFAULT_GEO_POLICY_ARC_CONFLICT 37770
#define IDS_POLICY_LABEL_IS_AFFILIATED 37771
#define IDS_POLICY_IS_AFFILIATED_YES 37772
#define IDS_POLICY_IS_AFFILIATED_NO 37773
#define IDS_POLICY_LABEL_IS_OFFHOURS_ACTIVE 37774
#define IDS_POLICY_OFFHOURS_ACTIVE 37775
#define IDS_POLICY_OFFHOURS_NOT_ACTIVE 37776
#define IDS_POLICY_SIGNIN_PROFILE 37777
#define IDS_POLICY_COPY_VALUE 37778
#define IDS_COPY_POLICIES_JSON 37779
#define IDS_COPY_POLICIES_DONE 37780
#define IDS_VIEW_POLICY_LOGS 37781
#define IDS_POLICY_MORE_ACTIONS 37782
#define IDS_POLICY_TABLE_COLUMN_SORT 37783
#define IDS_POLICY_TABLE_COLUMN_SORT_ASCENDING 37784
#define IDS_POLICY_TABLE_COLUMN_SORT_DESCENDING 37785
#define IDS_POLICY_BANNER_PROMOTION_TITLE 37786
#define IDS_POLICY_BANNER_PROMOTION_DESC 37787
#define IDS_POLICY_BANNER_PROMOTION_BTN 37788
#define IDS_DEVTOOLS_BLOCKED_BY_POLICY 37789
#define IDS_DEVTOOLS_NOT_ALLOWED 37790
#define IDS_POLICY_LOGS_TITLE 37791
#define IDS_POLICY_LOGS_FILTER_PLACEHOLDER 37792
#define IDS_VERSION_INFO 37793
#define IDS_EXPORT_POLICY_LOGS_JSON 37794
#define IDS_REFRESH_POLICY_LOGS 37795
#define IDS_POLICY_TEST_TITLE 37796
#define IDS_POLICY_TEST_RESTART_AND_APPLY 37797
#define IDS_POLICY_TEST_APPLY 37798
#define IDS_POLICY_TEST_IMPORT 37799
#define IDS_POLICY_TEST_DESC 37800
#define IDS_POLICY_TEST_REVERT 37801
#define IDS_POLICY_TEST_TABLE_SCOPE 37802
#define IDS_POLICY_TEST_ADD 37803
#define IDS_POLICY_SELECT_NAME 37804
#define IDS_POLICY_TEST_TABLE_PRESET 37805
#define IDS_LOCAL_TEST_POLICIES_ENABLED 37806
#define IDS_POLICY_TEST_PRESET_CUSTOM 37807
#define IDS_POLICY_TEST_PRESET_LOCAL_MACHINE 37808
#define IDS_POLICY_TEST_PRESET_CLOUD_ACCOUNT 37809
#define IDS_POLICY_TEST_USER_AFFILIATED 37810
#define IDS_CHROME_URLS_DISABLED_PAGE_HEADER 37811
#define IDS_CHROME_URLS_DISABLED_PAGE_TITLE 37812
#define IDS_CHROME_URLS_DISABLED_PAGE_MESSAGE 37813
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_PASTE 37814
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_COPY_VM 37815
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_TOAST_BUTTON 37816
#define IDS_POLICY_DLP_ANDROID_APPS 37817
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_DISMISS_BUTTON 37818
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_PASTE 37819
#define IDS_POLICY_DLP_CLIPBOARD_WARN_PROCEED_BUTTON 37820
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_COPY_VM 37821
#define IDS_POLICY_DLP_PRINTING_BLOCKED_TITLE 37822
#define IDS_POLICY_DLP_PRINTING_BLOCKED_MESSAGE 37823
#define IDS_POLICY_DLP_PRINTING_WARN_TITLE 37824
#define IDS_POLICY_DLP_PRINTING_WARN_MESSAGE 37825
#define IDS_POLICY_DLP_PRINTING_WARN_CONTINUE_BUTTON 37826
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_TITLE 37827
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_MESSAGE 37828
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_TITLE 37829
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_MESSAGE 37830
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_TITLE 37831
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_MESSAGE 37832
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_TITLE 37833
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_MESSAGE 37834
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_TITLE 37835
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_MESSAGE 37836
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_TITLE 37837
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_MESSAGE 37838
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_CONTINUE_BUTTON 37839
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_TITLE 37840
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_MESSAGE 37841
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_CONTINUE_BUTTON 37842
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_TITLE 37843
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_MESSAGE 37844
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CONTINUE_BUTTON 37845
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CANCEL_BUTTON 37846
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_TITLE 37847
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_TITLE 37848
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_TITLE 37849
#define IDS_POLICY_DLP_FILES_MOVE_WARN_TITLE 37850
#define IDS_POLICY_DLP_FILES_COPY_WARN_TITLE 37851
#define IDS_POLICY_DLP_FILES_OPEN_WARN_TITLE 37852
#define IDS_POLICY_DLP_FILES_DOWNLOAD_REVIEW_TITLE 37853
#define IDS_POLICY_DLP_FILES_TRANSFER_REVIEW_TITLE 37854
#define IDS_POLICY_DLP_FILES_UPLOAD_REVIEW_TITLE 37855
#define IDS_POLICY_DLP_FILES_MOVE_REVIEW_TITLE 37856
#define IDS_POLICY_DLP_FILES_COPY_REVIEW_TITLE 37857
#define IDS_POLICY_DLP_FILES_OPEN_REVIEW_TITLE 37858
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_MESSAGE 37859
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_MESSAGE 37860
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_MESSAGE 37861
#define IDS_POLICY_DLP_FILES_MOVE_WARN_MESSAGE 37862
#define IDS_POLICY_DLP_FILES_COPY_WARN_MESSAGE 37863
#define IDS_POLICY_DLP_FILES_OPEN_WARN_MESSAGE 37864
#define IDS_POLICY_DLP_FILES_WARN_MESSAGE 37865
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_CONTINUE_BUTTON 37866
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_CONTINUE_BUTTON 37867
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_CONTINUE_BUTTON 37868
#define IDS_POLICY_DLP_FILES_MOVE_WARN_CONTINUE_BUTTON 37869
#define IDS_POLICY_DLP_FILES_COPY_WARN_CONTINUE_BUTTON 37870
#define IDS_POLICY_DLP_FILES_OPEN_WARN_CONTINUE_BUTTON 37871
#define IDS_POLICY_DLP_FILES_DESTINATION_REMOVABLE_STORAGE 37872
#define IDS_POLICY_DLP_FILES_REVIEW_BUTTON 37873
#define IDS_POLICY_DLP_FILES_DISMISS_BUTTON 37874
#define IDS_POLICY_DLP_FILES_OK_BUTTON 37875
#define IDS_POLICY_DLP_WARN_CANCEL_BUTTON 37876
#define IDS_POLICY_DLP_CLIPBOARD_BUBBLE_MESSAGE 37877
#define IDS_POLICY_DLP_FROM_YOUR_ADMIN_MESSAGE 37878
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_TITLE 37879
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_MESSAGE 37880
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_TITLE 37881
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_MESSAGE 37882
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_TITLE 37883
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_MESSAGE 37884
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCKED_TITLE 37885
#define IDS_POLICY_DLP_FILES_TRANSFER_BLOCKED_TITLE 37886
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCKED_TITLE 37887
#define IDS_POLICY_DLP_FILES_MOVE_BLOCKED_TITLE 37888
#define IDS_POLICY_DLP_FILES_COPY_BLOCKED_TITLE 37889
#define IDS_POLICY_DLP_FILES_OPEN_BLOCKED_TITLE 37890
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_SINGLE_FILE_MESSAGE 37891
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_MESSAGE 37892
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_SINGLE_FILE_MESSAGE 37893
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_MESSAGE 37894
#define IDS_POLICY_DLP_FILES_BLOCK_MESSAGE 37895
#define IDS_POLICY_DLP_FILES_DOWNLOAD_JUSTIFICATION_LABEL 37896
#define IDS_POLICY_DLP_FILES_UPLOAD_JUSTIFICATION_LABEL 37897
#define IDS_POLICY_DLP_FILES_COPY_JUSTIFICATION_LABEL 37898
#define IDS_POLICY_DLP_FILES_MOVE_JUSTIFICATION_LABEL 37899
#define IDS_POLICY_DLP_FILES_OPEN_JUSTIFICATION_LABEL 37900
#define IDS_POLICY_DLP_FILES_TRANSFER_JUSTIFICATION_LABEL 37901
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_TITLE 37902
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_TITLE 37903
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_TITLE 37904
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_TITLE 37905
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_TITLE 37906
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_TITLE 37907
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_MESSAGE 37908
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_MESSAGE 37909
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_MESSAGE 37910
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_MESSAGE 37911
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_MESSAGE 37912
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_MESSAGE 37913
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_DATA_CONTROLS_ACCESSIBLE_NAME 37914
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_MALWARE_PROTECTION_ACCESSIBLE_NAME 37915
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_SENSITIVE_DATA_PROTECTION_ACCESSIBLE_NAME 37916
#define IDS_POLICY_DLP_FILES_JUSTIFICATION_TEXTAREA_ACCESSIBLE_DESCRIPTION 37917
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_TITLE 37918
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_MESSAGE 37919
#define IDS_POLICY_REBOOT_BUTTON 37920
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_DIALOG_MESSAGE 37921
#define IDS_REBOOT_SCHEDULED_TITLE_MINUTES 37922
#define IDS_REBOOT_SCHEDULED_TITLE_SECONDS 37923
#define IDS_POLICY_DEVICE_POST_REBOOT_TITLE 37924
#define IDS_POLICY_DEVICE_LOCATED_TITLE 37925
#define IDS_POLICY_DEVICE_LOCATED_MESSAGE 37926
#define IDS_POLICY_BROWSING_DATA_DEPENDENCY_APPLIED_INFO 37927
#define IDS_POLICY_BROWSING_DATA_PLATFORM_UNSUPPORTED 37928
#define IDS_POLICY_NOT_SUPPORTED_AS_USER_POLICY_ON_IOS 37929
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_CONTROL_MESSAGE 37930
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_NO_CONTROL_MESSAGE 37931
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_DISPLAY_SOURCE 37932
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_PHOTO 37933
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_VIDEO 37934
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_SCAN 37935
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_PHOTO 37936
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_VIDEO 37937
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_SCAN 37938
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_BUTTON 37939
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_CANCEL_BUTTON 37940
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DISPLAY_SOURCE 37941
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_CANCEL_BUTTON 37942
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_TITLE 37943
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_TITLE 37944
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ONEDRIVE_MESSAGE 37945
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_ONEDRIVE_MESSAGE 37946
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_GOOGLE_DRIVE_MESSAGE 37947
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_GOOGLE_DRIVE_MESSAGE 37948
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_TITLE 37949
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_MESSAGE 37950
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_SKIP_CHECKBOX 37951
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CANCEL_BUTTON 37952
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CLOSE_BUTTON 37953
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_ONEDRIVE 37954
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_ONEDRIVE 37955
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_ONEDRIVE 37956
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 37957
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 37958
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 37959
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_MESSAGE 37960
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_EDIT_BUTTON 37961
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_DELETE_BUTTON 37962
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_TITLE 37963
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_MESSAGE 37964
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_RETAKE_BUTTON 37965
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_TITLE 37966
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_MESSAGE 37967
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_RETAKE_BUTTON 37968
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_TITLE 37969
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_MESSAGE 37970
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_RETAKE_BUTTON 37971
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ERROR_DISMISS_BUTTON 37972
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_TITLE 37973
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_BUTTON 37974
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_CANCEL_BUTTON 37975
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_DISPLAY_SOURCE 37976
#define IDS_POLICY_SKYVAULT_MIGRATION_BANNER 37977
#define IDS_POLICY_SKYVAULT_MISCONFIGURED_POLICY_MESSAGE 37978
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_TITLE 37979
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_RECORDING_UPLOAD_TITLE 37980
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_ONEDRIVE_MESSAGE 37981
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_CANCEL_BUTTON 37982
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_TITLE 37983
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_BUTTON 37984
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_CANCEL_BUTTON 37985
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_GOOGLE_DRIVE 37986
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_ONEDRIVE 37987
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_TITLE 37988
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_MESSAGE 37989
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_TITLE 37990
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_MESSAGE 37991
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_BUTTON 37992
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_TITLE 37993
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_MESSAGE 37994
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_TITLE 37995
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_MESSAGE 37996
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_BUTTON 37997
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_TITLE 37998
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_MESSAGE 37999
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_BUTTON 38000
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOURS 38001
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOUR 38002
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTES 38003
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTE 38004
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_MESSAGE 38005
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_ON_MESSAGE 38006
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_DONE_MESSAGE 38007
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_NOW_BUTTON 38008
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_HOURS_BUTTON 38009
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_MINUTES_BUTTON 38010
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOURS 38011
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOUR 38012
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTES 38013
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTE 38014
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_START_MESSAGE 38015
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_STORE_MESSAGE 38016
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_NOW_BUTTON 38017
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_HOURS_BUTTON 38018
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_MINUTES_BUTTON 38019
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_TITLE 38020
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_MESSAGE 38021
#define IDS_POLICY_SKYVAULT_DELETION_BANNER 38022
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_SPACE 38023
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_FILE_NOT_EXIST 38024
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_ODFS_SIGN_IN 38025
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_INTERNET 38026
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_GENERIC 38027
#define PRINT_PREVIEW_MEDIA_ASME_F_28X40IN 38028
#define PRINT_PREVIEW_MEDIA_ISO_2A0_1189X1682MM 38029
#define PRINT_PREVIEW_MEDIA_ISO_A0_841X1189MM 38030
#define PRINT_PREVIEW_MEDIA_ISO_A0X3_1189X2523MM 38031
#define PRINT_PREVIEW_MEDIA_ISO_A10_26X37MM 38032
#define PRINT_PREVIEW_MEDIA_ISO_A1_594X841MM 38033
#define PRINT_PREVIEW_MEDIA_ISO_A1X3_841X1783MM 38034
#define PRINT_PREVIEW_MEDIA_ISO_A1X4_841X2378MM 38035
#define PRINT_PREVIEW_MEDIA_ISO_A2_420X594MM 38036
#define PRINT_PREVIEW_MEDIA_ISO_A2X3_594X1261MM 38037
#define PRINT_PREVIEW_MEDIA_ISO_A2X4_594X1682MM 38038
#define PRINT_PREVIEW_MEDIA_ISO_A2X5_594X2102MM 38039
#define PRINT_PREVIEW_MEDIA_ISO_A3_297X420MM 38040
#define PRINT_PREVIEW_MEDIA_ISO_A3_EXTRA_322X445MM 38041
#define PRINT_PREVIEW_MEDIA_ISO_A3X3_420X891MM 38042
#define PRINT_PREVIEW_MEDIA_ISO_A3X4_420X1189MM 38043
#define PRINT_PREVIEW_MEDIA_ISO_A3X5_420X1486MM 38044
#define PRINT_PREVIEW_MEDIA_ISO_A3X6_420X1783MM 38045
#define PRINT_PREVIEW_MEDIA_ISO_A3X7_420X2080MM 38046
#define PRINT_PREVIEW_MEDIA_ISO_A4_210X297MM 38047
#define PRINT_PREVIEW_MEDIA_ISO_A4_EXTRA_235_5X322_3MM 38048
#define PRINT_PREVIEW_MEDIA_ISO_A4_TAB_225X297MM 38049
#define PRINT_PREVIEW_MEDIA_ISO_A4X3_297X630MM 38050
#define PRINT_PREVIEW_MEDIA_ISO_A4X4_297X841MM 38051
#define PRINT_PREVIEW_MEDIA_ISO_A4X5_297X1051MM 38052
#define PRINT_PREVIEW_MEDIA_ISO_A4X6_297X1261MM 38053
#define PRINT_PREVIEW_MEDIA_ISO_A4X7_297X1471MM 38054
#define PRINT_PREVIEW_MEDIA_ISO_A4X8_297X1682MM 38055
#define PRINT_PREVIEW_MEDIA_ISO_A4X9_297X1892MM 38056
#define PRINT_PREVIEW_MEDIA_ISO_A5_148X210MM 38057
#define PRINT_PREVIEW_MEDIA_ISO_A5_EXTRA_174X235MM 38058
#define PRINT_PREVIEW_MEDIA_ISO_A6_105X148MM 38059
#define PRINT_PREVIEW_MEDIA_ISO_A7_74X105MM 38060
#define PRINT_PREVIEW_MEDIA_ISO_A8_52X74MM 38061
#define PRINT_PREVIEW_MEDIA_ISO_A9_37X52MM 38062
#define PRINT_PREVIEW_MEDIA_ISO_B0_1000X1414MM 38063
#define PRINT_PREVIEW_MEDIA_ISO_B10_31X44MM 38064
#define PRINT_PREVIEW_MEDIA_ISO_B1_707X1000MM 38065
#define PRINT_PREVIEW_MEDIA_ISO_B2_500X707MM 38066
#define PRINT_PREVIEW_MEDIA_ISO_B3_353X500MM 38067
#define PRINT_PREVIEW_MEDIA_ISO_B4_250X353MM 38068
#define PRINT_PREVIEW_MEDIA_ISO_B5_176X250MM 38069
#define PRINT_PREVIEW_MEDIA_ISO_B5_EXTRA_201X276MM 38070
#define PRINT_PREVIEW_MEDIA_ISO_B6C4_125X324MM 38071
#define PRINT_PREVIEW_MEDIA_ISO_B6_125X176MM 38072
#define PRINT_PREVIEW_MEDIA_ISO_B7_88X125MM 38073
#define PRINT_PREVIEW_MEDIA_ISO_B8_62X88MM 38074
#define PRINT_PREVIEW_MEDIA_ISO_B9_44X62MM 38075
#define PRINT_PREVIEW_MEDIA_ISO_C0_917X1297MM 38076
#define PRINT_PREVIEW_MEDIA_ISO_C10_28X40MM 38077
#define PRINT_PREVIEW_MEDIA_ISO_C1_648X917MM 38078
#define PRINT_PREVIEW_MEDIA_ISO_C2_458X648MM 38079
#define PRINT_PREVIEW_MEDIA_ISO_C3_324X458MM 38080
#define PRINT_PREVIEW_MEDIA_ISO_C4_229X324MM 38081
#define PRINT_PREVIEW_MEDIA_ISO_C5_162X229MM 38082
#define PRINT_PREVIEW_MEDIA_ISO_C6C5_114X229MM 38083
#define PRINT_PREVIEW_MEDIA_ISO_C6_114X162MM 38084
#define PRINT_PREVIEW_MEDIA_ISO_C7C6_81X162MM 38085
#define PRINT_PREVIEW_MEDIA_ISO_C7_81X114MM 38086
#define PRINT_PREVIEW_MEDIA_ISO_C8_57X81MM 38087
#define PRINT_PREVIEW_MEDIA_ISO_C9_40X57MM 38088
#define PRINT_PREVIEW_MEDIA_ISO_DL_110X220MM 38089
#define PRINT_PREVIEW_MEDIA_ISO_ID_1_53_98X85_6MM 38090
#define PRINT_PREVIEW_MEDIA_ISO_RA0_860X1220MM 38091
#define PRINT_PREVIEW_MEDIA_ISO_RA1_610X860MM 38092
#define PRINT_PREVIEW_MEDIA_ISO_RA2_430X610MM 38093
#define PRINT_PREVIEW_MEDIA_ISO_RA3_305X430MM 38094
#define PRINT_PREVIEW_MEDIA_ISO_RA4_215X305MM 38095
#define PRINT_PREVIEW_MEDIA_ISO_SRA0_900X1280MM 38096
#define PRINT_PREVIEW_MEDIA_ISO_SRA1_640X900MM 38097
#define PRINT_PREVIEW_MEDIA_ISO_SRA2_450X640MM 38098
#define PRINT_PREVIEW_MEDIA_ISO_SRA3_320X450MM 38099
#define PRINT_PREVIEW_MEDIA_ISO_SRA4_225X320MM 38100
#define PRINT_PREVIEW_MEDIA_JIS_B0_1030X1456MM 38101
#define PRINT_PREVIEW_MEDIA_JIS_B1_728X1030MM 38102
#define PRINT_PREVIEW_MEDIA_JIS_B2_515X728MM 38103
#define PRINT_PREVIEW_MEDIA_JIS_B3_364X515MM 38104
#define PRINT_PREVIEW_MEDIA_JIS_B4_257X364MM 38105
#define PRINT_PREVIEW_MEDIA_JIS_B5_182X257MM 38106
#define PRINT_PREVIEW_MEDIA_JIS_B6_128X182MM 38107
#define PRINT_PREVIEW_MEDIA_JIS_B7_91X128MM 38108
#define PRINT_PREVIEW_MEDIA_JIS_B8_64X91MM 38109
#define PRINT_PREVIEW_MEDIA_JIS_B9_45X64MM 38110
#define PRINT_PREVIEW_MEDIA_JIS_B10_32X45MM 38111
#define PRINT_PREVIEW_MEDIA_JIS_EXEC_216X330MM 38112
#define PRINT_PREVIEW_MEDIA_JPN_CHOU2_111_1X146MM 38113
#define PRINT_PREVIEW_MEDIA_JPN_CHOU3_120X235MM 38114
#define PRINT_PREVIEW_MEDIA_JPN_CHOU4_90X205MM 38115
#define PRINT_PREVIEW_MEDIA_JPN_CHOU40_90X225MM 38116
#define PRINT_PREVIEW_MEDIA_JPN_HAGAKI_100X148MM 38117
#define PRINT_PREVIEW_MEDIA_JPN_KAHU_240X322_1MM 38118
#define PRINT_PREVIEW_MEDIA_JPN_KAKU1_270X382MM 38119
#define PRINT_PREVIEW_MEDIA_JPN_KAKU2_240X332MM 38120
#define PRINT_PREVIEW_MEDIA_JPN_KAKU3_216X277MM 38121
#define PRINT_PREVIEW_MEDIA_JPN_KAKU4_197X267MM 38122
#define PRINT_PREVIEW_MEDIA_JPN_KAKU5_190X240MM 38123
#define PRINT_PREVIEW_MEDIA_JPN_KAKU7_142X205MM 38124
#define PRINT_PREVIEW_MEDIA_JPN_KAKU8_119X197MM 38125
#define PRINT_PREVIEW_MEDIA_JPN_OUFUKU_148X200MM 38126
#define PRINT_PREVIEW_MEDIA_JPN_YOU4_105X235MM 38127
#define PRINT_PREVIEW_MEDIA_JPN_YOU6_98X190MM 38128
#define PRINT_PREVIEW_MEDIA_NA_10X11_10X11IN 38129
#define PRINT_PREVIEW_MEDIA_NA_10X13_10X13IN 38130
#define PRINT_PREVIEW_MEDIA_NA_10X14_10X14IN 38131
#define PRINT_PREVIEW_MEDIA_NA_10X15_10X15IN 38132
#define PRINT_PREVIEW_MEDIA_NA_11X12_11X12IN 38133
#define PRINT_PREVIEW_MEDIA_NA_11X15_11X15IN 38134
#define PRINT_PREVIEW_MEDIA_NA_12X19_12X19IN 38135
#define PRINT_PREVIEW_MEDIA_NA_5X7_5X7IN 38136
#define PRINT_PREVIEW_MEDIA_NA_6X9_6X9IN 38137
#define PRINT_PREVIEW_MEDIA_NA_7X9_7X9IN 38138
#define PRINT_PREVIEW_MEDIA_NA_9X11_9X11IN 38139
#define PRINT_PREVIEW_MEDIA_NA_A2_4_375X5_75IN 38140
#define PRINT_PREVIEW_MEDIA_NA_ARCH_A_9X12IN 38141
#define PRINT_PREVIEW_MEDIA_NA_ARCH_B_12X18IN 38142
#define PRINT_PREVIEW_MEDIA_NA_ARCH_C_18X24IN 38143
#define PRINT_PREVIEW_MEDIA_NA_ARCH_D_24X36IN 38144
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E_36X48IN 38145
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E2_26X38IN 38146
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E3_27X39IN 38147
#define PRINT_PREVIEW_MEDIA_NA_B_PLUS_12X19_17IN 38148
#define PRINT_PREVIEW_MEDIA_NA_C5_6_5X9_5IN 38149
#define PRINT_PREVIEW_MEDIA_NA_C_17X22IN 38150
#define PRINT_PREVIEW_MEDIA_NA_D_22X34IN 38151
#define PRINT_PREVIEW_MEDIA_NA_EDP_11X14IN 38152
#define PRINT_PREVIEW_MEDIA_NA_EUR_EDP_12X14IN 38153
#define PRINT_PREVIEW_MEDIA_NA_E_34X44IN 38154
#define PRINT_PREVIEW_MEDIA_NA_EXECUTIVE_7_25X10_5IN 38155
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_EUR_8_5X12IN 38156
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_US_11X14_875IN 38157
#define PRINT_PREVIEW_MEDIA_NA_FOOLSCAP_8_5X13IN 38158
#define PRINT_PREVIEW_MEDIA_NA_F_44X68IN 38159
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LEGAL_8X13IN 38160
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LETTER_8X10IN 38161
#define PRINT_PREVIEW_MEDIA_NA_INDEX_3X5_3X5IN 38162
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_4X6IN 38163
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_EXT_6X8IN 38164
#define PRINT_PREVIEW_MEDIA_NA_INDEX_5X8_5X8IN 38165
#define PRINT_PREVIEW_MEDIA_NA_INVOICE_5_5X8_5IN 38166
#define PRINT_PREVIEW_MEDIA_NA_LEDGER_11X17IN 38167
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_8_5X14IN 38168
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_EXTRA_9_5X15IN 38169
#define PRINT_PREVIEW_MEDIA_NA_LETTER_8_5X11IN 38170
#define PRINT_PREVIEW_MEDIA_NA_LETTER_EXTRA_9_5X12IN 38171
#define PRINT_PREVIEW_MEDIA_NA_LETTER_PLUS_8_5X12_69IN 38172
#define PRINT_PREVIEW_MEDIA_NA_MONARCH_3_875X7_5IN 38173
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_9_3_875X8_875IN 38174
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_10_4_125X9_5IN 38175
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_11_4_5X10_375IN 38176
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_12_4_75X11IN 38177
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_14_5X11_5IN 38178
#define PRINT_PREVIEW_MEDIA_NA_OFICIO_8_5X13_4IN 38179
#define PRINT_PREVIEW_MEDIA_NA_PERSONAL_3_625X6_5IN 38180
#define PRINT_PREVIEW_MEDIA_NA_QUARTO_8_5X10_83IN 38181
#define PRINT_PREVIEW_MEDIA_NA_SUPER_A_8_94X14IN 38182
#define PRINT_PREVIEW_MEDIA_NA_SUPER_B_13X19IN 38183
#define PRINT_PREVIEW_MEDIA_NA_WIDE_FORMAT_30X42IN 38184
#define PRINT_PREVIEW_MEDIA_OE_12X16_12X16IN 38185
#define PRINT_PREVIEW_MEDIA_OE_14X17_14X17IN 38186
#define PRINT_PREVIEW_MEDIA_OE_18X22_18X22IN 38187
#define PRINT_PREVIEW_MEDIA_OE_A2PLUS_17X24IN 38188
#define PRINT_PREVIEW_MEDIA_OE_BUSINESS_CARD_2X3_5IN 38189
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_10R_10X12IN 38190
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_12R_12X15IN 38191
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_14X18_14X18IN 38192
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_16R_16X20IN 38193
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_20R_20X24IN 38194
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22R_22X29_5IN 38195
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22X28_22X28IN 38196
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24R_24X31_5IN 38197
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24X30_24X30IN 38198
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_30R_30X40IN 38199
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_L_3_5X5IN 38200
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_S8R_8X12IN 38201
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_4X4IN 38202
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_5X5IN 38203
#define PRINT_PREVIEW_MEDIA_OM_16K_184X260MM 38204
#define PRINT_PREVIEW_MEDIA_OM_16K_195X270MM 38205
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X85MM 38206
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X91MM 38207
#define PRINT_PREVIEW_MEDIA_OM_CARD_54X86MM 38208
#define PRINT_PREVIEW_MEDIA_OM_DAI_PA_KAI_275X395MM 38209
#define PRINT_PREVIEW_MEDIA_OM_DSC_PHOTO_89X119MM 38210
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_210X330MM 38211
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_SP_215X315MM 38212
#define PRINT_PREVIEW_MEDIA_OM_INVITE_220X220MM 38213
#define PRINT_PREVIEW_MEDIA_OM_ITALIAN_110X230MM 38214
#define PRINT_PREVIEW_MEDIA_OM_JUURO_KU_KAI_198X275MM 38215
#define PRINT_PREVIEW_MEDIA_OM_LARGE_PHOTO_200X300 38216
#define PRINT_PREVIEW_MEDIA_OM_MEDIUM_PHOTO_130X180MM 38217
#define PRINT_PREVIEW_MEDIA_OM_PA_KAI_267X389MM 38218
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X40_300X400MM 38219
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X45_300X450MM 38220
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_35X46_350X460MM 38221
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_40X60_400X600MM 38222
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X75_500X750MM 38223
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X76_500X760MM 38224
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_60X90_600X900MM 38225
#define PRINT_PREVIEW_MEDIA_OM_SQUARE_PHOTO_89X89MM 38226
#define PRINT_PREVIEW_MEDIA_OM_WIDE_PHOTO_100X200MM 38227
#define PRINT_PREVIEW_MEDIA_OM_SMALL_PHOTO_100X150MM 38228
#define PRINT_PREVIEW_MEDIA_PRC_16K_146X215MM 38229
#define PRINT_PREVIEW_MEDIA_PRC_1_102X165MM 38230
#define PRINT_PREVIEW_MEDIA_PRC_2_102X176MM 38231
#define PRINT_PREVIEW_MEDIA_PRC_32K_97X151MM 38232
#define PRINT_PREVIEW_MEDIA_PRC_4_110X208MM 38233
#define PRINT_PREVIEW_MEDIA_PRC_6_120X320MM 38234
#define PRINT_PREVIEW_MEDIA_PRC_7_160X230MM 38235
#define PRINT_PREVIEW_MEDIA_PRC_8_120X309MM 38236
#define PRINT_PREVIEW_MEDIA_ROC_16K_7_75X10_75IN 38237
#define PRINT_PREVIEW_MEDIA_ROC_8K_10_75X15_5IN 38238
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_INCHES 38239
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_MM 38240
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_INCHES 38241
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_MM 38242
#define IDS_PRINT_COMPOSITOR_SERVICE_DISPLAY_NAME 38244
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_TITLE 38648
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_1 38649
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_2 38650
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_3 38651
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_EXPAND_LABEL 38652
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_4 38653
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_1 38654
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_2 38655
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_3 38656
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_LINK 38657
#define IDS_SETTINGS_TOPICS_PAGE_TITLE 38658
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_LABEL 38659
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_SUB_LABEL_V2 38660
#define IDS_SETTINGS_TOPICS_PAGE_DISCLAIMER_DESKTOP 38661
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_CANONICAL 38662
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_DISABLED 38663
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 38664
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 38665
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 38666
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 38667
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC 38668
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC_A11Y_LABEL 38669
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC 38670
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC_A11Y_LABEL 38671
#define IDS_SETTINGS_TOPICS_PAGE_UNBLOCK_TOPIC_A11Y_LABEL 38672
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_CANONICAL 38673
#define IDS_SETTINGS_TOPICS_PAGE_FIRST_LEVEL_TOPIC_DESCRIPTOR 38674
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_TITLE 38675
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_BODY 38676
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_TITLE 38677
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_BODY 38678
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION 38679
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_LEARN_MORE_LINK 38680
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION_LEARN_MORE_ARIA_LABEL 38681
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BODY 38682
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BUTTON_TEXT 38683
#define IDS_SETTINGS_FLEDGE_PAGE_FOOTER_V2 38684
#define IDS_SETTINGS_UNBLOCK_TOPIC_BUTTON_TEXT_V2 38685
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_HEADING_NEW 38686
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_NEW 38687
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_HEADING 38688
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_DESCRIPTION 38689
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_EXPLANATION 38690
#define IDS_SETTINGS_TOPICS_PAGE_ACTIVE_TOPICS_HEADING 38691
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_STATUS_LABEL 38692
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TIME_LABEL 38693
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_SOURCE_LABEL 38694
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TEXT_LABEL 38695
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_SETTINGS 38696
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_DEFAULT 38697
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_CONFIRMATION 38698
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_ACTIVE 38699
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_INACTIVE 38700
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_NOT_REQUIRED 38701
#define IDS_PRIVACY_SANDBOX_TOPICS_INVALID_TOPIC 38702
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_1 38703
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_2 38704
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_3 38705
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_4 38706
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_5 38707
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_6 38708
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_7 38709
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_8 38710
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_9 38711
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_10 38712
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_11 38713
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_12 38714
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_13 38715
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_14 38716
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_15 38717
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_16 38718
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_17 38719
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_18 38720
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_19 38721
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_20 38722
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_21 38723
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_22 38724
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_23 38725
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_24 38726
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_25 38727
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_26 38728
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_27 38729
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_28 38730
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_29 38731
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_30 38732
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_31 38733
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_32 38734
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_33 38735
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_34 38736
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_35 38737
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_36 38738
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_37 38739
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_38 38740
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_39 38741
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_40 38742
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_41 38743
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_42 38744
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_43 38745
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_44 38746
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_45 38747
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_46 38748
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_47 38749
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_48 38750
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_49 38751
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_50 38752
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_51 38753
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_52 38754
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_53 38755
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_54 38756
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_55 38757
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_56 38758
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_57 38759
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_58 38760
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_59 38761
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_60 38762
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_61 38763
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_62 38764
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_63 38765
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_64 38766
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_65 38767
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_66 38768
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_67 38769
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_68 38770
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_69 38771
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_70 38772
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_71 38773
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_72 38774
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_73 38775
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_74 38776
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_75 38777
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_76 38778
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_77 38779
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_78 38780
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_79 38781
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_80 38782
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_81 38783
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_82 38784
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_83 38785
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_84 38786
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_85 38787
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_86 38788
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_87 38789
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_88 38790
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_89 38791
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_90 38792
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_91 38793
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_92 38794
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_93 38795
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_94 38796
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_95 38797
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_96 38798
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_97 38799
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_98 38800
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_99 38801
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_100 38802
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_101 38803
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_102 38804
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_103 38805
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_104 38806
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_105 38807
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_106 38808
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_107 38809
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_108 38810
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_109 38811
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_110 38812
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_111 38813
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_112 38814
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_113 38815
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_114 38816
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_115 38817
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_116 38818
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_117 38819
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_118 38820
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_119 38821
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_120 38822
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_121 38823
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_122 38824
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_123 38825
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_124 38826
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_125 38827
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_126 38828
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_127 38829
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_128 38830
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_129 38831
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_130 38832
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_131 38833
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_132 38834
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_133 38835
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_134 38836
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_135 38837
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_136 38838
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_137 38839
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_138 38840
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_139 38841
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_140 38842
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_141 38843
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_142 38844
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_143 38845
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_144 38846
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_145 38847
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_146 38848
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_147 38849
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_148 38850
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_149 38851
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_150 38852
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_151 38853
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_152 38854
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_153 38855
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_154 38856
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_155 38857
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_156 38858
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_157 38859
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_158 38860
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_159 38861
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_160 38862
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_161 38863
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_162 38864
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_163 38865
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_164 38866
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_165 38867
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_166 38868
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_167 38869
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_168 38870
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_169 38871
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_170 38872
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_171 38873
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_172 38874
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_173 38875
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_174 38876
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_175 38877
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_176 38878
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_177 38879
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_178 38880
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_179 38881
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_180 38882
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_181 38883
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_182 38884
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_183 38885
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_184 38886
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_185 38887
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_186 38888
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_187 38889
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_188 38890
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_189 38891
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_190 38892
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_191 38893
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_192 38894
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_193 38895
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_194 38896
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_195 38897
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_196 38898
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_197 38899
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_198 38900
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_199 38901
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_200 38902
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_201 38903
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_202 38904
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_203 38905
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_204 38906
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_205 38907
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_206 38908
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_207 38909
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_208 38910
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_209 38911
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_210 38912
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_211 38913
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_212 38914
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_213 38915
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_214 38916
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_215 38917
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_216 38918
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_217 38919
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_218 38920
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_219 38921
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_220 38922
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_221 38923
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_222 38924
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_223 38925
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_224 38926
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_225 38927
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_226 38928
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_227 38929
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_228 38930
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_229 38931
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_230 38932
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_231 38933
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_232 38934
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_233 38935
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_234 38936
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_235 38937
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_236 38938
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_237 38939
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_238 38940
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_239 38941
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_240 38942
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_241 38943
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_242 38944
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_243 38945
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_244 38946
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_245 38947
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_246 38948
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_247 38949
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_248 38950
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_249 38951
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_250 38952
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_251 38953
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_252 38954
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_253 38955
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_254 38956
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_255 38957
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_256 38958
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_257 38959
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_258 38960
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_259 38961
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_260 38962
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_261 38963
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_262 38964
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_263 38965
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_264 38966
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_265 38967
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_266 38968
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_267 38969
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_268 38970
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_269 38971
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_270 38972
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_271 38973
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_272 38974
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_273 38975
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_274 38976
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_275 38977
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_276 38978
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_277 38979
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_278 38980
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_279 38981
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_280 38982
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_281 38983
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_282 38984
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_283 38985
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_284 38986
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_285 38987
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_286 38988
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_287 38989
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_288 38990
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_289 38991
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_290 38992
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_291 38993
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_292 38994
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_293 38995
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_294 38996
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_295 38997
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_296 38998
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_297 38999
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_298 39000
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_299 39001
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_300 39002
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_301 39003
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_302 39004
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_303 39005
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_304 39006
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_305 39007
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_306 39008
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_307 39009
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_308 39010
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_309 39011
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_310 39012
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_311 39013
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_312 39014
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_313 39015
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_314 39016
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_315 39017
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_316 39018
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_317 39019
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_318 39020
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_319 39021
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_320 39022
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_321 39023
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_322 39024
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_323 39025
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_324 39026
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_325 39027
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_326 39028
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_327 39029
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_328 39030
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_329 39031
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_330 39032
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_331 39033
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_332 39034
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_333 39035
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_334 39036
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_335 39037
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_336 39038
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_337 39039
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_338 39040
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_339 39041
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_340 39042
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_341 39043
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_342 39044
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_343 39045
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_344 39046
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_345 39047
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_346 39048
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_347 39049
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_348 39050
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_349 39051
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_350 39052
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_351 39053
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_352 39054
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_353 39055
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_354 39056
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_355 39057
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_356 39058
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_357 39059
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_358 39060
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_359 39061
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_360 39062
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_361 39063
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_362 39064
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_363 39065
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_364 39066
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_365 39067
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_366 39068
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_367 39069
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_368 39070
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_369 39071
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_370 39072
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_371 39073
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_372 39074
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_373 39075
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_374 39076
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_375 39077
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_376 39078
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_377 39079
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_378 39080
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_379 39081
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_380 39082
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_381 39083
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_382 39084
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_383 39085
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_384 39086
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_385 39087
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_386 39088
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_387 39089
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_388 39090
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_389 39091
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_390 39092
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_391 39093
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_392 39094
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_393 39095
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_394 39096
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_395 39097
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_396 39098
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_397 39099
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_398 39100
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_399 39101
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_400 39102
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_401 39103
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_402 39104
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_403 39105
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_404 39106
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_405 39107
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_406 39108
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_407 39109
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_408 39110
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_409 39111
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_410 39112
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_411 39113
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_412 39114
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_413 39115
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_414 39116
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_415 39117
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_416 39118
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_417 39119
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_418 39120
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_419 39121
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_420 39122
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_421 39123
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_422 39124
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_423 39125
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_424 39126
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_425 39127
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_426 39128
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_427 39129
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_428 39130
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_429 39131
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_430 39132
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_431 39133
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_432 39134
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_433 39135
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_434 39136
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_435 39137
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_436 39138
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_437 39139
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_438 39140
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_439 39141
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_440 39142
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_441 39143
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_442 39144
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_443 39145
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_444 39146
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_445 39147
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_446 39148
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_447 39149
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_448 39150
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_449 39151
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_450 39152
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_451 39153
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_452 39154
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_453 39155
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_454 39156
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_455 39157
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_456 39158
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_457 39159
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_458 39160
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_459 39161
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_460 39162
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_461 39163
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_462 39164
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_463 39165
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_464 39166
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_465 39167
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_466 39168
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_467 39169
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_468 39170
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_469 39171
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_470 39172
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_471 39173
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_472 39174
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_473 39175
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_474 39176
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_475 39177
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_476 39178
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_477 39179
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_478 39180
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_479 39181
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_480 39182
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_481 39183
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_482 39184
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_483 39185
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_484 39186
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_485 39187
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_486 39188
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_487 39189
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_488 39190
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_489 39191
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_490 39192
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_491 39193
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_492 39194
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_493 39195
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_494 39196
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_495 39197
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_496 39198
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_497 39199
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_498 39200
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_499 39201
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_500 39202
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_501 39203
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_502 39204
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_503 39205
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_504 39206
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_505 39207
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_506 39208
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_507 39209
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_508 39210
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_509 39211
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_510 39212
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_511 39213
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_512 39214
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_513 39215
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_514 39216
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_515 39217
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_516 39218
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_517 39219
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_518 39220
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_519 39221
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_520 39222
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_521 39223
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_522 39224
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_523 39225
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_524 39226
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_525 39227
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_526 39228
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_527 39229
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_528 39230
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_529 39231
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_530 39232
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_531 39233
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_532 39234
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_533 39235
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_534 39236
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_535 39237
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_536 39238
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_537 39239
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_538 39240
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_539 39241
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_540 39242
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_541 39243
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_542 39244
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_543 39245
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_544 39246
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_545 39247
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_546 39248
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_547 39249
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_548 39250
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_549 39251
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_550 39252
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_551 39253
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_552 39254
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_553 39255
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_554 39256
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_555 39257
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_556 39258
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_557 39259
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_558 39260
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_559 39261
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_560 39262
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_561 39263
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_562 39264
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_563 39265
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_564 39266
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_565 39267
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_566 39268
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_567 39269
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_568 39270
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_569 39271
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_570 39272
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_571 39273
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_572 39274
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_573 39275
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_574 39276
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_575 39277
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_576 39278
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_577 39279
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_578 39280
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_579 39281
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_580 39282
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_581 39283
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_582 39284
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_583 39285
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_584 39286
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_585 39287
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_586 39288
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_587 39289
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_588 39290
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_589 39291
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_590 39292
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_591 39293
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_592 39294
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_593 39295
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_594 39296
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_595 39297
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_596 39298
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_597 39299
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_598 39300
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_599 39301
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_600 39302
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_601 39303
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_602 39304
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_603 39305
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_604 39306
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_605 39307
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_606 39308
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_607 39309
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_608 39310
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_609 39311
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_610 39312
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_611 39313
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_612 39314
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_613 39315
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_614 39316
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_615 39317
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_616 39318
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_617 39319
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_618 39320
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_619 39321
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_620 39322
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_621 39323
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_622 39324
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_623 39325
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_624 39326
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_625 39327
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_626 39328
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_627 39329
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_628 39330
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_629 39331
#define IDS_REGISTER_PROTOCOL_HANDLER_TOOLTIP 39332
#define IDS_REGISTER_PROTOCOL_HANDLER_MAILTO_NAME 39333
#define IDS_REGISTER_PROTOCOL_HANDLER_WEBCAL_NAME 39334
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM 39335
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE 39336
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_FRAGMENT 39337
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE_FRAGMENT 39338
#define IDS_REGISTER_PROTOCOL_HANDLER_ACCEPT 39339
#define IDS_REGISTER_PROTOCOL_HANDLER_DENY 39340
#define IDS_REGISTER_PROTOCOL_HANDLER_IGNORE 39341
#define IDS_CONFIRM_PROTOCOL_HANDLER_TITLE 39342
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE 39343
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE_WITH_INITIATING_ORIGIN 39344
#define IDS_CONFIRM_PROTOCOL_HANDLER_REMEMBER 39345
#define IDS_RESET_PASSWORD_TITLE 39346
#define IDS_RESET_PASSWORD_WARNING_HEADING 39347
#define IDS_RESET_PASSWORD_WARNING_HEADING_V2 39348
#define IDS_RESET_PASSWORD_WARNING_HEADING_WITH_ORG_NAME 39349
#define IDS_RESET_PASSWORD_HEADING 39350
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH 39351
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_V2 39352
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 39353
#define IDS_RESET_PASSWORD_BUTTON 39354
#define IDS_RESET_PASSWORD_LEARN_MORE 39355
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH 39356
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 39357
#define IDS_SAVED_TAB_GROUPS_CREATION_JUST_NOW 39358
#define IDS_SAVED_TAB_GROUPS_CREATION_MINUTES_AGO_FORMAT 39359
#define IDS_SAVED_TAB_GROUPS_CREATION_HOURS_AGO_FORMAT 39360
#define IDS_SAVED_TAB_GROUPS_CREATION_DAYS_AGO_FORMAT 39361
#define IDS_SAVED_TAB_GROUPS_CREATION_MONTHS_AGO_FORMAT 39362
#define IDS_SAVED_TAB_GROUPS_CREATION_YEARS_AGO_FORMAT 39363
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE 39364
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE_NON_EEA 39365
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CHANGE_DEFAULT_ENGINE 39366
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CONFIRMATION_TOAST_LABEL 39367
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_ENTRY_POINT_SUBTITLE 39368
#define IDS_SEARCH_ENGINE_CHOICE_BUTTON_TITLE 39369
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_TITLE 39370
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE 39371
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK 39372
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK_A11Y_LABEL 39373
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_TITLE 39380
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_FIRST_PARAGRAPH 39381
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_SECOND_PARAGRAPH 39382
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_THIRD_PARAGRAPH 39383
#define IDS_SEARCH_ENGINE_FALLBACK_MARKETING_SNIPPET 39384
#define IDS_SEARCH_ENGINE_CHOICE_MORE_BUTTON 39385
#define IDS_SEARCH_ENGINE_CHOICE_CONTINUE_BUTTON 39386
#define IDS_SEARCH_ENGINE_CHOICE_CHEVRON_A11Y_LABEL 39387
#define IDS_SEARCH_ENGINE_CHOICE_LIST_A11Y_LABEL 39388
#define IDS_SEARCH_ENGINE_CHOICE_GUEST_SESSION_CHECKBOX 39389
#define IDS_SSL_OPEN_DETAILS_BUTTON 39390
#define IDS_SSL_CLOSE_DETAILS_BUTTON 39391
#define IDS_CAPTIVE_PORTAL_AUTHORIZATION_DIALOG_NAME 39392
#define IDS_CAPTIVE_PORTAL_HEADING_WIRED 39393
#define IDS_CAPTIVE_PORTAL_HEADING_WIFI 39394
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIRED 39395
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI 39396
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI_SSID 39397
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIRED 39398
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI 39399
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI_SSID 39400
#define IDS_CAPTIVE_PORTAL_BUTTON_OPEN_LOGIN_PAGE 39401
#define IDS_MITM_SOFTWARE_HEADING 39402
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_ENTERPRISE 39403
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_NONENTERPRISE 39404
#define IDS_MITM_SOFTWARE_EXPLANATION_ENTERPRISE 39405
#define IDS_MITM_SOFTWARE_EXPLANATION_NONENTERPRISE 39406
#define IDS_MITM_SOFTWARE_EXPLANATION 39407
#define IDS_LOOKALIKE_URL_TITLE 39408
#define IDS_LOOKALIKE_URL_HEADING 39409
#define IDS_LOOKALIKE_URL_IGNORE 39410
#define IDS_LOOKALIKE_URL_CONTINUE 39411
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH 39412
#define IDS_LOOKALIKE_URL_HEADING_NO_SUGGESTED_URL 39413
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH_NO_SUGGESTED_URL 39414
#define IDS_LOOKALIKE_URL_BACK_TO_SAFETY 39415
#define IDS_LOOKALIKE_URL_CLOSE_PAGE 39416
#define IDS_ENTERPRISE_BLOCK_TITLE 39417
#define IDS_ENTERPRISE_BLOCK_HEADING 39418
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH 39419
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 39420
#define IDS_ENTERPRISE_BLOCK_GO_BACK 39421
#define IDS_ENTERPRISE_WARN_TITLE 39422
#define IDS_ENTERPRISE_WARN_HEADING 39423
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH 39424
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 39425
#define IDS_ENTERPRISE_WARN_GO_BACK 39426
#define IDS_ENTERPRISE_WARN_CONTINUE_TO_SITE 39427
#define IDS_ENTERPRISE_INTERSTITIALS_LEARN_MORE_ACCCESSIBILITY_TEXT 39428
#define IDS_CLOCK_ERROR_TITLE 39429
#define IDS_CLOCK_ERROR_AHEAD_HEADING 39430
#define IDS_CLOCK_ERROR_BEHIND_HEADING 39431
#define IDS_CLOCK_ERROR_UPDATE_DATE_AND_TIME 39432
#define IDS_CLOCK_ERROR_PRIMARY_PARAGRAPH 39433
#define IDS_CLOCK_ERROR_EXPLANATION 39434
#define IDS_SSL_V2_TITLE 39435
#define IDS_SSL_V2_HEADING 39436
#define IDS_SSL_V2_PRIMARY_PARAGRAPH 39437
#define IDS_SSL_OVERRIDABLE_SAFETY_BUTTON 39438
#define IDS_SSL_OVERRIDABLE_CLOSE_PAGE_BUTTON 39439
#define IDS_SSL_OVERRIDABLE_PROCEED_PARAGRAPH 39440
#define IDS_SSL_RELOAD 39441
#define IDS_SSL_NONOVERRIDABLE_PINNED 39442
#define IDS_SSL_NONOVERRIDABLE_HSTS 39443
#define IDS_SSL_NONOVERRIDABLE_REVOKED 39444
#define IDS_SSL_NONOVERRIDABLE_MORE 39445
#define IDS_SSL_NONOVERRIDABLE_INVALID 39446
#define IDS_SAFEBROWSING_V3_TITLE 39447
#define IDS_SAFEBROWSING_V3_OPEN_DETAILS_BUTTON 39448
#define IDS_SAFEBROWSING_V3_CLOSE_DETAILS_BUTTON 39449
#define IDS_SAFEBROWSING_OVERRIDABLE_SAFETY_BUTTON 39450
#define IDS_SAFEBROWSING_HEADING 39451
#define IDS_MALWARE_V3_PRIMARY_PARAGRAPH 39452
#define IDS_MALWARE_V3_EXPLANATION_PARAGRAPH 39453
#define IDS_MALWARE_V3_PROCEED_PARAGRAPH 39454
#define IDS_SAFE_BROWSING_SCOUT_REPORTING_AGREE 39455
#define IDS_SAFE_BROWSING_ENHANCED_PROTECTION_MESSAGE 39456
#define IDS_HARMFUL_V3_PRIMARY_PARAGRAPH 39457
#define IDS_HARMFUL_V3_EXPLANATION_PARAGRAPH 39458
#define IDS_HARMFUL_V3_PROCEED_PARAGRAPH 39459
#define IDS_PHISHING_V4_PRIMARY_PARAGRAPH 39460
#define IDS_PHISHING_V4_EXPLANATION_PARAGRAPH 39461
#define IDS_PHISHING_V4_PROCEED_PARAGRAPH 39462
#define IDS_MALWARE_WEBVIEW_HEADING 39463
#define IDS_MALWARE_WEBVIEW_EXPLANATION_PARAGRAPH 39464
#define IDS_PHISHING_WEBVIEW_HEADING 39465
#define IDS_PHISHING_WEBVIEW_EXPLANATION_PARAGRAPH 39466
#define IDS_HARMFUL_WEBVIEW_HEADING 39467
#define IDS_HARMFUL_WEBVIEW_EXPLANATION_PARAGRAPH 39468
#define IDS_BILLING_WEBVIEW_HEADING 39469
#define IDS_BILLING_WEBVIEW_EXPLANATION_PARAGRAPH 39470
#define IDS_SUPERVISED_USER_URL_BLOCKED_MESSAGE 39471
#define IDS_SUPERVISED_USER_LEARN_MORE 39472
#define IDS_CONNECTION_HELP_SHOW_MORE 39473
#define IDS_CONNECTION_HELP_SHOW_LESS 39474
#define IDS_CONNECTION_HELP_TITLE 39475
#define IDS_CONNECTION_HELP_HEADING 39476
#define IDS_CONNECTION_HELP_GENERAL_HELP 39477
#define IDS_CONNECTION_HELP_SPECIFIC_ERROR_HEADING 39478
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_TITLE 39479
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_TITLE 39480
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_TITLE 39481
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_DETAILS 39482
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_DETAILS 39483
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_DETAILS 39484
#define IDS_BILLING_TITLE 39487
#define IDS_BILLING_HEADING 39488
#define IDS_BILLING_PRIMARY_PARAGRAPH 39489
#define IDS_BILLING_PRIMARY_BUTTON 39490
#define IDS_BILLING_PROCEED_BUTTON 39491
#define IDS_BLOCKED_INTERCEPTION_HEADING 39492
#define IDS_KNOWN_INTERCEPTION_TITLE 39493
#define IDS_KNOWN_INTERCEPTION_HEADER 39494
#define IDS_KNOWN_INTERCEPTION_BODY1 39495
#define IDS_KNOWN_INTERCEPTION_BODY2 39496
#define IDS_KNOWN_INTERCEPTION_INFOBAR_HEADING 39497
#define IDS_KNOWN_INTERCEPTION_INFOBAR_BUTTON_TEXT 39498
#define IDS_LEGACY_TLS_HEADING 39499
#define IDS_LEGACY_TLS_PRIMARY_PARAGRAPH 39500
#define IDS_LEGACY_TLS_EXPLANATION 39501
#define IDS_INSECURE_FORM_TITLE 39502
#define IDS_INSECURE_FORM_HEADING 39503
#define IDS_INSECURE_FORM_PRIMARY_PARAGRAPH 39504
#define IDS_INSECURE_FORM_BACK_BUTTON 39505
#define IDS_INSECURE_FORM_SUBMIT_BUTTON 39506
#define IDS_HTTPS_ONLY_MODE_TITLE 39507
#define IDS_HTTPS_ONLY_MODE_HEADING 39508
#define IDS_HTTPS_ONLY_MODE_PRIMARY_PARAGRAPH 39509
#define IDS_HTTPS_ONLY_BALANCED_MODE_HEADING 39510
#define IDS_HTTPS_ONLY_BALANCED_MODE_PRIMARY_PARAGRAPH 39511
#define IDS_HTTPS_ONLY_MODE_WITH_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 39512
#define IDS_HTTPS_ONLY_MODE_WITH_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 39514
#define IDS_HTTPS_ONLY_MODE_FOR_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 39515
#define IDS_HTTPS_ONLY_MODE_FOR_INCOGNITO_PRIMARY_PARAGRAPH 39516
#define IDS_HTTPS_ONLY_MODE_BACK_BUTTON 39517
#define IDS_HTTPS_ONLY_MODE_SUBMIT_BUTTON 39518
#define IDS_ABH_PROMPT_TITLE 39519
#define IDS_ABH_PROMPT_BALANCED_MODE_FIRST_ITEM_TEXT 39520
#define IDS_ABH_PROMPT_BALANCED_MODE_SECOND_ITEM_TEXT 39521
#define IDS_ABH_PROMPT_SECONDARY_TEXT 39522
#define IDS_ABH_PROMPT_LEARN_MORE_LINK 39523
#define IDS_ABH_PROMPT_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 39524
#define IDS_ABH_PROMPT_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 39525
#define IDS_ABH_PROMPT_INCOGNITO_PRIMARY_PARAGRAPH 39526
#define IDS_ABH_PROMPT_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 39527
#define IDS_WEBVIEW_CONTENT_RESTRICTION_BLOCKED_MESSAGE 39529
#define IDS_WEBVIEW_CONTENT_RESTRICTION_LEARN_MORE 39530
#define IDS_WEBVIEW_CONTENT_RESTRICTION_GO_BACK 39531
#define IDS_SHARING_DEVICE_TYPE_COMPUTER 39532
#define IDS_SHARING_DEVICE_TYPE_DEVICE 39533
#define IDS_SHARING_DEVICE_TYPE_PHONE 39534
#define IDS_SHARING_DEVICE_TYPE_TABLET 39535
#define IDS_SHARING_DEVICE_TYPE_DESKTOP 39536
#define IDS_SHARING_DEVICE_TYPE_LAPTOP 39537
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_DEAULT_DEVICE_NAME 39538
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_USER_GIVEN_DEVICE_NAME 39539
#define IDS_SEND_TAB_PUSH_NOTIFICATION_BODY 39540
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_TITLE 39541
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_BODY 39542
#define IDS_SEND_TAB_RECEIVE_TOAST_FOREGROUND 39543
#define IDS_SEND_TAB_RECEIVE_TOAST_BACKGROUND 39544
#define IDS_SEND_TAB_RECEIVE_TOAST_BACKGROUND_ACTION_BUTTON 39545
#define IDS_SEND_TAB_TO_SELF_POST_SEND_SUCCESS_TOAST 39546
#define IDS_SEND_TAB_TO_SELF_POST_SEND_SUCCESS_TOAST_ANDROID 39547
#define IDS_SEND_TAB_TO_SELF_POST_SEND_THROTTLED_TOAST 39548
#define IDS_SEND_TAB_TO_SELF_POST_SEND_THROTTLED_TOAST_ANDROID 39549
#define IDS_SEND_TAB_TO_SELF_POST_SEND_NO_INTERNET_TOAST 39550
#define IDS_SEND_TAB_TO_SELF_POST_SEND_FAILURE_TOAST 39551
#define IDS_SITE_SETTINGS_TYPE_ADS 39552
#define IDS_SITE_SETTINGS_TYPE_ADS_MID_SENTENCE 39553
#define IDS_SITE_SETTINGS_TYPE_ANTI_ABUSE 39554
#define IDS_SITE_SETTINGS_TYPE_AR 39555
#define IDS_SITE_SETTINGS_TYPE_AR_MID_SENTENCE 39556
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS 39557
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS_MID_SENTENCE 39558
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN 39559
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN_MID_SENTENCE 39560
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE 39561
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE_MID_SENTENCE 39562
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC 39563
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC_MID_SENTENCE 39564
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES 39565
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES_MID_SENTENCE 39566
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING 39567
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING_MID_SENTENCE 39568
#define IDS_SITE_SETTINGS_TYPE_CAMERA 39569
#define IDS_SITE_SETTINGS_TYPE_CAMERA_MID_SENTENCE 39570
#define IDS_SITE_SETTINGS_TYPE_CAMERA_WITH_COUNT 39571
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM 39572
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_MID_SENTENCE 39573
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_WITH_COUNT 39574
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL 39575
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_MID_SENTENCE 39576
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS 39577
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS_MID_SENTENCE 39578
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SUB_MENU 39579
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD 39580
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD_MID_SENTENCE 39581
#define IDS_SITE_SETTINGS_TYPE_COOKIES 39582
#define IDS_SITE_SETTINGS_TYPE_COOKIES_MID_SENTENCE 39583
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API 39584
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API_MID_SENTENCE 39585
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING 39586
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING_MID_SENTENCE 39587
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION 39588
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION_MID_SENTENCE 39589
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT 39590
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_MID_SENTENCE 39591
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_OPTIMIZER 39592
#define IDS_SITE_SETTINGS_TYPE_LOCATION 39593
#define IDS_SITE_SETTINGS_TYPE_LOCATION_MID_SENTENCE 39594
#define IDS_SITE_SETTINGS_TYPE_MIC 39595
#define IDS_SITE_SETTINGS_TYPE_MIC_MID_SENTENCE 39596
#define IDS_SITE_SETTINGS_TYPE_MIC_WITH_COUNT 39597
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX 39598
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX_MID_SENTENCE 39599
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS 39600
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS_MID_SENTENCE 39601
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS 39602
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS_MID_SENTENCE 39603
#define IDS_SITE_SETTINGS_TYPE_NFC 39604
#define IDS_SITE_SETTINGS_TYPE_NFC_MID_SENTENCE 39605
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS 39606
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS_MID_SENTENCE 39607
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS 39608
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS_MID_SENTENCE 39609
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID 39610
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID_MID_SENTENCE 39611
#define IDS_SITE_SETTINGS_TYPE_SOUND 39612
#define IDS_SITE_SETTINGS_TYPE_SOUND_MID_SENTENCE 39613
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES 39614
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES_MID_SENTENCE 39615
#define IDS_SITE_SETTINGS_TYPE_VR 39616
#define IDS_SITE_SETTINGS_TYPE_VR_MID_SENTENCE 39617
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS 39618
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS_MID_SENTENCE 39619
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE 39620
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE_MID_SENTENCE 39621
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK 39622
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_MID_SENTENCE 39623
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK 39624
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK_MID_SENTENCE 39625
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT 39626
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT_MID_SENTENCE 39627
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS 39628
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS_MID_SENTENCE 39629
#define IDS_SITE_SETTINGS_TYPE_HANDLERS 39630
#define IDS_SITE_SETTINGS_TYPE_HANDLERS_MID_SENTENCE 39631
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES 39632
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES_MID_SENTENCE 39633
#define IDS_SITE_SETTINGS_TYPE_IMAGES 39634
#define IDS_SITE_SETTINGS_TYPE_IMAGES_MID_SENTENCE 39635
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT 39636
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT_MID_SENTENCE 39637
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK 39638
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK_MID_SENTENCE 39639
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER 39640
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER_MID_SENTENCE 39641
#define IDS_SITE_SETTINGS_TYPE_PDF_DOCUMENTS 39642
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK 39643
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK_MID_SENTENCE 39644
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS 39645
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS_MID_SENTENCE 39646
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS 39648
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS_MID_SENTENCE 39649
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION 39650
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION_MID_SENTENCE 39651
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING 39652
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING_MID_SENTENCE 39653
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE 39654
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE_SUBLABEL 39655
#define IDS_SITE_SETTINGS_TYPE_OFFER_WRITING_HELP 39656
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_HEADER 39657
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_HEADER_V2 39658
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY 39659
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY_V2 39660
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_TURN_ON 39661
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_FOR_EVERY_THREAD_V3 39662
#define IDS_STS_SETTINGS_OPTION_1_CHOOSE_HOW_RELEVANT_OPEN_TABS_CAN_BE_USED_V3 39663
#define IDS_STS_SETTINGS_OPTION_1_LEARN_MORE 39664
#define IDS_STS_SETTINGS_OPTION_1_NEVER_SHARE_THESE_SITES 39665
#define IDS_STS_SETTINGS_OPTION_1_SITES_ADDED_HERE_WONT_BE_REFERENCED_V2 39666
#define IDS_STS_SETTINGS_OPTION_1_SITES_ADDED_HERE_WONT_BE_REFERENCED_V3 39667
#define IDS_STS_SETTINGS_ENTRYPOINT_GOOGLE_SEARCH_AI_MODE 39668
#define IDS_STS_SETTINGS_ENTRYPOINT_GET_RESPONSES_WITH_CONTEXT 39669
#define IDS_STS_MEGAPLUS_SHARE_RELEVANT_OPEN_TABS 39670
#define IDS_STS_MEGAPLUS_SHARE_RELEVANT_OPEN_TABS_V2 39671
#define IDS_STS_MEGAPLUS_SHARE_RELEVANT_OPEN_TABS_V3 39672
#define IDS_STS_IPH_TRY_IT_HEADER 39673
#define IDS_STS_IPH_TRY_IT_HEADER_V2 39674
#define IDS_STS_IPH_TRY_IT_BODY 39675
#define IDS_STS_IPH_TRY_IT_BODY_V2 39676
#define IDS_STS_IPH_TRY_IT_TURN_ON 39677
#define IDS_STS_IPH_TRY_IT_NOT_NOW 39678
#define IDS_STS_IPH_DEFAULT_ON_HEADER 39679
#define IDS_STS_IPH_DEFAULT_ON_HEADER_V2 39680
#define IDS_STS_IPH_DEFAULT_ON_BODY 39681
#define IDS_STS_IPH_DEFAULT_ON_BODY_V2 39682
#define IDS_STS_IPH_DEFAULT_ON_LINK 39683
#define IDS_STS_IPH_DEFAULT_ON_BODY_END 39684
#define IDS_STS_IPH_DEFAULT_ON_TURN_ON 39685
#define IDS_STS_IPH_DEFAULT_ON_NOT_NOW 39686
#define IDS_CERT_ERROR_NO_SUBJECT_ALTERNATIVE_NAMES_DETAILS 39687
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DETAILS 39688
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DESCRIPTION 39689
#define IDS_CERT_ERROR_EXPIRED_DETAILS 39690
#define IDS_CERT_ERROR_EXPIRED_DESCRIPTION 39691
#define IDS_CERT_ERROR_NOT_YET_VALID_DETAILS 39692
#define IDS_CERT_ERROR_NOT_YET_VALID_DESCRIPTION 39693
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DETAILS 39694
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DESCRIPTION 39695
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DESCRIPTION 39696
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DETAILS 39697
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DESCRIPTION 39698
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DETAILS 39699
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DESCRIPTION 39700
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DETAILS 39701
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DESCRIPTION 39702
#define IDS_CERT_ERROR_REVOKED_CERT_DETAILS 39703
#define IDS_CERT_ERROR_REVOKED_CERT_DESCRIPTION 39704
#define IDS_CERT_ERROR_INVALID_CERT_DETAILS 39705
#define IDS_CERT_ERROR_INVALID_CERT_DESCRIPTION 39706
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DETAILS 39707
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DESCRIPTION 39708
#define IDS_CERT_ERROR_WEAK_KEY_DETAILS 39709
#define IDS_CERT_ERROR_WEAK_KEY_DESCRIPTION 39710
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DETAILS 39711
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DESCRIPTION 39712
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DETAILS 39713
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DESCRIPTION 39714
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DETAILS 39715
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DESCRIPTION 39716
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DETAILS 39717
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DESCRIPTION 39718
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DETAILS 39719
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DESCRIPTION 39720
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DETAILS 39721
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DESCRIPTION 39722
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DETAILS 39723
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DESCRIPTION 39724
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS 39725
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS_V2 39726
#define IDS_ALWAYS_ALLOW_ADS 39727
#define IDS_BLOCKED_ADS_PROMPT_EXPLANATION 39728
#define IDS_BLOCKED_ADS_PROMPT_TITLE 39729
#define IDS_BLOCK_INTERSTITIAL_TITLE 39736
#define IDS_CHILD_BLOCK_INTERSTITIAL_HEADER 39737
#define IDS_BLOCK_INTERSTITIAL_HEADER_ACCESS_REQUESTS_DISABLED 39738
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_BLOCK_ALL 39739
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_SAFE_SITES 39740
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_MANUAL 39741
#define IDS_CHILD_BLOCK_INTERSTITIAL_MESSAGE_NOT_SIGNED_IN 39742
#define IDS_REQUEST_SENT_OK 39743
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_BUTTON 39744
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_INSTEAD_BUTTON 39745
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_A_MESSAGE_BUTTON 39746
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_MESSAGE 39747
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_SINGLE_PARENT 39748
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_MULTI_PARENT 39749
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_SINGLE_PARENT 39750
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_MULTI_PARENT 39751
#define IDS_SUPERVISED_USER_VERIFY_PAGE_TAB_TITLE 39752
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_HEADING 39753
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_PARAGRAPH 39754
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_BUTTON 39755
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_YOUTUBE_HEADING 39756
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_BLOCKED_SITE_HEADING 39757
#define IDS_PARENT_WEBSITE_APPROVAL_BLOCK_ALL_URL 39758
#define IDS_PARENT_WEBSITE_APPROVAL_SAFE_SITES_URL 39759
#define IDS_PARENT_WEBSITE_APPROVAL_MANUAL_URL 39760
#define IDS_PARENT_WEBSITE_APPROVAL_DIALOG_A11Y_NAME 39761
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_TITLE 39762
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_DESCRIPTION 39763
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_BACK_BUTTON 39764
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_TITLE 39765
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_BACK_BUTTON 39766
#define IDS_SYNC_BASIC_ENCRYPTION_DATA 39770
#define IDS_SYNC_DATATYPE_AUTOFILL 39771
#define IDS_SYNC_DATATYPE_BOOKMARKS 39772
#define IDS_SYNC_DATATYPE_PASSWORDS_AND_PASSKEYS 39773
#define IDS_SYNC_DATATYPE_PREFERENCES 39774
#define IDS_SYNC_DATATYPE_TABS 39775
#define IDS_SYNC_DATATYPE_HISTORY_AND_TABS 39776
#define IDS_SYNC_DATATYPE_READING_LIST 39777
#define IDS_SYNC_EMPTY_PASSPHRASE_ERROR 39778
#define IDS_SYNC_FULL_ENCRYPTION_DATA 39779
#define IDS_SYNC_LOGIN_SETTING_UP 39780
#define IDS_SYNC_PASSPHRASE_LABEL 39781
#define IDS_SYNC_PASSPHRASE_MISMATCH_ERROR 39782
#define IDS_SYNC_ENTER_PASSPHRASE_BODY_WITH_DATE 39783
#define IDS_SYNC_ENTER_PASSPHRASE_BODY 39784
#define IDS_BULK_UPLOAD_SUBTITLE 39785
#define IDS_BULK_UPLOAD_BOOKMARK_FOLDER_SUBTITLE 39786
#define IDS_SYNC_DEVICE_NAME_COMPUTER_FORMAT 39787
#define IDS_SYNC_DEVICE_NAME_PHONE_FORMAT 39788
#define IDS_SYNC_DEVICE_NAME_TABLET_FORMAT 39789
#define IDS_SYNC_DEVICE_NAME_DEVICE_FORMAT 39790
#define IDS_SYNC_DEVICE_NAME_DESKTOP_FORMAT 39791
#define IDS_SYNC_DEVICE_NAME_LAPTOP_FORMAT 39792
#define IDS_SYNC_DEVICE_NAME_WITH_MODEL_FORMAT 39793
#define IDS_TAB_GROUP_COLOR_GREY 39794
#define IDS_TAB_GROUP_COLOR_BLUE 39795
#define IDS_TAB_GROUP_COLOR_RED 39796
#define IDS_TAB_GROUP_COLOR_YELLOW 39797
#define IDS_TAB_GROUP_COLOR_MAGENTA 39798
#define IDS_TAB_GROUP_COLOR_GREEN 39799
#define IDS_TAB_GROUP_COLOR_PINK 39800
#define IDS_TAB_GROUP_COLOR_LIME 39801
#define IDS_TAB_GROUP_COLOR_PURPLE 39802
#define IDS_TAB_GROUP_COLOR_CYAN 39803
#define IDS_TAB_GROUP_COLOR_ORANGE 39804
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO 39805
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY 39806
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED 39807
#define IDS_TAB_RESUME_DECORATORS_CONTINUE_READING 39808
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT 39809
#define IDS_TAB_RESUME_DECORATORS_TIME_OF_DAY 39810
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO_IOS 39811
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY_IOS 39812
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED_IOS 39813
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT_IOS 39814
#define IDS_TAB_RESUME_N_MINUTES_AGO_NARROW 39815
#define IDS_TAB_RESUME_N_HOURS_AGO_NARROW 39816
#define IDS_TRANSLATE_NOTIFICATION_UNDO 39832
#define IDS_TRANSLATE_HEADER 39833
#define IDS_TRANSLATE_BUBBLE_CHOOSE_LANGUAGE_TO_TRANSLATE_TO 39834
#define IDS_TRANSLATE_BUBBLE_SEARCH_LANGUAGES 39835
#define IDS_TRANSLATE_BUBBLE_NO_RESULTS 39836
#define IDS_TRANSLATE_DETECTED_LANGUAGE 39837
#define IDS_BOOKMARK_BAR_UNDO 39838
#define IDS_BOOKMARK_BAR_REDO 39839
#define IDS_BOOKMARK_BAR_UNDO_ADD 39840
#define IDS_BOOKMARK_BAR_REDO_ADD 39841
#define IDS_BOOKMARK_BAR_UNDO_DELETE 39842
#define IDS_BOOKMARK_BAR_REDO_DELETE 39843
#define IDS_BOOKMARK_BAR_UNDO_EDIT 39844
#define IDS_BOOKMARK_BAR_REDO_EDIT 39845
#define IDS_BOOKMARK_BAR_UNDO_MOVE 39846
#define IDS_BOOKMARK_BAR_REDO_MOVE 39847
#define IDS_BOOKMARK_BAR_UNDO_REORDER 39848
#define IDS_BOOKMARK_BAR_REDO_REORDER 39849
#define IDS_IMPORTED_FROM_SAFARI_FOLDER 39850
#define IDS_IMPORTED_FOLDER 39851
#define IDS_CLOSE_TUTORIAL 39852
#define IDS_CLOSE_PROMO 39853
#define IDS_HELP_BUBBLE 39854
#define IDS_PROMO_DISMISS_BUTTON 39855
#define IDS_PROMO_SNOOZE_BUTTON 39856
#define IDS_PROMO_SHOW_TUTORIAL_BUTTON 39857
#define IDS_TUTORIAL_RESTART_TUTORIAL 39858
#define IDS_PROMO_LEARN_MORE_BUTTON 39859
#define IDS_TUTORIAL_CLOSE_TUTORIAL 39860
#define IDS_TUTORIAL_NEXT_BUTTON 39861
#define IDS_PROMO_MANAGE_BUTTON 39862
#define IDS_PROMO_UNDO_BUTTON 39863
#define IDS_VERSION_UI_TITLE 39864
#define IDS_VERSION_UI_OFFICIAL 39865
#define IDS_VERSION_UI_UNOFFICIAL 39866
#define IDS_VERSION_UI_32BIT 39867
#define IDS_VERSION_UI_64BIT 39868
#define IDS_VERSION_UI_64BIT_INTEL 39869
#define IDS_VERSION_UI_64BIT_ARM 39871
#define IDS_VERSION_UI_REVISION 39873
#define IDS_VERSION_UI_OS 39874
#define IDS_VERSION_UI_USER_AGENT 39876
#define IDS_VERSION_UI_COMMAND_LINE 39877
#define IDS_VERSION_UI_COPY_LABEL 39881
#define IDS_VERSION_UI_COPY_NOTICE 39882
#define IDS_VERSION_UI_EXECUTABLE_PATH 39883
#define IDS_VERSION_UI_PROFILE_PATH 39884
#define IDS_VERSION_UI_MODULE_PATH 39885
#define IDS_VERSION_UI_USER_DATA_PATH 39886
#define IDS_VERSION_UI_PATH_NOTFOUND 39887
#define IDS_VERSION_UI_VARIATIONS 39888
#define IDS_VERSION_UI_VARIATIONS_SOURCE_NAME 39889
#define IDS_VERSION_UI_VARIATIONS_SEED_NAME 39890
#define IDS_VERSION_UI_VARIATIONS_CMD 39891
#define IDS_VERSION_UI_COPY_VARIATIONS_LABEL 39892
#define IDS_VERSION_UI_COPY_VARIATIONS_NOTICE 39893
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TITLE 39898
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_NO_THANKS_BUTTON 39899
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TURN_ON_BUTTON 39900
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_LEARN_MORE 39901
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_DESCRIPTION 39902
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_ACTION 39903
#define IDS_WALLET_WALLETABLE_PASS_SAVE_LOYALTY_CARD_DIALOG_TITLE 39904
#define IDS_WALLET_WALLETABLE_PASS_SAVE_EVENT_TICKET_DIALOG_TITLE 39905
#define IDS_WALLET_WALLETABLE_PASS_SAVE_TRANSPORT_TICKET_DIALOG_TITLE 39906
#define IDS_WALLET_WALLETABLE_PASS_SAVE_BOARDING_PASS_DIALOG_TITLE 39907
#define IDS_WALLET_WALLETABLE_PASS_GOOGLE_WALLET_TITLE 39908
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SUBTITLE 39909
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_NO_THANKS_BUTTON 39910
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SAVE_BUTTON 39911
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_ISSUER_ATTRIBUTE_NAME 39912
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_MEMBER_ID_ATTRIBUTE_NAME 39913
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_EVENT_NAME_ATTRIBUTE_NAME 39914
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_ISSUER_ATTRIBUTE_NAME 39915
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_VENUE_ATTRIBUTE_NAME 39916
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_DATE_ATTRIBUTE_NAME 39917
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_OPERATOR_ATTRIBUTE_NAME 39918
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_ATTRIBUTE_NAME 39919
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_VALUE 39920
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_DATE_ATTRIBUTE_NAME 39921
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_AIRLINE_ATTRIBUTE_NAME 39922
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_FLIGHT_CODE_ATTRIBUTE_NAME 39923
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_ATTRIBUTE_NAME 39924
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_VALUE 39925
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_DATE_ATTRIBUTE_NAME 39926
#define IDS_COLLABORATION_SIGNIN_TITLE 39927
#define IDS_COLLABORATION_SIGNIN_DESCRIPTION 39928
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_TITLE 39929
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_DESCRIPTION 39930
#define IDS_COLLABORATION_SIGNIN_SYNC_DISMISS 39931
#define IDS_COLLABORATION_SYNC_TITLE 39932
#define IDS_COLLABORATION_SYNC_DESCRIPTION 39933
#define IDS_COLLABORATION_ONE_GROUP_REMOVED_NOTIFICATION 39934
#define IDS_COLLABORATION_ONE_UNNAMED_GROUP_REMOVED_NOTIFICATION 39935
#define IDS_COLLABORATION_TWO_GROUPS_REMOVED_NOTIFICATION 39936
#define IDS_COLLABORATION_SEVERAL_GROUPS_REMOVED_NOTIFICATION 39937
#define IDS_COLLABORATION_RECENT_ACTIVITY_MENU_OPTION 39938
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_HEADER 39939
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_BODY 39940
#define IDS_COLLABORATION_LINK_FAILED_HEADER 39941
#define IDS_COLLABORATION_LINK_FAILED_BODY 39942
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_HEADER 39943
#define IDS_COLLABORATION_SHARE_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 39944
#define IDS_COLLABORATION_JOIN_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 39945
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_UPDATE_BUTTON 39946
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_NOT_NOW_BUTTON 39947
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_CONTINUE_BODY 39948
#define IDS_COLLABORATION_SIGNED_OUT_HEADER 39949
#define IDS_COLLABORATION_SIGNED_OUT_BODY 39950
#define IDS_COLLABORATION_SIGNED_OUT_POSITIVE_BUTTON 39951
#define IDS_COLLABORATION_GROUP_IS_FULL_DESCRIPTION 39952
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_HEADER 39953
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_BODY 39954
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_HEADER 39955
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_BODY 39956
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_SYNC_HISTORY_BODY 39957
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_HEADER 39958
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_BODY 39959
#define IDS_COLLABORATION_ENTREPRISE_TABS_SYNC_DISABLED_BODY 39960
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_HEADER 39961
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_BODY 39962
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_HEADER 39963
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_BODY 39964
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_PANEL_OUT_OF_DATE_MESSAGE_CELL_TEXT 39968
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_AVAILABLE_AGAIN_IPH_MESSAGE 39969
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_SELF 39970
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_ADDED 39971
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_ADDED_THIS_TAB 39972
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_CHANGED_THIS_TAB 39973
#define IDS_TAB_AX_DATA_SHARING_RECENT_ACTIVITY_MEMBER_ADDED_THIS_TAB 39974
#define IDS_TAB_AX_DATA_SHARING_RECENT_ACTIVITY_MEMBER_CHANGED_THIS_TAB 39975
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_REMOVED 39976
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_UPDATED 39977
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_NAME_UPDATED 39978
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_COLOR_UPDATED 39979
#define DATA_SHARING_GROUP_LABEL_NEW_ACTIVITY 39980
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_JOINED_GROUP 39981
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_LEFT_GROUP 39982
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TIME_DELTA 39983
#define IDS_DATA_SHARING_RECENT_ACTIVITY_SEPARATOR 39984
#define IDS_DATA_SHARING_RECENT_ACTIVITY_DESCRIPTION_FULL 39985
#define IDS_DATA_SHARING_RECENT_ACTIVITY_EMPTY 39986
#define IDS_DATA_SHARING_RECENT_ACTIVITY_JUST_NOW 39987
#define IDS_DATA_SHARING_RECENT_ACTIVITY_UNKNOWN_USER 39988
#define IDS_DATA_SHARING_SHARED_TAB_GROUPS_ACTIVITY 39989
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED 39990
#define IDS_DATA_SHARING_TOAST_TAB_UPDATED 39991
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED_ACTION 39992
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER 39993
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_MULTIPLE_MEMBERS 39994
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_ACTION 39995
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE 39996
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE_MULTIPLE_GROUPS 39997
#define IDS_DATA_SHARING_TAB_GROUP_DEFAULT_TITLE_TABS_COUNT 39998
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE 39999
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE_WITH_NAME 40000
#define IDS_CONTEXTUAL_CUEING_MENU_DISMISS 40001
#define IDS_CONTEXTUAL_CUEING_MENU_EDIT_PROMPT 40002
#define IDS_CONTEXTUAL_CUEING_MENU_SETTINGS 40003
#define IDS_CONTEXTUAL_CUEING_SETTINGS_PAGE_TITLE 40004
#define IDS_CONTEXTUAL_CUEING_SETTINGS_PAGE_SUBLABEL 40005
#define IDS_CONTEXTUAL_CUEING_SETTINGS_TOGGLE_LABEL 40006
#define IDS_CONTEXTUAL_CUEING_SETTINGS_TOGGLE_SUBLABEL 40007
#define IDS_CONTEXTUAL_CUEING_SETTINGS_WHEN_ON_1 40008
#define IDS_CONTEXTUAL_CUEING_SETTINGS_WHEN_ON_2 40009
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_1_PRIVATE 40010
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_1_NON_PRIVATE 40011
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_2 40012
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_2_LINK 40013
#define IDS_CONTEXTUAL_CUEING_TAB_SHARING_HEADING 40014
#define IDS_CONTEXTUAL_CUEING_TAB_SHARING_CURRENT_TAB 40015
#define IDS_CONTEXTUAL_CUEING_TAB_SHARING_EXPAND_BUTTON_ANNOUNCEMENT_V2 40016
#define IDS_CONTEXTUAL_TASKS_CONTEXTUAL_TASKS_TITLE 40017
#define IDS_CONTEXTUAL_TASKS_CUSTOMIZE_CHROME_LABEL 40018
#define IDS_CONTEXTUAL_TASKS_ENTRY_POINT_TOOLTIP 40019
#define IDS_CONTEXTUAL_TASKS_AI_MODE_TITLE 40020
#define IDS_CONTEXTUAL_TASKS_MENU_OPEN_IN_NEW_TAB 40021
#define IDS_CONTEXTUAL_TASKS_MENU_MY_ACTIVITY 40022
#define IDS_CONTEXTUAL_TASKS_MENU_HELP 40023
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_TITLE 40024
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_TITLE 40025
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_SHORT_TITLE 40026
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_DESCRIPTION 40027
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_LEARN_MORE 40028
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_ACCEPT_BUTTON 40029
#define IDS_CONTEXTUAL_TASKS_CONTINUE_THREAD_MESSAGE 40030
#define IDS_CONTEXTUAL_TASKS_REOPEN_TABS_BUTTON_TEXT 40031
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_MOST_RECENT_TABS 40032
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_GEMINI_MODELS 40033
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_NEW_THREAD_TOOL_TIP 40034
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_HISTORY_TOOL_TIP 40035
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CONTEXT_TOOL_TIP 40036
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_MORE_OPTIONS_TOOL_TIP 40037
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CLOSE_TOOL_TIP 40038
#define IDS_CONTEXTUAL_TASKS_TOOLBAR_CLOSE_TAB_TOOL_TIP 40039
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_TITLE 40040
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_BODY 40041
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_RELOAD_BUTTON 40042
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE 40043
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE_WITHOUT_NAME 40044
#define IDS_CONTEXTUAL_TASKS_COMPOSEBOX_PLACEHOLDER_TEXT 40045
#define IDS_CONTEXTUAL_TASKS_THREAD_CLOSED 40046
#define IDS_CANCEL 40119
#define IDS_CONTINUE 40120
#define IDS_CLOSE 40121
#define IDS_CLEAR 40122
#define IDS_DONE 40123
#define IDS_LEARN_MORE 40124
#define IDS_LEARN_MORE_MAYBE_TITLE_CASE 40125
#define IDS_OK 40126
#define IDS_RELOAD 40127
#define IDS_ADD 40128
#define IDS_MOVE 40129
#define IDS_REMOVE 40130
#define IDS_OPEN 40131
#define IDS_RESTORE 40132
#define IDS_SAVE 40133
#define IDS_MENU 40134
#define IDS_INSTALL 40135
#define IDS_UPDATE 40136
#define IDS_NO_THANKS 40139
#define IDS_NOT_NOW 40140
#define IDS_TURN_OFF 40141
#define IDS_PLUGIN_NOT_SUPPORTED 40142
#define IDS_PRINT 40143
#define IDS_RECENT_TABS 40144
#define IDS_RECENTLY_CLOSED 40145
#define IDS_YOUR_DEVICES 40146
#define IDS_CHOOSE 40147
#define IDS_ACCNAME_BACK 40148
#define IDS_ACCNAME_FORWARD 40149
#define IDS_ACCNAME_OK 40150
#define IDS_ACCNAME_CANCEL 40151
#define IDS_ACCNAME_DONE 40152
#define IDS_ACCNAME_SAVE 40153
#define IDS_ACCNAME_CLOSE 40154
#define IDS_ACCNAME_OPEN 40155
#define IDS_ACCNAME_OPEN_IN_NEW_TAB 40156
#define IDS_ACCNAME_PREVIOUS 40157
#define IDS_ACCNAME_NEXT 40158
#define IDS_ACCNAME_LOCATION 40159
#define IDS_ACCNAME_TAB_LIST 40160
#define IDS_UTILITY_PROCESS_JSON_PARSER_NAME 40161
#define IDS_SESSION_CRASHED_VIEW_RESTORE_BUTTON 40162
#define IDS_SESSION_CRASHED_VIEW_STARTUP_PAGES_BUTTON 40163
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_PRIVACY 40164
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_SAFETY_CHECK 40165
#define IDS_CONTENT_BOOKMARK_PARSER_SERVICE_DISPLAY_NAME 40166
#define IDS_PATCH_SERVICE_DISPLAY_NAME 40167
#define IDS_PASSWORD_MANAGER_CSV_PASSWORD_PARSER_SERVICE_DISPLAY_NAME 40168
#define IDS_UNZIP_SERVICE_DISPLAY_NAME 40169
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_HEADING 40170
#define IDS_SEND_TAB_TO_SELF_DEVICE_LAST_UPDATE_DAYS 40171
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_NOW 40172
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_MINUTES 40173
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_HOURS 40174
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_TITLE 40175
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_TITLE 40176
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_BODY 40177
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_BODY 40178
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_BODY 40179
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_BODY 40180
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_BODY 40181

// ---------------------------------------------------------------------------
// From extensions_strings.h:

#define IDS_EXTENSION_BAD_FILE_ENCODING 46070
#define IDS_EXTENSION_CANT_GET_ABSOLUTE_PATH 46071
#define IDS_EXTENSION_CONTAINS_PRIVATE_KEY 46072
#define IDS_EXTENSION_CRX_EXISTS 46073
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_TOO_LARGE 46074
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_JS_MIME_TYPE 46075
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_CSS_MIME_TYPE 46076
#define IDS_EXTENSION_DIRECTORY_NO_EXISTS 46077
#define IDS_EXTENSION_ERROR_WHILE_SIGNING 46078
#define IDS_EXTENSION_FAILED_DURING_PACKAGING 46079
#define IDS_EXTENSION_LOAD_ABOUT_PAGE_FAILED 46080
#define IDS_EXTENSION_LOAD_BACKGROUND_SCRIPT_FAILED 46081
#define IDS_EXTENSION_LOAD_BACKGROUND_PAGE_FAILED 46082
#define IDS_EXTENSION_LOAD_CSS_FAILED 46083
#define IDS_EXTENSION_LOAD_JAVASCRIPT_FAILED 46084
#define IDS_EXTENSION_LOAD_OPTIONS_PAGE_FAILED 46085
#define IDS_EXTENSION_LOCALES_NO_DEFAULT_LOCALE_SPECIFIED 46086
#define IDS_EXTENSION_MANIFEST_UNREADABLE 46087
#define IDS_EXTENSION_MANIFEST_INVALID 46088
#define IDS_EXTENSION_PACKAGE_IMAGE_ERROR 46089
#define IDS_EXTENSION_PACKAGE_UNZIP_ERROR 46090
#define IDS_EXTENSION_PRIVATE_KEY_EXISTS 46091
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_READ 46092
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_EXPORT 46093
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_OUTPUT 46094
#define IDS_EXTENSION_PRIVATE_KEY_INVALID 46095
#define IDS_EXTENSION_PRIVATE_KEY_NO_EXISTS 46096
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_PATH 46097
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_FORMAT 46098
#define IDS_EXTENSION_PUBLIC_KEY_FAILED_TO_EXPORT 46099
#define IDS_EXTENSION_SHARING_VIOLATION 46100
#define IDS_EXTENSION_CANT_INSTALL_POLICY_BLOCKED 46101
#define IDS_EXTENSION_CANT_MODIFY_POLICY_REQUIRED 46102
#define IDS_EXTENSION_CANT_UNINSTALL_POLICY_REQUIRED 46103
#define IDS_EXTENSION_MANIFEST_VERSION_NOT_SUPPORTED 46104
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_RISK_SCORE 46105
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_CATEGORY 46106
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_POLICY_FALLBACK 46107
#define IDS_DEVICE_NAME_WITH_PRODUCT_SERIAL 46108
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR 46109
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR_SERIAL 46110
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR 46111
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR_SERIAL 46112
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR 46113
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR_SERIAL 46114
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR 46115
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR_SERIAL 46116
#define IDS_DEVICE_PERMISSIONS_PROMPT_SINGLE_SELECTION 46117
#define IDS_DEVICE_PERMISSIONS_PROMPT_MULTIPLE_SELECTION 46118
#define IDS_CAMERA_FACING_USER 46119
#define IDS_CAMERA_FACING_ENVIRONMENT 46120
#define IDS_EXTENSION_USB_DEVICE_PRODUCT_NAME_AND_VENDOR 46121
#define IDS_EXTENSION_TASK_MANAGER_APPVIEW_TAG_PREFIX 46122
#define IDS_EXTENSION_TASK_MANAGER_EXTENSIONOPTIONS_TAG_PREFIX 46123
#define IDS_EXTENSION_TASK_MANAGER_MIMEHANDLERVIEW_TAG_PREFIX 46124
#define IDS_EXTENSION_TASK_MANAGER_WEBVIEW_TAG_PREFIX 46125
#define IDS_EXTENSION_WARNINGS_NETWORK_DELAY 46126
#define IDS_EXTENSION_WARNINGS_DOWNLOAD_FILENAME_CONFLICT 46127
#define IDS_EXTENSION_WARNING_RELOAD_TOO_FREQUENT 46128
#define IDS_EXTENSION_WARNING_RULESET_FAILED_TO_LOAD 46129
#define IDS_EXTENSION_WARNING_ENABLED_RULE_COUNT_EXCEEDED 46130
#define IDS_EXTENSION_IS_BLOCKLISTED 46131
#define IDS_APP_CANT_DOWNGRADE_VERSION 46132
#define IDS_EXTENSION_CANT_DOWNGRADE_VERSION 46133
#define IDS_EXTENSION_MOVE_DIRECTORY_TO_PROFILE_FAILED 46134
#define IDS_EXTENSION_INSTALL_DEPENDENCY_OLD_VERSION 46135
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_SHARED_MODULE 46136
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_ALLOWLISTED 46137
#define IDS_EXTENSION_INSTALL_DISALLOWED_ON_SITE 46138
#define IDS_EXTENSION_INSTALL_GALLERY_ONLY 46139
#define IDS_EXTENSION_INSTALL_INCORRECT_APP_CONTENT_TYPE 46140
#define IDS_EXTENSION_INSTALL_INCORRECT_INSTALL_HOST 46141
#define IDS_EXTENSION_INSTALL_KIOSK_MODE_ONLY 46142
#define IDS_EXTENSION_INSTALL_NOT_ENABLED 46143
#define IDS_EXTENSION_OVERLAPPING_WEB_EXTENT 46144
#define IDS_EXTENSION_INSTALL_PROCESS_CRASHED 46145
#define IDS_EXTENSION_INSTALL_UNEXPECTED_ID 46146
#define IDS_EXTENSION_INSTALL_UNEXPECTED_VERSION 46147
#define IDS_EXTENSION_PACKAGE_ERROR_CODE 46148
#define IDS_EXTENSION_PACKAGE_ERROR_MESSAGE 46149
#define IDS_EXTENSION_PACKAGE_INSTALL_ERROR 46150
#define IDS_EXTENSION_WEBGL_NOT_SUPPORTED 46151
#define IDS_EXTENSION_WEB_STORE_TITLE 46152
#define IDS_EXTENSIONS_LOAD_ERROR_ALERT_HEADING 46153
#define IDS_EXTENSIONS_LOAD_ERROR_MESSAGE 46154
#define IDS_WEBSTORE_DOWNLOAD_ACCESS_DENIED 46155
#define IDS_EXTENSIONS_SUPERVISED_USER_PARENTAL_PERMISSION_FAILURE 46156
#define IDS_EXTENSIONS_SUPERVISED_USER_BLOCKED_BY_PARENT 46157
#define IDS_EXTENSION_PROMPT_MESSAGE_FROM_ADMIN 46158

// ---------------------------------------------------------------------------
// From generated_resources.h:

#define IDS_ACCESS_CODE_CAST_ACCESS_CODE_MESSAGE 1800
#define IDS_ACCESS_CODE_CAST_BACK 1801
#define IDS_ACCESS_CODE_CAST_CAST 1802
#define IDS_ACCESS_CODE_CAST_CONNECT 1803
#define IDS_ACCESS_CODE_CAST_DIALOG_TITLE 1804
#define IDS_ACCESS_CODE_CAST_ENTER_CHARACTER 1805
#define IDS_ACCESS_CODE_CAST_ERROR_ACCESS_CODE 1806
#define IDS_ACCESS_CODE_CAST_ERROR_DIFFERENT_NETWORK 1807
#define IDS_ACCESS_CODE_CAST_ERROR_NETWORK 1808
#define IDS_ACCESS_CODE_CAST_ERROR_PERMISSION 1809
#define IDS_ACCESS_CODE_CAST_ERROR_TOO_MANY_REQUESTS 1810
#define IDS_ACCESS_CODE_CAST_ERROR_UNKNOWN 1811
#define IDS_ACCESS_CODE_CAST_ERROR_PROFILE_SYNC 1812
#define IDS_ACCESS_CODE_CAST_INPUT_ARIA_LABEL 1813
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_DAYS 1814
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_HOURS 1815
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_MONTHS 1816
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_YEARS 1817
#define IDS_ACCESS_CODE_CAST_SUBMIT 1818
#define IDS_ACCESS_CODE_CAST_USE_CAMERA 1819
#define IDS_HANDOFF_TAKE_OVER_TASK_LABEL 1820
#define IDS_HANDOFF_GIVE_TASK_BACK_LABEL 1821
#define IDS_HANDOFF_TAKE_OVER_TASK_A11Y_LABEL 1822
#define IDS_HANDOFF_GIVE_TASK_BACK_A11Y_LABEL 1823
#define IDS_TASK_IN_PROGRESS_TOAST_BODY 1824
#define IDS_ACTOR_TASK_NUDGE_CHECK_TASK_LABEL 1825
#define IDS_ACTOR_TASK_NUDGE_TASK_COMPLETE_LABEL 1826
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_TAB_CLOSED_SUBTITLE 1827
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_CHECK_TASK_SUBTITLE 1828
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_ACTING_TASK_SUBTITLE 1829
#define IDS_ACTOR_TASK_LIST_BUBBLE_A11Y_LABEL 1830
#define IDS_ACTOR_TASK_INDICATOR_TOOLTIP 1831
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_PAUSED_TASK_SUBTITLE 1832
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_COMPLETED_TASK_SUBTITLE 1833
#define IDS_EXPERIMENTAL_TRIGGERING_TASK_LIST_BUBBLE_ROW_COMPLETED_TASK_SUBTITLE 1834
#define IDS_ACTOR_TASK_LIST_BUBBLE_ROW_FAILED_TASK_SUBTITLE 1835
#define IDS_TOOLTIP_TAB_ALERT_STATE_ACTOR_ACCESSING 1836
#define IDS_TAB_AX_LABEL_ACTOR_ACCESSING 1837
#define IDS_ACTOR_PIP_WORKING_STATUS 1838
#define IDS_ACTOR_PIP_PAUSED_STATUS 1839
#define IDS_ACTOR_PIP_NEEDS_ATTENTION_STATUS 1840
#define IDS_ACTOR_PIP_COMPLETE_STATUS 1841
#define IDS_ACTOR_OVERLAY_SNACKBAR_MESSAGE 1842
#define IDS_GLIC_BUTTON_STATUS_REVIEW 1843
#define IDS_GLIC_BUTTON_STATUS_REVIEW_A11Y_LABEL 1844
#define IDS_GLIC_BUTTON_STATUS_DONE 1845
#define IDS_GLIC_BUTTON_STATUS_DONE_A11Y_LABEL 1846
#define IDS_GLIC_BUTTON_STATUS_WORKING_A11Y_LABEL 1847
#define IDS_ACTOR_NOTIFICATION_TITLE_WORKING_ON_TASK 1848
#define IDS_ACTOR_NOTIFICATION_TITLE_CHECK_YOUR_TASK 1849
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_PAUSED 1850
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_STOPPED 1851
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_COMPLETE 1852
#define IDS_ACTOR_NOTIFICATION_BUTTON_GO_TO_CHROME 1853
#define IDS_ACTOR_NOTIFICATION_BODY_WORKING 1854
#define IDS_ACTOR_NOTIFICATION_BODY_USER_INPUT 1855
#define IDS_ACTOR_NOTIFICATION_BODY_PAUSED 1856
#define IDS_ACTOR_NOTIFICATION_BODY_COMPLETE 1857
#define IDS_ACTOR_NOTIFICATION_BODY_STOPPED 1858
#define IDS_ACTOR_NOTIFICATION_TITLE_WILL_STOP_TASK 1859
#define IDS_ACTOR_NOTIFICATION_BODY_WILL_STOP_TASK_LONG_RUNNING 1860
#define IDS_ACTOR_NOTIFICATION_BODY_WILL_STOP_TASK_NO_RESPONSE 1861
#define IDS_PEEK_STATE_ACTING 1862
#define IDS_PEEK_STATE_PAUSED 1863
#define IDS_PEEK_STATE_WAITING 1864
#define IDS_PEEK_STATE_VIEW_BUTTON_LABEL 1865
#define IDS_PEEK_STATE_CLOSE_BUTTON_DESCRIPTION 1866
#define IDS_PEEK_STATE_PLAY_BUTTON_A11Y_LABEL 1867
#define IDS_PEEK_STATE_PAUSE_BUTTON_A11Y_LABEL 1868
#define IDS_PEEK_STATE_ACCESSIBLE_LABEL 1869
#define IDS_ACTOR_LEAVE_SITE_DIALOG_TITLE 1870
#define IDS_ACTOR_LEAVE_SITE_DIALOG_DESCRIPTION 1871
#define IDS_ACTOR_LEAVE_SITE_DIALOG_LEAVE_SITE 1872
#define IDS_APP_MANAGEMENT_CAMERA 1873
#define IDS_APP_MANAGEMENT_LOCATION 1874
#define IDS_APP_MANAGEMENT_MICROPHONE 1875
#define IDS_APP_MANAGEMENT_NOTIFICATIONS 1876
#define IDS_APP_MANAGEMENT_PERMISSIONS 1878
#define IDS_APP_MANAGEMENT_PERMISSIONS_WITH_ORIGIN 1879
#define IDS_APP_MANAGEMENT_MORE_SETTINGS 1880
#define IDS_APP_MANAGEMENT_WINDOW 1881
#define IDS_APP_MANAGEMENT_UNINSTALL_APP 1882
#define IDS_APP_MANAGEMENT_RUN_ON_OS_LOGIN 1883
#define IDS_APP_MANAGEMENT_POLICY_APP_POLICY_STRING 1884
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_TITLE 1885
#define IDS_APP_MANAGEMENT_INTENT_SHARING_APP_OPEN 1886
#define IDS_APP_MANAGEMENT_INTENT_SHARING_BROWSER_OPEN 1887
#define IDS_APP_MANAGEMENT_INTENT_SHARING_APP_OPEN_EXISTING_TAB 1888
#define IDS_APP_MANAGEMENT_INTENT_SHARING_BROWSER_OPEN_NEW_TAB 1889
#define IDS_APP_MANAGEMENT_INTENT_SHARING_TAB_EXPLANATION 1890
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_DIALOG_TITLE 1891
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_CHANGE_BUTTON 1892
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TITLE 1893
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_1_APP 1894
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_2_APPS 1895
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_3_APPS 1896
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_4_APPS 1897
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_5_OR_MORE_APPS 1898
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_1_APP 1899
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_2_APPS 1900
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_3_APPS 1901
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_4_APPS 1902
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_5_OR_MORE_APPS 1903
#define IDS_APP_MANAGEMENT_APP_VERSION_TITLE 1904
#define IDS_APP_MANAGEMENT_APP_SIZE_TITLE 1905
#define IDS_APP_MANAGEMENT_APP_DATA_SIZE_TITLE 1906
#define IDS_APP_MANAGEMENT_FILE_HANDLING_HEADER 1907
#define IDS_APP_MANAGEMENT_FILE_HANDLING_OVERFLOW_DIALOG_TITLE 1908
#define IDS_APP_MANAGEMENT_FILE_HANDLING_SET_DEFAULTS_LINK 1909
#define IDS_APP_MANAGEMENT_FILE_HANDLING_TYPES 1910
#define IDS_APP_MANAGEMENT_APP_CONTENT_TITLE 1911
#define IDS_APP_MANAGEMENT_APP_CONTENT_SUBTITLE 1912
#define IDS_APP_MANAGEMENT_APP_CONTENT_DIALOG_SUBTITLE 1913
#define IDS_APP_MANAGEMENT_IS_SUB_APP_PERMISSION_EXPLANATION 1914
#define IDS_APP_MANAGEMENT_HAS_SUB_APPS_PERMISSION_EXPLANATION 1915
#define IDS_SUB_APPS_INSTALL_DIALOG_PRIVACY_DESCRIPTION 1916
#define IDS_BOOKMARK_GROUP_FROM_FIREFOX 1919
#define IDS_BOOKMARK_GROUP_FROM_SAFARI 1920
#define IDS_BOOKMARK_GROUP 1921
#define IDS_UNNAMED_BOOKMARK_BUTTON_ACCESSIBLE_NAME 1922
#define IDS_BOOKMARK_BAR_SHOW_APPS_SHORTCUT 1923
#define IDS_BOOKMARK_BAR_SHOW_TAB_GROUPS 1924
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS_DEFAULT_NAME 1925
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS 1926
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_NAME 1927
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_TOOLTIP 1928
#define IDS_BOOKMARK_BAR_OVERFLOW_BUTTON_TOOLTIP 1929
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT 1930
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_WINDOW 1931
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_INCOGNITO 1932
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_TAB_GROUP 1933
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_TAB 1934
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_WINDOW 1935
#define IDS_BOOKMARK_BAR_OPEN_INCOGNITO 1936
#define IDS_BOOKMARK_BAR_OPEN_IN_SPLIT_VIEW 1937
#define IDS_BOOKMARK_BAR_EDIT 1938
#define IDS_BOOKMARK_BAR_RENAME_FOLDER 1939
#define IDS_BOOKMARK_BAR_REMOVE 1940
#define IDS_BOOKMARK_BAR_ADD_NEW_BOOKMARK 1941
#define IDS_BOOKMARK_BAR_NEW_FOLDER 1942
#define IDS_SHOW_BOOKMARK_BAR 1943
#define IDS_HIDE_BOOKMARK_BAR 1944
#define IDS_BOOKMARK_BAR_SUBMENU_LABEL 1945
#define IDS_BOOKMARK_BAR_SUBMENU_ALWAYS_HIDE 1946
#define IDS_BOOKMARK_BAR_SUBMENU_ALWAYS_SHOW 1947
#define IDS_BOOKMARK_BAR_SUBMENU_ONLY_ON_NTP 1948
#define IDS_BOOKMARK_BAR_SHOULD_OPEN_ALL 1949
#define IDS_BOOKMARK_BAR_ALREADY_CREATED_GROUP 1950
#define IDS_BOOKMARK_BAR_REPLACE_OR_CREATE_NEW_GROUP_TITLE 1951
#define IDS_BOOKMARK_BAR_REPLACE_OLD_GROUP_BUTTON 1952
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARKED 1953
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARK 1954
#define IDS_BOOKMARK_BUBBLE_NAME_LABEL 1955
#define IDS_BOOKMARK_AX_BUBBLE_NAME_LABEL 1956
#define IDS_BOOKMARK_BUBBLE_FOLDER_LABEL 1957
#define IDS_BOOKMARK_BUBBLE_CHOOSER_ANOTHER_FOLDER 1958
#define IDS_BOOKMARK_DICE_PROMO_SYNC_MESSAGE 1959
#define IDS_BOOKMARK_VERIFY_PROMO_SUBTITLE 1960
#define IDS_BOOKMARK_PROMO_TITLE 1961
#define IDS_BOOKMARK_EDITOR_NAME_LABEL 1962
#define IDS_BOOKMARK_AX_EDITOR_NAME_LABEL 1963
#define IDS_BOOKMARK_AX_EDITOR_URL_LABEL 1964
#define IDS_BOOKMARK_EDITOR_URL_LABEL 1965
#define IDS_BOOKMARK_EDITOR_CONFIRM_DELETE 1966
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_SUBTITLE 1967
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_BUTTON 1968
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_MENU_ITEM 1969
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE 1970
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE_NEW 1971
#define IDS_UNNAMED_BOOKMARK_FOLDER 1972
#define IDS_BOOKMARK_ALL_TABS_DIALOG_TITLE 1973
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_TITLE 1974
#define IDS_BOOKMARK_MANAGER_TITLE 1975
#define IDS_BOOKMARK_MANAGER_SEARCH_BUTTON 1976
#define IDS_BOOKMARK_MANAGER_V2 1977
#define IDS_BOOKMARK_MANAGER 1978
#define IDS_BOOKMARK_MANAGER_ORGANIZE_MENU 1979
#define IDS_BOOKMARK_MANAGER_INVALID_URL 1980
#define IDS_EXPORT_BOOKMARKS_DEFAULT_FILENAME 1981
#define IDS_BOOKMARK_MANAGER_ADD_BOOKMARK_TITLE 1982
#define IDS_BOOKMARK_MANAGER_ADD_FOLDER_TITLE 1983
#define IDS_BOOKMARK_MANAGER_CLEAR_SEARCH 1984
#define IDS_BOOKMARK_MANAGER_EMPTY_LIST 1985
#define IDS_BOOKMARK_MANAGER_EMPTY_UNMODIFIABLE_LIST 1986
#define IDS_BOOKMARK_MANAGER_FOLDER_LABEL 1987
#define IDS_BOOKMARK_MANAGER_FOLDER_RENAME_TITLE 1988
#define IDS_BOOKMARK_MANAGER_FOLDER_LIST_CHANGED 1989
#define IDS_BOOKMARK_MANAGER_LIST_AX_LABEL 1990
#define IDS_BOOKMARK_MANAGER_MENU_ADD_BOOKMARK 1991
#define IDS_BOOKMARK_MANAGER_MENU_ADD_FOLDER 1992
#define IDS_BOOKMARK_MANAGER_MENU_CUT 1993
#define IDS_BOOKMARK_MANAGER_MENU_COPY 1994
#define IDS_BOOKMARK_MANAGER_MENU_PASTE 1995
#define IDS_BOOKMARK_MANAGER_MENU_EXPORT 1996
#define IDS_BOOKMARK_MANAGER_MENU_HELP_CENTER 1997
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT 1998
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_BEGAN 1999
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_ENDED 2000
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL 2001
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_WITH_COUNT 2002
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW 2003
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW_WITH_COUNT 2004
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO 2005
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO_WITH_COUNT 2006
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP 2007
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP_WITH_COUNT 2008
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB 2009
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_WINDOW 2010
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_INCOGNITO 2011
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB_GROUP 2012
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_SPLIT_VIEW 2013
#define IDS_BOOKMARK_MANAGER_MENU_RENAME 2014
#define IDS_BOOKMARK_MANAGER_MENU_SHOW_IN_FOLDER 2015
#define IDS_BOOKMARK_MANAGER_MENU_SORT 2016
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS 2017
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_AX_LABEL 2018
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_MULTI_AX_LABEL 2019
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_TITLE 2020
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_CONFIRM 2021
#define IDS_BOOKMARK_MANAGER_ITEMS_SELECTED 2022
#define IDS_BOOKMARK_MANAGER_ITEMS_UNSELECTED 2023
#define IDS_BOOKMARK_MANAGER_SIDEBAR_AX_LABEL 2024
#define IDS_BOOKMARK_MANAGER_TOAST_FOLDER_SORTED 2025
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_DELETED 2026
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_DELETED 2027
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_COPIED 2028
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_COPIED 2029
#define IDS_BOOKMARKS_MENU 2030
#define IDS_BOOKMARKS_AND_LISTS_MENU 2031
#define IDS_SHOW_BOOKMARK_SIDE_PANEL 2032
#define IDS_BOOKMARK_THIS_TAB 2033
#define IDS_BOOKMARK_ALL_TABS 2034
#define IDS_BOOKMARKS_LIST_TITLE 2035
#define IDS_TOOLTIP_STARRED 2036
#define IDS_BOOKMARK_SCREEN_READER_CREATED 2037
#define IDS_BOOKMARK_SCREEN_READER_FOLDER_CREATED 2038
#define IDS_BOOKMARK_SCREEN_READER_REORDERED 2039
#define IDS_BOOKMARK_SCREEN_READER_MOVED 2040
#define IDS_BOOKMARK_BAR_HIDDEN_INACTIVITY_PROMO_LABEL 2041
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_ACCESSING 2042
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_SHARING 2043
#define IDS_TOOLTIP_GLIC_CLOSE 2044
#define IDS_TAB_AX_LABEL_GLIC_ACCESSING 2045
#define IDS_TAB_AX_LABEL_GLIC_SHARING 2046
#define IDS_GLIC_PROMO_BODY 2047
#define IDS_GLIC_STATUS_ICON_MENU_CUSTOMIZE_KEYBOARD_SHORTCUT 2048
#define IDS_GLIC_STATUS_ICON_MENU_EXIT 2049
#define IDS_GLIC_STATUS_ICON_MENU_SETTINGS 2050
#define IDS_GLIC_OS_WIDGET_TOGGLE_HELP_BUBBLE 2051
#define IDS_GLIC_OS_WIDGET_KEYBOARD_SHORTCUT_HELP_BUBBLE 2052
#define IDS_GLIC_OFFLINE_NOTICE_HEADER 2053
#define IDS_GLIC_OFFLINE_NOTICE_ACTION 2054
#define IDS_GLIC_OFFLINE_NOTICE_ACTION_BUTTON 2055
#define IDS_GLIC_EXPERIMENTAL_OPT_IN_OFFLINE_NOTICE_MESSAGE 2056
#define IDS_GLIC_UNRESPONSIVE_MESSAGE 2057
#define IDS_GLIC_ERROR_NOTICE_HEADER 2058
#define IDS_GLIC_ERROR_NOTICE 2059
#define IDS_GLIC_ERROR_NOTICE_ACTION_BUTTON 2060
#define IDS_GLIC_SHOW_ERROR_BUTTON 2061
#define IDS_GLIC_NOTICE_CLOSE_BUTTON_LABEL 2062
#define IDS_GLIC_SIGN_IN_NOTICE_HEADER 2063
#define IDS_GLIC_SIGN_IN_NOTICE 2064
#define IDS_GLIC_SIGN_IN_NOTICE_ACTION_BUTTON 2065
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_HEADER 2066
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_ACTION_BUTTON 2067
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE 2068
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_WITH_LINK 2069
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_CLOSE_BUTTON 2070
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_HEADER 2071
#define IDS_GLIC_INELIGIBLE_ACCOUNT_NOTICE_HEADER 2072
#define IDS_GLIC_INELIGIBLE_ACCOUNT_NOTICE 2073
#define IDS_GLIC_MANAGED_BY_ORGANIZATION 2074
#define IDS_SETTINGS_GLIC_ROW_SUBLABEL 2075
#define IDS_SETTINGS_GLIC_POLICY_DISABLED_MESSAGE 2076
#define IDS_SITE_SETTINGS_TYPE_INLINE_CUE_MENU 2077
#define IDS_SITE_SETTINGS_TYPE_INLINE_CUE_MENU_MID_SENTENCE 2078
#define IDS_SETTINGS_SITE_SETTINGS_INLINE_CUE_MENU_ALLOWED 2079
#define IDS_SETTINGS_SITE_SETTINGS_INLINE_CUE_MENU_BLOCKED 2080
#define IDS_SETTINGS_SITE_SETTINGS_INLINE_CUE_MENU_DESCRIPTION 2081
#define IDS_SETTINGS_SITE_SETTINGS_INLINE_CUE_MENU_BLOCKED_EXCEPTIONS 2082
#define IDS_SETTINGS_GLIC_PREFERENCES_SECTION 2083
#define IDS_SETTINGS_GLIC_PERMISSIONS_SECTION 2084
#define IDS_SETTINGS_GLIC_AUTO_BROWSE_SECTION 2085
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE 2086
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT 2087
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_EDIT_LABEL 2088
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_CLEAR_LABEL 2089
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_LABEL 2090
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_ARIA_LABEL 2091
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_LEARN_MORE_ARIA_LABEL 2092
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_LEARN_MORE_ARIA_LABEL 2093
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT 2094
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_EDIT_LABEL 2095
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_CLEAR_LABEL 2096
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT 2097
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_EDIT_LABEL 2098
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_CLEAR_LABEL 2099
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING 2100
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING_SUBLABEL 2101
#define IDS_SETTINGS_GLIC_KEEP_SIDEPANEL_OPEN_ON_NEW_TABS 2102
#define IDS_SETTINGS_GLIC_MEDIA_UNDERSTANDING 2103
#define IDS_SETTINGS_GLIC_MEDIA_UNDERSTANDING_SUBLABEL 2104
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE 2105
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL 2106
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL_DATA_PROTECTED 2107
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE 2108
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL 2109
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL_DATA_PROTECTED 2110
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE 2111
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL 2112
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 2113
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE 2114
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL 2115
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 2116
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON 2117
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON_SUBLABEL 2118
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON 2119
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON_SUBLABEL 2120
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_WHEN_ON_1 2121
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1 2122
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1_LEARN_MORE_LABEL 2123
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_1 2124
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2 2125
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2_NO_LIVE 2126
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_1 2127
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_2 2128
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT_LABEL 2129
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT 2130
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON 2131
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON_SUBLABEL 2132
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_TOGGLE 2133
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_SUB_LABEL 2134
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_WHEN_ON_1 2135
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_WHEN_ON_2 2136
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_CONSIDER_1 2137
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_CONSIDER_2 2138
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_CONSIDER_3 2139
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE 2140
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE_SUBLABEL 2141
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_1 2142
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_2 2143
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_1 2144
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_2 2145
#define IDS_SETTINGS_GLIC_ACTOR_LOGIN_PERMISSIONS_SECTION_TITLE 2146
#define IDS_SETTINGS_GLIC_ACTOR_LOGIN_PERMISSIONS_SECTION_SUBLABEL 2147
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_PAGE_TITLE 2148
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_OFFLINE_WARNING 2149
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_PAGE_DESCRIPTION 2150
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_NO_SITES 2151
#define IDS_SETTINGS_GLIC_REVOKE_ACTOR_LOGIN_PERMISSION_ARIA_LABEL 2152
#define IDS_SETTINGS_GLIC_REMOVE_ACTOR_LOGIN_DIALOG_TITLE 2153
#define IDS_SETTINGS_GLIC_REMOVE_ACTOR_LOGIN_DIALOG_DESCRIPTION 2154
#define IDS_SETTINGS_GLIC_REVOKE_ACTOR_LOGIN_DIALOG_TITLE 2155
#define IDS_SETTINGS_GLIC_REVOKE_ACTOR_LOGIN_DIALOG_DESCRIPTION 2156
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_REMOVE_ERROR 2157
#define IDS_GLIC_PIN 2158
#define IDS_GLIC_UNPIN 2159
#define IDS_GLIC_SCREEN_PICKER_REQUESTER 2160
#define IDS_GLIC_SCREEN_PICKER_HEADLINE 2161
#define IDS_GLIC_SCREEN_PICKER_DESCRIPTION 2162
#define IDS_GLIC_SCREEN_PICKER_CTA 2163
#define IDS_GLIC_INACTIVE_VIEW_CARD_TEXT 2164
#define IDS_GLIC_WINDOW_TITLE 2165
#define IDS_TASK_MANAGER_GLIC_RENDERER_PREFIX 2166
#define IDS_TAB_CXMENU_GLIC_START_SHARE 2167
#define IDS_TAB_CXMENU_GLIC_CREATE_NEW_CHAT 2168
#define IDS_TAB_CXMENU_GLIC_UNSHARE 2169
#define IDS_GLIC_BUTTON_CXMENU_UNPIN 2170
#define IDS_GLIC_SETTING_LABEL 2171
#define IDS_GLIC_BUTTON_ENTRYPOINT_LABEL 2172
#define IDS_GLIC_BUTTON_ENTRYPOINT_PINNED_LABEL 2173
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_GEMINI_LABEL 2174
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_ABOUT_THIS_PAGE_LABEL 2175
#define IDS_CONTENT_CONTEXT_GLICSHAREIMAGE 2176
#define IDS_GLIC_CONTEXT_MENU_SUMMARIZE_PAGE_WITH_GEMINI 2177
#define IDS_GLIC_SUMMARIZE_PAGE_PROMPT 2178
#define IDS_GLIC_CONTEXT_MENU_ASK_GEMINI_ABOUT 2179
#define IDS_GLIC_PROMO_CONFIRM 2180
#define IDS_GLIC_TRYIT_TITLE 2181
#define IDS_GLIC_TRYIT_BODY 2182
#define IDS_GLIC_SHORTCUT_IPH_TEXT_TEMPLATE 2183
#define IDS_GLIC_SHORTCUT_IPH_TEXT 2184
#define IDS_GLIC_SELECTION_ASK_ABOUT 2185
#define IDS_GLIC_SELECTION_MENU_HIDE_FOR_SITE 2186
#define IDS_EDUCATIONAL_TIP_GLIC_TITLE 2187
#define IDS_EDUCATIONAL_TIP_GLIC_DESCRIPTION 2188
#define IDS_EDUCATIONAL_TIP_GLIC_BUTTON 2189
#define IDS_EDUCATIONAL_TIP_GLIC_DISMISS_BUTTON 2190
#define IDS_GLIC_END_TASK_CONFIRMATION_TITLE 2191
#define IDS_GLIC_END_TASK_CONFIRMATION_DESCRIPTION 2192
#define IDS_GLIC_END_TASK_CONFIRMATION_CANCEL 2193
#define IDS_GLIC_END_TASK_CONFIRMATION_YES 2194
#define IDS_TAB_BOTTOM_SHEET_RESIZING_VIEW_TEXT 2195
#define IDS_GLIC_LOCATION_MISMATCH_NOTICE_HEADER 2196
#define IDS_GLIC_LOCATION_MISMATCH_NOTICE 2197
#define IDS_GLIC_GET_HELP 2198
#define IDS_GLIC_CHAT_HIDDEN_TITLE 2199
#define IDS_GLIC_CHAT_HIDDEN_DESCRIPTION 2200
#define IDS_GLIC_TASK_PAUSED_TITLE 2201
#define IDS_GLIC_TASK_PAUSED_DESCRIPTION 2202
#define IDS_GLIC_BOTTOM_SHEET_CLOSED_A11Y_LABEL 2203
#define IDS_GLIC_BOTTOM_SHEET_HALF_HEIGHT_A11Y_LABEL 2204
#define IDS_GLIC_BOTTOM_SHEET_FULL_HEIGHT_A11Y_LABEL 2205
#define IDS_GLOBAL_MEDIA_CONTROLS_ICON_TOOLTIP_TEXT 2206
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL_WITH_COLON 2207
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL 2208
#define IDS_GLOBAL_MEDIA_CONTROLS_STOP_CASTING_BUTTON_LABEL 2209
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION 2210
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_SHOW_LANGUAGE 2211
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_PROGRESS 2212
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR 2213
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 2214
#define IDS_GLOBAL_MEDIA_CONTROLS_CAPTION_SETTINGS 2215
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_TRANSLATE_TARGET_LANGUAGE_ACCNAME 2216
#define IDS_GLOBAL_MEDIA_CONTROLS_DIALOG_NAME 2217
#define IDS_GLOBAL_MEDIA_CONTROLS_CONTROL_CAST_SESSIONS_PROMO 2218
#define IDS_GMC_LOCAL_MEDIA_CAST_SESSIONS_PROMO 2219
#define IDS_GMC_LOCAL_MEDIA_CAST_START_PROMO 2220
#define IDS_MEDIA_TOOLBAR_CONTEXT_REPORT_CAST_ISSUE 2221
#define IDS_MEDIA_TOOLBAR_CONTEXT_SHOW_OTHER_SESSIONS 2222
#define IDS_MEDIA_PREVIEW_CAMERA_ACCESSIBLE_NAME 2223
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_ACCESSIBLE_NAME 2224
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND 2225
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND_COMBOBOX 2226
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_PREVIEW_BADGE 2227
#define IDS_MEDIA_PREVIEW_MIC_ACCESSIBLE_NAME 2228
#define IDS_MEDIA_PREVIEW_AUDIO_STREAM_ACCESSIBLE_NAME 2229
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND 2230
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND_COMBOBOX 2231
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC 2232
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC_PARENTHETICAL 2233
#define IDS_MEDIA_PREVIEW_ANNOUNCE_SELECTED_DEVICE_CHANGE 2234
#define IDS_MEDIA_ROUTER_ICON_TOOLTIP_TEXT 2235
#define IDS_MEDIA_ROUTER_MENU_ITEM_TITLE 2236
#define IDS_MEDIA_ROUTER_PRESENTATION_CAST_MODE 2237
#define IDS_MEDIA_ROUTER_DESKTOP_MIRROR_CAST_MODE 2238
#define IDS_MEDIA_ROUTER_TAB_MIRROR_CAST_MODE 2239
#define IDS_MEDIA_ROUTER_ALTERNATIVE_SOURCES_BUTTON 2240
#define IDS_MEDIA_ROUTER_ABOUT 2241
#define IDS_MEDIA_ROUTER_HELP 2242
#define IDS_MEDIA_ROUTER_TOGGLE_MEDIA_REMOTING 2243
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_WITH_HOSTNAME 2244
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT 2245
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_DESKTOP 2246
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_TAB 2247
#define IDS_MEDIA_ROUTER_ISSUE_UNABLE_TO_CAST_DESKTOP 2248
#define IDS_MEDIA_ROUTER_ISSUE_TAB_AUDIO_NOT_SUPPORTED 2249
#define IDS_MEDIA_ROUTER_ISSUE_DESKTOP_AUDIO_NOT_SUPPORTED 2250
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_PENDING_AUTHORIZATION 2252
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_NOT_ALLOWED 2253
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_NOTIFICATION_DISABLED 2254
#define IDS_MEDIA_ROUTER_ISSUE_FAILED_TO_CAST 2255
#define IDS_MEDIA_ROUTER_ISSUE_CANNOT_TERMINATE 2256
#define IDS_MEDIA_ROUTER_STATUS_LOOKING_FOR_DEVICES 2257
#define IDS_MEDIA_ROUTER_STATUS_NO_DEVICES_FOUND 2258
#define IDS_MEDIA_ROUTER_NO_DEVICES_FOUND_BUTTON 2259
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_BUTTON 2260
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LABEL 2261
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LINK 2262
#define IDS_MEDIA_ROUTER_SINK_AVAILABLE 2263
#define IDS_MEDIA_ROUTER_SINK_CONNECTING 2264
#define IDS_MEDIA_ROUTER_SINK_DISCONNECTING 2265
#define IDS_MEDIA_ROUTER_SINK_PAUSED 2266
#define IDS_MEDIA_ROUTER_STOP_CASTING 2267
#define IDS_MEDIA_ROUTER_SOURCE_NOT_SUPPORTED 2268
#define IDS_MEDIA_ROUTER_AVAILABLE_SPECIFIC_SITES 2269
#define IDS_MEDIA_ROUTER_CASTING_DESKTOP 2270
#define IDS_MEDIA_ROUTER_CASTING_TAB 2271
#define IDS_MEDIA_ROUTER_PRESENTATION_ROUTE_DESCRIPTION 2272
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE 2273
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_GENERIC_ACCESSIBLE_NAME 2274
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_SCREEN_ACCESSIBLE_NAME 2275
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_TAB_ACCESSIBLE_NAME 2276
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME 2277
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_GENERIC_ACCESSIBLE_NAME 2278
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_SCREEN_ACCESSIBLE_NAME 2279
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_TAB_ACCESSIBLE_NAME 2280
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP 2281
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_GENERIC_ACCESSIBLE_NAME 2282
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_SCREEN_ACCESSIBLE_NAME 2283
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_TAB_ACCESSIBLE_NAME 2284
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_TITLE 2285
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_BODY_TEXT 2286
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CHECKBOX 2287
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_OPTIMIZE_BUTTON 2288
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CANCEL_BUTTON 2289
#define IDS_MEDIA_ROUTER_WIRED_DISPLAY_SINK_NAME 2290
#define IDS_MEDIA_ROUTER_FEEDBACK_TITLE 2291
#define IDS_MEDIA_ROUTER_FEEDBACK_NA 2292
#define IDS_MEDIA_ROUTER_FEEDBACK_FORM_DESCRIPTION 2293
#define IDS_MEDIA_ROUTER_FEEDBACK_HEADER 2294
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_ANSWER 2295
#define IDS_MEDIA_ROUTER_FEEDBACK_REQUIRED 2296
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_QUESTION 2297
#define IDS_MEDIA_ROUTER_FEEDBACK_PROMPT 2298
#define IDS_MEDIA_ROUTER_FEEDBACK_MIRRORING_QUALITY_SUBHEADING 2299
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTHNESS 2300
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_QUALITY 2301
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_QUALITY 2302
#define IDS_MEDIA_ROUTER_FEEDBACK_CONTENT_QUESTION 2303
#define IDS_MEDIA_ROUTER_FEEDBACK_ADDITIONAL_COMMENTS 2304
#define IDS_MEDIA_ROUTER_FEEDBACK_ALLOW_CONTACT_BY_EMAIL 2305
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_EMAIL_ADDRESS 2306
#define IDS_MEDIA_ROUTER_FEEDBACK_EMAIL_FIELD 2307
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_BUTTON 2308
#define IDS_MEDIA_ROUTER_FEEDBACK_DISCARD_CONFIRMATION 2309
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_BUG_OR_ERROR 2310
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_FEATURE_REQUEST 2311
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_PROJECTION_QUALITY 2312
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_DISCOVERY 2313
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_OTHER 2314
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_FREEZES 2315
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_JERKY 2316
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_STUTTER 2317
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTH 2318
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_PERFECT 2319
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_UNWATCHABLE 2320
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_POOR 2321
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_ACCEPTABLE 2322
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GOOD 2323
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GREAT 2324
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_UNINTELLIGIBLE 2325
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_POOR 2326
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_ACCEPTABLE 2327
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_GOOD 2328
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_PERFECT 2329
#define IDS_MEDIA_ROUTER_FEEDBACK_SENDING 2330
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_FAIL 2331
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_SUCCESS 2332
#define IDS_MEDIA_ROUTER_FEEDBACK_RESENDING 2333
#define IDS_MEDIA_ROUTER_FEEDBACK_LOGS_HEADER 2334
#define IDS_MEDIA_ROUTER_FEEDBACK_FINE_LOGS_WARNING 2335
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS_HTML 2336
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS 2337
#define IDS_MEDIA_ROUTER_FEEDBACK_PRIVACY_DATA_USAGE 2338
#define IDS_MEDIA_ROUTER_FEEDBACK_SETUP_VISIBILITY_QUESTION 2339
#define IDS_MEDIA_ROUTER_FEEDBACK_YES 2340
#define IDS_MEDIA_ROUTER_FEEDBACK_NO 2341
#define IDS_MEDIA_ROUTER_FEEDBACK_DID_NOT_TRY 2342
#define IDS_MEDIA_ROUTER_FEEDBACK_SOFTWARE_QUESTION 2343
#define IDS_MEDIA_ROUTER_FEEDBACK_UNKNOWN 2344
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_QUESTION 2345
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_SAME_WIFI 2346
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_DIFFERENT_WIFI 2347
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_WIRED_PC 2348
#define IDS_AVATAR_BUTTON_GUEST 2349
#define IDS_AVATAR_BUTTON_GUEST_TOOLTIP 2350
#define IDS_INCOGNITO_BUBBLE_ACCESSIBLE_TITLE 2351
#define IDS_AVATAR_BUTTON_INCOGNITO 2352
#define IDS_AVATAR_BUTTON_INCOGNITO_TOOLTIP 2353
#define IDS_AVATAR_BUTTON_SYNC_ERROR 2354
#define IDS_AVATAR_BUTTON_SYNC_ERROR_TOOLTIP 2355
#define IDS_AVATAR_BUTTON_SYNC_PAUSED 2356
#define IDS_AVATAR_BUTTON_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED 2357
#define IDS_AVATAR_BUTTON_SIGNIN_PAUSED 2358
#define IDS_AVATAR_BUTTON_WORK 2359
#define IDS_AVATAR_BUTTON_SCHOOL 2360
#define IDS_AVATAR_BUTTON_GREETING 2361
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_UNLOCK 2362
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_GET 2363
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_VERIFY 2364
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_UNLOCK 2365
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_GET 2366
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_VERIFY 2367
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_UNLOCK 2368
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_GET 2369
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_VERIFY 2370
#define IDS_PROFILES_MENU_NAME 2371
#define IDS_PROFILES_ADD_PROFILE_LABEL 2372
#define IDS_PROFILES_PROFILE_BUBBLE_ACCESSIBLE_TITLE 2373
#define IDS_PROFILES_ACCOUNT_REMOVAL_TITLE 2374
#define IDS_PROFILES_DICE_SIGNIN_BUTTON 2375
#define IDS_PROFILES_DICE_WEB_ONLY_SIGNIN_BUTTON 2376
#define IDS_PROFILES_DICE_SYNC_DISABLED_TITLE 2377
#define IDS_PROFILES_DASHER_FEATURE_DISABLED_TITLE 2378
#define IDS_PROFILES_DICE_SYNC_PAUSED_TITLE 2379
#define IDS_AI_SIGNIN_PROMO_TITLE 2380
#define IDS_AI_VERIFY_PROMO_SUBTITLE 2381
#define IDS_PROFILES_VERIFY_ACCOUNT_BUTTON 2382
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION 2383
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION_WITH_BOOKMARKS 2384
#define IDS_PROFILE_MENU_PROFILE_IDENTIFIER_WITH_SEPARATOR 2385
#define IDS_PROFILE_MENU_PROFILE_MANAGED_HEADER 2386
#define IDS_GUEST_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2387
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2388
#define IDS_PROFILE_MENU_OPEN_GUEST_PROFILE 2389
#define IDS_PROFILE_MENU_CLOSE_PROFILE_X_WINDOWS_BUTTON 2390
#define IDS_PROFILES_OPEN_SYNC_SETTINGS_BUTTON 2391
#define IDS_PROFILE_MENU_CUSTOMIZE_PROFILE_BUTTON 2392
#define IDS_PROFILE_MENU_OPEN_ACCOUNT_SETTINGS 2393
#define IDS_PROFILE_MENU_AUTOFILL_SETTINGS_BUTTON 2394
#define IDS_PROFILE_MENU_BATCH_UPLOAD_BUTTON 2395
#define IDS_PROFILES_GUEST_PROFILE_NAME 2396
#define IDS_DEFAULT_PROFILE_NAME 2397
#define IDS_LEGACY_DEFAULT_PROFILE_NAME 2398
#define IDS_NEW_NUMBERED_PROFILE_NAME 2399
#define IDS_SINGLE_PROFILE_DISPLAY_NAME 2400
#define IDS_GUEST_PROFILE_NAME 2401
#define IDS_DEFAULT_AVATAR_NAME_8 2402
#define IDS_DEFAULT_AVATAR_NAME_9 2403
#define IDS_DEFAULT_AVATAR_NAME_10 2404
#define IDS_DEFAULT_AVATAR_NAME_11 2405
#define IDS_DEFAULT_AVATAR_NAME_12 2406
#define IDS_DEFAULT_AVATAR_NAME_13 2407
#define IDS_DEFAULT_AVATAR_NAME_14 2408
#define IDS_DEFAULT_AVATAR_NAME_15 2409
#define IDS_DEFAULT_AVATAR_NAME_16 2410
#define IDS_DEFAULT_AVATAR_NAME_17 2411
#define IDS_DEFAULT_AVATAR_NAME_18 2412
#define IDS_DEFAULT_AVATAR_NAME_19 2413
#define IDS_DEFAULT_AVATAR_NAME_20 2414
#define IDS_DEFAULT_AVATAR_NAME_21 2415
#define IDS_DEFAULT_AVATAR_NAME_22 2416
#define IDS_DEFAULT_AVATAR_NAME_23 2417
#define IDS_DEFAULT_AVATAR_NAME_24 2418
#define IDS_DEFAULT_AVATAR_NAME_25 2419
#define IDS_DEFAULT_AVATAR_NAME_26 2420
#define IDS_DEFAULT_AVATAR_LABEL_0 2421
#define IDS_DEFAULT_AVATAR_LABEL_1 2422
#define IDS_DEFAULT_AVATAR_LABEL_2 2423
#define IDS_DEFAULT_AVATAR_LABEL_3 2424
#define IDS_DEFAULT_AVATAR_LABEL_4 2425
#define IDS_DEFAULT_AVATAR_LABEL_5 2426
#define IDS_DEFAULT_AVATAR_LABEL_6 2427
#define IDS_DEFAULT_AVATAR_LABEL_7 2428
#define IDS_DEFAULT_AVATAR_LABEL_8 2429
#define IDS_DEFAULT_AVATAR_LABEL_9 2430
#define IDS_DEFAULT_AVATAR_LABEL_10 2431
#define IDS_DEFAULT_AVATAR_LABEL_11 2432
#define IDS_DEFAULT_AVATAR_LABEL_12 2433
#define IDS_DEFAULT_AVATAR_LABEL_13 2434
#define IDS_DEFAULT_AVATAR_LABEL_14 2435
#define IDS_DEFAULT_AVATAR_LABEL_15 2436
#define IDS_DEFAULT_AVATAR_LABEL_16 2437
#define IDS_DEFAULT_AVATAR_LABEL_17 2438
#define IDS_DEFAULT_AVATAR_LABEL_18 2439
#define IDS_DEFAULT_AVATAR_LABEL_19 2440
#define IDS_DEFAULT_AVATAR_LABEL_20 2441
#define IDS_DEFAULT_AVATAR_LABEL_21 2442
#define IDS_DEFAULT_AVATAR_LABEL_22 2443
#define IDS_DEFAULT_AVATAR_LABEL_23 2444
#define IDS_DEFAULT_AVATAR_LABEL_24 2445
#define IDS_DEFAULT_AVATAR_LABEL_25 2446
#define IDS_DEFAULT_AVATAR_LABEL_26 2447
#define IDS_DEFAULT_AVATAR_LABEL_27 2448
#define IDS_DEFAULT_AVATAR_LABEL_28 2449
#define IDS_DEFAULT_AVATAR_LABEL_29 2450
#define IDS_DEFAULT_AVATAR_LABEL_30 2451
#define IDS_DEFAULT_AVATAR_LABEL_31 2452
#define IDS_DEFAULT_AVATAR_LABEL_32 2453
#define IDS_DEFAULT_AVATAR_LABEL_33 2454
#define IDS_DEFAULT_AVATAR_LABEL_34 2455
#define IDS_DEFAULT_AVATAR_LABEL_35 2456
#define IDS_DEFAULT_AVATAR_LABEL_36 2457
#define IDS_DEFAULT_AVATAR_LABEL_37 2458
#define IDS_DEFAULT_AVATAR_LABEL_38 2459
#define IDS_DEFAULT_AVATAR_LABEL_39 2460
#define IDS_DEFAULT_AVATAR_LABEL_40 2461
#define IDS_DEFAULT_AVATAR_LABEL_41 2462
#define IDS_DEFAULT_AVATAR_LABEL_42 2463
#define IDS_DEFAULT_AVATAR_LABEL_43 2464
#define IDS_DEFAULT_AVATAR_LABEL_44 2465
#define IDS_DEFAULT_AVATAR_LABEL_45 2466
#define IDS_DEFAULT_AVATAR_LABEL_46 2467
#define IDS_DEFAULT_AVATAR_LABEL_47 2468
#define IDS_DEFAULT_AVATAR_LABEL_48 2469
#define IDS_DEFAULT_AVATAR_LABEL_49 2470
#define IDS_DEFAULT_AVATAR_LABEL_50 2471
#define IDS_DEFAULT_AVATAR_LABEL_51 2472
#define IDS_DEFAULT_AVATAR_LABEL_52 2473
#define IDS_DEFAULT_AVATAR_LABEL_53 2474
#define IDS_DEFAULT_AVATAR_LABEL_54 2475
#define IDS_DEFAULT_AVATAR_LABEL_55 2476
#define IDS_PROFILES_LOCAL_PROFILE_STATE 2477
#define IDS_PROFILES_MANAGE_BUTTON_LABEL 2478
#define IDS_PROFILES_DEFAULT_NAME 2479
#define IDS_SYNC_LOGIN_NAME_PROHIBITED 2480
#define IDS_SIGN_IN_LOGIN_NAME_PROHIBITED 2481
#define IDS_SYNC_USER_NAME_IN_USE_ERROR 2482
#define IDS_SYNC_USER_NAME_IN_USE_BY_ERROR 2483
#define IDS_SCREEN_LOCK_SIGN_OUT 2484
#define IDS_FEATURE_SHOWCASE_PASSWORD_MANAGER_NO_THANKS 2489
#define IDS_FEATURE_SHOWCASE_PASSWORD_MANAGER_ADD_TO_TOOLBAR 2490
#define IDS_BATCH_UPLOAD_TITLE 2491
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS_WITH_DEDUPLICATION 2492
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_WITH_DEDUPLICATION 2493
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO_WITH_DEDUPLICATION 2494
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_WITH_DEDUPLICATION 2495
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO_WITH_DEDUPLICATION 2496
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS 2497
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS 2498
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO 2499
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS 2500
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO 2501
#define IDS_BATCH_UPLOAD_SECTION_TITLE_PASSWORDS 2502
#define IDS_BATCH_UPLOAD_SECTION_TITLE_BOOKMARKS 2503
#define IDS_BATCH_UPLOAD_SECTION_TITLE_READING_LIST 2504
#define IDS_BATCH_UPLOAD_SECTION_TITLE_ADDRESSES 2505
#define IDS_BATCH_UPLOAD_SECTION_TITLE_EXTENSIONS 2506
#define IDS_BATCH_UPLOAD_SECTION_TITLE_THEMES_WITH_DESCRIPTION 2507
#define IDS_BATCH_UPLOAD_SAVE_TO_ACCOUNT_OK_BUTTON_LABEL 2508
#define IDS_BATCH_UPLOAD_AVATAR_BUTTON_SAVING_TO_ACCOUNT 2509
#define IDS_BATCH_UPLOAD_LAST_ITEM_SELECTED_SCREEN_READER 2510
#define IDS_BATCH_UPLOAD_SCREEN_READER_ITEM_COUNT_SELECTED 2511
#define IDS_BATCH_UPLOAD_SCREEN_READER_SELECT_ALL 2512
#define IDS_BATCH_UPLOAD_PROMO_TITLE 2513
#define IDS_BATCH_UPLOAD_PROMO_TITLE_OK_BUTTON_LABEL 2514
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS 2515
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS_COMBO 2516
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_ITEMS_WITH_LINK 2517
#define IDS_PROFILE_CUSTOMIZATION_DONE_BUTTON_LABEL 2518
#define IDS_PROFILE_CUSTOMIZATION_THEME_PICKER_LABEL 2519
#define IDS_PROFILE_CUSTOMIZATION_WELCOME 2520
#define IDS_PROFILE_CUSTOMIZATION_INPUT_LABEL 2521
#define IDS_PROFILE_CUSTOMIZATION_INPUT_TITLE 2522
#define IDS_PROFILE_CUSTOMIZATION_INPUT_PLACEHOLDER 2523
#define IDS_PROFILE_CUSTOMIZATION_INPUT_ERROR_MESSAGE 2524
#define IDS_PROFILE_CUSTOMIZATION_SKIP_BUTTON_LABEL 2525
#define IDS_PROFILE_CUSTOMIZATION_DELETE_PROFILE_BUTTON_LABEL 2526
#define IDS_PROFILE_CUSTOMIZATION_LOCAL_PROFILE_CREATION_TITLE 2527
#define IDS_PROFILE_CUSTOMIZATION_AVATAR_SELECTION_BACK_BUTTON_LABEL 2528
#define IDS_ENTERPRISE_PROFILE_WELCOME_TITLE 2529
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_MANAGED_BY 2530
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_STRICT_SEPARATION 2531
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_SEPARATION 2532
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED 2533
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_ACCOUNT_MANAGED 2534
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED_BY 2535
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_EMAIL_MANAGED_BY 2536
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED_BY 2537
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED 2538
#define IDS_ENTERPRISE_WELCOME_PROFILE_REQUIRED_TITLE 2539
#define IDS_ENTERPRISE_WELCOME_PROFILE_SETUP_TITLE 2540
#define IDS_ENTERPRISE_WELCOME_PROFILE_WILL_BE_MANAGED_TITLE 2541
#define IDS_ENTERPRISE_PROFILE_WELCOME_CREATE_PROFILE_BUTTON 2542
#define IDS_ENTERPRISE_PROFILE_WELCOME_LINK_DATA_CHECKBOX 2543
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SCHOOL_TITLE 2544
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_WORK_TITLE 2545
#define IDS_ENTERPRISE_WELCOME_PROFILE_OIDC_DISCLOSURE_TITLE 2546
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_TITLE 2547
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_ENFORCED_SUBTITLE 2548
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_SUBTITLE 2549
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SUBTITLE 2550
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_KNOWN_DOMAIN_SUBTITLE 2551
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_TITLE 2552
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_TITLE 2553
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_DETAILS 2554
#define IDS_ENTERPRISE_PROFILE_WELCOME_BACK 2555
#define IDS_ENTERPRISE_OIDC_WELCOME_PROCESSING_SUBTITLE 2556
#define IDS_ENTERPRISE_OIDC_WELCOME_LONG_PROCESSING_SUBTITLE 2557
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_TITLE 2558
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_SUBTITLE 2559
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_TITLE 2560
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_SUBTITLE 2561
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_RETRY_LABEL 2562
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_TITLE 2563
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_SUBTITLE 2564
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_TITLE 2565
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_SUBTITLE 2566
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE 2567
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE_WITH_BOOKMARKS 2568
#define IDS_ENTERPRISE_VALUE_PROPOSITION_SCHOOL_SUBTITLE 2569
#define IDS_ENTERPRISE_VALUE_PROPOSITION_WORK_SUBTITLE 2570
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_WORK_TITLE 2571
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_SCHOOL_TITLE 2572
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_TITLE 2573
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_CONSUMER_TITLE 2574
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_SCHOOL_CHOICE 2575
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_WORK_CHOICE 2576
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_CHOICE 2577
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_SCHOOL_NOT_RECOMMENDED 2578
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_WORK_NOT_RECOMMENDED 2579
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_DETAILS 2580
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_ALREADY_SIGNED_IN_DETAILS 2581
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WORK_CHOICE 2582
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_SCHOOL_CHOICE 2583
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_ALREADY_SIGNED_IN_CHOICE 2584
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_CHOICE_DETAILS 2585
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_PROFILE_INFORMATION_DETAILS 2586
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_DEVICE_INFORMATION_DETAILS 2587
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_CONTINUE_BUTTON_LABEL 2588
#define IDS_ENTERPRISE_DEVICE_SIGNALS_DISCLAIMER_CANCEL_BUTTON_LABEL 2589
#define IDS_BROWSING_HISTORY_COUNT 2590
#define IDS_BOOKMARKS_COUNT 2591
#define IDS_EXTENSIONS_COUNT 2592
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_THREE_COUNTS_CHOICE_DETAILS 2593
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_TWO_COUNTS_CHOICE_DETAILS 2594
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_ONE_COUNT_CHOICE_DETAILS 2595
#define IDS_ACCNAME_YOUR_AVATAR 2596
#define IDS_ACCNAME_ENTERPRISE_ORGANIZATION_ICON 2597
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TITLE 2598
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TEXT 2599
#define IDS_MANAGED_BY_PARENT_A11Y 2600
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_KIDS_BODY 2601
#define IDS_PROFILE_PICKER_ADD_SPACE_BUTTON 2602
#define IDS_PROFILE_PICKER_BROWSE_AS_GUEST_BUTTON 2603
#define IDS_PROFILE_PICKER_BACK_BUTTON_ARIA_LABEL 2604
#define IDS_PROFILE_PICKER_BACK_BUTTON_SIGN_IN_LABEL 2605
#define IDS_PROFILE_PICKER_PAUSE_EFFECTS_BUTTON 2606
#define IDS_PROFILE_PICKER_PLAY_EFFECTS_BUTTON 2607
#define IDS_PROFILE_PICKER_PROFILE_CARD_NEEDS_SIGNIN_PROMPT 2608
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL_SUPERVISED 2609
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL 2610
#define IDS_PROFILE_PICKER_PROFILE_CARD_INPUT_LABEL 2611
#define IDS_PROFILE_PICKER_PROFILE_MORE_ACTIONS_ARIA_LABEL 2612
#define IDS_PROFILE_PICKER_PROFILE_MENU_REMOVE_TEXT 2613
#define IDS_PROFILE_PICKER_PROFILE_MENU_CUSTOMIZE_TEXT 2614
#define IDS_PROFILE_PICKER_ASK_ON_STARTUP 2615
#define IDS_PROFILE_PICKER_OPEN_ALL_PROFILES_BUTTON 2616
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE_TITLE 2617
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_TITLE 2618
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_BODY 2619
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_TITLE 2620
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_BODY 2621
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_TITLE 2622
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_BODY 2623
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_TITLE 2624
#define IDS_PROFILE_PICKER_REMOVE_WARNING_HISTORY 2625
#define IDS_PROFILE_PICKER_REMOVE_WARNING_PASSWORDS 2626
#define IDS_PROFILE_PICKER_REMOVE_WARNING_BOOKMARKS 2627
#define IDS_PROFILE_PICKER_REMOVE_WARNING_AUTOFILL 2628
#define IDS_PROFILE_PICKER_REMOVE_WARNING_CALCULATING 2629
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_SIGNIN_BUTTON_LABEL 2630
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_NOT_NOW_BUTTON_LABEL 2631
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DONT_SIGN_IN_BUTTON_LABEL 2632
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_STAY_SIGNED_OUT_BUTTON_LABEL 2633
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_CUSTOMIZE_AVATAR_BUTTON_LABEL 2634
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_AVATAR_TEXT 2635
#define IDS_PROFILE_PICKER_IPH_NEXT_BUTTON_LABEL 2636
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SWITCH_BUTTON_LABEL 2637
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_BY_DESCRIPTION 2638
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_DESCRIPTION 2639
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE 2640
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_TITLE 2641
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE 2642
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_SIGN_IN_AS 2643
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO 2644
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO_BOOKMARKS 2645
#define IDS_FRE_SIGN_IN_SUBTITLE_0 2646
#define IDS_FRE_DEVICES_CARD_TITLE 2647
#define IDS_FRE_DEVICES_CARD_DESCRIPTION 2648
#define IDS_FRE_SECURITY_CARD_TITLE 2649
#define IDS_FRE_SECURITY_CARD_DESCRIPTION 2650
#define IDS_FRE_BACKUP_CARD_TITLE 2651
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION 2652
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION_WITH_PASSWORDS 2653
#define IDS_UNO_FRE_REFRESH_BACKUP_CARD_DESCRIPTION_WITH_PASSWORDS 2654
#define IDS_FRE_DECLINE_SIGN_IN_BUTTON_TITLE 2655
#define IDS_FRE_STAY_SIGNED_OUT_BUTTON_TITLE 2656
#define IDS_FRE_ACCEPT_SIGN_IN_BUTTON_TITLE 2657
#define IDS_FRE_CREATE_ACCOUNT_DESCRIPTION 2658
#define IDS_FRE_SIGN_IN_CELEBRATION_WELCOME_TITLE 2659
#define IDS_FRE_MANAGED_DESCRIPTION 2660
#define IDS_FRE_MANAGED_BY_DESCRIPTION 2661
#define IDS_FRE_NATIVE_TOOLBAR_DONT_SIGN_IN_BUTTON_LABEL 2662
#define IDS_FRE_NATIVE_TOOLBAR_START_BROWSING_BUTTON_LABEL 2663
#define IDS_FRE_NEXT_BUTTON_TITLE 2664
#define IDS_FRE_FINISH_OR_CONTINUE_TITLE 2665
#define IDS_FRE_FINISH_OR_CONTINUE_SEE_MORE_TIPS_BUTTON_LABEL 2666
#define IDS_FRE_FINISH_OR_CONTINUE_SEE_WHATS_NEW_BUTTON_LABEL 2667
#define IDS_FRE_FINISH_OR_CONTINUE_START_BROWSING_BUTTON_LABEL 2668
#define IDS_FRE_DEFAULT_BROWSER_TITLE_NEW 2669
#define IDS_FRE_DEFAULT_BROWSER_SET_AS_DEFAULT 2670
#define IDS_FRE_DEFAULT_BROWSER_SKIP 2671
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SET_AS_DEFAULT 2672
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_NO_THANKS 2673
#define IDS_FEATURE_SHOWCASE_LENS_OVERLAY_SUBTITLE 2674
#define IDS_FEATURE_SHOWCASE_LENS_OVERLAY_NOT_NOW 2675
#define IDS_FEATURE_SHOWCASE_LENS_OVERLAY_YES_IM_IN 2676
#define IDS_FEATURE_SHOWCASE_STEPPER_A11Y_LABEL 2677
#define IDS_FEATURE_SHOWCASE_THEMES_SUBTITLE 2678
#define IDS_FEATURE_SHOWCASE_THEMES_APPLY_THEME 2679
#define IDS_FEATURE_SHOWCASE_THEMES_NO_THANKS 2680
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TITLE 2681
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TOOLTIP 2682
#define IDS_SIGNOUT_CONFIRMATION_UNSYNCED_DATA_WITH_ACCOUNT_EXTENSIONS 2683
#define IDS_HISTORY_SYNC_OPT_IN_TITLE 2684
#define IDS_HISTORY_SYNC_OPT_IN_SUBTITLE 2685
#define IDS_HISTORY_SYNC_OPT_IN_DESCRIPTION 2686
#define IDS_HISTORY_SYNC_OPT_IN_ACCEPT_BUTTON 2687
#define IDS_HISTORY_SYNC_OPT_IN_REJECT_BUTTON 2688
#define IDS_TABS_DISABLED_ERROR_DESCRIPTION 2689
#define IDS_AVATAR_BUTTON_SYNC_HISTORY 2690
#define IDS_AVATAR_BUTTON_SYNC_PROMO 2691
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO 2692
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO_WITH_BOOKMARK_CLEANUP_PROMO 2693
#define IDS_PROFILE_MENU_SYNC_PROMO_SYNC_HISTORY_DESCRIPTION 2694
#define IDS_PROFILE_MENU_SYNC_PROMO_BUTTON_LABEL 2695
#define IDS_PROFILE_MENU_DESCRIPTION_WITH_SYNC_PROMO 2696
#define IDS_PROFILE_MENU_BUTTON_LABEL_WITH_SYNC_PROMO 2697
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD 2698
#define IDS_PROFILE_MENU_PROMO_BUTTON_WITH_BATCH_UPLOAD 2699
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD_BOOKMARK_CLEANUP 2700
#define IDS_SIGN_IN_BENEFITS_IPH_TEXT 2701
#define IDS_SIGN_IN_BENEFITS_WITHOUT_BOOKMARKS_AND_EXTENSIONS_IPH_TEXT 2702
#define IDS_AVATAR_BUTTON_SIGNIN_ON_PHONE 2703
#define IDS_PROFILE_MENU_SIGNIN_ON_PHONE_BUTTON_LABEL 2704
#define IDS_QR_CODE_BUBBLE_SIGNIN_ON_PHONE_SUBTITLE 2705
#define IDS_TYPE_A_SHORTCUT 2706
#define IDS_SHORTCUT_SET 2707
#define IDS_SHORTCUT_NOT_SET 2708
#define IDS_SHORTCUT_INCLUDE_START_MODIFIER 2709
#define IDS_SHORTCUT_TOO_MANY_MODIFIERS 2710
#define IDS_SHORTCUT_NEED_CHARACTER 2711
#define IDS_SHORTCUT_CLEAR 2712
#define IDS_SETTINGS_CONTINUE 6583
#define IDS_SETTINGS_GOT_IT 6584
#define IDS_SETTINGS_MORE_ACTIONS 6585
#define IDS_SETTINGS_MORE_ACTIONS_BUTTON_ARIA_LABEL 6586
#define IDS_SETTINGS_OPENS_IN_NEW_TAB 6587
#define IDS_SETTINGS_SEND_FEEDBACK_ROLE_DESCRIPTION 6588
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_ON 6589
#define IDS_SETTINGS_COLUMN_HEADING_CONSIDER 6590
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_USED 6591
#define IDS_RELAUNCH_CONFIRMATION_DIALOG_BODY 6592
#define IDS_SETTINGS_ABOUT_PAGE_BROWSER_VERSION 6593
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_UPDATE_ERRORS 6594
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_SYSTEM_REQUIREMENTS 6595
#define IDS_SETTINGS_ABOUT_PAGE_RELAUNCH 3761
#define IDS_SETTINGS_ACCESSIBILITY 6602
#define IDS_SETTINGS_ACCESSIBILITY_WEB_STORE 6603
#define IDS_SETTINGS_MORE_FEATURES_LINK 6604
#define IDS_SETTINGS_MORE_FEATURES_LINK_DESCRIPTION 6605
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_TITLE 6606
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_SUBTITLE 6607
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_COMPLETE 6608
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_ERROR 6609
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_PROGRESS 6610
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOADING 6611
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_TITLE 6612
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_SUBTITLE 6613
#define IDS_SETTINGS_AX_TREE_FIXING_TITLE 6614
#define IDS_SETTINGS_AX_TREE_FIXING_SUBTITLE 6615
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_TITLE 6616
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_TITLE 6617
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_SUBTITLE 6618
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_SUBTITLE 6619
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_PROGRESS 6620
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_COMPLETE 6621
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR 6622
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 6623
#define IDS_SETTINGS_CAPTIONS_MASK_OFFENSIVE_WORDS_TITLE 6624
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_TITLE 6625
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_SUBTITLE 6626
#define IDS_SETTINGS_ACCESSIBILITY_FOCUS_HIGHLIGHT_DESCRIPTION 4472
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_TITLE 4405
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_SUBTITLE 6627
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_TITLE 6628
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_DESCRIPTION 6629
#define IDS_SETTINGS_APPEARANCE 6630
#define IDS_SETTINGS_CUSTOM_WEB_ADDRESS 6631
#define IDS_SETTINGS_ENTER_CUSTOM_WEB_ADDRESS 6632
#define IDS_SETTINGS_HOME_BUTTON_DISABLED 6633
#define IDS_SETTINGS_THEMES 6634
#define IDS_SETTINGS_GTK_THEME 6635
#define IDS_SETTINGS_USE_GTK_THEME 6636
#define IDS_SETTINGS_QT_THEME 6637
#define IDS_SETTINGS_USE_QT_THEME 6638
#define IDS_SETTINGS_CLASSIC_THEME 6639
#define IDS_SETTINGS_USE_CLASSIC_THEME 6640
#define IDS_SETTINGS_RESET_TO_DEFAULT 6641
#define IDS_SETTINGS_CUSTOMIZE_TOOLBAR 6643
#define IDS_SETTINGS_RESET_TOOLBAR_TO_DEFAULT 6644
#define IDS_SETTINGS_CHROME_COLORS 6645
#define IDS_SETTINGS_COLOR_SCHEME_MODE 6646
#define IDS_SETTINGS_SHOW_HOME_BUTTON 6647
#define IDS_SETTINGS_CTRL_TAB_MRU 6648
#define IDS_SETTINGS_SHOW_BOOKMARKS_BAR 6649
#define IDS_SETTINGS_BOOKMARKS_BAR 6650
#define IDS_SETTINGS_BOOKMARKS_BAR_ALWAYS_SHOW 6651
#define IDS_SETTINGS_BOOKMARKS_BAR_ONLY_SHOW_ON_NTP 6652
#define IDS_SETTINGS_BOOKMARKS_BAR_ALWAYS_HIDE 6653
#define IDS_SETTINGS_SHOW_TAB_SEARCH_BUTTON 6654
#define IDS_SETTINGS_SHOW_PROJECTS_PANEL_BUTTON 6655
#define IDS_SETTINGS_SHOW_EVERYTHING_MENU_BUTTON 6656
#define IDS_SETTINGS_TAB_STRIP_POSITION 6657
#define IDS_SETTINGS_VERTICAL_TABS_EXPAND_ON_HOVER 6658
#define IDS_SETTINGS_ALLOW_SPLIT_VIEW_DRAG_AND_DROP 6659
#define IDS_SETTINGS_SHOW_TAB_GROUPS_IN_BOOKMARKS_BAR 6660
#define IDS_SETTINGS_AUTO_PIN_NEW_TAB_GROUPS 6661
#define IDS_SETTINGS_HOVER_CARD_TITLE 6662
#define IDS_SETTINGS_SHOW_HOVER_CARD_IMAGES 6663
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE 6664
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE_STANDALONE 6665
#define IDS_SETTINGS_SIDE_PANEL_POSITION 6666
#define IDS_SETTINGS_SIDE_PANEL_ALIGNMENT_GLIC 6667
#define IDS_SETTINGS_SIDE_PANEL_ALIGNMENT_CONTEXTUAL_TASKS 6668
#define IDS_SETTINGS_SIDE_PANEL_ALIGNMENT_CHROME_PANELS 6669
#define IDS_SETTINGS_TAB_SEARCH_POSITION 6670
#define IDS_SETTINGS_UI_FEATURE_ALIGN_LEFT 6671
#define IDS_SETTINGS_UI_FEATURE_ALIGN_RIGHT 6672
#define IDS_SETTINGS_UI_FEATURE_ALIGN_SIDE 6673
#define IDS_SETTINGS_UI_FEATURE_ALIGN_TOP 6674
#define IDS_SETTINGS_HOME_PAGE_NTP 6675
#define IDS_SETTINGS_CHANGE_HOME_PAGE 6676
#define IDS_SETTINGS_ADVANCED 6679
#define IDS_SETTINGS_BASIC 6680
#define IDS_SETTINGS_MENU_BUTTON_LABEL 6681
#define IDS_SETTINGS_MENU_EXTENSIONS_LINK_TOOLTIP 6682
#define IDS_SETTINGS_SEARCH_PROMPT 6683
#define IDS_SETTINGS_SEARCH_NO_RESULTS_HELP 6684
#define IDS_SETTINGS_SETTINGS 6685
#define IDS_SETTINGS_ALT_PAGE_TITLE 6686
#define IDS_SETTINGS_SUBPAGE_BUTTON 6687
#define IDS_SETTINGS_RESTART 6688
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION 6689
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_TITLE 6690
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_WITH_DISABLE_AND_MANAGE_OPTION 6691
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_WITH_MANAGE_OPTION 6692
#define IDS_SETTINGS_CLEAR 6693
#define IDS_SETTINGS_CUSTOM 6694
#define IDS_SETTINGS_DELETE 6695
#define IDS_SETTINGS_EDIT 6696
#define IDS_SETTINGS_END_TIME 6697
#define IDS_SETTINGS_NOT_VALID 6698
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS 6699
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS_FOR_CONTENT_TYPE 6700
#define IDS_SETTINGS_INPUT_MAX_LENGTH_DESCRIPTION 6701
#define IDS_SETTINGS_RETRY 6702
#define IDS_SETTINGS_SLIDER_MIN_MAX_ARIA_ROLE_DESCRIPTION 6703
#define IDS_SETTINGS_START_TIME 6704
#define IDS_PASSWORDS_PAGE_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6705
#define IDS_PASSWORDS_PAGE_COPY_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6706
#define IDS_PASSWORDS_PAGE_EDIT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6707
#define IDS_PASSWORDS_PAGE_EXPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6708
#define IDS_PASSWORDS_PAGE_DELETE_ALL_DATA_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6709
#define IDS_SETTINGS_AUTOFILL_AND_PASSWORDS 6710
#define IDS_IDENTITY_DOCS_SUBMENU_OPTION 6711
#define IDS_TRAVEL_SUBMENU_OPTION 6712
#define IDS_SETTINGS_AUTOFILL_AT_MEMORY_TRIGGER_SETTING_LABEL 6713
#define IDS_SETTINGS_AUTOFILL_AT_MEMORY_TRIGGER_SETTING_SECONDARY_LABEL 6714
#define IDS_SETTINGS_AUTOFILL_AT_MEMORY_TRIGGER_SETTING_INPUT_AREA_LABEL 6715
#define IDS_SETTINGS_AUTOFILL_AT_MEMORY_TRIGGER_SETTING_EDIT_BUTTON_LABEL 6716
#define IDS_SETTINGS_AUTOFILL_AT_MEMORY_TRIGGER_SETTING_CLEAR_BUTTON_LABEL 6717
#define IDS_SETTINGS_YOUR_SAVED_INFO_DESCRIPTION 6718
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_LABEL 6719
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_DESCRIPTION 6720
#define IDS_SETTINGS_RELATED_SERVICES_TITLE 6721
#define IDS_PASSWORDS_PAGE_IMPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 6722
#define IDS_SETTINGS_GOOGLE_PAYMENTS 6723
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_ADD_TITLE 6724
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EDIT_TITLE 6725
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_COUNTRY 6726
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_PHONE 6727
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EMAIL 6728
#define IDS_SETTINGS_AUTOFILL_DETAIL 6729
#define IDS_SETTINGS_AUTOFILL_DROPDOWN_NO_OPTION_SELECTED 6730
#define IDS_SETTINGS_AUTOFILL_CARD_DESCRIPTION 6731
#define IDS_SETTINGS_AUTOFILL_CARD_A11Y_LABELED 6732
#define IDS_SETTINGS_AUTOFILL_CARD_EXP_DATE_A11Y_LABELED 6733
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_ADDRESS 6734
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD 6735
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD_WITH_CVC 6736
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_HOME_ADDRESS 6737
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_WORK_ADDRESS 6738
#define IDS_AUTOFILL_ADD_VIRTUAL_CARD 6739
#define IDS_AUTOFILL_REMOVE_VIRTUAL_CARD 6740
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD 6741
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD_IN_WALLET 6742
#define IDS_AUTOFILL_VIRTUAL_CARD_TURNED_ON_LABEL 6743
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_TITLE 6744
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_LABEL 6745
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_CONFIRM_BUTTON_LABEL 6746
#define IDS_SETTINGS_ADDRESS_REMOVE 6747
#define IDS_SETTINGS_REMOVE_VERIFIED_EMAIL_PERMISSION 6748
#define IDS_SETTINGS_REMOVE_VERIFIED_EMAIL_PERMISSION_TITLE 6749
#define IDS_SETTINGS_REMOVE_VERIFIED_EMAIL_PERMISSION_BODY 6750
#define IDS_SETTINGS_ADDRESS_REMOVE_CONFIRMATION_TITLE 6751
#define IDS_SETTINGS_ADDRESS_REMOVED_MESSAGE 6752
#define IDS_SETTINGS_EDIT_CREDIT_CARD_TITLE 6753
#define IDS_SETTINGS_LOCAL_CARD_REMOVE_CONFIRMATION_TITLE 6754
#define IDS_SETTINGS_LOCAL_PAYMENT_METHOD_REMOVE_CONFIRMATION_DESCRIPTION 6755
#define IDS_SETTINGS_GOOGLE_WALLET 6756
#define IDS_SETTINGS_PAYMENTS_MANAGE_LOYALTY_CARDS_AND_PAYMENT_METHODS 6757
#define IDS_SETTINGS_REMOTE_WALLET_PASSES_LINK_LABEL 6758
#define IDS_SETTINGS_PAYMENTS_SAVED_TO_THIS_DEVICE_ONLY 6759
#define IDS_SETTINGS_CREDIT_AND_DEBIT_CARD_TITLE 6760
#define IDS_SETTINGS_ADD_CREDIT_CARD_TITLE 6761
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_LINK_LABEL 6762
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_WALLET_LINK_LABEL 6763
#define IDS_SETTINGS_NAME_ON_CREDIT_CARD 6764
#define IDS_SETTINGS_CREDIT_CARD_NUMBER 6765
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_DATE 6766
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_MONTH 6767
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_YEAR 6768
#define IDS_SETTINGS_CREDIT_CARD_EXPIRED 6769
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME 6770
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME_INVALID 6771
#define IDS_SETTINGS_CREDIT_CARD_CVC_TITLE 6772
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE 6773
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE_AMEX 6774
#define IDS_SETTINGS_CREDIT_CARD_CVC_PLACEHOLDER 6775
#define IDS_SETTINGS_ADD_PAYMENT_METHODS 6776
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_CREDIT_OR_DEBIT_CARD 6777
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_IBAN 6778
#define IDS_SETTINGS_IBAN_SAVED_TO_THIS_DEVICE_ONLY 6779
#define IDS_SETTINGS_IBAN_INVALID_VALIDATION_MESSAGE 6780
#define IDS_IBAN_NICKNAME 6781
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_IBAN 6782
#define IDS_SETTINGS_AUTOFILL_A11Y_IBAN_DESCRIPTION 6783
#define IDS_SETTINGS_ADD_IBAN_TITLE 6784
#define IDS_SETTINGS_EDIT_IBAN_TITLE 6785
#define IDS_SETTINGS_IBAN_EDIT 6786
#define IDS_SETTINGS_LOCAL_IBAN_REMOVE_CONFIRMATION_TITLE 6787
#define IDS_SETTINGS_PASSWORD_MANAGER 6788
#define IDS_SETTINGS_PASSWORD_MANAGER_DESCRIPTION 6789
#define IDS_SETTINGS_PAYMENT_METHODS_NONE 6790
#define IDS_AUTOFILL_PASSKEYS_TITLE 6791
#define IDS_SETTINGS_PASSKEYS_LENGTH_ERROR 6792
#define IDS_SETTINGS_PASSKEYS_SITE_LABEL 6793
#define IDS_SETTINGS_PASSKEYS_DIALOG_TITLE 6794
#define IDS_SETTINGS_PASSKEYS_EDIT_DIALOG_FOOTNOTE 6795
#define IDS_SETTINGS_ADDRESS_NONE 6796
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_LABEL 6797
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_SIGNED_OUT_ENABLED_DESC 6798
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_SAVED_INFO 6799
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_HEADER 6800
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_NONE 6801
#define IDS_SETTINGS_AUTOFILL_AI_MORE_ACTIONS_FOR_ENTITY_INSTANCE 6802
#define IDS_SETTINGS_AUTOFILL_AI_DELETE_ENTITY_INSTANCE_DIALOG_TEXT 6803
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_MONTH_DROPDOWN 6804
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_DAY_DROPDOWN 6805
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_YEAR_DROPDOWN 6806
#define IDS_SETTINGS_AUTOFILL_AI_MONTH_DROPDOWN_NO_OPTION_SELECTED 6807
#define IDS_SETTINGS_AUTOFILL_AI_DAY_DROPDOWN_NO_OPTION_SELECTED 6808
#define IDS_SETTINGS_AUTOFILL_AI_YEAR_DROPDOWN_NO_OPTION_SELECTED 6809
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_DATE_VALIDATION_ERROR 6810
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_VALIDATION_ERROR 6811
#define IDS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_REQUIRED_FIELD_ERROR 6812
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_LABEL 6813
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_SUB_LABEL 6814
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_SAVED_INFO 6815
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_NOTIFICATIONS 6816
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_USAGE 6817
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_STORAGE 6818
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_EDIT 6830
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE 6831
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 6832
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 6833
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 6834
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 6835
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 6836
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 6837
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_ACTION_OK 6838
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVED_MESSAGE 6839
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVED_MESSAGE 6840
#define IDS_SETTINGS_DEFAULT_BROWSER 6841
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_BUTTON 6842
#define IDS_SETTINGS_CLEAR_PERIOD_TITLE 6843
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC 6844
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_ERROR 6845
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PASSPHRASE_ERROR 6846
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PAUSED 6847
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY 6848
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC 6849
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_WITH_EXCEPTION 6850
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SUPERVISED_PROFILE 6851
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SIGNED_IN_PROFILE 6852
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY 6853
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY_SIGNED_IN_NO_LINK 6854
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_GOOGLE_DSE 6855
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_NON_GOOGLE_DSE 6856
#define IDS_SETTINGS_CLEAR_DOWNLOAD_HISTORY 6857
#define IDS_SETTINGS_CLEAR_CACHE 6858
#define IDS_SETTINGS_CLEAR_COOKIES 6859
#define IDS_SETTINGS_CLEAR_PASSWORDS 6860
#define IDS_SETTINGS_CLEAR_FORM_DATA 6861
#define IDS_SETTINGS_CLEAR_HOSTED_APP_DATA 6862
#define IDS_SETTINGS_CLEAR_PERIOD_15_MIN 6863
#define IDS_SETTINGS_CLEAR_PERIOD_15_MINUTES 6864
#define IDS_SETTINGS_CLEAR_PERIOD_HOUR 6865
#define IDS_SETTINGS_CLEAR_PERIOD_24_HOURS 6866
#define IDS_SETTINGS_CLEAR_PERIOD_7_DAYS 6867
#define IDS_SETTINGS_CLEAR_PERIOD_FOUR_WEEKS 6868
#define IDS_SETTINGS_CLEAR_PERIOD_EVERYTHING 6869
#define IDS_SETTINGS_NOTIFICATION_WARNING 6870
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SHOW_MORE 6871
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_MORE 6872
#define IDS_SETTINGS_MANAGE_IN_YOUR_GEMINI_APPS_ACTIVITY 6873
#define IDS_SETTINGS_GEMINI_APPS_ACTIVITY 6874
#define IDS_SETTINGS_DELETE_DATA_FROM_DEVICE 6875
#define IDS_SETTINGS_DELETION_CONFIRMATION_TOAST_LABEL 6876
#define IDS_SETTINGS_DELETION_CONFIRMATION_ALL_TIME_TOAST_LABEL 6877
#define IDS_SETTINGS_SEARCH_GEMINI_PASSWORDS_OTHER_DATA_SUB_LABEL 6878
#define IDS_SETTINGS_DOWNLOADS 6879
#define IDS_SETTINGS_DOWNLOAD_LOCATION 6880
#define IDS_SETTINGS_CHANGE_DOWNLOAD_LOCATION 6881
#define IDS_SETTINGS_PROMPT_FOR_DOWNLOAD 6882
#define IDS_SETTINGS_OPEN_FILE_TYPES_AUTOMATICALLY 6883
#define IDS_SETTINGS_DOWNLOADS_SHOW_WHEN_FINISHED 6884
#define IDS_SETTINGS_ON_STARTUP 6885
#define IDS_SETTINGS_ON_STARTUP_OPEN_NEW_TAB 6886
#define IDS_SETTINGS_ON_STARTUP_CONTINUE 6887
#define IDS_SETTINGS_ON_STARTUP_OPEN_SPECIFIC 6888
#define IDS_SETTINGS_ON_STARTUP_CONTINUE_AND_OPEN_SPECIFIC 6889
#define IDS_SETTINGS_ON_STARTUP_USE_CURRENT 6890
#define IDS_SETTINGS_ON_STARTUP_ADD_NEW_PAGE 6891
#define IDS_SETTINGS_ON_STARTUP_EDIT_PAGE 6892
#define IDS_SETTINGS_ON_STARTUP_SITE_URL 6893
#define IDS_SETTINGS_ON_STARTUP_REMOVE 6894
#define IDS_SETTINGS_ON_STARTUP_PAGE_TOOLTIP 6895
#define IDS_SETTINGS_INVALID_URL 6896
#define IDS_SETTINGS_URL_TOOL_LONG 6897
#define IDS_SETTINGS_PERFORMANCE_PAGE_TITLE 6898
#define IDS_SETTINGS_PERFORMANCE_GENERAL_PAGE_TITLE 6899
#define IDS_SETTINGS_PERFORMANCE_MEMORY_PAGE_TITLE 6900
#define IDS_SETTINGS_PERFORMANCE_SPEED_PAGE_TITLE 6901
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING 6902
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_HEURISTICS_LABEL 6903
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RECOMMENDED_BADGE 6904
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_ON_TIMER_LABEL 6905
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 6906
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CHOOSE_DISCARD_TIME_ARIA_LABEL 6907
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_LABEL 6908
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_LABEL 6909
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_LABEL 6910
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_DESCRIPTION 6911
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_DESCRIPTION 6912
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_DESCRIPTION 6913
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_BUTTON_ARIA_LABEL 6914
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_SAVE_BUTTON_ARIA_LABEL 6915
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_HEADER 6916
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_DESCRIPTION 6917
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADDITIONAL_SITES 6918
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS 6919
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS_EMPTY 6920
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_MANUAL 6921
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ACTIVE_SITE_ARIA_DESCRIPTION 6922
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_HELP 6923
#define IDS_SETTINGS_PERFORMANCE_BATTERY_PAGE_TITLE 6924
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING 6925
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_ON_BATTERY_LABEL 6926
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_BELOW_THRESHOLD_LABEL 6927
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 6928
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_LINK_OS_SETTING_DESCRIPTION 6929
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_LABEL 6930
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_DESCRIPTION_WITH_LEARN_LINK 6931
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_TITLE 6932
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_SUBTITLE 6933
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_LABEL 6934
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_DESCRIPTION 6935
#define IDS_SETTINGS_LANGUAGES_PAGE_TITLE 6936
#define IDS_SETTINGS_LANGUAGES_CARD_TITLE 6937
#define IDS_SETTINGS_LANGUAGE_SEARCH 6938
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_TO_TOP 6939
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_UP 6940
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_DOWN 6941
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_REMOVE 6942
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_ADD 6943
#define IDS_SETTINGS_LANGUAGES_MANAGE_LANGUAGES_TITLE 6944
#define IDS_SETTINGS_LANGUAGES_NO_LANGUAGES_ADDED 6945
#define IDS_SETTINGS_LANGUAGES_EXPAND_ACCESSIBILITY_LABEL 6946
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_HEADER 6947
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_DESC 6948
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE 6949
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE_SUBLABEL 6950
#define IDS_SETTINGS_LANGUAGES_TRANSLATE_TARGET 6951
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_TITLE 6952
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_BODY 6953
#define IDS_SETTINGS_LANGUAGES_ADD_ARIA_LABEL 6954
#define IDS_SETTINGS_LANGUAGES_REMOVE_AUTOMATIC_ARIA_LABEL 6955
#define IDS_SETTINGS_LANGUAGES_REMOVE_NEVER_ARIA_LABEL 6956
#define IDS_SETTINGS_TRANSLATE_PAGE_TITLE 6957
#define IDS_SETTINGS_TARGET_TRANSLATE_LABEL 6958
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE 6959
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE_ADD_ARIA_LABEL 6960
#define IDS_SETTINGS_LANGUAGES_NEVER_LANGUAGES 6961
#define IDS_SETTINGS_LANGUAGES_NEVER_TRANSLATE_ADD_ARIA_LABEL 6962
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_TITLE 6963
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_BASIC_LABEL 6964
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_LABEL 6965
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_DESCRIPTION 6966
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_SPELL_CHECK 6967
#define IDS_SETTING_LANGUAGES_SPELL_CHECK_DISABLED_REASON 6968
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_LANGUAGES_LIST_TITLE 6969
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_MANAGE 6970
#define IDS_SETTINGS_LANGUAGES_EDIT_DICTIONARY_TITLE 6971
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD 6972
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_BUTTON 6973
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_DUPLICATE_ERROR 6974
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_LENGTH_ERROR 6975
#define IDS_SETTINGS_LANGUAGES_DELETE_DICTIONARY_WORD_BUTTON 6976
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS 6977
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS_NONE 6978
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED 6979
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED_HELP 6980
#define IDS_SETTINGS_PRELOAD_PAGES_TITLE 6983
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_TITLE 6984
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_EXPAND_A11Y_LABEL 6985
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_SUMMARY 6986
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_ONE 6987
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_TITLE 6988
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_SUMMARY 6989
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_EXPAND_A11Y_LABEL 6990
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_ONE 6991
#define IDS_SETTINGS_PRIVACY 6992
#define IDS_SETTINGS_PRIVACY_MORE 6993
#define IDS_SETTINGS_AI_COMPOSE_SUBLABEL_V2 6995
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_LABEL 6996
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_SUB_LABEL 6997
#define IDS_SETTINGS_OFFER_WRITING_HELP_ENABLED_SUB_LABEL 6998
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SUB_LABEL 6999
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SITES_LABEL_V2 7000
#define IDS_SETTINGS_OFFER_WRITING_HELP_NO_DISABLED_SITES 7001
#define IDS_SETTINGS_OFFER_WRITING_HELP_REMOVE_SITE_ARIA_LABEL 7002
#define IDS_SETTINGS_COMPOSE_SETTING_LINK_A11Y 7003
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_HELP 7004
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_EXAMPLES 7005
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_REFERENCES 7006
#define IDS_SETTINGS_COMPOSE_CONSIDER_DATA 7007
#define IDS_SETTINGS_ANTI_ABUSE_ENABLED_SUB_LABEL 7008
#define IDS_SETTINGS_ANTI_ABUSE_DISABLED_SUB_LABEL 7009
#define IDS_SETTINGS_ANTI_ABUSE_DESCRIPTION 7010
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_ONE 7011
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_TWO 7012
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_THREE 7013
#define IDS_SETTINGS_ANTI_ABUSE_THINGS_TO_CONSIDER_SECTION_ONE 7014
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG 7015
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG_MORE 7016
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_LABEL 7017
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_SUB_LABEL 7018
#define IDS_SETTINGS_AD_PRIVACY_RESTRICTED_LINK_ROW_SUB_LABEL 7019
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TITLE 7020
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_LABEL 7021
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_ENABLED 7022
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_DISABLED 7023
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_LABEL 7024
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_ENABLED 7025
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_DISABLED 7026
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_LABEL 7027
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_ENABLED 7028
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_DISABLED 7029
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_REGION_A11Y_DESCRIPTION 7030
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_REGION_A11Y_DESCRIPTION 7031
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_V2 7032
#define IDS_SETTINGS_FLEDGE_PAGE_TITLE 7033
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_LABEL 7034
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_SUB_LABEL 7035
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_HEADING 7036
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION 7037
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE 7038
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_DISABLED 7039
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_EMPTY 7040
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_REGION_A11Y_DESCRIPTION 7041
#define IDS_SETTINGS_FLEDGE_PAGE_SEE_ALL_SITES_LABEL 7042
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE 7043
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE_A11Y_LABEL 7044
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_HEADING 7045
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION 7046
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION_EMPTY 7047
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_REGION_A11Y_DESCRIPTION 7048
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE 7049
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE_A11Y_LABEL 7050
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_HEADING 7051
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_1 7052
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_2 7053
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_3 7054
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE_A11Y_LABEL 7055
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TITLE 7056
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_LABEL 7057
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_SUB_LABEL 7058
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_1 7059
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_2 7060
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_3 7061
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_1 7062
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_2 7063
#define IDS_SETTINGS_PRIVACY_GUIDE_LABEL 7064
#define IDS_SETTINGS_PRIVACY_GUIDE_SUBLABEL 7065
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_HEADER 7066
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_START_BUTTON 7067
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_LABEL 7068
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_ROLE_DESC 7069
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_BUTTON 7070
#define IDS_SETTINGS_PRIVACY_GUIDE_STEPS 7071
#define IDS_SETTINGS_PRIVACY_GUIDE_NEXT_BUTTON 7072
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_HEADER 7073
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_SUB_HEADER 7074
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_HEADER 7075
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER 7076
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER_NO_LINKS 7077
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_LEAVE_BUTTON 7078
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_LABEL 7079
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_SUB_LABEL_AD_TOPICS 7080
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_LABEL 7081
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_AI_SETTINGS_LABEL 7082
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_CARD_HEADER 7083
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION1 7084
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION2 7085
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION1 7086
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_CARD_HEADER 7087
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_CARD_HEADER 7088
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_SETTING_LABEL 7089
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_SETTING_LABEL 7090
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION1 7091
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_FEATURE_DESCRIPTION1 7092
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION2 7093
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_PRIVACY_DESCRIPTION1 7094
#define IDS_SETTINGS_PRIVACY_GUIDE_COOKIES_CARD_HEADER 7095
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_HEADER 7096
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION1 7097
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION2 7098
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION3 7099
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION1 7100
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW 7103
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_ARIA_LABEL 7104
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_LABEL 7105
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_PRIMARY_LABEL 7106
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SECONDARY_LABEL 7107
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_SECONDARY_LABEL 7108
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_BULK_LABEL 7109
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_LABEL 7110
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_LABEL 7111
#define IDS_SETTINGS_SAFETY_CHECK_PASSWORDS_PRIMARY_LABEL 7112
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_EXTENSIONS 7113
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_IGNORED_TOAST_LABEL 7114
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCKED_TOAST_LABEL 7115
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_RESET_TOAST_LABEL 7116
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_COUNT_LABEL 7117
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_LABEL 7118
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_ARIA_LABEL 7119
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_LABEL 7120
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_ARIA_LABEL 7121
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_LABEL 7122
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_ARIA_LABEL 7123
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_MORE_ACTIONS_ARIA_LABEL 7124
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_LABEL 7125
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_TOAST_LABEL 7126
#define IDS_SETTINGS_SAFETY_CHECK_TOAST_UNDO_BUTTON_LABEL 7127
#define IDS_SETTINGS_NETWORK_PREDICTION_ENABLED_DESC 7128
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION 7129
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION_DESC 7130
#define IDS_SETTINGS_SAFEBROWSING_ENABLE_REPORTING_DESC 7131
#define IDS_SETTINGS_SAFEBROWSING_SECTION_LABEL 7132
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED 7133
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_DESC_UPDATED 7134
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_EXPAND_ACCESSIBILITY_LABEL 7135
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_ONE 7136
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_THREE 7137
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FOUR 7138
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FIVE 7139
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_TWO 7140
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_THREE 7141
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_FOUR 7142
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_ONE 7143
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_TWO 7144
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_THREE 7145
#define IDS_SETTINGS_SAFEBROWSING_STANDARD 7146
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_DESC 7147
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_EXPAND_ACCESSIBILITY_LABEL 7150
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_ONE 7151
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_HELP_IMPROVE 7152
#define IDS_SETTINGS_SAFEBROWSING_NONE 7153
#define IDS_SETTINGS_SAFEBROWSING_NONE_DESC 7154
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_TITLE 7155
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_DESC 7156
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_CONFIRM 7157
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK 7158
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TITLE 7159
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TEXT 7160
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_LEARN_MORE_ACCESSIBILITY_LABEL 7161
#define IDS_SETTINGS_PERMISSIONS_DESCRIPTION 7162
#define IDS_SETTINGS_SECURITY 7163
#define IDS_SETTINGS_SECURITY_DESCRIPTION 7164
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM 7165
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM_DESC 7166
#define IDS_SETTINGS_SECURITY_BUNDLE_TOAST_FOR_USER_OPTED_INTO_ENHANCED_BUNDLE 7167
#define IDS_SETTINGS_SECURITY_BUNDLE_RESET_TO_DEFAULTS_BUTTON_LABEL 7168
#define IDS_SETTINGS_SECURITY_TITLE 7169
#define IDS_SETTINGS_SECURITY_STANDARD_BUNDLE_TITLE 7170
#define IDS_SETTINGS_SECURITY_ENHANCED_BUNDLE_TITLE 7171
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_TITLE 7172
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_DESCRIPTION 7173
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_TITLE 7174
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_SUBTITLE 7175
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_HEADING 7176
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_CONTENT 7177
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_HEADING 7178
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_ONE 7179
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_TWO 7180
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_THREE 7181
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_TITLE 7182
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_SUBTITLE 7183
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_TWO 7184
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_THREE 7185
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED 7186
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_CUSTOM 7187
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_STRICT 7188
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_STANDARD 7189
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_OFF 7190
#define IDS_SETTINGS_SECURITY_ACCOUNT_AND_NETWORK_SECTION_TITLE 7191
#define IDS_SETTINGS_SECURITY_ADVANCED_PROTECTION_PROGRAM_LABEL 7192
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_TITLE 7193
#define IDS_SETTINGS_SECURITY_SECURE_DNS_TITLE 7194
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DESCRIPTION 7195
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DEFAULT 7196
#define IDS_SETTINGS_SECURITY_SECURE_DNS_FALLBACK 7197
#define IDS_SETTINGS_SECURITY_SECURE_DNS_CUSTOM 7198
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_TITLE 7199
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_DESCRIPTION 7200
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES 7201
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES 7202
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES_DESCRIPTION 7203
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS 7204
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS_DESCRIPTION 7205
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_TITLE 7206
#define IDS_SETTINGS_HTTPS_ONLY_MODE 7207
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION 7208
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION_ADVANCED_PROTECTION 7209
#define IDS_SETTINGS_HTTPS_FIRST_MODE_TITLE 7210
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION 7211
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION_ADVANCED_PROTECTION 7212
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_LABEL 7213
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_LABEL 7214
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_LABEL 7215
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_LABEL 7216
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_SUBLABEL 7217
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_LABEL 7218
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_SUBLABEL 7219
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_LABEL 7220
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_SUBLABEL 7221
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_LABEL 7222
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_SUBLABEL 7223
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_LABEL 7224
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_SUBLABEL 7225
#define IDS_SETTINGS_MANAGE_CERTIFICATES 7226
#define IDS_SETTINGS_MANAGE_CERTIFICATES_DESCRIPTION 7227
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES 7228
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES_DESCRIPTION 7229
#define IDS_SETTINGS_MANAGE 7230
#define IDS_SETTINGS_SECURE_DNS 7231
#define IDS_SETTINGS_AUTOMATIC_MODE_DESCRIPTION 7233
#define IDS_SETTINGS_SECURE_DNS_DROPDOWN_ACCESSIBILITY_LABEL 7234
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_DESCRIPTION 7235
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_PRIVACY_POLICY 7236
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_MANAGED_ENVIRONMENT 7237
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_PARENTAL_CONTROL 7238
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_DESCRIPTION 7239
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_PLACEHOLDER 7240
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_FORMAT_ERROR 7241
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_CONNECTION_ERROR 7242
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_TITLE 7243
#define IDS_SETTINGS_CONTENT_SETTINGS 7244
#define IDS_SETTINGS_SITE_SETTINGS 7245
#define IDS_SETTINGS_SITE_SETTINGS_DESCRIPTION 7246
#define IDS_SETTINGS_CLEAR_DATA 7247
#define IDS_SETTINGS_CLEARING_DATA 7248
#define IDS_SETTINGS_CLEARED_DATA 7249
#define IDS_SETTINGS_CLEAR_BROWSING_DATA 7250
#define IDS_SETTINGS_CLEAR_DATA_DESCRIPTION 7251
#define IDS_SETTINGS_TITLE_AND_COUNT 7252
#define IDS_SETTINGS_SYNC_AND_GOOGLE_SERVICES_PRIVACY_DESC_UNIFIED_CONSENT 7253
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF 7254
#define IDS_SETTINGS_RECENT_PERMISSIONS_NO_CHANGES 7255
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_ONE_ITEM 7256
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_TWO_ITEMS 7257
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_MORE_THAN_TWO_ITEMS 7258
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_ONE_ITEM 7259
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_TWO_ITEMS 7260
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_MORE_THAN_TWO_ITEMS 7261
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_ONE_ITEM 7262
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_TWO_ITEMS 7263
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_MORE_THAN_TWO_ITEMS 7264
#define IDS_SETTINGS_RESET_PROMPT_TITLE 7265
#define IDS_SETTINGS_RESET 7266
#define IDS_SETTINGS_RESET_SETTINGS_TRIGGER 7267
#define IDS_SETTINGS_RESET_LEARN_MORE_ACCESSIBILITY_TEXT 7268
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_TITLE 7269
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_BODY 7270
#define IDS_SETTINGS_RESET_PINNED_TABS 7271
#define IDS_SETTINGS_RESET_EXTENSIONS 7272
#define IDS_SETTINGS_RESET_HOMEPAGE 7273
#define IDS_SETTINGS_RESET_DSE 7274
#define IDS_SETTINGS_SEARCH 7275
#define IDS_SETTINGS_DEFAULT_SEARCH 7276
#define IDS_SETTINGS_SEARCH_EXPLANATION_ACCESSIBILITY_LABEL 7277
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 7278
#define IDS_SETTINGS_SEARCH_SITE_SEARCH 7279
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS 7280
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS_EXPLANATION 7281
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS 7282
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS_EXPLANATION 7283
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES 7284
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS 7285
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS 7286
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_TITLE 7287
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_DESCRIPTION 7288
#define IDS_SETTINGS_SEARCH_ACTIVATE 7289
#define IDS_SETTINGS_SEARCH_DEACTIVATE 7290
#define IDS_SETTINGS_SEARCH_ACTIVATE_SHORTCUT 7291
#define IDS_SETTINGS_SEARCH_DEACTIVATE_SHORTCUT 7292
#define IDS_SETTINGS_SEARCH_DISABLE_EXTENSION 7293
#define IDS_SETTINGS_SEARCH_MANAGE_EXTENSION 7294
#define IDS_SETTINGS_SEARCH_NO_SITE_SHORTCUTS 7295
#define IDS_SETTINGS_SEARCH_NO_FEATURE_SHORTCUTS 7296
#define IDS_SETTINGS_SEARCH_ENGINES 7297
#define IDS_SETTINGS_SEARCH_ENGINES_PAGE_EXPLANATION 7298
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH 7299
#define IDS_SETTINGS_SEARCH_ENGINES_SUBTITLE_FOR_POLICY 7300
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH 7301
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE 7302
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SEARCH_ENGINE 7303
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SITE_SEARCH 7304
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SITE_SEARCH 7305
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_TITLE 7306
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION 7307
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION_FOR_POLICY 7308
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES 7309
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES_EXPLANATION 7310
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH 7311
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH_EXPLANATION 7312
#define IDS_SETTINGS_SEARCH_ENGINES_NO_SITES_ADDED 7313
#define IDS_SETTINGS_SEARCH_ENGINES_INACTIVE_SHORTCUTS 7314
#define IDS_SETTINGS_SEARCH_ENGINES_NO_OTHER_ENGINES 7315
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES 7316
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES_EXPLANATION 7317
#define IDS_SETTINGS_SEARCH_ENGINES_NAME 7318
#define IDS_SETTINGS_SEARCH_ENGINES_SHORTCUT 7319
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL 7320
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL_EXPLANATION 7321
#define IDS_SETTINGS_SEARCH_ENGINES_MAKE_DEFAULT 7322
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE 7323
#define IDS_SETTINGS_SEARCH_ENGINES_DEACTIVATE 7324
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_DETAILS 7325
#define IDS_SETTINGS_SEARCH_ENGINES_MANAGE_EXTENSION 7326
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TITLE 7327
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_DESCRIPTION 7328
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_SPACE_OR_TAB 7329
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TAB 7330
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_SITES 7331
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_INACTIVE_SITES 7332
#define IDS_SETTINGS_SEARCH_ENGINES_MORE_ACTIONS_ARIA_LABEL 7333
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE_BUTTON_ARIA_LABEL 7334
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH_BUTTON_ARIA_LABEL 7335
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE_BUTTON_ARIA_LABEL 7336
#define IDS_SETTINGS_EXCEPTIONS_EMBEDDED_ON_HOST 7337
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES 7338
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_DESCRIPTION 7339
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_FILTER 7340
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SEARCH 7341
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT 7342
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_MOST_VISITED 7343
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_STORAGE 7344
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_NAME 7345
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_HEADER 7346
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_EDIT_HEADER 7347
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANT_LABEL 7348
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANTS 7349
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_HEADER 7350
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_SITE_DETAILS 7351
#define IDS_SETTINGS_SITE_SETTINGS_SITE_ENTRY_PARTITIONED_LABEL 7352
#define IDS_SETTINGS_SITE_SETTINGS_SITE_REPRESENTATION_SEPARATOR 7353
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR 7354
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR_DESCRIPTION 7355
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DEFAULT_BEHAVIOR_DESC 7356
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DESC 7357
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS 7358
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION 7359
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION_SHORT 7360
#define IDS_SETTINGS_SITE_SETTINGS_ADS_DESCRIPTION 7361
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED 7362
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED 7363
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED_EXCEPTIONS 7364
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED_EXCEPTIONS 7365
#define IDS_SETTINGS_SITE_SETTINGS_AR_DESCRIPTION 7366
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED 7367
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED 7368
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED_EXCEPTIONS 7369
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED_EXCEPTIONS 7370
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_DESCRIPTION 7371
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ASK 7372
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED 7373
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ALLOWED_EXCEPTIONS 7374
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED_EXCEPTIONS 7375
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 7376
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED 7377
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED 7378
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED_EXCEPTIONS 7379
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED_EXCEPTIONS 7380
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_DESCRIPTION 7381
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED 7382
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED 7383
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_SUB_LABEL 7384
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED_EXCEPTIONS 7385
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_EXCEPTIONS 7386
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_DESCRIPTION 7387
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_ASK 7388
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_BLOCKED 7389
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_DESCRIPTION 7390
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ASK 7391
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED 7392
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ALLOWED_EXCEPTIONS 7393
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED_EXCEPTIONS 7394
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_DESCRIPTION 7395
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ASK 7396
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED 7397
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_SUB_LABEL 7398
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ALLOWED_EXCEPTIONS 7399
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_EXCEPTIONS 7400
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_DESCRIPTION 7401
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ASK 7402
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED 7403
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ALLOWED_EXCEPTIONS 7404
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED_EXCEPTIONS 7405
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_DESCRIPTION 7406
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ASK 7407
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED 7408
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ALLOWED_EXCEPTIONS 7409
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED_EXCEPTIONS 7410
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_DESCRIPTION 7411
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED 7412
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED 7413
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED_EXCEPTIONS 7414
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED_EXCEPTIONS 7415
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_DESCRIPTION 7416
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_ASK 7417
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED 7418
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED_EXCEPTIONS 7419
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_DESCRIPTION 7420
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ASK 7421
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED 7422
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ALLOWED_EXCEPTIONS 7423
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED_EXCEPTIONS 7424
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_DESCRIPTION 7425
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_ALLOWED_EXCEPTIONS 7426
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_BLOCKED_EXCEPTIONS 7427
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_DESCRIPTION 7428
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ALLOWED_EXCEPTIONS 7429
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCKED_EXCEPTIONS 7430
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_DESCRIPTION 7431
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_ASK 7432
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_BLOCKED 7433
#define IDS_SITE_SETTINGS_SMART_CARD_READERS 7434
#define IDS_SITE_SETTINGS_SMART_CARD_READERS_DESCRIPTION 7435
#define IDS_SITE_SETTINGS_SMART_CARDS_DEFAULT_DESCRIPTION 7436
#define IDS_SITE_SETTINGS_SMART_CARDS_ASK 7437
#define IDS_SITE_SETTINGS_SMART_CARDS_BLOCKED 7438
#define IDS_SITE_SETTINGS_NO_SMART_CARD_READERS_FOUND 7439
#define IDS_SITE_SETTINGS_RESET_SMART_CARD_CONFIRMATION 7440
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_DESCRIPTION 7441
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED 7442
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED 7443
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_SUB_LABEL 7444
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED_EXCEPTIONS 7445
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_EXCEPTIONS 7446
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_DESCRIPTION 7447
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_ALLOWED_EXCEPTIONS 7448
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCKED_EXCEPTIONS 7449
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_DESCRIPTION 7450
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED 7451
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED 7452
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED_EXCEPTIONS 7453
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED_EXCEPTIONS 7454
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED 7455
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED 7456
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES 7457
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SUB_LABEL 7458
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SAFE_BROWSING_OFF_SUB_LABEL 7459
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_EXCEPTIONS 7460
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_EXCEPTIONS 7461
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_DESCRIPTION 7462
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ASK 7463
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED 7464
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ALLOWED_EXCEPTIONS 7465
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED_EXCEPTIONS 7466
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_DESCRIPTION 7467
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ASK 7468
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED 7469
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_SUB_LABEL 7470
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ALLOWED_EXCEPTIONS 7471
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_EXCEPTIONS 7472
#define IDS_SETTINGS_SITE_SETTINGS_MIC_DESCRIPTION 7473
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ASK 7474
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED 7475
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_SUB_LABEL 7476
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ALLOWED_EXCEPTIONS 7477
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_EXCEPTIONS 7478
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_DESCRIPTION 7479
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ASK 7480
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED 7481
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ALLOWED_EXCEPTIONS 7482
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED_EXCEPTIONS 7483
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_DESCRIPTION 7484
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED 7485
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ASK 7486
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED 7487
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_SUB_LABEL 7488
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED_EXCEPTIONS 7489
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_EXCEPTIONS 7490
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_DESCRIPTION 7491
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED 7492
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ASK 7493
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED 7494
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_SUB_LABEL 7495
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED_EXCEPTIONS 7496
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_EXCEPTIONS 7497
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED 7498
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL 7499
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL_SUB_LABEL 7500
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ASK_STATE 7501
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_QUIET 7502
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_CPSS 7503
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_LOUD 7504
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_TITLE 7505
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED 7506
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_SUB_LABEL 7507
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED_EXCEPTIONS 7508
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_EXCEPTIONS 7509
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_DESCRIPTION 7510
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED 7511
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED 7512
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED_EXCEPTIONS 7513
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED_EXCEPTIONS 7514
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_DESCRIPTION 7515
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_ALLOWED 7516
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_DESCRIPTION 7517
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED 7518
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED 7519
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED_EXCEPTIONS 7520
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED_EXCEPTIONS 7521
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_DESCRIPTION 7522
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED 7523
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED 7524
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED_EXCEPTIONS 7525
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED_EXCEPTIONS 7526
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_DESCRIPTION 7527
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_ALLOWED 7528
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED 7529
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED_SUB_LABEL 7530
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_DESCRIPTION 7538
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_ALLOWED 7539
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED 7540
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED_EXCEPTIONS 7541
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_DESCRIPTION 7542
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_ASK 7543
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_BLOCKED 7544
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_DESCRIPTION 7545
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED 7546
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED 7547
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_SUB_LABEL 7548
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED_EXCEPTIONS 7549
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_EXCEPTIONS 7550
#define IDS_SETTINGS_SITE_SETTINGS_USB_DESCRIPTION 7551
#define IDS_SETTINGS_SITE_SETTINGS_USB_ASK 7552
#define IDS_SETTINGS_SITE_SETTINGS_USB_BLOCKED 7553
#define IDS_SETTINGS_SITE_SETTINGS_VR_DESCRIPTION 7554
#define IDS_SETTINGS_SITE_SETTINGS_VR_ASK 7555
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED 7556
#define IDS_SETTINGS_SITE_SETTINGS_VR_ALLOWED_EXCEPTIONS 7557
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED_EXCEPTIONS 7558
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_DESCRIPTION 7559
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ASK 7560
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCK 7561
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ALLOWED_EXCEPTIONS 7562
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCKED_EXCEPTIONS 7563
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_DESCRIPTION 7564
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ASK 7565
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCK 7566
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ALLOWED_EXCEPTIONS 7567
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCKED_EXCEPTIONS 7568
#define IDS_SETTINGS_SITE_SETTINGS_ZOOM_LEVELS_DESCRIPTION 7569
#define IDS_SETTINGS_SITE_SETTINGS_AR_ASK 7570
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCK 7571
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ASK 7572
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCK 7573
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_DESCRIPTION 7574
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ASK 7575
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCK 7576
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ALLOWED_EXCEPTIONS 7577
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCKED_EXCEPTIONS 7578
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_DESCRIPTION 7579
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ASK 7580
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCK 7581
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ALLOWED_EXCEPTIONS 7582
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCKED_EXCEPTIONS 7583
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_DESCRIPTION 7584
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_TITLE 7585
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_LABEL 7586
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_ENABLED 7587
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_DISABLED 7588
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_ALLOW_RADIO_LABEL 7589
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_BLOCK_RADIO_LABEL 7590
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_LABEL 7591
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_SUB_LABEL 7592
#define IDS_SETTINGS_COOKIES_ALL_SITES_LINK 7593
#define IDS_SETTINGS_TRACKING_PROTECTION_ADVANCED_LABEL 7594
#define IDS_SETTINGS_TRACKING_PROTECTION_DO_NOT_TRACK_TOGGLE_SUB_LABEL 7595
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_TITLE 7596
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_DESCRIPTION 7597
#define IDS_SETTINGS_SITE_SETTINGS_APP_PROTOCOL_HANDLERS 7598
#define IDS_SETTINGS_SITE_SETTINGS_APP_ALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 7599
#define IDS_SETTINGS_SITE_SETTINGS_APP_DISALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 7600
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCK 7601
#define IDS_SETTINGS_SITE_SETTINGS_PDF_DOWNLOAD_PDFS 7602
#define IDS_SETTINGS_SITE_SETTINGS_RECENT_ACTIVITY 7603
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_ZOOM_LEVEL 7604
#define IDS_SETTINGS_SITE_SETTINGS_ASK_BEFORE_SENDING 7605
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_ASK_RECOMMENDED 7606
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_BLOCKED 7607
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_DESCRIPTION 7608
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK 7609
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED 7610
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK_EXCEPTIONS 7611
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED_EXCEPTIONS 7612
#define IDS_SETTINGS_SITE_SETTINGS_BLOCKED 7613
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW 7614
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK 7615
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY 7616
#define IDS_SETTINGS_SITE_SETTINGS_ASK_DEFAULT_MENU 7617
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_DEFAULT_MENU 7618
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DEFAULT_MENU 7619
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_DEFAULT_MENU 7620
#define IDS_SETTINGS_SITE_SETTINGS_ACTION_BLOCK_ON_UNFAMILIAR_SITES_DEFAULT_MENU 7621
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_DEFAULT_MENU 7622
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_MENU 7623
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_MENU 7624
#define IDS_SETTINGS_SITE_SETTINGS_ASK_MENU 7625
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_MENU 7626
#define IDS_SETTINGS_SITE_SETTINGS_RESET_MENU 7627
#define IDS_SETTINGS_SITE_SETTINGS_RESET_FROM_LIST_A11Y 7628
#define IDS_SETTINGS_SITE_SETTINGS_VIEW_FROM_LIST_A11Y 7629
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY_MENU 7630
#define IDS_SETTINGS_SITE_SETTINGS_USAGE 7631
#define IDS_SETTINGS_SITE_SETTINGS_USAGE_NONE 7632
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS 7633
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS_MORE 7634
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT 7635
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT_MORE 7636
#define IDS_SETTINGS_SITE_SETTINGS_ALLOWLISTED 7637
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_BLOCKLISTED_SINGULAR 7638
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_NOT_BLOCKLISTED_SINGULAR 7639
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_KILL_SWITCH 7640
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_INSECURE_ORIGIN 7641
#define IDS_SETTINGS_SITE_SETTINGS_RESET_BUTTON 7642
#define IDS_SETTINGS_SITE_SETTINGS_DELETE 7643
#define IDS_SETTINGS_SITE_SETTINGS_THIRD_PARTY_COOKIES_EXCEPTION_LABEL 7644
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_DIALOG_TITLE 7645
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_DIALOG_TITLE 7646
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE 7647
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE_ACCESSIBILITY 7648
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_DESCRIPTION 7649
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_DESCRIPTION 7650
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_LABEL 7651
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_LABEL 7652
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DETAILS_SUBPAGE_ACCESSIBILITY_LABEL 7653
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MEMBERSHIP_LABEL 7654
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MORE_ACTIONS_TITLE 7655
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SHOW_RELATED_SITES_BUTTON 7656
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SITE_DELETE_STORAGE_BUTTON 7657
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION 7658
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION 7659
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION 7660
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION_INSTALLED 7661
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION_INSTALLED 7662
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION_INSTALLED 7663
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_SIGN_OUT 7664
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_SIGN_OUT 7665
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_RWS_STORAGE_SIGN_OUT 7666
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_DIALOG_TITLE 7667
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_CONFIRMATION 7668
#define IDS_SETTINGS_SITE_SETTINGS_PARENT_APP_PERMISSION_EXPLANATION 7669
#define IDS_SETTINGS_SITE_SETTINGS_SUB_APP_PERMISSION_EXPLANATION 7670
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_DIALOG_TITLE 7671
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION 7672
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION_NEW 7673
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_SIGN_OUT 7674
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_OFFLINE_DATA 7675
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_AD_PERSONALIZATION 7676
#define IDS_SETTINGS_SITE_SETTINGS_SITE_GROUP_DELETE_OFFLINE_DATA 7677
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_DIALOG_TITLE 7678
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_APP_DIALOG_TITLE 7679
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_PARTITIONED_DIALOG_TITLE 7680
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_DIALOG_TITLE 7681
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_DIALOG_TITLE 7682
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_PLURAL_DIALOG_TITLE 7683
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_LOGOUT 7684
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_LOGOUT 7685
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_OFFLINE_DATA 7686
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_PERMISSIONS 7687
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_CONFIRM 7688
#define IDS_SETTINGS_SITE_SETTINGS_COOKIE_REMOVE_SITE 7689
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_ALL 7690
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE 7691
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_IS_DEFAULT 7692
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_SET_DEFAULT 7693
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE 7694
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_ONLY 7695
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_SITE_EXCEPTION_DESC 7696
#define IDS_SETTINGS_SITE_SETTINGS_NO_ZOOMED_SITES 7697
#define IDS_SETTINGS_SITE_NO_SITES_ADDED 7698
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_AUTOPLAY 7699
#define IDS_SETTINGS_SITE_SETTINGS_EMPTY_ALL_SITES_PAGE 7700
#define IDS_SETTINGS_SITE_SETTINGS_NO_SITES_FOUND 7701
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_DESCRIPTION 7702
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ASK 7703
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCK 7704
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ALLOWED_EXCEPTIONS 7705
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCKED_EXCEPTIONS 7706
#define IDS_SETTINGS_SITE_SETTINGS_EXTENSION_ID_DESCRIPTION 7707
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_ALLOWED_SUB_LABEL 7708
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_BLOCKED_SUB_LABEL 7709
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_DELETE_ON_EXIT_SUB_LABEL 7710
#define IDS_SETTINGS_EXPIRES_AFTER_TIME_LABEL 7711
#define IDS_SETTINGS_SITE_DATA_PAGE_TITLE 7712
#define IDS_SETTINGS_SITE_DATA_PAGE_DESCRIPTION 7713
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_HEADING 7714
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_DESCRIPTION 7715
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_LABEL 7716
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_SUB_LABEL 7717
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_RADIO_LABEL 7718
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_LABEL 7719
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_SUB_LABEL 7720
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_HEADING 7721
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_DESCRIPTION 7722
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_EXCEPTIONS_SUB_HEADING 7723
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_EXCEPTIONS_SUB_HEADING 7724
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_TITLE 7725
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_DESCRIPTION 7726
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CONFIRM_BUTTON 7727
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CANCEL_BUTTON 7728
#define IDS_SETTINGS_ADD_SITE_TO_ALLOW_LIST_LABEL 7729
#define IDS_SETTINGS_ADD_SITE_TO_BLOCK_LIST_LABEL 7730
#define IDS_SETTINGS_ADD_SITE_CONTEXT_MENU_LABEL 7731
#define IDS_SETTINGS_STORAGE_ACCESS_DESCRIPTION 7732
#define IDS_SETTINGS_STORAGE_ACCESS_ASK 7733
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED 7734
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_EXCEPTIONS 7735
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_EXCEPTIONS 7736
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_ALL 7737
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_SITE 7738
#define IDS_SETTINGS_STORAGE_ACCESS_OPEN_EXPAND 7739
#define IDS_SETTINGS_STORAGE_ACCESS_CLOSE_EXPAND 7740
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_SITE_LABEL 7741
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_SITE_LABEL 7742
#define IDS_SETTINGS_NO_BLUETOOTH_DEVICES_FOUND 7743
#define IDS_SETTINGS_NO_USB_DEVICES_FOUND 7744
#define IDS_SETTINGS_NO_SERIAL_PORTS_FOUND 7745
#define IDS_SETTINGS_NO_HID_DEVICES_FOUND 7746
#define IDS_SETTINGS_RESET_BLUETOOTH_CONFIRMATION 7747
#define IDS_SETTINGS_RESET_HID_CONFIRMATION 7748
#define IDS_SETTINGS_RESET_SERIAL_PORTS_CONFIRMATION 7749
#define IDS_SETTINGS_RESET_USB_CONFIRMATION 7750
#define IDS_SETTINGS_ADD_SITE_TITLE 7751
#define IDS_SETTINGS_ADD_SITES_TITLE 7752
#define IDS_SETTINGS_EDIT_SITE_TITLE 7753
#define IDS_SETTINGS_ADD_SITE 7754
#define IDS_SETTINGS_SITE_SETTINGS_NUM_COOKIES 7755
#define IDS_SETTINGS_PEOPLE 7756
#define IDS_SETTINGS_CHANGE_PICTURE_PROFILE_PHOTO 7757
#define IDS_SETTINGS_PEOPLE_VERIFY_ACCOUNT_BUTTON 7758
#define IDS_SETTINGS_TURN_OFF_SYNC_MANAGED_PROFILE_EXPLANATION 7759
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE 7760
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE_SUPERVISED_PROFILE 7761
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_MANAGED_CONFIRM 7762
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_CHECKBOX 7763
#define IDS_SETTINGS_SYNC_SETTINGS_SAVED_TOAST_LABEL 7764
#define IDS_SETTINGS_CHROME_SIGNIN_OPTION_SAVED_TOAST_LABEL 7765
#define IDS_SETTINGS_PROFILE_NAME_INPUT_LABEL 7766
#define IDS_SETTINGS_PROFILE_SHORTCUT_TOGGLE_LABEL 7767
#define IDS_SETTINGS_CUSTOMIZE_PROFILE 7768
#define IDS_SETTINGS_PICK_A_THEME_COLOR 7769
#define IDS_SETTINGS_PICK_AN_AVATAR 7770
#define IDS_SETTINGS_CREATE_SHORTCUT 7771
#define IDS_SETTINGS_CREATE_SHORTCUT_SUBTITLE 7772
#define IDS_SETTINGS_ACCOUNT_PAGE_TITLE 7773
#define IDS_SETTINGS_ACCOUNT_DATATYPES_HEADING 7774
#define IDS_SETTINGS_ACCOUNT_BODY 7775
#define IDS_SETTINGS_ACCOUNT_SYNC_DISABLED 7777
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE 7778
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE_SUB_LABEL_OFF 7779
#define IDS_SETTINGS_GOOGLE_SERVICES_PAGE_TITLE 7780
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPLANATION 7781
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION 7782
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION_SUPERVISED_PROFILE 7783
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPAND_ACCESSIBILITY_LABEL 7784
#define IDS_SETTINGS_ENCRYPT_WITH_SYNC_PASSPHRASE_LABEL 7785
#define IDS_SETTINGS_PASSPHRASE_EXPLANATION_TEXT 7786
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ENCRYPTION 7787
#define IDS_SETTINGS_PASSPHRASE_RECOVER 7788
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE 7789
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE_V2 7790
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_WAA_TITLE 7791
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_TITLE 7792
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_PLACEHOLDER 7793
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_SIGNIN 7794
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_DO_NOT_SIGNIN 7795
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_ALWAYS_ASK 7796
#define IDS_SETTINGS_GOOGLE_ACCOUNT 7797
#define IDS_SETTINGS_MANAGE_GOOGLE_ACCOUNT 7798
#define IDS_SETTINGS_IMPORT_SETTINGS_TITLE 7800
#define IDS_SETTINGS_IMPORT_FROM_LABEL 7801
#define IDS_SETTINGS_IMPORT_ITEMS_LABEL 7802
#define IDS_SETTINGS_IMPORT_LOADING_PROFILES 7803
#define IDS_SETTINGS_IMPORT_HISTORY_CHECKBOX 7804
#define IDS_SETTINGS_IMPORT_FAVORITES_CHECKBOX 7805
#define IDS_SETTINGS_IMPORT_PASSWORDS_CHECKBOX 7806
#define IDS_SETTINGS_IMPORT_SEARCH_ENGINES_CHECKBOX 7807
#define IDS_SETTINGS_IMPORT_AUTOFILL_FORM_DATA_CHECKBOX 7808
#define IDS_SETTINGS_IMPORT_CHOOSE_FILE 7809
#define IDS_SETTINGS_IMPORT_COMMIT 7810
#define IDS_SETTINGS_IMPORT_SUCCESS 7811
#define IDS_SETTINGS_IMPORT_NO_PROFILE_FOUND 7812
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_LABEL 7813
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_SUBLABEL_V2 7814
#define IDS_SETTINGS_HISTORY_SEARCH_LEARN_MORE_A11Y_LABEL 7815
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_PAGE_CONTENT 7816
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_SEARCH_FROM 7817
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_LOG_START 7818
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA 7819
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA_ENCRYPTED 7820
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_ON 7821
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_OFF 7822
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SETTING_SUBLABEL_V2 7823
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_PAGE_CONTENT 7824
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_RECALL_INFO 7825
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_DATA_ENCRYPTED 7826
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_OUTDATED 7827
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_ON 7828
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_OFF 7829
#define IDS_SETTINGS_GOOGLE_SEARCH_AI_MODE_WORKSPACE_LABEL 7830
#define IDS_SETTINGS_GOOGLE_SEARCH_AI_MODE_WORKSPACE_SUBLABEL 7831
#define IDS_SETTINGS_PAGE_ZOOM_LABEL 7832
#define IDS_SETTINGS_FONT_SIZE_LABEL 7833
#define IDS_SETTINGS_VERY_SMALL_FONT 7834
#define IDS_SETTINGS_SMALL_FONT 7835
#define IDS_SETTINGS_MEDIUM_FONT 7836
#define IDS_SETTINGS_LARGE_FONT 7837
#define IDS_SETTINGS_VERY_LARGE_FONT 7838
#define IDS_SETTINGS_CUSTOMIZE_FONTS 7839
#define IDS_SETTINGS_FONTS 7840
#define IDS_SETTINGS_STANDARD_FONT_LABEL 7841
#define IDS_SETTINGS_SERIF_FONT_LABEL 7842
#define IDS_SETTINGS_SANS_SERIF_FONT_LABEL 7843
#define IDS_SETTINGS_FIXED_WIDTH_FONT_LABEL 7844
#define IDS_SETTINGS_MATH_FONT_LABEL 7845
#define IDS_SETTINGS_MINIMUM_FONT_SIZE_LABEL 7846
#define IDS_SETTINGS_TINY_FONT_SIZE 7847
#define IDS_SETTINGS_HUGE_FONT_SIZE 7848
#define IDS_SETTINGS_QUICK_BROWN_FOX 7849
#define IDS_SETTINGS_SYSTEM 7850
#define IDS_SETTINGS_SYSTEM_HARDWARE_ACCELERATION_LABEL 7851
#define IDS_SETTINGS_SYSTEM_FEATURE_NOTIFICATIONS_LABEL 7854
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_LABEL 7855
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_EXTENSION_LABEL 7856
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_POLICY_LABEL 7857
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_ORGANIZATION_LABEL 7858
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_DEVICE_LABEL 7859
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_MULTIPLE_SOURCES_LABEL 7860
#define IDS_PAGE_NOT_AVAILABLE_FOR_GUEST_HEADING 7863
#define IDS_SETTINGS_SECURITY_KEYS_TITLE 7864
#define IDS_SETTINGS_SECURITY_KEYS_DESC 7865
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN 7866
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_BUTTON 7867
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_DESC 7868
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_INITIAL_TITLE 7869
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CREATE_TITLE 7870
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CHANGE_TITLE 7871
#define IDS_SETTINGS_SECURITY_KEYS_RESET 7872
#define IDS_SETTINGS_SECURITY_KEYS_RESET_DESC 7873
#define IDS_SETTINGS_SECURITY_KEYS_RESET_TITLE 7874
#define IDS_SETTINGS_SECURITY_KEYS_RESET_CONFIRM_TITLE 7875
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP1 7876
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP2 7877
#define IDS_SETTINGS_SECURITY_KEYS_NO_RESET 7878
#define IDS_SETTINGS_SECURITY_KEYS_RESET_ERROR 7879
#define IDS_SETTINGS_SECURITY_KEYS_RESET_SUCCESS 7880
#define IDS_SETTINGS_SECURITY_KEYS_RESET_NOTALLOWED 7881
#define IDS_SETTINGS_SECURITY_KEYS_NO_PIN 7882
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN_INTRO 7883
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT 7884
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_SIN 7885
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_PL 7886
#define IDS_SETTINGS_SECURITY_KEYS_SAME_PIN_AS_CURRENT 7887
#define IDS_SETTINGS_SECURITY_KEYS_NEW_PIN 7888
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CONFIRM 7889
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN 7890
#define IDS_SETTINGS_SECURITY_KEYS_PIN 7891
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_SHORT_SMALL 7892
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_LONG 7893
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_MISMATCH 7894
#define IDS_SETTINGS_SECURITY_KEYS_CONFIRM_PIN 7895
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SUCCESS 7896
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR 7897
#define IDS_SETTINGS_SECURITY_KEYS_PIN_HARD_LOCK 7898
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SOFT_LOCK 7899
#define IDS_SETTINGS_SECURITY_KEYS_SHOW_PINS 7900
#define IDS_SETTINGS_SECURITY_KEYS_HIDE_PINS 7901
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_LABEL 7902
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_USERNAME_LABEL 7903
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_DISPLAYNAME_LABEL 7904
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_WEBSITE_LABEL 7905
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DESC 7906
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DIALOG_TITLE 7907
#define IDS_SETTINGS_SECURITY_KEYS_UPDATE_CREDENTIAL_DIALOG_TITLE 7908
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_TITLE 7909
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_CREDENTIAL 7910
#define IDS_SETTINGS_SECURITY_KEYS_INPUT_ERROR_TOO_LONG 7911
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_CREDENTIALS 7912
#define IDS_SETTINGS_SECURITY_KEYS_NO_CREDENTIAL_MANAGEMENT 7913
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_REMOVED 7914
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_PIN 7915
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_ERROR 7916
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_SUCCESS 7917
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_FAILED 7918
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_SUCCESS 7919
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_FAILED 7920
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_LABEL 7921
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_DESCRIPTION 7922
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DIALOG_TITLE 7923
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ADD_TITLE 7924
#define IDS_SETTINGS_SECURITY_KEYS_BIO_CHOOSE_NAME 7925
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL 7926
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL_TOO_LONG 7927
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_NO_ENROLLMENTS_LABEL 7928
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLMENTS_LABEL 7929
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_LABEL 7930
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_TRY_AGAIN_LABEL 7931
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_FAILED_LABEL 7932
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_COMPLETE_LABEL 7933
#define IDS_SETTINGS_SECURITY_KEYS_NO_BIOMETRIC_ENROLLMENT 7934
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DELETE 7935
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NO_PIN 7936
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_STORAGE_FULL 7937
#define IDS_SETTINGS_SECURITY_KEYS_TOUCH_TO_CONTINUE 7938
#define IDS_SETTINGS_SECURITY_KEYS_PIN_PROMPT 7939
#define IDS_SETTINGS_SECURITY_KEYS_FORCE_PIN_CHANGE 7940
#define IDS_SETTINGS_EXTENSION_OR_APP_DISPLAY_NAME 7941
#define IDS_SETTINGS_SAFETY_HUB 7942
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_BUTTON_LABEL 7943
#define IDS_SETTINGS_SAFETY_HUB_PAGE_CARD_SECTION_HEADER 7944
#define IDS_SETTINGS_SAFETY_HUB_PAGE_MODULE_SECTION_HEADER 7945
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_HEADER 7946
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_RECENTLY 7947
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SOME_TIME_AGO 7948
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_WEAK_OR_REUSED 7949
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SIGN_IN 7950
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_GO_TO_PASSWORD_MANAGER 7951
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_PASSWORDS 7952
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS_POLICY 7953
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_NAVIGATION_ARIA_LABEL 7954
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_HEADER 7955
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_SUBHEADER 7956
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_HEADER 7957
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_SUBHEADER 7958
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_HEADER 7959
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_MANAGED_SUBHEADER 7960
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_EXTENSION_SUBHEADER 7961
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_USER_SUBHEADER 7962
#define IDS_SETTINGS_SAFETY_HUB_SB_NAVIGATION_ARIA_LABEL 7963
#define IDS_SETTINGS_SAFETY_HUB_GO_SITE_SETTINGS_ITEM 7964
#define IDS_SETTINGS_SAFETY_HUB_GO_NOTIFICATION_SETTINGS_ITEM 7965
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_SUBHEADER 7966
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_HEADER 7967
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_SUBHEADER_RESTART 7968
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_PRIMARY_LABEL 7969
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_SECONDARY_LABEL 7970
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_MENU_NOTIFICATION 7971
#define IDS_SETTINGS_SAFETY_HUB_REVIEW_NOTIFICATION_PERMISSIONS_MENU_NOTIFICATION 7972
#define IDS_SETTINGS_SAFETY_HUB_COMPROMISED_PASSWORDS_MENU_NOTIFICATION 7973
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MENU_NOTIFICATION 7974
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MENU_NOTIFICATION 7975
#define IDS_SETTINGS_SAFETY_HUB_PASSWORDS_MODULE_NAME 7976
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MODULE_NAME 7977
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_UPPERCASE_NAME 7978
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_LOWERCASE_NAME 7979
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_UPPERCASE_NAME 7980
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_LOWERCASE_NAME 7981
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_UPPERCASE_NAME 7982
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_LOWERCASE_NAME 7983
#define IDS_SETTINGS_SAFETY_HUB_MODULE_NAME_SEPARATOR 7984
#define IDS_SETTINGS_AI_INNOVATIONS_PAGE_TITLE 7985
#define IDS_SETTINGS_AI_PAGE_TITLE 7986
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_3 7987
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_LEARN_MORE_ACCESSIBILITY_LABEL 7988
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_AI 7989
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_REVIEWERS 7990
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_LOGGING_MANAGED_DISABLED 7991
#define IDS_SETTINGS_AI_SUBPAGE_FEATURE_MANAGED_DISABLED_LABEL 7992
#define IDS_SETTINGS_PASSWORD_CHANGE_LABEL 7993
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL 7994
#define IDS_SETTINGS_PASSWORD_CHANGE_DATA_BREACH 7995
#define IDS_SETTINGS_PASSWORD_CHANGE_WHERE_SAVED 7996
#define IDS_SETTINGS_PASSWORD_CHANGE_EXPERIMENTAL 7997
#define IDS_SETTINGS_PASSWORD_CHANGE_CONTENT 7998
#define IDS_SETTINGS_PASSWORD_CHANGE_ENCRYPTION 7999
#define IDS_SETTINGS_SAFEBROWSING_TURN_ON_ENHANCED_TOAST_BUTTON 8000
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_ON_TOAST_MESSAGE 8001
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_OFF_TOAST_MESSAGE 8002
#define IDS_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED_DESCRIPTION 8003
#define IDS_SETTINGS_AI_PAGE_MAIN_TITLE 8004
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_1 8005
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_2 8006
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_SUBLABEL_3 8007
#define IDS_SETTINGS_CPU_PERFORMANCE_OVERRIDE_TITLE 8008
#define IDS_SETTINGS_CPU_PERFORMANCE_OVERRIDE_DESCRIPTION 8009
#define IDS_SETTINGS_CPU_PERFORMANCE_NOMINAL_TIER 8010
#define IDS_SETTINGS_CPU_PERFORMANCE_MODEL 8011
#define IDS_SETTINGS_CPU_PERFORMANCE_CORES 8012
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_DEFAULT 8013
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_UNKNOWN 8014
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_LOW 8015
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_MID 8016
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_HIGH 8017
#define IDS_SETTINGS_CPU_PERFORMANCE_TIER_ULTRA 8018
#define IDS_SETTINGS_SKILLS_SETTING_SUBLABEL 8019
#define IDS_SETTINGS_SKILLS_GALLERY_HEADER 8020
#define IDS_SETTINGS_SKILLS_GALLERY_LABEL 8021
#define IDS_SETTINGS_SYNC_GO_TO_SKILLS_BUTTON 8022
#define IDS_SETTINGS_SKILLS_WHEN_ON_BULLET_ONE 8023
#define IDS_SETTINGS_SKILLS_THINGS_TO_CONSIDER_BULLET_ONE 8024
#define IDS_SETTINGS_SKILLS_THINGS_TO_CONSIDER_BULLET_TWO 8025
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_LABEL 8026
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 8027
#define IDS_SETTINGS_SUBPAGE_LEARN_MORE_ARIA_LABEL 8028
#define IDS_SETTINGS_CAPTIONS 8029
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_TITLE 8030
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_SUBTITLE 8031
#define IDS_SETTINGS_CAPTIONS_TEXT_SIZE 8032
#define IDS_SETTINGS_CAPTIONS_TEXT_FONT 8033
#define IDS_SETTINGS_CAPTIONS_TEXT_COLOR 8034
#define IDS_SETTINGS_CAPTIONS_TEXT_OPACITY 8035
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_OPACITY 8036
#define IDS_SETTINGS_CAPTIONS_OPACITY_OPAQUE 8037
#define IDS_SETTINGS_CAPTIONS_OPACITY_SEMI_TRANSPARENT 8038
#define IDS_SETTINGS_CAPTIONS_OPACITY_TRANSPARENT 8039
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW 8040
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_NONE 8041
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_RAISED 8042
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DEPRESSED 8043
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_UNIFORM 8044
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DROP_SHADOW 8045
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_COLOR 8046
#define IDS_SETTINGS_CAPTIONS_COLOR_BLACK 8047
#define IDS_SETTINGS_CAPTIONS_COLOR_WHITE 8048
#define IDS_SETTINGS_CAPTIONS_COLOR_RED 8049
#define IDS_SETTINGS_CAPTIONS_COLOR_GREEN 8050
#define IDS_SETTINGS_CAPTIONS_COLOR_BLUE 8051
#define IDS_SETTINGS_CAPTIONS_COLOR_YELLOW 8052
#define IDS_SETTINGS_CAPTIONS_COLOR_CYAN 8053
#define IDS_SETTINGS_CAPTIONS_COLOR_MAGENTA 8054
#define IDS_SETTINGS_CAPTIONS_DEFAULT_SETTING 8055
#define IDS_SETTINGS_CAPTIONS_LANGUAGE 8056
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_TITLE 8057
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE 8058
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE_LIVE_CAPTION_ONLY 8059
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE 8060
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE_SUBTITLE 8061
#define IDS_SETTINGS_CAPTIONS_REMOVE_LANGUAGE_LABEL 8062
#define IDS_SETTINGS_CAPTIONS_MAKE_DEFAULT_LANGUAGE_LABEL 8063
#define IDS_SETTINGS_CAPTIONS_DEFAULT_LANGUAGE_LABEL 8064
#define IDS_SETTINGS_NEARBY_SHARE_TITLE 8065
#define IDS_SETTINGS_NEARBY_SHARE_TITLE_PH 8066
#define IDS_SETTINGS_NEARBY_SHARE_SET_UP_BUTTON_TITLE 8067
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ROW_TITLE 8068
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_DIALOG_TITLE 8069
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_FIELD_LABEL 8070
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DEVICE_NAME 8071
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_TITLE 8072
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_DESCRIPTION 8073
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_ARIA_LABEL 8074
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ARIA_DESCRIPTION 8075
#define IDS_SETTINGS_NEARBY_SHARE_CONFIRM_DEVICE_NAME 8076
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_LABEL 8077
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_ROW_TITLE 8078
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DATA_USAGE 8079
#define IDS_SETTINGS_NEARBY_SHARE_UPDATE_DATA_USAGE 8080
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_DIALOG_TITLE 8081
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_LABEL 8082
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_DESCRIPTION 8083
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_LABEL 8084
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_DESCRIPTION 8085
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_TOOLTIP 8086
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_LABEL 8087
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_DESCRIPTION 8088
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_DATA_DESCRIPTION 8089
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_WIFI_ONLY_DESCRIPTION 8090
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_OFFLINE_DESCRIPTION 8091
#define IDS_SETTINGS_NEARBY_SHARE_CONTACT_VISIBILITY_ROW_TITLE 8092
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_VISIBILITY 8093
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_TITLE 8094
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_SAVE 8095
#define IDS_SETTINGS_NEARBY_SHARE_DESCRIPTION 8096
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_TITLE 8097
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_ON 8098
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_OFF 8099
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION 8100
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION_DESC 8101
#define IDS_SETTINGS_SPELLING_PREF 8102
#define IDS_SETTINGS_ENABLE_LOGGING_PREF 8103
#define IDS_SETTINGS_ENABLE_LOGGING_PREF_DESC 8104
#define IDS_SETTINGS_SUGGEST_PREF 8105
#define IDS_SETTINGS_PEOPLE_SIGNED_IN_TO_ACCOUNT 8106
#define IDS_SETTINGS_PEOPLE_SYNCING_TO_ACCOUNT 8107
#define IDS_SETTINGS_PEOPLE_SYNC_PAUSED 8108
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT 8109
#define IDS_SETTINGS_PEOPLE_SYNC_TURN_OFF 8110
#define IDS_SETTINGS_SETTINGS_CHECKBOX_LABEL 8111
#define IDS_SETTINGS_PEOPLE_SYNC_NOT_WORKING 8112
#define IDS_SETTINGS_PEOPLE_SYNC_PASSWORDS_NOT_WORKING 8113
#define IDS_SETTINGS_SYNC_ADVANCED_PAGE_TITLE 8114
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_PAGE_TITLE 8115
#define IDS_SETTINGS_PEOPLE_SYNC_ANOTHER_ACCOUNT 8116
#define IDS_SETTINGS_TURN_ON_SYNC_BUTTON_UPDATE_SETTINGS_UI_ENABLED 8117
#define IDS_SETTINGS_ACCOUNT_AWARE_SIGNIN_BUTTON_LABEL 8118
#define IDS_SETTINGS_ERROR_PASSWORDS_USER_ERROR_DESCRIPTION 8119
#define IDS_SETTINGS_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_ERROR_DESCRIPTION 8120
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL 8121
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_WITH_BOOKMARKS 8122
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_SIMPLE 8123
#define IDS_SETTINGS_CHANGE_ACCOUNT 8124
#define IDS_SETTINGS_SYNC_DISCONNECT_CONFIRM 8125
#define IDS_SETTINGS_PEOPLE_SIGN_OUT 8126
#define IDS_SETTINGS_AUTOFILL_CHECKBOX_LABEL 8127
#define IDS_SETTINGS_HISTORY_CHECKBOX_LABEL 8128
#define IDS_SETTINGS_EXTENSIONS_CHECKBOX_LABEL 8129
#define IDS_SETTINGS_OPEN_TABS_CHECKBOX_LABEL 8130
#define IDS_SETTINGS_SAVED_TAB_GROUPS_CHECKBOX_LABEL 8131
#define IDS_SETTINGS_PRODUCT_COMPARISONS_CHECKBOX_LABEL 8132
#define IDS_SETTINGS_WIFI_CONFIGURATIONS_CHECKBOX_LABEL 8133
#define IDS_SETTINGS_SYNC_EVERYTHING_CHECKBOX_LABEL 8134
#define IDS_SETTINGS_APPS_CHECKBOX_LABEL 8135
#define IDS_SETTINGS_APPS_CHECKBOX_SUBLABEL 8136
#define IDS_SETTINGS_NON_PERSONALIZED_SERVICES_SECTION_LABEL 8137
#define IDS_SETTINGS_CUSTOMIZE_SYNC 8138
#define IDS_SETTINGS_SYNC_DATA 8139
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS_CHECKBOX_LABEL 8140
#define IDS_SETTINGS_PASSPHRASE_PLACEHOLDER 8141
#define IDS_SETTINGS_EXISTING_PASSPHRASE_TITLE 8142
#define IDS_SETTINGS_SUBMIT_PASSPHRASE 8143
#define IDS_SETTINGS_ENCRYPT_WITH_GOOGLE_CREDENTIALS_LABEL 8144
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_GOOGLE_CREDENTIALS_LABEL 8145
#define IDS_SETTINGS_BOOKMARKS_CHECKBOX_LABEL 8146
#define IDS_SETTINGS_READING_LIST_CHECKBOX_LABEL 8147
#define IDS_SETTINGS_ENCRYPTION_OPTIONS 8148
#define IDS_SETTINGS_MISMATCHED_PASSPHRASE_ERROR 8149
#define IDS_SETTINGS_EMPTY_PASSPHRASE_ERROR 8150
#define IDS_SETTINGS_INCORRECT_PASSPHRASE_ERROR 8151
#define IDS_SETTINGS_NEW_MANAGE_SYNCED_DATA_TITLE_UNIFIED_CONSENT 8152
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_BROWSER_PAGE_TITLE 8153
#define IDS_SETTINGS_SYNC_SYNC_AND_NON_PERSONALIZED_SERVICES 8154
#define IDS_SETTINGS_PASSPHRASE_CONFIRMATION_PLACEHOLDER 8155
#define IDS_SETTINGS_SYNC_LOADING 8156
#define IDS_SETTINGS_SYNC_TIMEOUT 8157
#define IDS_SETTINGS_SYNC 8158
#define IDS_SETTINGS_SYNC_SETTINGS_CANCEL_SYNC 8159
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_TITLE 8160
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_BODY 8161
#define IDS_SYNC_UNAVAILABLE_FOR_NON_GOOGLE_ACCOUNT 8162
#define IDS_SETTINGS_ABOUT_UPGRADE_CHECK_STARTED 8165
#define IDS_SETTINGS_UPDATE_TO_ROLLBACK_VERSION_DISALLOWED 8166
#define IDS_SETTINGS_THEME_CHECKBOX_LABEL 8168
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TITLE 8172
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES 8173
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES 8174
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES 8175
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_HASH_COPIED_TOAST 8176
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM 8177
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TITLE 8178
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_VIEW_LINK 8180
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ADMIN_CERTS_TITLE 8182
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_USER_CERTS_TITLE 8183
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TRUSTED_CERTS_LIST 8184
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_INTERMEDIATE_CERTS_LIST 8185
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DISTRUSTED_CERTS_LIST 8186
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NO_CERTIFICATES_ROW 8187
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_LABEL 8188
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_ARIA_LABEL 8189
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_LABEL 8190
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_ARIA_LABEL 8191
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_LABEL 8192
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_ARIA_LABEL 8193
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NUM_CERTS 8194
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_DESCRIPTION 8195
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES_DESCRIPTION 8196
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES_DESCRIPTION 8197
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK 8198
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK_ARIA_LABEL 8199
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TOGGLE_LABEL 8200
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CUSTOM_CERTS_TITLE 8201
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_PLATFORM 8202
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_ADMIN 8203
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_EXTENSION 8204
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CERT_TITLE 8205
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CLIENT_CERT_DESCRIPTION 8206
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_SERVER_CERT_DESCRIPTION 8207
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_READ_FILE_ERROR 8208
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_MULTIPLE_CERT_ERROR 8209
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR_TITLE 8210
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR 8211
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ENTER_PASSWORD_TITLE 8212
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_ERROR_TITLE 8213
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_FILE 8214
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_FAILED 8215
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BAD_PASSWORD 8216
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_MAC 8217
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_UNSUPPORTED 8218
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_LABEL 8219
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 8220
#define IDS_CERTIFICATE_MANAGER_V2_LIST_EXPAND_ARIA_LABEL 8221
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_VIEW_ARIA_LABEL 8222
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_DELETE_ARIA_LABEL 8223
#define IDS_CERTIFICATE_MANAGER_V2_CERT_HASH_COPY_ARIA_LABEL 8224
#define IDS_SUPPORT_TOOL_ISSUE_DETAILS_PAGE_TITLE 8248
#define IDS_SUPPORT_TOOL_DATA_SELECTION_PAGE_TITLE 8249
#define IDS_SUPPORT_TOOL_REVIEW_PII_PAGE_TITLE 8250
#define IDS_SUPPORT_TOOL_DATA_EXPORT_DONE_PAGE_TITLE 8251
#define IDS_SUPPORT_TOOL_DATA_EXPORTED_TEXT 8252
#define IDS_SUPPORT_TOOL_SUPPORT_CASE_ID 8253
#define IDS_SUPPORT_TOOL_EMAIL 8254
#define IDS_SUPPORT_TOOL_DESCRIBE_ISSUE_TEXT 8255
#define IDS_SUPPORT_TOOL_ISSUE_DESCRIPTION_PLACEHOLDER 8256
#define IDS_SUPPORT_TOOL_PII_WARNING_TEXT 8257
#define IDS_SUPPORT_TOOL_INCLUDE_ALL_PII_RADIO_BUTTON 8258
#define IDS_SUPPORT_TOOL_REMOVE_PII_RADIO_BUTTON 8259
#define IDS_SUPPORT_TOOL_PII_REMOVAL_DISCLAIMER 8260
#define IDS_SUPPORT_TOOL_MANUALLY_SELECT_PII_RADIO_BUTTON 8261
#define IDS_SUPPORT_TOOL_CANCEL_BUTTON_TEXT 8262
#define IDS_SUPPORT_TOOL_EXPORT_BUTTON_TEXT 8263
#define IDS_SUPPORT_TOOL_BACK_BUTTON_TEXT 8264
#define IDS_SUPPORT_TOOL_DISMISS_BUTTON_TEXT 8265
#define IDS_SUPPORT_TOOL_CONTINUE_BUTTON_TEXT 8266
#define IDS_SUPPORT_TOOL_DATA_COLLECTION_SPINNER 8267
#define IDS_SUPPORT_TOOL_DATA_EXPORT_SPINNER 8268
#define IDS_SUPPORT_TOOL_TAB_TITLE 8269
#define IDS_SUPPORT_TOOL_URL_GENERATOR_PAGE_TITLE 8270
#define IDS_SUPPORT_TOOL_DATA_COLLECTOR_LIST_TITLE 8271
#define IDS_SUPPORT_TOOL_GET_LINK_TEXT 8272
#define IDS_SUPPORT_TOOL_COPY_LINK_DESCRIPTION 8273
#define IDS_SUPPORT_TOOL_COPY_LINK_BUTTON_TEXT 8274
#define IDS_SUPPORT_TOOL_COPY_TOKEN_BUTTON_TEXT 8275
#define IDS_SUPPORT_TOOL_DONT_INCLUDE_EMAIL 8276
#define IDS_SUPPORT_TOOL_LINK_COPIED_TEXT 8277
#define IDS_SUPPORT_TOOL_TOKEN_COPIED_TEXT 8278
#define IDS_SUPPORT_TOOL_SELECT_DATA_COLLECTOR_ERROR 8279
#define IDS_SUPPORT_TOOL_SELECT_ALL 8280
#define IDS_SUPPORT_TOOL_CHROME_SYSTEM_INFO 8281
#define IDS_SUPPORT_TOOL_CRASH_IDS 8282
#define IDS_SUPPORT_TOOL_MEMORY_DETAILS 8283
#define IDS_SUPPORT_TOOL_UI_HIEARCHY 8284
#define IDS_SUPPORT_TOOL_ADDITIONAL_CROS_PLATFROM_LOGS 8285
#define IDS_SUPPORT_TOOL_DEVICE_EVENT 8286
#define IDS_SUPPORT_TOOL_INTEL_WIFI_DEBUG_DUMP 8287
#define IDS_SUPPORT_TOOL_TOUCH_EVENTS 8288
#define IDS_SUPPORT_TOOL_CHROMEOS_FLEX_LOGS 8289
#define IDS_SUPPORT_TOOL_DBUS_DETAILS 8290
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_ROUTES 8291
#define IDS_SUPPORT_TOOL_CHROMEOS_SHILL_LOGS 8292
#define IDS_SUPPORT_TOOL_POLICIES 8293
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_STATE 8294
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_LOGS 8295
#define IDS_SUPPORT_TOOL_CHROMEOS_CHROME_USER_LOGS 8296
#define IDS_SUPPORT_TOOL_CHROMEOS_BLUETOOTH_FLOSS 8297
#define IDS_SUPPORT_TOOL_CHROMEOS_CONNECTED_INPUT_DEVICES 8298
#define IDS_SUPPORT_TOOL_CHROMEOS_TRAFFIC_COUNTERS 8299
#define IDS_SUPPORT_TOOL_CHROMEOS_VIRTUAL_KEYBOARD 8300
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_HEALTH 8301
#define IDS_SUPPORT_TOOL_PERFORMANCE 8302
#define IDS_SUPPORT_TOOL_SIGN_IN 8303
#define IDS_SUPPORT_TOOL_CHROMEOS_APP_SERVICE 8304
#define IDS_SUPPORT_TOOL_CHROMEOS_KIOSK_APP_LEVEL_LOGS 8305
#define IDS_SUPPORT_TOOL_CHROME_UPDATER 8306
#define IDS_SUPPORT_TOOL_ANDROID_APP_INFO 8307
#define IDS_SUPPORT_TOOL_WIFI_SSID 8308
#define IDS_SUPPORT_TOOL_CELLULAR_LOCATION_INFO 8309
#define IDS_SUPPORT_TOOL_EMAIL_ADDRESS 8310
#define IDS_SUPPORT_TOOL_GAIA_ID 8311
#define IDS_SUPPORT_TOOL_STABLE_IDENTIDIERS 8312
#define IDS_SUPPORT_TOOL_PRINTING_IPP_ADDRESS 8313
#define IDS_SUPPORT_TOOL_IP_ADDRESS 8314
#define IDS_SUPPORT_TOOL_MAC_ADDRESS 8315
#define IDS_SUPPORT_TOOL_WINDOW_TITLES 8316
#define IDS_SUPPORT_TOOL_URLS 8317
#define IDS_SUPPORT_TOOL_SERIAL_NUMBERS 8318
#define IDS_SUPPORT_TOOL_REMOVABLE_STORAGE_NAMES 8319
#define IDS_SUPPORT_TOOL_EAP 8320
#define IDS_SUPPORT_TOOL_CREDIT_CARD 8321
#define IDS_SUPPORT_TOOL_IBAN 8322
#define IDS_SUPPORT_TOOL_CRASH_ID 8323
#define IDS_SUPPORT_TOOL_MEMORY 8324
#define IDS_SUPPORT_TOOL_BLUETOOTH_HID_DEVICE 8325
#define IDS_EXTENSIONS_ALLOW_FILE_ACCESS 8326
#define IDS_EXTENSIONS_ALLOW_ON_ALL_URLS 8327
#define IDS_EXTENSIONS_ALLOW_ON_FOLLOWING_SITES 8328
#define IDS_EXTENSIONS_VIEW_ACTIVITY_LOG 8329
#define IDS_EXTENSIONS_BACKGROUND_PAGE 8330
#define IDS_EXTENSIONS_SERVICE_WORKER_BACKGROUND 8331
#define IDS_EXTENSIONS_CORRUPTED_EXTENSION 8332
#define IDS_EXTENSIONS_ENABLE_ERROR_COLLECTION 8333
#define IDS_EXTENSIONS_ERROR_NO_ERRORS_CODE_MESSAGE 8334
#define IDS_EXTENSIONS_INSTALL_DROP_TARGET 8335
#define IDS_EXTENSIONS_INSTALL_WARNINGS 8336
#define IDS_EXTENSIONS_LOG_LEVEL_ERROR 8337
#define IDS_EXTENSIONS_LOG_LEVEL_INFO 8338
#define IDS_EXTENSIONS_LOG_LEVEL_WARN 8339
#define IDS_EXTENSIONS_PATH 8340
#define IDS_EXTENSIONS_PERMISSIONS_OFF 8341
#define IDS_EXTENSIONS_RELOAD_TERMINATED 8342
#define IDS_EXTENSIONS_REPAIR_CORRUPTED 8343
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_ICON_TOOLTIP 8344
#define IDS_EXTENSIONS_VIEW_IFRAME 8345
#define IDS_EXTENSIONS_VIEW_INACTIVE 8346
#define IDS_EXTENSIONS_VIEW_INCOGNITO 8347
#define IDS_EXTENSIONS_DEVELOPER_MODE 8348
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE 8349
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_DETAILS 8350
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_TOAST 8351
#define IDS_EXTENSIONS_DISABLED_UPDATE_REQUIRED_BY_POLICY 8352
#define IDS_EXTENSIONS_DISABLED_PUBLISHED_IN_STORE_REQUIRED_BY_POLICY 8353
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_ALLOW 8354
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_TITLE 8355
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_WARNING 8356
#define IDS_EXTENSIONS_MENU_BUTTON_LABEL 8357
#define IDS_EXTENSIONS_ERROR_PAGE_HEADING 8358
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_ALLOW_ALL_EXTENSIONS 8359
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_CUSTOMIZE_PER_EXTENSION 8360
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_RESTRICT_EXTENSIONS 8361
#define IDS_EXTENSIONS_ERROR_ANONYMOUS_FUNCTION 8362
#define IDS_EXTENSIONS_ERROR_CONTEXT 8363
#define IDS_EXTENSIONS_ERROR_CONTEXT_UNKNOWN 8364
#define IDS_EXTENSIONS_CLEAR_ACTIVITIES 8365
#define IDS_EXTENSIONS_ERROR_CLEAR_ALL 8366
#define IDS_EXTENSIONS_A11Y_CLEAR_ENTRY 8367
#define IDS_EXTENSIONS_ERROR_STACK_TRACE 8368
#define IDS_EXTENSIONS_ERROR_LINES_NOT_SHOWN 8369
#define IDS_EXTENSIONS_HOST_PERMISSIONS_DESCRIPTION 8370
#define IDS_EXTENSIONS_PERMISSIONS_LEARN_MORE_A11Y_LABEL 8371
#define IDS_EXTENSIONS_HOST_PERMISSIONS_EDIT 8372
#define IDS_EXTENSIONS_ITEM_ERRORS 8373
#define IDS_EXTENSIONS_ITEM_WARNINGS 8374
#define IDS_EXTENSIONS_ITEM_HOST_PERMISSIONS_HEADING 8375
#define IDS_EXTENSIONS_NEW_HOST_PERMISSIONS_HEADING 8376
#define IDS_EXTENSIONS_HOST_PERMISSIONS_SUB_HEADING 8377
#define IDS_EXTENSIONS_HOST_ACCESS_ON_CLICK 8378
#define IDS_EXTENSIONS_HOST_ACCESS_ASK_ON_EVERY_VISIT 8379
#define IDS_EXTENSIONS_HOST_ACCESS_ON_SPECIFIC_SITES 8380
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_SPECIFIC_SITES 8381
#define IDS_EXTENSIONS_HOST_ACCESS_ON_ALL_SITES 8382
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_ALL_SITES 8383
#define IDS_EXTENSIONS_ITEM_ALLOWED_HOSTS 8384
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_LINE 8385
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_MULTI_LINE 8386
#define IDS_EXTENSIONS_ACTIVITY_LOG_PAGE_HEADING 8387
#define IDS_EXTENSIONS_ACTIVITY_LOG_SEARCH_LABEL 8388
#define IDS_EXTENSIONS_ACTIVITY_LOG_TYPE_COLUMN 8389
#define IDS_EXTENSIONS_ACTIVITY_LOG_NAME_COLUMN 8390
#define IDS_EXTENSIONS_ACTIVITY_LOG_COUNT_COLUMN 8391
#define IDS_EXTENSIONS_ACTIVITY_LOG_TIME_COLUMN 8392
#define IDS_EXTENSIONS_ACTIVITY_LOG_HISTORY_TAB_HEADING 8393
#define IDS_EXTENSIONS_ACTIVITY_LOG_STREAM_TAB_HEADING 8394
#define IDS_EXTENSIONS_START_ACTIVITY_STREAM 8395
#define IDS_EXTENSIONS_STOP_ACTIVITY_STREAM 8396
#define IDS_EXTENSIONS_EMPTY_STREAM_STARTED 8397
#define IDS_EXTENSIONS_EMPTY_STREAM_STOPPED 8398
#define IDS_EXTENSIONS_ACTIVITY_ARGUMENTS_HEADING 8399
#define IDS_EXTENSIONS_WEB_REQUEST_INFO_HEADING 8400
#define IDS_EXTENSIONS_ACTIVITY_LOG_MORE_ACTIONS_LABEL 8401
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPAND_ALL 8402
#define IDS_EXTENSIONS_ACTIVITY_LOG_COLLAPSE_ALL 8403
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPORT_HISTORY 8404
#define IDS_EXTENSIONS_ITEM_ID 8405
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS 8406
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS_EXTRA 8407
#define IDS_EXTENSIONS_ITEM_NO_ACTIVE_VIEWS 8408
#define IDS_EXTENSIONS_ITEM_ALLOW_INCOGNITO 8409
#define IDS_EXTENSIONS_ITEM_ALLOW_USER_SCRIPTS 8410
#define IDS_EXTENSIONS_ALLOW_USER_SCRIPTS_WARNING 8411
#define IDS_EXTENSIONS_ITEM_DEPENDENCIES 8412
#define IDS_EXTENSIONS_DEPENDENT_ENTRY 8413
#define IDS_EXTENSIONS_ITEM_DESCRIPTION 8414
#define IDS_EXTENSIONS_ITEM_DETAILS 8415
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_LABEL 8416
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 8417
#define IDS_EXTENSIONS_EXTENSION_A11Y_ASSOCIATION 8418
#define IDS_EXTENSIONS_APP_ICON 8419
#define IDS_EXTENSIONS_EXTENSION_ICON 8420
#define IDS_EXTENSIONS_ITEM_ID_HEADING 8421
#define IDS_EXTENSIONS_EXTENSION_ENABLED 8422
#define IDS_EXTENSIONS_APP_ENABLED 8423
#define IDS_EXTENSIONS_ITEM_OFF 8424
#define IDS_EXTENSIONS_ITEM_ON 8425
#define IDS_EXTENSIONS_ITEM_EXTENSION_WEBSITE 8426
#define IDS_EXTENSIONS_ITEM_CHROME_WEB_STORE 8427
#define IDS_EXTENSIONS_VIEW_IN_DEVTOOLS 8428
#define IDS_EXTENSIONS_ITEM_OPTIONS 8429
#define IDS_EXTENSIONS_ITEM_PERMISSIONS 8430
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_EMPTY 8431
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_AND_SITE_ACCESS_EMPTY 8432
#define IDS_EXTENSIONS_ITEM_PIN_TO_TOOLBAR 8433
#define IDS_EXTENSIONS_ITEM_REMOVE_EXTENSION 8434
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS 8435
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_ADD_HOST 8436
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_EMPTY 8437
#define IDS_EXTENSIONS_REMOVE_SITES_DIALOG_TITLE 8438
#define IDS_EXTENSIONS_ITEM_SOURCE 8439
#define IDS_EXTENSIONS_ITEM_SOURCE_INSTALLED_BY_DEFAULT 8440
#define IDS_EXTENSIONS_ITEM_SOURCE_POLICY 8441
#define IDS_EXTENSIONS_ITEM_SOURCE_SIDELOADED 8442
#define IDS_EXTENSIONS_ITEM_SOURCE_UNPACKED 8443
#define IDS_EXTENSIONS_ITEM_SOURCE_WEBSTORE 8444
#define IDS_EXTENSIONS_ITEM_VERSION 8445
#define IDS_EXTENSIONS_ITEM_RELOADED 8446
#define IDS_EXTENSIONS_ITEM_RELOADING 8447
#define IDS_EXTENSIONS_LOAD_ERROR_HEADING 8448
#define IDS_EXTENSIONS_LOAD_ERROR_ERROR_LABEL 8449
#define IDS_EXTENSIONS_LOAD_ERROR_FILE_LABEL 8450
#define IDS_EXTENSIONS_LOAD_ERROR_COULD_NOT_LOAD_MANIFEST 8451
#define IDS_EXTENSIONS_LOAD_ERROR_RETRY 8452
#define IDS_EXTENSIONS_LOADING_ACTIVITIES 8453
#define IDS_MISSING_OR_UNINSTALLED_EXTENSION 8454
#define IDS_EXTENSIONS_NO_ACTIVITIES 8455
#define IDS_EXTENSIONS_NO_INSTALLED_ITEMS 8456
#define IDS_EXTENSIONS_NO_DESCRIPTION 8457
#define IDS_EXTENSIONS_OPENS_IN_NEW_TAB 8458
#define IDS_EXTENSIONS_PACK_DIALOG_TITLE 8459
#define IDS_EXTENSIONS_PACK_DIALOG_WARNING_TITLE 8460
#define IDS_EXTENSIONS_PACK_DIALOG_ERROR_TITLE 8461
#define IDS_EXTENSIONS_PACK_DIALOG_PROCEED_ANYWAY 8462
#define IDS_EXTENSIONS_PACK_DIALOG_BROWSE_BUTTON 8463
#define IDS_EXTENSIONS_PACK_DIALOG_EXTENSION_ROOT_LABEL 8464
#define IDS_EXTENSIONS_PACK_DIALOG_KEY_FILE_LABEL 8465
#define IDS_EXTENSIONS_PACK_DIALOG_CONFIRM_BUTTON 8466
#define IDS_EXTENSIONS_TOOLBAR_TITLE 8467
#define IDS_EXTENSIONS_SEARCH 8468
#define IDS_EXTENSIONS_SITE_PERMISSIONS 8469
#define IDS_EXTENSIONS_SITE_PERMISSIONS_PAGE_TITLE 8470
#define IDS_EXTENSIONS_SITE_PERMISSIONS_VIEW_ALL_SITES 8471
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_PAGE_TITLE 8472
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_ONE_EXTENSION 8473
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_EXTENSION_COUNT 8474
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_ALL_SITES 8475
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_THIS_SITE 8476
#define IDS_EXTENSIONS_SITE_SETTINGS 8477
#define IDS_EXTENSIONS_PERMITTED_SITES 8478
#define IDS_EXTENSIONS_RESTRICTED_SITES 8479
#define IDS_EXTENSIONS_NO_SITES_ADDED 8480
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ADD_SITE_DIALOG_TITLE 8481
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_SITE_DIALOG_TITLE 8482
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_URL 8483
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS_DIALOG_TITLE 8484
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS 8485
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ASK_ON_EVERY_VISIT 8486
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_ERROR 8487
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_LABEL 8488
#define IDS_EXTENSIONS_SITE_PERMISSIONS_INCLUDES_SUBDOMAINS 8489
#define IDS_EXTENSIONS_EDIT_SHORTCUT_INPUT_LABEL 8490
#define IDS_EXTENSIONS_EDIT_SHORTCUT_BUTTON_LABEL 8491
#define IDS_EXTENSIONS_SET_SHORTCUT_IN_SYSTEM_SETTINGS 8492
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_LABEL 8493
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_GLOBAL 8494
#define IDS_EXTENSIONS_APPS_TITLE 8495
#define IDS_EXTENSIONS_REMOVE 8496
#define IDS_EXTENSIONS_MORE_OPTIONS 8497
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_TITLE 8498
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_ERROR 8499
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_LABEL 8500
#define IDS_EXTENSIONS_SIDEBAR_EXTENSIONS 8501
#define IDS_EXTENSIONS_SIDEBAR_DISCOVER_MORE 8502
#define IDS_EXTENSIONS_WHATS_NEW_SIDEBAR_PROMO 8503
#define IDS_EXTENSIONS_SIDEBAR_KEYBOARD_SHORTCUTS 8504
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED 8505
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED_DONE 8506
#define IDS_EXTENSIONS_TOOLBAR_PACK 8507
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW 8508
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW_TOOLTIP 8509
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_DONE 8510
#define IDS_EXTENSIONS_TOOLBAR_UPDATING_TOAST 8511
#define IDS_EXTENSIONS_SUBPAGE_BUTTON 8512
#define IDS_EXTENSIONS_SECTION_HEADER 8513
#define IDS_EXTENSIONS_SAFETY_HUB_HEADER 8514
#define IDS_EXTENSIONS_SC_MALWARE 8515
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_OFF 8516
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_ON 8517
#define IDS_EXTENSIONS_SC_UNPUBLISHED_OFF 8518
#define IDS_EXTENSIONS_SC_UNPUBLISHED_ON 8519
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_ON 8520
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_OFF 8521
#define IDS_EXTENSIONS_SC_TITLE 8522
#define IDS_EXTENSIONS_SC_KEEP_EXT 8523
#define IDS_EXTENSIONS_SC_THREEDOT_DETAILS 8524
#define IDS_EXTENSIONS_SC_REMOVE_ALL 8525
#define IDS_EXTENSIONS_SC_ALL_DONE_FOR_NOW 8526
#define IDS_EXTENSIONS_SC_REMOVE_BUTTON_A11Y_LABEL 8527
#define IDS_EXTENSIONS_SC_OPTION_MENU_A11Y_LABEL 8528
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_TITLE 8529
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_HEADER 8530
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_SUBTITLE 8531
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_HEADER 8532
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_HEADER 8533
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_SUBTITLE 8534
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_HEADER 8535
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_REMOVE_BUTTON 8536
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISMISS_BUTTON 8537
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON 8538
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_ACTION_MENU_BUTTON_LABEL 8539
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON_ACC_LABEL 8540
#define IDS_EXTENSIONS_MV2_DEPRECATION_UNSUPPORTED_EXTENSION_OFF_TEXT 8541
#define IDS_EXTENSIONS_CANT_INSTALL_MV2_EXTENSION 8542
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER 8554
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER_V2 8555
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_IPH_DESCRIPTION 8556
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_LINK_LABEL 8557
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_DESCRIPTION 8558
#define IDS_EXTENSIONS_ZERO_STATE_PLAIN_LINK_IPH_DESCRIPTION 8559
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LABEL 8560
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LABEL 8561
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LABEL 8562
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LABEL 8563
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TITLE 8564
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LINK 8565
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LINK 8566
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LINK 8567
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LINK 8568
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WEB_STORE_LINK 8569
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TEXT 8570
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_SUBTITLE 8571
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_TITLE 8572
#define IDS_NEARBY_CONFIRMATION_PAGE_TITLE 8573
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_TITLE 8574
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_SUBTITLE_ON_DISABLED 8575
#define IDS_QUICK_SHARE_V2_VISIBILITY_YOUR_DEVICES_SUBLABEL 8576
#define IDS_QUICK_SHARE_V2_VISIBILITY_CONTACTS_SUBLABEL 8577
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_LABEL 8578
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_SUBLABEL 8579
#define IDS_QUICK_SHARE_V2_VISIBILITY_ONLY_FOR_TEN_MINUTES_LABEL 8580
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOAD_FAILED 8581
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOADING 8582
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE 8583
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE_PH 8584
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_TITLE 8585
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE 8586
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE_PH 8587
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL 8588
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL_SELF_SHARE 8589
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_NONE 8590
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME 8591
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME_SELF_SHARE 8592
#define IDS_NEARBY_CONTACT_VISIBILITY_ZERO_STATE_TEXT 8593
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_YOUR_DEVICES 8594
#define IDS_NEARBY_DEVICE_NAME_EMPTY_ERROR 8595
#define IDS_NEARBY_DEVICE_NAME_TOO_LONG_ERROR 8596
#define IDS_NEARBY_DEVICE_NAME_INVALID_CHARACTERS_ERROR 8597
#define IDS_NEARBY_DISCOVERY_PAGE_INFO 8598
#define IDS_NEARBY_DISCOVERY_PAGE_SUBTITLE 8599
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE 8600
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE_PH 8601
#define IDS_NEARBY_DISCOVERY_PAGE_PLACEHOLDER 8602
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME 8603
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME_HELP 8604
#define IDS_NEARBY_ONBOARDING_PAGE_SUBTITLE 8605
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE 8606
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE_PH 8607
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY 8608
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY_HELP_ALL_CONTACTS 8609
#define IDS_NEARBY_VISIBILITY_PAGE_MANAGE_CONTACTS 8610
#define IDS_NEARBY_VISIBILITY_PAGE_SUBTITLE 8611
#define IDS_NEARBY_VISIBILITY_PAGE_TITLE 8612
#define IDS_NEARBY_SHARE_FEATURE_NAME 8613
#define IDS_NEARBY_SHARE_FEATURE_NAME_PH 8614
#define IDS_NEARBY_ACTIONS_ACCEPT 8615
#define IDS_NEARBY_ACTIONS_CANCEL 8616
#define IDS_NEARBY_ACTIONS_CLOSE 8617
#define IDS_NEARBY_ACTIONS_CONFIRM 8618
#define IDS_NEARBY_ACTIONS_DECLINE 8619
#define IDS_NEARBY_ACTIONS_NEXT 8620
#define IDS_NEARBY_ACTIONS_REJECT 8621
#define IDS_NEARBY_DEFAULT_DEVICE_NAME 8622
#define IDS_NEARBY_ERROR_CANCELLED 8623
#define IDS_NEARBY_ERROR_CANT_RECEIVE 8624
#define IDS_NEARBY_ERROR_CANT_SHARE 8625
#define IDS_NEARBY_ERROR_NO_RESPONSE 8626
#define IDS_NEARBY_ERROR_TRANSFER_IN_PROGRESS 8627
#define IDS_NEARBY_ERROR_NOT_ENOUGH_SPACE 8628
#define IDS_NEARBY_ERROR_REJECTED 8629
#define IDS_NEARBY_ERROR_SOMETHING_WRONG 8630
#define IDS_NEARBY_ERROR_TIME_OUT 8631
#define IDS_NEARBY_ERROR_TRY_AGAIN 8632
#define IDS_NEARBY_ERROR_UNSUPPORTED_FILE_TYPE 8633
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_APPS 8634
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_APPS 8635
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_IMAGES 8636
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_IMAGES 8637
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_UNKNOWN 8638
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 8639
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_VIDEOS 8640
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_VIDEOS 8641
#define IDS_NEARBY_SECURE_CONNECTION_ID 8642
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_ADDRESSES 8643
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_ADDRESSES 8644
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_LINKS 8645
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_LINKS 8646
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_PHONE_NUMBERS 8647
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_PHONE_NUMBERS 8648
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_UNKNOWN 8649
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 8650
#define IDS_NEARBY_CAPITALIZED_UNKNOWN_ATTACHMENTS 8651
#define IDS_NEARBY_NOT_CAPITALIZED_UNKNOWN_ATTACHMENTS 8652
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE 8653
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_MINUTES 8654
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_SECONDS 8655
#define IDS_NEARBY_HIGH_VISIBILITY_HELP_TEXT 8656
#define IDS_NEARBY_HIGH_VISIBILITY_TIMEOUT_TEXT 8657
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_ERROR 8658
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_DESCRIPTION 8659
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_ERROR 8660
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION 8661
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION_PH 8662
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_TITLE 8663
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_CONNECTION_ID 8664
#define IDS_NEARBY_PREVIEW_TITLE_MULTIPLE_FILE 8665
#define IDS_NEARBY_ACCOUNT_ROW_LABEL 8666
#define IDS_NEARBY_ACCOUNT_ROW_LABEL_PH 8667
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP 8668
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP_PH 8669
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_BOTTOM 8670
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS 8671
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS_DESCRIPTION 8672
#define IDS_NEARBY_VISIBILITY_CONTACTS_BUTTON 8673
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS 8674
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS_DESCRIPTION 8675
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES 8676
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES_DESCRIPTION 8677
#define IDS_NEARBY_VISIBILITY_ALL_CONTACTS_TOGGLE 8678
#define IDS_NEARBY_VISIBLITY_HIDDEN 8679
#define IDS_NEARBY_VISIBLITY_HIDDEN_DESCRIPTION 8680
#define IDS_NEARBY_VISIBLITY_UNKNOWN 8681
#define IDS_NEARBY_VISIBLITY_UNKNOWN_DESCRIPTION 8682
#define IDS_NEARBY_NOTIFICATION_ACTION_COPY_TO_CLIPBOARD 8683
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_FOLDER 8684
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_NETWORK_LIST 8685
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_URL 8686
#define IDS_NEARBY_NOTIFICATION_ACCEPT_ACTION 8687
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE 8688
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE_WIFI_CREDENTIALS 8689
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE 8690
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE_PH 8691
#define IDS_NEARBY_NOTIFICATION_DECLINE_ACTION 8692
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE 8693
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE_PH 8694
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_MESSAGE 8695
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_TITLE 8696
#define IDS_NEARBY_NOTIFICATION_SET_UP_ACTION 8697
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_ACTION 8698
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_TITLE 8699
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_MESSAGE 8700
#define IDS_NEARBY_NOTIFICATION_GO_TO_SETTINGS_ACTION 8701
#define IDS_NEARBY_NOTIFICATION_DISMISS_ACTION 8702
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE 8703
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE_WIFI_CREDENTIALS 8704
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE 8705
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE_WIFI_CREDENTIALS 8706
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE 8707
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE_WIFI_CREDENTIALS 8708
#define IDS_NEARBY_NOTIFICATION_SEND_FAILURE_TITLE 8709
#define IDS_NEARBY_NOTIFICATION_SEND_PROGRESS_TITLE 8710
#define IDS_NEARBY_NOTIFICATION_SEND_SUCCESS_TITLE 8711
#define IDS_NEARBY_NOTIFICATION_SOURCE 8712
#define IDS_NEARBY_NOTIFICATION_SOURCE_PH 8713
#define IDS_NEARBY_NOTIFICATION_SENDER_CANCELLED 8714
#define IDS_WHATS_NEW_TITLE 8715
#define IDS_PASSWORD_MANAGER_UI_TITLE 8716
#define IDS_PASSWORD_MANAGER_UI_DESCRIPTION 8717
#define IDS_PASSWORD_MANAGER_UI_SEARCH_PROMPT 8718
#define IDS_PASSWORD_MANAGER_UI_CHECKUP 8719
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS 8720
#define IDS_PASSWORD_MANAGER_UI_SETTINGS 8721
#define IDS_PASSWORD_MANAGER_UI_SAVE_PASSWORDS_TOGGLE_LABEL 8722
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_LABEL 8723
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_DESC 8724
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS_DESCRIPTION 8725
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_BUTTON 8726
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_TITLE 8727
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_DESCRIPTION 8728
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_TITLE 8729
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_DESCRIPTION 8730
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_TITLE 8731
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_DESCRIPTION 8732
#define IDS_PASSWORD_MANAGER_UI_SHARE 8733
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_DESCRIPTION 8734
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_TITLE 8735
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_LOADING_TITLE 8736
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_SUCCESS_TITLE 8737
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CANCELED_TITLE 8738
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_FAMILY_MEMBER 8739
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NO_OTHER_FAMILY_MEMBERS 8740
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_FAMILY_PICKER_DESCRIPTION 8741
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_SINGLE 8742
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_MULTIPLE 8743
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_WEBSITE 8744
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_ANDROID_APP 8745
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_VIEW_FAMILY 8746
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_MEMBER_UNAVAILABLE 8747
#define IDS_PASSWORD_MANAGER_UI_SHARING_IS_MANAGED_BY_ADMIN 8748
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_AVAILABLE 8749
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_TRY_AGAIN 8750
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_GOT_IT 8751
#define IDS_PASSWORD_MANAGER_UI_SHARE_DIALOG_TITLE 8752
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BANNER_TITLE 8753
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_ACCOUNT_STORE_USERS 8754
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SYNCING_USERS 8755
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SIGNEDOUT_USERS 8756
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_DEVICE 8757
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_ACCOUNT 8758
#define IDS_PASSWORD_MANAGER_UI_IMPORT_STORE_PICKER_ACCESSIBLE_NAME 8759
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SELECT_FILE_DESCRIPTION 8760
#define IDS_PASSWORD_MANAGER_UI_SELECT_FILE 8761
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_PASSWORD 8762
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_URL 8763
#define IDS_PASSWORD_MANAGER_UI_IMPORT_INVALID_URL 8764
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_URL 8765
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_USERNAME 8766
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_PASSWORD 8767
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_NOTE 8768
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_ACCOUNT 8769
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_DEVICE 8770
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_UNKNOWN 8771
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_BAD_FORMAT 8772
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FILE_SIZE_EXCEEDED 8773
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_LIMIT_EXCEEDED 8774
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_TITLE 8775
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TITLE 8776
#define IDS_PASSWORD_MANAGER_UI_IMPORT_COMPLETE_TITLE 8777
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DELETE_FILE_OPTION 8778
#define IDS_PASSWORD_MANAGER_UI_IMPORT_VIEW_PASSWORDS 8779
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ALREADY_ACTIVE 8780
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TIP 8781
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FAILURES_SUMMARY 8782
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BAD_ROWS_FORMAT 8783
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_ACCOUNT 8784
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_DEVICE 8785
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_TITLE 8786
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_DESCRIPTION 8787
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CANCEL 8788
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SKIP 8789
#define IDS_PASSWORD_MANAGER_UI_IMPORT_REPLACE 8790
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TITLE 8791
#define IDS_PASSWORD_MANAGER_UI_DOWNLOAD_FILE 8792
#define IDS_PASSWORD_MANAGER_UI_EXPORT_BANNER_DESCRIPTION 8793
#define IDS_PASSWORD_MANAGER_UI_EXPORT_SUCCESSFUL 8794
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TRY_AGAIN 8795
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TITLE 8796
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIPS 8797
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ENOUGH_SPACE 8798
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ANOTHER_FOLDER 8799
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_TITLE 8800
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RESULT 8801
#define IDS_PASSWORD_MANAGER_UI_JUST_NOW 8802
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_COUNT 8803
#define IDS_PASSWORD_MANAGER_UI_NO_COMPROMISED_PASSWORDS 8804
#define IDS_PASSWORD_MANAGER_UI_HAS_COMPROMISED_PASSWORDS 8805
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_COUNT 8806
#define IDS_PASSWORD_MANAGER_UI_NO_REUSED_PASSWORDS 8807
#define IDS_PASSWORD_MANAGER_UI_HAS_REUSED_PASSWORDS 8808
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_COUNT 8809
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_GREEN_STATE_A11Y 8810
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_YELLOW_STATE_A11Y 8811
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RED_STATE_A11Y 8812
#define IDS_PASSWORD_MANAGER_UI_NO_WEAK_PASSWORDS 8813
#define IDS_PASSWORD_MANAGER_UI_HAS_WEAK_PASSWORDS 8814
#define IDS_PASSWORD_MANAGER_UI_CHECK_PASSWORDS_AFTER_ERROR 8815
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_TITLE 8816
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_DESCRIPTION 8817
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_TITLE 8818
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_DESCRIPTION 8819
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_TITLE 8820
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_DESCRIPTION 8821
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_CONFIRMATION 8822
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_ACCOUNTS 8823
#define IDS_PASSWORD_MANAGER_UI_USERNAME_LABEL 8824
#define IDS_PASSWORD_MANAGER_UI_SITES_LABEL 8825
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LABEL 8826
#define IDS_PASSWORD_MANAGER_UI_NOTE_LABEL 8827
#define IDS_PASSWORD_MANAGER_UI_NO_NOTE_ADDED 8828
#define IDS_PASSWORD_MANAGER_UI_COPY_PASSWORD 8829
#define IDS_PASSWORD_MANAGER_UI_COPY_USERNAME 8830
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD 8831
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD 8832
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD_A11Y 8833
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD_A11Y 8834
#define IDS_PASSWORD_MANAGER_UI_FEDERATION_LABEL 8835
#define IDS_PASSWORD_MANAGER_UI_USERNAME_COPIED_TO_CLIPBOARD 8836
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_COPIED_TO_CLIPBOARD 8837
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD 8838
#define IDS_PASSWORD_MANAGER_UI_WEBSITE_LABEL 8839
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_FOOTNOTE 8840
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LEAKED 8841
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED 8842
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED_AND_LEAKED 8843
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON 8844
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON_ARIA_DESCRIPTION 8845
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS 8846
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS_ARIA_DESCRIPTION 8847
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_DESCRIPTION 8848
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_DESCRIPTION 8849
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_DESCRIPTION 8850
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_SIGNED_OUT 8851
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OFFLINE 8852
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_COMPROMISED_SECTION 8853
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_NO_PASSWORDS 8854
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_QUOTA_LIMIT 8855
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OTHER_ERROR 8856
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RUNNING_LABEL 8857
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROGRESS 8858
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_CANCELED 8859
#define IDS_PASSWORD_MANAGER_UI_MUTED_COMPROMISED_PASSWORDS 8860
#define IDS_PASSWORD_MANAGER_UI_MUTE_ISSUE 8861
#define IDS_PASSWORD_MANAGER_UI_UNMUTE_ISSUE 8862
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_CREDENTIALS_WITH_REUSED_PASSWORD 8863
#define IDS_PASSWORD_MANAGER_UI_HELP 8864
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSWORD 8871
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_EDIT_FOOTNOTE 8872
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DELETED 8873
#define IDS_PASSWORD_MANAGER_UI_UNDO 8874
#define IDS_PASSWORD_MANAGER_UI_SEARCH_RESULT 8875
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_IN_APP 8876
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_MANAGER_PIN 8877
#define IDS_PASSWORD_MANAGER_UI_ALREADY_CHANGED_PASSWORD 8878
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_DESCRIPTION 8879
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_TITLE 8880
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_TITLE 8881
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_DESCRIPTION 8882
#define IDS_PASSWORD_MANAGER_UI_SHOW_MORE 8883
#define IDS_PASSWORD_MANAGER_UI_NOT_VALID_WEB_ADDRESS 8884
#define IDS_PASSWORD_MANAGER_UI_MISSING_TLD 8885
#define IDS_PASSWORD_MANAGER_UI_USERNAME_ALREADY_USED 8886
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT 8887
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT_WARNING 8888
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT 8889
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT_DESCRIPTION 8890
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD 8891
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD_ARIA_DESCRIPTION 8892
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT 8893
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_DESCRIPTION 8894
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT_DIALOG_DESCRIPTION 8895
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_PASSWORDS_TITLE 8896
#define IDS_PASSWORD_MANAGER_UI_OPENS_IN_NEW_TAB 8897
#define IDS_PASSWORD_MANAGER_UI_VIEW_PASSWORD_ARIA_DESCRIPTION 8898
#define IDS_PASSWORD_MANAGER_UI_RUN_CHECKUP_ARIA_DESCRIPTION 8899
#define IDS_PASSWORD_MANAGER_UI_REMOVE_BLOCKED_SITE_ARIA_DESCRIPTION 8900
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_ACCOUNT_STORE_USERS 8901
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SYNCING_USERS 8902
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SIGNEDOUT_USERS 8903
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_TITLE 8904
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_DESCRIPTION 8905
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_ACTION 8906
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_TITLE 8907
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_DESCRIPTION 8908
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_TITLE 8909
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_DESCRIPTION 8910
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_TITLE 8911
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_DESCRIPTION 8912
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_TOGGLE_SUB_LABEL 8913
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_WITH_PASSKEYS_TOGGLE_LABEL 8914
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_TITLE 8915
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_BODY 8916
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_ACCOUNT_CHECKBOX_LABEL 8917
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_DEVICE_CHECKBOX_LABEL 8918
#define IDS_PASSWORD_MANAGER_UI_APPS_LABEL 8919
#define IDS_PASSWORD_MANAGER_UI_SITES_AND_APPS_LABEL 8920
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_CHECKUP_ARIA_DESCRIPTION 8921
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORDS_ARIA_DESCRIPTION 8922
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORD_SETTINGS_ARIA_DESCRIPTION 8923
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TITLE 8924
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_DESCRIPTION 8925
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_BUTTON 8926
#define IDS_PASSWORD_MANAGER_UI_NO_PASSWORDS_FOUND 8929
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSKEY 8930
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_LABEL 8931
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_PLACEHOLDER 8932
#define IDS_PASSWORD_MANAGER_UI_USERNAME_PLACEHOLDER 8933
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_TITLE 8934
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_DESCRIPTION 8935
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_HIDDEN_INFO_LABEL 8936
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_MANAGEMENT_INFO_LABEL 8937
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_LABEL 8938
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_SUBLABEL 8939
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TITLE 8940
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_DESCRIPTION 8941
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_BUTTON 8942
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TOAST_MESSAGE 8943
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_TITLE 8944
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DESCRIPTION 8945
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DELETE_ALL 8946
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRM 8947
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_SUCCESS_TOAST 8948
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE 8949
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE_LOCAL 8950
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_DESCIPTION 8951
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_ONE 8952
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO 8953
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO_AND_X_MORE 8954
#define IDS_PASSWORD_MANAGER_PASSWORDS_COUNTER 8955
#define IDS_PASSWORD_MANAGER_PASSKEYS_COUNTER 8956
#define IDS_PASSWORD_MANAGER_UI_COPY_DISPLAY_NAME_LABEL 8957
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_COPIED_TO_CLIPBOARD 8958
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DELETED 8959
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ARIA_LABEL 8960
#define IDS_PASSWORD_MANAGER_UI_DEVICE_ONLY_PASSWORDS_ICON_TOOLTIP 8961
#define IDS_PASSWORD_MANAGER_UI_MOVE_TO_ACCOUNT_ICON_TOOLTIP 8962
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_ARIA_LABEL 8963
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_DETAILS_CARD_ARIA_LABEL 8964
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 8965
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 8966
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 8967
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 8968
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_SHARE_BUTTON_ARIA_LABEL 8969
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_SHARE_BUTTON_NO_USERNAME_ARIA_LABEL 8970
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_NO_USERNAME_ARIA_LABEL 8971
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_ARIA_LABEL 8972
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 8973
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 8974
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 8975
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 8976
#define IDS_PASSWORD_MANAGER_UI_FEDERATED_CREDENTIAL_ARIA_LABEL 8977
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT 8978
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TITLE 8979
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_DESCRIPTION 8980
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_ACTION_BUTTON 8981
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_IN_SETTINGS_SUB_LABEL 8982
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_TITLE_LINUX 8985
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_DESCRIPTION_LINUX 8986
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_ACTION 8987
#define IDS_PASSWORD_MANAGER_UI_NO_USERNAME 8988
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_MOVED_TOAST_MESSAGE 8989
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_TITLE 8990
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_DESCRIPTION 8991
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_ACTION_BUTTON 8992
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_TITLE 8993
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_ACTION_BUTTON 8994
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_DESCRIPTION 8995
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_TITLE 8996
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_SAVE_BUTTON 8997
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LIST_ITEM_DEVICE_ONLY_ACCESSIBLE_TEXT 8998
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ITEM_ARIA_LABEL 8999
#define IDS_PASSWORD_MANAGER_UI_PROMO_CARD_ARIA_LABEL 9000
#define IDS_PASSWORD_MANAGER_UI_CLOSE_PROMO_CARD_BUTTON_ARIA_LABEL 9001
#define IDS_PASSWORD_MANAGER_PIN_CHANGED 9002
#define IDS_PASSWORD_MANAGER_UI_CONFIRM 9003
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_TITLE 9004
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_DESCRIPTION 9005
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGED_TITLE 9006
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_TITLE 9007
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_BODY 9008
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_ACCEPT_BUTTON 9009
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_SIGN_IN_CHECK 9010
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_CHANGING_PASSWORD 9011
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_SIGN_IN_TO_CONTINUE 9012
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CHANGE_PASSWORD 9013
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_TITLE 9014
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITHOUT_PRIVACY_NOTICE 9015
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITH_PRIVACY_NOTICE 9016
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITHOUT_PRIVACY_NOTICE 9017
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITH_PRIVACY_NOTICE 9018
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_PRIVACY_NOTICE 9019
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_DESCRIPTION 9020
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CHECKUP_BUTTON 9021
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CHECKUP_BUTTON_ARIA_DESCRIPTION 9022
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_TITLE 9023
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL_WITH_LEARN_MORE 9024
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION 9025
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION_DETAILS 9026
#define IDS_PASSWORD_MANAGER_UI_VIEW_DETAILS_BUTTON 9027
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_TITLE 9028
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_DIALOG_DETAILS 9029
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TAKE_OVER_TASK_BUTTON 9030
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_UNCHANGED 9031
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_RETRY_BUTTON 9032
#define IDS_UTILITY_PROCESS_PRINTING_SERVICE_NAME 9033
#define IDS_UTILITY_PROCESS_PRINT_BACKEND_SERVICE_NAME 9034
#define IDS_PRINT_INVALID_PRINTER_SETTINGS 9035
#define IDS_PRINT_PREVIEW_TITLE 9036
#define IDS_PRINT_PREVIEW_DESCRIPTION 9037
#define IDS_PRINT_PREVIEW_LOADING 9038
#define IDS_PRINT_PREVIEW_FAILED 9039
#define IDS_PRINT_PREVIEW_INVALID_PRINTER_SETTINGS 9040
#define IDS_PRINT_PREVIEW_PRINT_BUTTON 9041
#define IDS_PRINT_PREVIEW_SAVE_BUTTON 9042
#define IDS_PRINT_PREVIEW_PRINTING 9043
#define IDS_PRINT_PREVIEW_SAVING 9044
#define IDS_PRINT_PREVIEW_OPTION_ALL_PAGES 9045
#define IDS_PRINT_PREVIEW_OPTION_ODD_PAGES 9046
#define IDS_PRINT_PREVIEW_OPTION_EVEN_PAGES 9047
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_PAGES 9048
#define IDS_PRINT_PREVIEW_DESTINATION_LABEL 9049
#define IDS_PRINT_PREVIEW_OPTION_BW 9050
#define IDS_PRINT_PREVIEW_OPTION_COLLATE 9051
#define IDS_PRINT_PREVIEW_OPTION_COLOR 9052
#define IDS_PRINT_PREVIEW_OPTION_LANDSCAPE 9053
#define IDS_PRINT_PREVIEW_OPTION_PORTRAIT 9054
#define IDS_PRINT_PREVIEW_OPTION_TWO_SIDED 9055
#define IDS_PRINT_PREVIEW_PRINT_ON_BOTH_SIDES_LABEL 9056
#define IDS_PRINT_PREVIEW_OPTION_LONG_EDGE 9057
#define IDS_PRINT_PREVIEW_OPTION_SHORT_EDGE 9058
#define IDS_PRINT_PREVIEW_PAGES_LABEL 9059
#define IDS_PRINT_PREVIEW_LAYOUT_LABEL 9060
#define IDS_PRINT_PREVIEW_COPIES_LABEL 9061
#define IDS_PRINT_PREVIEW_SCALING_LABEL 9062
#define IDS_PRINT_PREVIEW_OPTION_DEFAULT_SCALING 9063
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_SCALING 9064
#define IDS_PRINT_PREVIEW_PAGES_PER_SHEET_LABEL 9065
#define IDS_PRINT_PREVIEW_EXAMPLE_PAGE_RANGE_TEXT 9066
#define IDS_PRINT_PREVIEW_PRINT_TO_PDF 9067
#define IDS_PRINT_PREVIEW_SHEET_SUMMARY_LABEL 9068
#define IDS_PRINT_PREVIEW_PAGE_SUMMARY_LABEL 9069
#define IDS_PRINT_PREVIEW_PAGE_RANGE_SYNTAX_INSTRUCTION 9070
#define IDS_PRINT_PREVIEW_PAGE_RANGE_LIMIT_INSTRUCTION_WITH_VALUE 9071
#define IDS_PRINT_PREVIEW_COPIES_INSTRUCTION 9072
#define IDS_PRINT_PREVIEW_SCALING_INSTRUCTION 9073
#define IDS_PRINT_PREVIEW_PRINT_PAGES_LABEL 9074
#define IDS_PRINT_PREVIEW_OPTIONS_LABEL 9075
#define IDS_PRINT_PREVIEW_OPTION_HEADER_FOOTER 9076
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAGE 9077
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAPER 9078
#define IDS_PRINT_PREVIEW_OPTION_ACTUAL_SIZE 9079
#define IDS_PRINT_PREVIEW_OPTION_BACKGROUND_COLORS_AND_IMAGES 9080
#define IDS_PRINT_PREVIEW_OPTION_SELECTION_ONLY 9081
#define IDS_PRINT_PREVIEW_OPTION_RASTERIZE 9082
#define IDS_PRINT_PREVIEW_MARGINS_LABEL 9083
#define IDS_PRINT_PREVIEW_DEFAULT_MARGINS 9084
#define IDS_PRINT_PREVIEW_NO_MARGINS 9085
#define IDS_PRINT_PREVIEW_CUSTOM_MARGINS 9086
#define IDS_PRINT_PREVIEW_MINIMUM_MARGINS 9087
#define IDS_PRINT_PREVIEW_TOP_MARGIN_LABEL 9088
#define IDS_PRINT_PREVIEW_BOTTOM_MARGIN_LABEL 9089
#define IDS_PRINT_PREVIEW_LEFT_MARGIN_LABEL 9090
#define IDS_PRINT_PREVIEW_RIGHT_MARGIN_LABEL 9091
#define IDS_PRINT_PREVIEW_MEDIA_SIZE_LABEL 9092
#define IDS_PRINT_PREVIEW_DPI_LABEL 9093
#define IDS_PRINT_PREVIEW_NON_ISOTROPIC_DPI_ITEM_LABEL 9094
#define IDS_PRINT_PREVIEW_DPI_ITEM_LABEL 9095
#define IDS_PRINT_PREVIEW_DESTINATION_SEARCH_TITLE 9096
#define IDS_PRINT_PREVIEW_SEARCH_BOX_PLACEHOLDER 9097
#define IDS_PRINT_PREVIEW_NO_DESTINATIONS_MESSAGE 9098
#define IDS_PRINT_PREVIEW_PRINT_DESTINATIONS_TITLE 9099
#define IDS_PRINT_PREVIEW_MANAGE 9100
#define IDS_PRINT_PREVIEW_SEE_MORE 9101
#define IDS_PRINT_PREVIEW_SEE_MORE_DESTINATIONS_LABEL 9102
#define IDS_PRINT_PREVIEW_EXTENSION_DESTINATION_ICON_TOOLTIP 9103
#define IDS_MORE_OPTIONS_LABEL 9104
#define IDS_PRINT_PREVIEW_COULD_NOT_PRINT 9105
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_SEARCH_BOX_PLACEHOLDER 9106
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_TITLE 9107
#define IDS_PRINT_PREVIEW_NO_ADVANCED_SETTINGS_MATCH_SEARCH_HINT 9108
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_CONFIRM 9109
#define IDS_PRINT_PREVIEW_NEW_SHOW_ADVANCED_OPTIONS 9110
#define IDS_PRINT_PREVIEW_BUTTON_SELECT 9111
#define IDS_PRINT_PREVIEW_BUTTON_GO_BACK 9112
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_DIALOG_TITLE 9113
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_PERMISSION_MESSAGE 9114
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_ERROR_MESSAGE 9115
#define IDS_PRINT_PREVIEW_MANAGED_SETTINGS_TEXT 9116
#define IDS_PRINT_PREVIEW_SYSTEM_DIALOG_OPTION 9147
#define IDS_DEFAULT_PRINT_DOCUMENT_TITLE 9150
#define IDS_PRINT_SPOOL_FAILED_TITLE_TEXT 9151
#define IDS_PRINT_SPOOL_FAILED_ERROR_TEXT 9152
#define IDS_SKILL_SAVED_TOAST_BODY 9153
#define IDS_SKILL_DELETED_TOAST_BODY 9154
#define IDS_SKILL_UNDO_TOAST_BUTTON 9155
#define IDS_SKILL_CARD_ACTION_MENU_LABEL 9156
#define IDS_ADD_NEW_SKILL_LABEL 9157
#define IDS_SKILL_PAGE_TITLE 9158
#define IDS_SKILL_PAGE_SEARCH_BAR_PLACEHOLDER_TEXT 9159
#define IDS_SKILL_PAGE_MAIN_MENU 9160
#define IDS_SKILLS_SIDEBAR_FOOTER_TEXT 9161
#define IDS_SKILLS_SIDEBAR_FOOTER_BRANDING 9162
#define IDS_SKILLS_ERROR_PAGE_TITLE 9163
#define IDS_SKILLS_ERROR_PAGE_DESCRIPTION 9164
#define IDS_SKILLS_DISABLED_ERROR_PAGE_DESCRIPTION 9165
#define IDS_SKILLS_REMOTE_AUTHORITY_UNREACHABLE_DESCRIPTION 9166
#define IDS_SKILLS_GO_TO_SETTINGS 9167
#define IDS_SKILLS_NO_SEARCH_RESULT_TITLE 9168
#define IDS_SKILLS_NO_SEARCH_RESULT_DESCRIPTION 9169
#define IDS_SKILL_PAGE_BROWSE_SKILLS_TITLE 9170
#define IDS_SKILL_PAGE_FIRST_PARTY_ADD_SKILL_ERROR_TOAST 9171
#define IDS_SKILLS_PAGE_ALL_CATEGORY 9172
#define IDS_SKILLS_CURATED_PREFIX 9173
#define IDS_SKILL_PAGE_EMPTY_STATE_TITLE 9174
#define IDS_SKILL_PAGE_EMPTY_STATE_DESCRIPTION 9175
#define IDS_SKILL_PAGE_USER_SKILLS_TITLE 9176
#define IDS_SKILL_PAGE_USER_SKILLS_DESCRIPTION 9177
#define IDS_SKILL_PAGE_USER_SKILLS_DELETE 9178
#define IDS_SKILL_PAGE_USER_SKILLS_COPY_INSTRUCTIONS 9179
#define IDS_SKILL_PAGE_INVALID_SKILL_TOAST 9180
#define IDS_SKILLS_DIALOG_ADD_SKILL_HEADER 9181
#define IDS_SKILLS_DIALOG_EDIT_SKILL_HEADER 9182
#define IDS_SKILLS_DIALOG_DESCRIPTION 9183
#define IDS_SKILLS_DIALOG_NAME_LABEL 9184
#define IDS_SKILLS_DIALOG_NAME_PLACEHOLDER 9185
#define IDS_SKILLS_DIALOG_CHOOSE_ICON_TOOLTIP 9186
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_LABEL 9187
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_PLACEHOLDER 9188
#define IDS_SKILLS_DIALOG_UNDO_TOOLTIP 9189
#define IDS_SKILLS_DIALOG_REDO_TOOLTIP 9190
#define IDS_SKILLS_DIALOG_REFINE_TOOLTIP 9191
#define IDS_SKILLS_DIALOG_REFINE_ERROR 9192
#define IDS_SKILLS_DIALOG_CHAR_LIMIT_ERROR 9193
#define IDS_SKILLS_DIALOG_ACCOUNT_INFO 9194
#define IDS_SKILLS_DIALOG_SAVE_ERROR 9195
#define IDS_SKILLS_EMOJI_PICKER_SEARCH_PLACEHOLDER 9196
#define IDS_SKILLS_EMOJI_PICKER_ARIA_LABEL 9197
#define IDS_VR_SHELL_SITE_IS_TRACKING_LOCATION 9198
#define IDS_VR_SHELL_SITE_IS_USING_MICROPHONE 9199
#define IDS_VR_SHELL_SITE_IS_USING_CAMERA 9200
#define IDS_VR_SHELL_SITE_IS_SHARING_SCREEN 9201
#define IDS_VR_SHELL_BG_IS_USING_MICROPHONE 9202
#define IDS_VR_SHELL_BG_IS_USING_CAMERA 9203
#define IDS_VR_SHELL_BG_IS_SHARING_SCREEN 9204
#define IDS_VR_SHELL_SITE_CAN_TRACK_LOCATION 9205
#define IDS_VR_SHELL_SITE_CAN_USE_MICROPHONE 9206
#define IDS_VR_SHELL_SITE_CAN_USE_CAMERA 9207
#define IDS_VR_SHELL_SITE_CAN_SHARE_SCREEN 9208
#define IDS_VR_SHELL_SITE_IS_USING_BLUETOOTH 9209
#define IDS_VR_SHELL_SITE_CAN_USE_BLUETOOTH 9211
#define IDS_DESKTOP_PROMPT_DOFF_HEADSET 9212
#define IDS_VR_DESKTOP_GENERIC_PERMISSION_PROMPT 9213
#define IDS_VR_SHELL_SITE_IS_USING_USB 9214
#define IDS_VR_SHELL_SITE_IS_USING_MIDI 9215
#define IDS_VR_SHELL_SITE_CAN_USE_MIDI 9216
#define IDS_VR_WEB_VR_TIMEOUT_MESSAGE 9217
#define IDS_WILDCARD 9218
#define IDS_BACKGROUND_CRASHED_APP_BALLOON_MESSAGE 9229
#define IDS_BACKGROUND_CRASHED_EXTENSION_BALLOON_MESSAGE 9230
#define IDS_BACKGROUND_APP_NOT_INSTALLED 9231
#define IDS_PERMISSIONS_REQUESTED_SCREENREADER_ANNOUNCEMENT 9232
#define IDS_PERMISSIONS_EXPIRED_SCREENREADER_ANNOUNCEMENT 9233
#define IDS_PERMISSIONS_BUBBLE_PROMPT 9234
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_ONE_PERM 9235
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS 9236
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS_MORE 9237
#define IDS_PERMISSIONS_BUBBLE_PROMPT_THIS_FILE 9238
#define IDS_PERMISSION_CUSTOMIZE 9239
#define IDS_ALTERNATE_NAV_URL_VIEW_LABEL 9240
#define IDS_DOWNLOAD_HISTORY_TITLE 9241
#define IDS_TAB_LOADING_TITLE 9242
#define IDS_HOVER_CARD_FILE_URL_SOURCE 9243
#define IDS_HOVER_CARD_BLOB_URL_SOURCE 9244
#define IDS_HOVER_CARD_VIEW_SOURCE_URL_SOURCE 9245
#define IDS_HOVER_CARD_CRASHED_TITLE 9246
#define IDS_HISTORY_SEARCH_PROMPT 9247
#define IDS_HISTORY_DELETE 9248
#define IDS_HISTORY_OPEN 9249
#define IDS_HISTORY_ITEMS_SELECTED 9250
#define IDS_HISTORY_ITEMS_UNSELECTED 9251
#define IDS_HISTORY_HISTORY_MENU_DESCRIPTION 9252
#define IDS_HISTORY_NO_SYNCED_RESULTS 9253
#define IDS_HISTORY_OPEN_TABS_MENU_ITEM 9254
#define IDS_HISTORY_TURN_ON_SYNC_BUTTON 9255
#define IDS_HISTORY_TURN_ON_SYNC_PROMO 9256
#define IDS_HISTORY_TURN_ON_SYNC_PROMO_DESC 9257
#define IDS_HISTORY_SIGNIN_ON_PHONE_PROMO_TITLE 9258
#define IDS_HISTORY_SIGNIN_ON_PHONE_PROMO_SUBTITLE 9259
#define IDS_HISTORY_SIGNIN_ON_PHONE_PROMO_BUTTON 9260
#define IDS_HISTORY_SYNC_HISTORY_PROMO 9261
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_OUT 9262
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN 9263
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN_SYNC_HISTORY_ON 9264
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_IN_SYNC_OFF 9265
#define IDS_HISTORY_SYNC_HISTORY_BUTTON 9266
#define IDS_EDIT 9267
#define IDS_CLEAR_SEARCH 9268
#define IDS_CONFIRM 9269
#define IDS_DISABLE 9270
#define IDS_SEARCH_CLEARED 9271
#define IDS_SEARCH_RESULTS 9272
#define IDS_SEARCH_RESULTS_SINGULAR 9273
#define IDS_SEARCH_RESULTS_PLURAL 9274
#define IDS_SEARCH_RESULT_BUBBLE_TEXT 9275
#define IDS_SEARCH_RESULTS_BUBBLE_TEXT 9276
#define IDS_SEARCH_NO_RESULTS 9277
#define IDS_SHOW_BUBBLE_INACTIVE_DESCRIPTION 9278
#define IDS_FOCUS_HELP_BUBBLE_DESCRIPTION 9279
#define IDS_FOCUS_HELP_BUBBLE_TOGGLE_DESCRIPTION 9280
#define IDS_FOCUS_HELP_BUBBLE_TUTORIAL_DESCRIPTION 9281
#define IDS_INSPECT_ELEMENT_ANDROID 9282
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT 9283
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_GEMINI 9284
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_DEVTOOLS 9285
#define IDS_CONTENT_CONTEXT_SAVE_TO_MEMORY_BANKS 9286
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_DIALOG_TITLE 9287
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_ENABLE 9288
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_DISABLE 9289
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_ENABLE 9290
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_DISABLE 9291
#define IDS_CONTENT_CONTEXT_BACK 9292
#define IDS_CONTENT_CONTEXT_FORWARD 9293
#define IDS_CONTENT_CONTEXT_SAVEPAGEAS 9294
#define IDS_CONTENT_CONTEXT_PRINT 9295
#define IDS_CONTENT_CONTEXT_PRINT_SELECTION 9296
#define IDS_CONTENT_CONTEXT_VIEWPAGESOURCE 9297
#define IDS_CONTENT_CONTEXT_OPENLINKWITH 9298
#define IDS_CONTENT_CONTEXT_OPENLINKWITH_CONFIGURE 9299
#define IDS_CONTENT_CONTEXT_INSPECTBACKGROUNDPAGE 9300
#define IDS_CONTENT_CONTEXT_READING_MODE 9301
#define IDS_CONTENT_CONTEXT_READING_MODE_SELECTION 9302
#define IDS_CONTENT_CONTEXT_LISTEN_TO_THIS_PAGE 9303
#define IDS_CONTENT_CONTEXT_CLOSE_GLIC 9304
#define IDS_CONTENT_CONTEXT_ARCHIVE_GLIC 9305
#define IDS_CONTENT_CONTEXT_RELOAD 9306
#define IDS_CONTENT_CONTEXT_RESTART_APP 9307
#define IDS_CONTENT_CONTEXT_RELOAD_PACKAGED_APP 9308
#define IDS_CONTENT_CONTEXT_TRANSLATE 9309
#define IDS_CONTENT_CONTEXT_EXIT_FULLSCREEN 9310
#define IDS_CONTENT_CONTEXT_RELOADFRAME 9311
#define IDS_CONTENT_CONTEXT_VIEWFRAMESOURCE 9312
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB 9313
#define IDS_CONTENT_CONTEXT_OPENLINKNEWWINDOW 9314
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD 9315
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD_V2 9316
#define IDS_CONTENT_CONTEXT_OPENLINKSPLITVIEW 9317
#define IDS_CONTENT_CONTEXT_OPENLINKLEFTVIEW 9318
#define IDS_CONTENT_CONTEXT_OPENLINKRIGHTVIEW 9319
#define IDS_CONTENT_CONTEXT_OPENLINKTOPVIEW 9320
#define IDS_CONTENT_CONTEXT_OPENLINKBOTTOMVIEW 9321
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILES 9322
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILES_V2 9323
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILE 9324
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP 9325
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP_SAMEAPP 9326
#define IDS_CONTENT_CONTEXT_OPENLINKWEBAPP_NEWTAB 9327
#define IDS_CONTENT_CONTEXT_SAVELINKAS 9328
#define IDS_CONTENT_CONTEXT_COPYLINKLOCATION 9329
#define IDS_CONTENT_CONTEXT_COPYEMAILADDRESS 9330
#define IDS_CONTENT_CONTEXT_COPYLINKTEXT 9331
#define IDS_CONTENT_CONTEXT_COPYLINKTOTEXT 9332
#define IDS_CONTENT_CONTEXT_ADD_LINK_TO_READING_LIST 9333
#define IDS_CONTENT_CONTEXT_ADD_A_NOTE 9334
#define IDS_CONTENT_CONTEXT_REMOVELINKTOTEXT 9335
#define IDS_CONTENT_CONTEXT_RESHARELINKTOTEXT 9336
#define IDS_CONTENT_CONTEXT_SAVEIMAGEAS 9337
#define IDS_CONTENT_CONTEXT_COPYIMAGELOCATION 9338
#define IDS_CONTENT_CONTEXT_COPYIMAGE 9339
#define IDS_CONTENT_CONTEXT_OPENIMAGENEWTAB 9340
#define IDS_CONTENT_CONTEXT_OPEN_ORIGINAL_IMAGE_NEW_TAB 9341
#define IDS_CONTENT_CONTEXT_LOAD_IMAGE 9342
#define IDS_CONTENT_CONTEXT_LOOP 9343
#define IDS_CONTENT_CONTEXT_CONTROLS 9344
#define IDS_CONTENT_CONTEXT_ROTATECW 9345
#define IDS_CONTENT_CONTEXT_ROTATECCW 9346
#define IDS_CONTENT_CONTEXT_VIDEO_FRAME 9347
#define IDS_CONTENT_CONTEXT_SAVEVIDEOFRAMEAS 9348
#define IDS_CONTENT_CONTEXT_SAVEVIDEOAS 9349
#define IDS_CONTENT_CONTEXT_COPYVIDEOLOCATION 9350
#define IDS_CONTENT_CONTEXT_COPYVIDEOFRAME 9351
#define IDS_CONTENT_CONTEXT_SEARCHFORVIDEOFRAME 9352
#define IDS_CONTENT_CONTEXT_OPENVIDEONEWTAB 9353
#define IDS_CONTENT_CONTEXT_SAVEAUDIOAS 9354
#define IDS_CONTENT_CONTEXT_COPYAUDIOLOCATION 9355
#define IDS_CONTENT_CONTEXT_OPENAUDIONEWTAB 9356
#define IDS_CONTENT_CONTEXT_PICTUREINPICTURE 9357
#define IDS_CONTENT_CONTEXT_UNDO 9358
#define IDS_CONTENT_CONTEXT_REDO 9359
#define IDS_CONTENT_CONTEXT_CUT 9360
#define IDS_CONTENT_CONTEXT_COPY 9361
#define IDS_CONTENT_CONTEXT_COPY_SELECTION 9362
#define IDS_CONTENT_CONTEXT_PASTE 9363
#define IDS_CONTENT_CONTEXT_PASTE_AND_MATCH_STYLE 9364
#define IDS_CONTENT_CONTEXT_ADD_TO_DICTIONARY 9365
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_MENU_OPTION 9367
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND 9368
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND_ONCE 9369
#define IDS_CONTENT_CONTEXT_RUN_LAYOUT_EXTRACTION 9370
#define IDS_CONTENT_CONTEXT_SPELLING_ASK_GOOGLE 9371
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TITLE 9372
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_ENABLE 9373
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_DISABLE 9374
#define IDS_CONTENT_CONTEXT_SPELLING_CHECKING 9375
#define IDS_CONTENT_CONTEXT_SPELLING_NO_SUGGESTIONS_FROM_GOOGLE 9376
#define IDS_CONTENT_CONTEXT_SELECTALL 9377
#define IDS_CONTENT_CONTEXT_PARTIAL_TRANSLATE 9378
#define IDS_CONTENT_CONTEXT_PARTIAL_TRANSLATE_SELECTION 9379
#define IDS_CONTENT_CONTEXT_SEARCHWEBFOR 9380
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORNEWTAB 9381
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORIMAGE 9382
#define IDS_CONTENT_CONTEXT_SEARCHLENSFORIMAGE 9383
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH_ALT1 9384
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH 9385
#define IDS_CONTENT_CONTEXT_GOTOURL 9386
#define IDS_CONTENT_CONTEXT_GENERATEPASSWORD 9387
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_USE_PASSKEY_FROM_ANOTHER_DEVICE 9388
#define IDS_CONTENT_CONTEXT_MORE_APPS 9389
#define IDS_CONTENT_CONTEXT_OPEN_WITH_APP 9390
#define IDS_CONTENT_CONTEXT_AUTOFILL_FEEDBACK 9391
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_AT_MEMORY 9392
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SELECT_PASSWORD 9393
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_IMPORT_PASSWORDS 9394
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SUGGEST_PASSWORD 9395
#define IDS_SHARE_MENU_TITLE 9399
#define IDS_CONTENT_CONTEXT_PLUGIN_RUN 9400
#define IDS_CONTENT_CONTEXT_PLUGIN_HIDE 9401
#define IDS_CONTENT_CONTEXT_ENABLE_FLASH 9402
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MENU 9404
#define IDS_CONTENT_CONTEXT_LANGUAGE_SETTINGS 9403
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MULTI_LINGUAL 9405
#define IDS_CONTENT_CONTEXT_CHECK_SPELLING_WHILE_TYPING 9406
#define IDS_PROFILE_ROW_VERIFY_MESSAGE 9407
#define IDS_ADDRESSES_AND_MORE_SUBMENU_OPTION 9408
#define IDS_YOUR_SAVED_INFO_CONTACT_INFO_SUBMENU_OPTION 9409
#define IDS_PASSWORDS_AND_AUTOFILL_MENU 9410
#define IDS_RELAUNCH_TO_UPDATE_ALT 9411
#define IDS_RELAUNCH_TO_UPDATE_ALT_MINOR_TEXT 9412
#define IDS_NEW_TAB 9413
#define IDS_NEW_INCOGNITO_TAB 9414
#define IDS_SHOW_AS_TAB 9415
#define IDS_NEW_WINDOW 9416
#define IDS_NEW_INCOGNITO_WINDOW 9417
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE_WITH_EMAIL 9418
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE 9419
#define IDS_PROFILE_ROW_SYNC_IS_ON 9420
#define IDS_PROFILE_ROW_TURN_ON_SYNC 9421
#define IDS_PROFILE_ROW_SYNC_ERROR_MESSAGE 9422
#define IDS_EDIT2 9423
#define IDS_CUT 9424
#define IDS_COPY 9425
#define IDS_PASTE 9426
#define IDS_DELETE 9427
#define IDS_FIND 9428
#define IDS_FIND_AND_EDIT_MENU 9429
#define IDS_PAYMENT_METHOD_SUBMENU_OPTION 9430
#define IDS_YOUR_SAVED_INFO_PAYMENTS_SUBMENU_OPTION 9431
#define IDS_SAVE_AND_SHARE_MENU 9432
#define IDS_CAST_SAVE_AND_SHARE_MENU 9433
#define IDS_SAVE_AND_SHARE_MENU_CAST 9434
#define IDS_SAVE_AND_SHARE_MENU_SAVE 9435
#define IDS_SAVE_AND_SHARE_MENU_SHARE 9436
#define IDS_SAVE_PAGE 9437
#define IDS_MORE_TOOLS_MENU 9438
#define IDS_ZOOM_MENU 9439
#define IDS_ZOOM_MENU2 9440
#define IDS_ZOOM_PLUS 9441
#define IDS_ZOOM_PLUS2 9442
#define IDS_ZOOM_NORMAL 9443
#define IDS_ZOOM_MINUS 9444
#define IDS_ZOOM_MINUS2 9445
#define IDS_COPY_URL 9446
#define IDS_OPEN_IN_APP_WINDOW 9447
#define IDS_MOVE_TAB_TO_NEW_WINDOW 9448
#define IDS_SEARCH_TABS 9449
#define IDS_CLOSE_PROFILE 9450
#define IDS_MANAGE_GOOGLE_ACCOUNT 9451
#define IDS_OPEN_GUEST_PROFILE 9452
#define IDS_ADD_NEW_PROFILE 9453
#define IDS_ACCNAME_ZOOM_PLUS2 9457
#define IDS_ACCNAME_ZOOM_MINUS2 9458
#define IDS_VIEW_SOURCE 9459
#define IDS_FEEDBACK 9460
#define IDS_DEV_TOOLS 9461
#define IDS_DEV_TOOLS_ELEMENTS 9462
#define IDS_DEV_TOOLS_CONSOLE 9463
#define IDS_DEV_TOOLS_DEVICES 9464
#define IDS_TASK_MANAGER 9465
#define IDS_TAKE_SCREENSHOT 9466
#define IDS_REPORT_UNSAFE_SITE 9467
#define IDS_RESTORE_SPLIT 9468
#define IDS_RESTORE_TAB 9469
#define IDS_REOPEN_WINDOW 9470
#define IDS_REOPEN_GROUP 9471
#define IDS_REOPEN_SPLIT 9472
#define IDS_RESTORE_WINDOW 9473
#define IDS_RESTORE_GROUP 9474
#define IDS_NAME_WINDOW 9475
#define IDS_CHROMELABS 9476
#define IDS_PREFERENCES 9477
#define IDS_TOS_NOTIFICATION_TITLE 9479
#define IDS_TOS_NOTIFICATION_BODY_TEXT 9480
#define IDS_TOS_NOTIFICATION_ACK_BUTTON_TEXT 9481
#define IDS_TOS_NOTIFICATION_REVIEW_BUTTON_TEXT 9482
#define IDS_TOS_NOTIFICATION_LINK 9483
#define IDS_HELP_MENU 9484
#define IDS_MANAGED 9485
#define IDS_MANAGED_BY 9486
#define IDS_MANAGED_BY_PARENT 9487
#define IDS_PROFILE_MANAGED_BY 9488
#define IDS_BROWSER_PROFILE_MANAGED 9489
#define IDS_CHROME_ENTERPRISE_RELEASE_NOTES 9490
#define IDS_CHROME_WHATS_NEW 9491
#define IDS_IMPORT_SETTINGS_MENU_LABEL 9492
#define IDS_PROFILING_ENABLED 9493
#define IDS_FULLSCREEN 9494
#define IDS_CLEAR_BROWSING_DATA 9495
#define IDS_SHOW_DOWNLOADS 9496
#define IDS_FIND_EXTENSIONS 9497
#define IDS_SHOW_EXTENSIONS 9498
#define IDS_EXTENSIONS_SUBMENU 9499
#define IDS_EXTENSIONS_SUBMENU_MANAGE_EXTENSIONS_ITEM 9500
#define IDS_EXTENSIONS_SUBMENU_CHROME_WEBSTORE_ITEM 9501
#define IDS_SHOW_PERFORMANCE 9502
#define IDS_SHOW_SEARCH_COMPANION 9503
#define IDS_SHOW_TRANSLATE 9504
#define IDS_SETTINGS 9505
#define IDS_OPTIONS 9506
#define IDS_HELP_PAGE 9507
#define IDS_BETA_FORUM 9508
#define IDS_GET_HELP 9509
#define IDS_EXIT 9510
#define IDS_AUTOCOMPLETE_MATCH_DESCRIPTION_SEPARATOR 9511
#define IDS_MANAGE_SEARCH_ENGINES 9512
#define IDS_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 9513
#define IDS_MANAGE_SEARCH_ENGINES_AND_SHORTCUTS 9514
#define IDS_SEARCH_ENGINES_EDITOR_KEYWORD_COLUMN 9515
#define IDS_SEARCH_ENGINES_EDITOR_DESCRIPTION_COLUMN 9516
#define IDS_SEARCH_ENGINES_EDITOR_DEFAULT_ENGINE 9517
#define IDS_DOWNLOAD_INTERRUPTED_STATUS 9518
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_ACCESS_DENIED 9519
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_ACCESS_DENIED 9520
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_PATH_TOO_LONG 9521
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_PATH_TOO_LONG 9522
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_DISK_FULL 9523
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_DISK_FULL 9524
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_LARGE 9525
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_LARGE 9526
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_TEMPORARY_PROBLEM 9527
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_TEMPORARY_PROBLEM 9528
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_VIRUS 9529
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_VIRUS 9530
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_BLOCKED 9531
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED 9532
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED_DOWNLOAD_UI 9533
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_BLOCKED 9534
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CONTENT_LENGTH_MISMATCH 9535
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CONTENT_LENGTH_MISMATCH 9536
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SECURITY_CHECK_FAILED 9537
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SECURITY_CHECK_FAILED 9538
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_SHORT 9539
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_SHORT 9540
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_SAME_AS_SOURCE 9541
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_SAME_AS_SOURCE 9542
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_TIMEOUT 9543
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_TIMEOUT 9544
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_DISCONNECTED 9545
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_DISCONNECTED 9546
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_DOWN 9547
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_DOWN 9548
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_ERROR 9549
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_ERROR 9550
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NO_FILE 9551
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NO_FILE 9552
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_PROBLEM 9553
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_PROBLEM 9554
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SHUTDOWN 9555
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SHUTDOWN 9556
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CRASH 9557
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CRASH 9558
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNAUTHORIZED 9559
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNAUTHORIZED 9560
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_CERT_PROBLEM 9561
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_CERT_PROBLEM 9562
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FORBIDDEN 9563
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FORBIDDEN 9564
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNREACHABLE 9565
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNREACHABLE 9566
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN_WHEN_COMPLETE 9567
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN 9568
#define IDS_DOWNLOAD_STATUS_STARTING 9569
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS 9579
#define IDS_DOWNLOAD_STATUS_SIZES 9580
#define IDS_DOWNLOAD_STATUS_OPEN_IN 9581
#define IDS_DOWNLOAD_STATUS_OPEN_WHEN_COMPLETE 9582
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_SHORT 9583
#define IDS_DOWNLOAD_STATUS_CANCELLED 9584
#define IDS_DOWNLOAD_STATUS_REMOVED 9585
#define IDS_DOWNLOAD_STATUS_INTERRUPTED 9586
#define IDS_DOWNLOAD_UNCONFIRMED_PREFIX 9587
#define IDS_PROMPT_DANGEROUS_DOWNLOAD 9588
#define IDS_PROMPT_DANGEROUS_DOWNLOAD_EXTENSION 9589
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT 9590
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT_IN_ADVANCED_PROTECTION 9591
#define IDS_PROMPT_DEEP_SCANNING_APP_DOWNLOAD 9592
#define IDS_PROMPT_CONFIRM_INSECURE_DOWNLOAD 9593
#define IDS_PROMPT_DOWNLOAD_BLOCKED_TOO_LARGE 9594
#define IDS_PROMPT_DOWNLOAD_BLOCKED_PASSWORD_PROTECTED 9595
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_WARNING 9596
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_BLOCKED 9597
#define IDS_PROMPT_DOWNLOAD_FORCED_SAVE_TO_CLOUD 9598
#define IDS_PROMPT_DOWNLOAD_BLOCKED_SCAN_FAILED 9599
#define IDS_PROMPT_DOWNLOAD_DEEP_SCANNED_OPENED_DANGEROUS 9600
#define IDS_PROMPT_DOWNLOAD_INSECURE_WARNING 9601
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED 9602
#define IDS_PROMPT_APP_DEEP_SCANNING 9603
#define IDS_PROMPT_DEEP_SCANNING 9604
#define IDS_BLOCK_REASON_UNCOMMON_DOWNLOAD_IN_ADVANCED_PROTECTION 9605
#define IDS_BLOCK_REASON_DEEP_SCANNING_UPDATED 9606
#define IDS_BLOCK_REASON_DEEP_SCANNING_SECOND_UPDATED 9607
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING_UPDATED 9608
#define IDS_BLOCK_REASON_PROMPT_FOR_LOCAL_PASSWORD_SCANNING 9609
#define IDS_DEEP_SCANNED_OPENED_DANGEROUS_DESCRIPTION 9610
#define IDS_BLOCK_REASON_SENSITIVE_CONTENT_WARNING 9611
#define IDS_SENSITIVE_CONTENT_BLOCKED_DESCRIPTION 9612
#define IDS_FORCED_SAVE_TO_CLOUD_DESCRIPTION 9613
#define IDS_BLOCKED_TOO_LARGE_DESCRIPTION 9614
#define IDS_BLOCKED_PASSWORD_PROTECTED_DESCRIPTION 9615
#define IDS_DEEP_SCANNED_FAILED_DESCRIPTION 9616
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY_STILL_ON_DEVICE 9617
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY 9618
#define IDS_DOWNLOADS_TOAST_COPIED_DOWNLOAD_LINK 9619
#define IDS_DOWNLOADS_TOAST_COPY_DOWNLOAD_LINK_FAILED 9620
#define IDS_DOWNLOADS_TOAST_COPIED_LINK 9621
#define IDS_EMAIL_VERIFIED 9622
#define IDS_CONFIRM_KEEP_DANGEROUS_DOWNLOAD_TITLE 9626
#define IDS_CONFIRM_DOWNLOAD 9627
#define IDS_CONTINUE_EXTENSION_DOWNLOAD 9628
#define IDS_DISCARD_DOWNLOAD 9629
#define IDS_OPEN_DOWNLOAD_NOW 9630
#define IDS_SCAN_DOWNLOAD 9631
#define IDS_REVIEW_DOWNLOAD 9632
#define IDS_OPEN_DOWNLOAD_ANYWAY 9633
#define IDS_DOWNLOAD_LINK_PAUSE 9634
#define IDS_DOWNLOAD_HISTORY_SEARCH 9635
#define IDS_DOWNLOAD_NO_DOWNLOADS 9636
#define IDS_DOWNLOAD_LINK_RESUME 9637
#define IDS_DOWNLOAD_LINK_CANCEL 9638
#define IDS_DOWNLOAD_LINK_RETRY 9639
#define IDS_DOWNLOAD_LINK_SHOW 9640
#define IDS_DOWNLOAD_TAB_CANCELLED 9641
#define IDS_DOWNLOAD_FILE_REMOVED 9642
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS_TIME_UNKNOWN 9643
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS 9644
#define IDS_DOWNLOAD_TAB_PROGRESS_SIZE 9645
#define IDS_DOWNLOAD_PROGRESS_PAUSED 9646
#define IDS_DOWNLOAD_LINK_CLEAR_ALL 9647
#define IDS_DOWNLOAD_LINK_OPEN_DOWNLOADS_FOLDER 9648
#define IDS_DOWNLOAD_MORE_ACTIONS 9649
#define IDS_DOWNLOAD_ACTION_MENU_DESCRIPTION 9650
#define IDS_DOWNLOAD_BY_EXTENSION_URL 9651
#define IDS_DOWNLOADS_PAGE_INITIATOR_LINE 9652
#define IDS_DOWNLOAD_IN_INCOGNITO 9653
#define IDS_UNDO_DESCRIPTION 9654
#define IDS_DOWNLOAD_UNDO 9655
#define IDS_DOWNLOAD_TOAST_CLEARED_ALL 9656
#define IDS_DOWNLOAD_DEEP_SCAN_UPDATED 9657
#define IDS_DOWNLOAD_LOCAL_PASSWORD_SCAN 9658
#define IDS_DOWNLOAD_KEEP_DANGEROUS_FILE 9659
#define IDS_DOWNLOAD_KEEP_SUSPICIOUS_FILE 9660
#define IDS_DOWNLOAD_KEEP_UNVERIFIED_FILE 9661
#define IDS_DOWNLOAD_KEEP_INSECURE_FILE 9662
#define IDS_DOWNLOAD_DELETE_FROM_HISTORY 9663
#define IDS_DOWNLOAD_COPY_DOWNLOAD_LINK 9664
#define IDS_DOWNLOAD_DANGEROUS_ICON_ACCESSIBLE_LABEL 9665
#define IDS_DOWNLOAD_SUSPICIOUS_ICON_ACCESSIBLE_LABEL 9666
#define IDS_DOWNLOAD_INSECURE_ICON_ACCESSIBLE_LABEL 9667
#define IDS_DOWNLOAD_UNVERIFIED_ICON_ACCESSIBLE_LABEL 9668
#define IDS_DOWNLOAD_SCREENREADER_SAVED_DANGEROUS 9669
#define IDS_DOWNLOAD_SCREENREADER_SAVED_SUSPICIOUS 9670
#define IDS_DOWNLOAD_SCREENREADER_SAVED_INSECURE 9671
#define IDS_DOWNLOAD_SCREENREADER_SAVED_UNVERIFIED 9672
#define IDS_DOWNLOAD_SCREENREADER_PAUSED 9673
#define IDS_DOWNLOAD_SCREENREADER_RESUMED 9674
#define IDS_DOWNLOAD_SCREENREADER_CANCELED 9675
#define IDS_DOWNLOAD_WARNING_BYPASS_DIALOG_TITLE 9676
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_DESCRIPTION 9677
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_ACCESSIBLE_ALERT 9678
#define IDS_DOWNLOAD_STATUS_PERCENT_COMPLETE_ACCESSIBLE_ALERT 9679
#define IDS_DOWNLOAD_STATUS_TIME_REMAINING_ACCESSIBLE_ALERT 9680
#define IDS_DOWNLOAD_FAILED_ACCESSIBLE_ALERT 9681
#define IDS_DOWNLOAD_CANCELLED_ACCESSIBLE_ALERT 9682
#define IDS_DOWNLOAD_COMPLETE_ACCESSIBLE_ALERT 9683
#define IDS_DOWNLOAD_PAUSED_ACCESSIBLE_ALERT 9684
#define IDS_PROMPT_DEEP_SCANNING_ACCESSIBLE_ALERT 9685
#define IDS_DEEP_SCANNING_ACCESSIBLE_ALERT 9686
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED_ACCESSIBLE_ALERT 9687
#define IDS_DOWNLOAD_NOTIFICATION_COPY_TO_CLIPBOARD 9688
#define IDS_DOWNLOAD_MENU_SHOW 9689
#define IDS_DOWNLOAD_MENU_OPEN_WHEN_COMPLETE 9690
#define IDS_DOWNLOAD_MENU_OPEN 9691
#define IDS_DOWNLOAD_MENU_ALWAYS_OPEN_TYPE 9692
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN 9693
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN_ALWAYS 9694
#define IDS_DOWNLOAD_MENU_CANCEL 9695
#define IDS_DOWNLOAD_MENU_PAUSE_ITEM 9696
#define IDS_DOWNLOAD_MENU_RESUME_ITEM 9697
#define IDS_DOWNLOAD_MENU_DISCARD 9698
#define IDS_DOWNLOAD_MENU_KEEP 9699
#define IDS_DOWNLOAD_MENU_LEARN_MORE_SCANNING 9700
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INTERRUPTED 9701
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INSECURE 9702
#define IDS_DOWNLOAD_MENU_DEEP_SCAN 9703
#define IDS_ABANDON_DOWNLOAD_DIALOG_TITLE 9714
#define IDS_ABANDON_DOWNLOAD_DIALOG_CONTINUE_BUTTON 9715
#define IDS_ABANDON_DOWNLOAD_DIALOG_INCOGNITO_MESSAGE 9716
#define IDS_ABANDON_DOWNLOAD_DIALOG_GUEST_MESSAGE 9717
#define IDS_ABANDON_DOWNLOAD_DIALOG_EXIT_BUTTON 9718
#define IDS_DOWNLOAD_BUBBLE_HEADER_LABEL 9719
#define IDS_DOWNLOAD_BUBBLE_FOOTER_LABEL 9720
#define IDS_DOWNLOAD_BUBBLE_FOOTER_TOOLTIP_LABEL 9721
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO 9722
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_CUSTOM_ACTION 9723
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_DISMISS 9724
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_TITLE 9725
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_MESSAGE_WITH_SEPARATOR 9726
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_WITH_SYMBOL 9727
#define IDS_DOWNLOAD_BUBBLE_STATUS_RESUMING 9728
#define IDS_DOWNLOAD_BUBBLE_STATUS_DONE 9729
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_DONE_UPDATED 9730
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_INSECURE 9731
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_SUSPICIOUS 9732
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_DANGEROUS 9733
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_UNVERIFIED 9734
#define IDS_DOWNLOAD_BUBBLE_STATUS_BLOCKED 9735
#define IDS_DOWNLOAD_BUBBLE_STATUS_SUSPICIOUS 9736
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNED_FAILED_UPDATED 9737
#define IDS_DOWNLOAD_BUBBLE_CONTINUE 9738
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_INSECURE_FILE 9739
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_SUSPICIOUS_FILE 9740
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_UNVERIFIED_FILE 9741
#define IDS_DOWNLOAD_BUBBLE_DELETE 9742
#define IDS_DOWNLOAD_BUBBLE_DELETE_FROM_HISTORY 9743
#define IDS_DOWNLOAD_BUBBLE_MAIN_BUTTON_SUBPAGE 9744
#define IDS_DOWNLOAD_BUBBLE_RESUME 9745
#define IDS_DOWNLOAD_BUBBLE_SCAN 9746
#define IDS_DOWNLOAD_BUBBLE_SCAN_UPDATED 9747
#define IDS_DOWNLOAD_BUBBLE_OPEN_UPDATED 9748
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW 9749
#define IDS_DOWNLOAD_BUBBLE_REVIEW 9750
#define IDS_DOWNLOAD_BUBBLE_RETRY 9751
#define IDS_DOWNLOAD_BUBBLE_OPEN_ANYWAY 9752
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_DISK_FULL 9753
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_DISK_FULL 9754
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_PATH_TOO_LONG 9755
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_PATH_TOO_LONG 9756
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NEEDS_PERMISSION 9757
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_TOO_LARGE 9758
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_BLOCKED_ORGANIZATION 9759
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_WRONG 9760
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NETWORK_ERROR 9761
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_SITE_UNAVAILABLE 9762
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNAVAILABLE 9763
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_FILE_UNAVAILABLE 9764
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNFINISHED 9765
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_INSECURE 9766
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS 9767
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DECEPTIVE 9768
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS_FILE_TYPE 9769
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_UNCOMMON_FILE 9770
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_NO_SAFE_BROWSING 9771
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LABEL 9772
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LINK 9773
#define IDS_DOWNLOAD_BUBBLE_STATUS_ENCRYPTED 9774
#define IDS_DOWNLOAD_BUBBLE_STATUS_TOO_BIG 9775
#define IDS_DOWNLOAD_BUBBLE_STATUS_ADVANCED_PROTECTION 9776
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ADVANCED_PROTECTION 9777
#define IDS_DOWNLOAD_BUBBLE_STATUS_UNKNOWN_SOURCE 9778
#define IDS_DOWNLOAD_BUBBLE_STATUS_SENSITIVE_CONTENT 9779
#define IDS_DOWNLOAD_BUBBLE_STATUS_SCAN_FAILED 9780
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_WARNING 9781
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_BLOCK 9782
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ENCRYPTED 9783
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_TOO_BIG 9784
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING 9785
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_SECONDARY 9786
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_ENTERPRISE_SECONDARY 9787
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_DISCARD 9788
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_CANCEL 9789
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SCAN_FAILED 9790
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING_ENTERPRISE 9791
#define IDS_DOWNLOAD_BUBBLE_INCOGNITO_INFORMATION_ROW 9792
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION 9793
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION_ACCESSIBILITY 9794
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION 9795
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION_ACCESSIBILITY 9796
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION 9797
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION_ACCESSIBILITY 9798
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION 9799
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION_ACCESSIBILITY 9800
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION 9801
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION_ACCESSIBILITY 9802
#define IDS_DOWNLOAD_BUBBLE_BACK_RECENT_DOWNLOADS 9803
#define IDS_DOWNLOAD_BUBBLE_CANCEL_MAIN_BUTTON_ACCESSIBILITY 9804
#define IDS_DOWNLOAD_BUBBLE_DELETE_MAIN_BUTTON_ACCESSIBILITY 9805
#define IDS_DOWNLOAD_BUBBLE_KEEP_MAIN_BUTTON_ACCESSIBILITY 9806
#define IDS_DOWNLOAD_BUBBLE_SCAN_MAIN_BUTTON_ACCESSIBILITY 9807
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW_MAIN_BUTTON_ACCESSIBILITY 9808
#define IDS_DOWNLOAD_BUBBLE_RESUME_MAIN_BUTTON_ACCESSIBILITY 9809
#define IDS_DOWNLOAD_BUBBLE_REVIEW_MAIN_BUTTON_ACCESSIBILITY 9810
#define IDS_DOWNLOAD_BUBBLE_RETRY_MAIN_BUTTON_ACCESSIBILITY 9811
#define IDS_DOWNLOAD_BUBBLE_OPEN_MAIN_BUTTON_ACCESSIBILITY 9812
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW 9813
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_REMINDER 9814
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_LINK 9815
#define IDS_DOWNLOAD_BUBBLE_TOOLTIP_IN_PROGRESS_COUNT 9816
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_COOKIE_THEFT 9819
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_ARCHIVE_MALWARE 9820
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_PROMPT_UPDATED 9821
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING 9822
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_CHECKING_SAFETY 9823
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_UPDATED 9824
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_ENCRYPTED_ARCHIVE 9825
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_DEEP_SCANNING_LINK 9826
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT 9827
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_EMPTY 9828
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_INVALID 9829
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT 9830
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_EMPTY 9831
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_INVALID 9832
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_IMMEDIATE_DEEP_SCAN_IN_PROGRESS 9833
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_CANCEL 9834
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_BYPASS 9835
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTION_STATUS 9836
#define IDS_DOWNLOAD_BUBBLE_STATUS_PASSWORD_NEEDED 9837
#define IDS_DOWNLOAD_BUBBLE_ACCEPT_LOCAL_DECRYPTION 9838
#define IDS_DOWNLOAD_BUBBLE_BYPASS_LOCAL_DECRYPTION 9839
#define IDS_DOWNLOAD_BUBBLE_LOCAL_DECRYPTION_CANCEL 9840
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_LOCAL_DECRYPTION_IN_PROGRESS 9841
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTING 9842
#define IDS_DOWNLOAD_LOCAL_DECRYPTION_PROMPT_ALERT 9843
#define IDS_WEB_APP_WITH_APP_TITLE 9844
#define IDS_OMNIBOX_PWA_INSTALL_ICON_LABEL 9845
#define IDS_OMNIBOX_PWA_INSTALL_ICON_TOOLTIP 9846
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON 9847
#define IDS_WEBAPP_UPDATE_REVIEW_UNINSTALL_BUTTON 9848
#define IDS_WEBAPP_UPDATE_REVIEW_IGNORE_BUTTON 9849
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON_MIGRATION 9850
#define IDS_ADD_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 9851
#define IDS_CREATE_SHORTCUTS_BUTTON_LABEL 9852
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_TITLE 9853
#define IDS_CREATE_SHORTCUT_NOT_APPS_AX_BUBBLE_LABEL 9854
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 9855
#define IDS_INSTALL_PWA_BUTTON_LABEL 9856
#define IDS_INSTALL_PWA_DIALOG_TITLE 9857
#define IDS_WEB_APP_INSTALL_FLOW_SUBTITLE 9858
#define IDS_WEB_APP_INSTALL_FLOW_NEXT 9859
#define IDS_WEB_APP_INSTALL_SUCCESS_TITLE 9860
#define IDS_WEB_APP_INSTALL_SUCCESS_OPEN_APP 9861
#define IDS_INSTALL_PWA_DIALOG_INSTALLING 9862
#define IDS_WEB_APP_DETAILED_INSTALL_DIALOG_DESCRIPTION_TITLE 9863
#define IDS_DIY_APP_INSTALL_DIALOG_TITLE 9864
#define IDS_DIY_APP_INSTALL_DIALOG_SUBTITLE 9865
#define IDS_WEB_APP_INSTALL_PIN_TO_SHELF 9866
#define IDS_DIY_APP_AX_BUBBLE_NAME_LABEL 9867
#define IDS_INSTALL_PWA_DIALOG_ORIGIN_LABEL 9868
#define IDS_WEB_APP_INSTALL_ADD_TO_START_MENU 9869
#define IDS_WEB_APP_INSTALL_CHROME_APPS_LOCATION 9870
#define IDS_WEB_APP_INSTALL_CREATE_DESKTOP_SHORTCUT 9871
#define IDS_WEB_APP_INSTALL_PIN_TO_TASKBAR 9872
#define IDS_WEB_APP_INSTALL_LAUNCHER 9873
#define IDS_BOOKMARK_APP_AX_BUBBLE_NAME_LABEL 9874
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TAB 9875
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_WINDOW 9876
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TABBED_WINDOW 9877
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_INCOGNITO_MODE 9878
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_GUEST_MODE 9879
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_POLICY_MODE 9880
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME 9881
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_ICON 9882
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_ICON 9883
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO 9884
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO 9885
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL 9886
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL_FORCED_MIGRATION 9887
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_URL 9888
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO_AND_URL 9889
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO_AND_URL 9890
#define IDS_WEBAPP_UPDATE_NEW_EXPLANATION 9891
#define IDS_WEBAPP_UPDATE_URL_ONLY_NEW_EXPLANATION 9892
#define IDS_WEBAPP_UPDATE_EXPLANATION 9893
#define IDS_WEBAPP_UPDATE_CURRENT_ICON 9894
#define IDS_WEBAPP_UPDATE_NEW_ICON 9895
#define IDS_WEBAPP_UPDATE_NEGATIVE_BUTTON 9896
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION 9897
#define IDS_FINISH_POLICY_WEB_APP_INSTALATION_RESTART 9898
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION_NOT_NOW 9899
#define IDS_ADD_TO_OS_LAUNCH_SURFACE 9904
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE 9905
#define IDS_INSTALL_DIY_TO_OS_LAUNCH_SURFACE 9906
#define IDS_UNINSTALL_FROM_OS_LAUNCH_SURFACE 9907
#define IDS_REVIEW_APP_UPDATE 9908
#define IDS_APPLICATION_INFO_WEB_STORE_LINK 9909
#define IDS_APPLICATION_INFO_HOMEPAGE_LINK 9910
#define IDS_ARC_APPLICATION_INFO_MANAGE_LINK 9911
#define IDS_APPLICATION_INFO_APP_OVERVIEW_TITLE 9912
#define IDS_APPLICATION_INFO_APP_PERMISSIONS_TITLE 9913
#define IDS_APPLICATION_INFO_UNINSTALL_BUTTON_TEXT 9914
#define IDS_APPLICATION_INFO_LICENSES_BUTTON_TEXT 9915
#define IDS_APPLICATION_INFO_SIZE_LABEL 9916
#define IDS_APPLICATION_INFO_VERSION_LABEL 9917
#define IDS_APPLICATION_INFO_CREATE_SHORTCUTS_BUTTON_TEXT 9918
#define IDS_APPLICATION_INFO_LAUNCH_OPTIONS_ACCNAME 9919
#define IDS_APPLICATION_INFO_SIZE_LOADING_LABEL 9920
#define IDS_APPLICATION_INFO_SIZE_SMALL_LABEL 9921
#define IDS_APPLICATION_INFO_REVOKE_PERMISSION_ALT_TEXT 9922
#define IDS_APPLICATION_INFO_APP_NO_PERMISSIONS_TEXT 9923
#define IDS_APPLICATION_INFO_EXTENSION_NO_PERMISSIONS_TEXT 9924
#define IDS_APPLICATION_INFO_RETAINED_FILES 9925
#define IDS_APPLICATION_INFO_RETAINED_DEVICES 9926
#define IDS_CREATE_SHORTCUTS_TITLE 9927
#define IDS_CREATE_SHORTCUTS_LABEL 9928
#define IDS_CREATE_SHORTCUTS_DESKTOP_CHKBOX 9929
#define IDS_CREATE_SHORTCUTS_MENU_CHKBOX 9930
#define IDS_CREATE_SHORTCUTS_COMMIT 9931
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_TITLE 9934
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_LABEL 9935
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_TITLE 9936
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_LABEL 9937
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_TITLE 9938
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_LABEL 9939
#define IDS_MANAGE 9940
#define IDS_LIST_BULLET 9941
#define IDS_BLOCKED_DOWNLOAD_NO_ACTION 9942
#define IDS_BLOCKED_DOWNLOAD_UNBLOCK 9943
#define IDS_ALLOWED_DOWNLOAD_TITLE 9944
#define IDS_BLOCKED_DOWNLOAD_TITLE 9945
#define IDS_BLOCKED_DOWNLOADS_EXPLANATION 9946
#define IDS_ALLOWED_DOWNLOAD_NO_ACTION 9947
#define IDS_ALLOWED_DOWNLOAD_BLOCK 9948
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_TITLE 9949
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_TITLE 9950
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_MESSAGE 9951
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_MESSAGE 9952
#define IDS_BLOCKED_IMAGES_TITLE 9953
#define IDS_BLOCKED_IMAGES_MESSAGE 9954
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_UNBLOCK 9955
#define IDS_BLOCKED_IMAGES_UNBLOCK 9956
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_NO_ACTION 9957
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_NO_ACTION 9958
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_BLOCK 9959
#define IDS_BLOCKED_IMAGES_NO_ACTION 9960
#define IDS_BLOCKED_POPUPS_TOOLTIP 9961
#define IDS_BLOCKED_POPUPS_TITLE 9962
#define IDS_BLOCKED_POPUPS_REDIRECTS_UNBLOCK 9963
#define IDS_BLOCKED_POPUPS_REDIRECTS_NO_ACTION 9964
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ALLOW 9965
#define IDS_BLOCKED_MEDIASTREAM_MIC_ALLOW 9966
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ALLOW 9967
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ASK 9968
#define IDS_BLOCKED_MEDIASTREAM_MIC_ASK 9969
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ASK 9970
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_BLOCK 9971
#define IDS_ALLOWED_MEDIASTREAM_MIC_BLOCK 9972
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_BLOCK 9973
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 9974
#define IDS_BLOCKED_MEDIASTREAM_MIC_NO_ACTION 9975
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_NO_ACTION 9976
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 9977
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_PAN_TILT_ZOOM_NO_ACTION 9978
#define IDS_ALLOWED_MEDIASTREAM_MIC_NO_ACTION 9979
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_NO_ACTION 9980
#define IDS_ALLOWED_CAMERA_PAN_TILT_ZOOM_NO_ACTION 9981
#define IDS_BLOCKED_POPUPS_EXPLANATORY_TEXT 9982
#define IDS_BLOCKED_JAVASCRIPT_TITLE 9983
#define IDS_BLOCKED_JAVASCRIPT_MESSAGE 9984
#define IDS_BLOCKED_JAVASCRIPT_UNBLOCK 9985
#define IDS_BLOCKED_JAVASCRIPT_NO_ACTION 9986
#define IDS_BLOCKED_SOUND_TITLE 9987
#define IDS_BLOCKED_SOUND_UNBLOCK 9988
#define IDS_BLOCKED_SOUND_NO_ACTION 9989
#define IDS_NOTIFICATIONS_OFF_EXPLANATORY_TEXT 9990
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_TITLE 9991
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DESCRIPTION 9992
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_DESCRIPTION 9993
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 9994
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_COMPACT_ALLOW_BUTTON 9995
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CONTINUE_BLOCKING_BUTTON 9996
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_EARLY_PROMO 9997
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 9998
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 9999
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ABUSIVE_DESCRIPTION 10000
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DISRUPTIVE_DESCRIPTION 10001
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 10002
#define IDS_GEOLOCATION_OFF_EXPLANATORY_TEXT 10003
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_TITLE 10004
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 10005
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 10006
#define IDS_STORAGE_ACCESS_PERMISSION_BUBBLE_MESSAGE 10007
#define IDS_STORAGE_ACCESS_PERMISSION_ALLOWED_TOOLTIP 10008
#define IDS_STORAGE_ACCESS_PERMISSION_BLOCKED_TOOLTIP 10009
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_BLOCKED_TITLE 10010
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_ALLOWED_TITLE 10011
#define IDS_COOKIE_CONTROLS_BUBBLE_SITE_NOT_WORKING_TITLE 10012
#define IDS_TRACKING_PROTECTION_BUBBLE_SITE_NOT_WORKING_DESCRIPTION 10013
#define IDS_COOKIE_CONTROLS_BUBBLE_SITE_NOT_WORKING_DESCRIPTION 10014
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_TITLE 10015
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_DESCRIPTION 10016
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_TITLE 10017
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_DESCRIPTION 10018
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_TITLE 10019
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_DESCRIPTION 10020
#define IDS_COOKIE_CONTROLS_BUBBLE_RELOADING_LABEL 10021
#define IDS_COOKIE_CONTROLS_BUBBLE_THIRD_PARTY_COOKIES_LABEL 10022
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_FORM_PLACEHOLDER 10023
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_ALLOWED_LABEL 10024
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_BLOCKED_LABEL 10025
#define IDS_COOKIE_CONTROLS_PROMO_TITLE 10026
#define IDS_COOKIE_CONTROLS_PROMO_TEXT 10027
#define IDS_COOKIE_CONTROLS_PROMO_CLOSE_BUTTON_TEXT 10028
#define IDS_COOKIE_CONTROLS_PROMO_SEE_HOW_BUTTON_TEXT 10029
#define IDS_JS_OPTIMIZATIONS_DISABLED_ICON_TOOLTIP 10030
#define IDS_JS_OPTIMIZATION_BUBBLE_TITLE 10031
#define IDS_JS_OPTIMIZATION_BUBBLE_POLICY_BODY 10032
#define IDS_JS_OPTIMIZATION_BUBBLE_ENABLE_BUTTON 10033
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_TEXT 10034
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_BUTTON 10035
#define IDS_CERT_SELECTOR_SUBJECT_COLUMN 10036
#define IDS_CERT_SELECTOR_ISSUER_COLUMN 10037
#define IDS_CERT_SELECTOR_PROVIDER_COLUMN 10038
#define IDS_CERT_SELECTOR_SERIAL_COLUMN 10039
#define IDS_CERT_EXPORT_TYPE_BASE64_ALL 10040
#define IDS_CERT_EXPORT_TYPE_BASE64 10041
#define IDS_CERT_EXPORT_TYPE_BASE64_CHAIN 10042
#define IDS_CERT_EXPORT_TYPE_DER 10043
#define IDS_CERT_EXPORT_TYPE_PKCS7 10044
#define IDS_CERT_EXPORT_TYPE_PKCS7_CHAIN 10045
#define IDS_CERT_INFO_DIALOG_TITLE 10046
#define IDS_CERT_INFO_GENERAL_TAB_LABEL 10047
#define IDS_CERT_INFO_DETAILS_TAB_LABEL 10048
#define IDS_CERT_INFO_MODIFICATIONS_TAB_LABEL 10049
#define IDS_CERT_INFO_TRUST_LABEL 10050
#define IDS_CERT_INFO_TRUST_STATE_LABEL 10051
#define IDS_CERT_INFO_TRUST_STATE_DISTRUSTED 10052
#define IDS_CERT_INFO_TRUST_STATE_HINT 10053
#define IDS_CERT_INFO_TRUST_STATE_TRUSTED 10054
#define IDS_CERT_INFO_CONSTRAINTS_LABEL 10055
#define IDS_CERT_INFO_ADD_CONSTRAINTS_LABEL 10056
#define IDS_CERT_INFO_ADD_CONSTRAINTS_BUTTON_LABEL 10057
#define IDS_CERT_INFO_ADD_CONSTRAINTS_PLACEHOLDER 10058
#define IDS_CERT_INFO_ADD_CONSTRAINT_ERROR_MESSAGE 10059
#define IDS_CERT_INFO_DELETE_CONSTRAINT_ERROR_MESSAGE 10060
#define IDS_CERT_INFO_TRUST_STATE_ERROR_MESSAGE 10061
#define IDS_CERT_USAGE_SSL_CLIENT 10062
#define IDS_CERT_USAGE_SSL_SERVER 10063
#define IDS_CERT_USAGE_OBJECT_SIGNER 10064
#define IDS_CERT_USAGE_SSL_CA 10065
#define IDS_CERT_INFO_IDN_VALUE_FORMAT 10066
#define IDS_CERT_INFO_FIELD_NOT_PRESENT 10067
#define IDS_CERT_DETAILS_CERTIFICATE_HIERARCHY_LABEL 10068
#define IDS_CERT_DETAILS_CERTIFICATE_FIELDS_LABEL 10069
#define IDS_CERT_DETAILS_CERTIFICATE_FIELD_VALUE_LABEL 10070
#define IDS_CERT_DETAILS_CERTIFICATE 10071
#define IDS_CERT_DETAILS_VERSION_FORMAT 10072
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_ALG 10073
#define IDS_CERT_DETAILS_SUBJECT_KEY_ALG 10074
#define IDS_CERT_DETAILS_SUBJECT_KEY 10075
#define IDS_CERT_RSA_PUBLIC_KEY_DUMP_FORMAT 10076
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_VALUE 10077
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE 10078
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE_A11Y_LABEL 10079
#define IDS_CERT_OID_AVA_COMMON_NAME 10080
#define IDS_CERT_OID_AVA_STATE_OR_PROVINCE 10081
#define IDS_CERT_OID_AVA_ORGANIZATION_NAME 10082
#define IDS_CERT_OID_AVA_ORGANIZATIONAL_UNIT_NAME 10083
#define IDS_CERT_OID_AVA_DN_QUALIFIER 10084
#define IDS_CERT_OID_AVA_COUNTRY_NAME 10085
#define IDS_CERT_OID_AVA_SERIAL_NUMBER 10086
#define IDS_CERT_OID_AVA_LOCALITY 10087
#define IDS_CERT_OID_AVA_DC 10088
#define IDS_CERT_OID_RFC1274_MAIL 10089
#define IDS_CERT_OID_RFC1274_UID 10090
#define IDS_CERT_OID_PKCS9_EMAIL_ADDRESS 10091
#define IDS_CERT_OID_BUSINESS_CATEGORY 10092
#define IDS_CERT_OID_EV_INCORPORATION_LOCALITY 10093
#define IDS_CERT_OID_EV_INCORPORATION_STATE 10094
#define IDS_CERT_OID_EV_INCORPORATION_COUNTRY 10095
#define IDS_CERT_OID_AVA_STREET_ADDRESS 10096
#define IDS_CERT_OID_AVA_POSTAL_CODE 10097
#define IDS_CERT_EXT_NS_CERT_TYPE 10098
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL 10099
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL_CA 10100
#define IDS_CERT_EXT_NS_CERT_BASE_URL 10101
#define IDS_CERT_EXT_NS_CERT_REVOCATION_URL 10102
#define IDS_CERT_EXT_NS_CA_REVOCATION_URL 10103
#define IDS_CERT_EXT_NS_CERT_RENEWAL_URL 10104
#define IDS_CERT_EXT_NS_CA_POLICY_URL 10105
#define IDS_CERT_EXT_NS_SSL_SERVER_NAME 10106
#define IDS_CERT_EXT_NS_COMMENT 10107
#define IDS_CERT_EXT_NS_LOST_PASSWORD_URL 10108
#define IDS_CERT_EXT_NS_CERT_RENEWAL_TIME 10109
#define IDS_CERT_X509_SUBJECT_DIRECTORY_ATTR 10110
#define IDS_CERT_KEYID_FORMAT 10111
#define IDS_CERT_ISSUER_FORMAT 10112
#define IDS_CERT_SERIAL_NUMBER_FORMAT 10113
#define IDS_CERT_X509_NAME_CONSTRAINTS 10114
#define IDS_CERT_X509_POLICY_MAPPINGS 10115
#define IDS_CERT_X509_POLICY_CONSTRAINTS 10116
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_CA 10117
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_NOT_CA 10118
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN 10119
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN_UNLIMITED 10120
#define IDS_CERT_REVOCATION_REASON_UNUSED 10121
#define IDS_CERT_REVOCATION_REASON_KEY_COMPROMISE 10122
#define IDS_CERT_REVOCATION_REASON_CA_COMPROMISE 10123
#define IDS_CERT_REVOCATION_REASON_AFFILIATION_CHANGED 10124
#define IDS_CERT_REVOCATION_REASON_SUPERSEDED 10125
#define IDS_CERT_REVOCATION_REASON_CESSATION_OF_OPERATION 10126
#define IDS_CERT_REVOCATION_REASON_CERTIFICATE_HOLD 10127
#define IDS_CERT_OCSP_RESPONDER_FORMAT 10128
#define IDS_CERT_CA_ISSUERS_FORMAT 10129
#define IDS_CERT_UNKNOWN_OID_INFO_FORMAT 10130
#define IDS_CERT_EXT_KEY_USAGE_FORMAT 10131
#define IDS_CERT_MULTILINE_INFO_START_FORMAT 10132
#define IDS_CERT_EXT_MS_APP_POLICIES 10133
#define IDS_CERT_EXT_MS_CERT_TEMPLATE 10134
#define IDS_CERT_EXT_MS_CERT_TYPE 10135
#define IDS_CERT_EXT_MS_CA_VERSION 10136
#define IDS_CERT_EXT_MS_NT_PRINCIPAL_NAME 10137
#define IDS_CERT_EXT_MS_NTDS_REPLICATION 10138
#define IDS_CERT_POLICY_ETSI_QEVCP_W 10139
#define IDS_CERT_POLICY_ETSI_QNCP_W 10140
#define IDS_CERT_EKU_MS_INDIVIDUAL_CODE_SIGNING 10141
#define IDS_CERT_EKU_MS_COMMERCIAL_CODE_SIGNING 10142
#define IDS_CERT_EKU_MS_TRUST_LIST_SIGNING 10143
#define IDS_CERT_EKU_MS_TIME_STAMPING 10144
#define IDS_CERT_EKU_MS_SERVER_GATED_CRYPTO 10145
#define IDS_CERT_EKU_MS_ENCRYPTING_FILE_SYSTEM 10146
#define IDS_CERT_EKU_MS_FILE_RECOVERY 10147
#define IDS_CERT_EKU_MS_WINDOWS_HARDWARE_DRIVER_VERIFICATION 10148
#define IDS_CERT_EKU_MS_QUALIFIED_SUBORDINATION 10149
#define IDS_CERT_EKU_MS_KEY_RECOVERY 10150
#define IDS_CERT_EKU_MS_DOCUMENT_SIGNING 10151
#define IDS_CERT_EKU_MS_LIFETIME_SIGNING 10152
#define IDS_CERT_EKU_MS_SMART_CARD_LOGON 10153
#define IDS_CERT_EKU_MS_KEY_RECOVERY_AGENT 10154
#define IDS_CERT_EKU_NETSCAPE_INTERNATIONAL_STEP_UP 10155
#define IDS_CERT_DUMP_ERROR 10156
#define IDS_CERT_EXTENSION_DUMP_ERROR 10157
#define IDS_CERTIFICATE_MANAGER_TITLE 10158
#define IDS_CERT_MANAGER_HARDWARE_BACKED_KEY_FORMAT 10159
#define IDS_CERT_MANAGER_HARDWARE_BACKED 10160
#define IDS_CERT_MANAGER_EXTENSION_PROVIDED_FORMAT 10161
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR 10162
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_LEARN_MORE 10163
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_OPT_OUT 10164
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_RESTART_NEEDED 10165
#define IDS_DEV_TOOLS_INFOBAR_LABEL 10166
#define IDS_DEV_TOOLS_CONFIRM_ADD_FILE_SYSTEM_MESSAGE 10167
#define IDS_DEV_TOOLS_EDIT_DIRECTORY_PERMISSION_TITLE 10168
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_TITLE 10169
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_1 10170
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_2 10171
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_ALLOW_TEXT 10172
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_DISABLE_TEXT 10173
#define IDS_DEV_TOOLS_CONFIRM_ALLOW_BUTTON 10174
#define IDS_DEV_TOOLS_CONFIRM_DENY_BUTTON 10175
#define IDS_RELOAD_MENU_NORMAL_RELOAD_ITEM 10176
#define IDS_RELOAD_MENU_HARD_RELOAD_ITEM 10177
#define IDS_RELOAD_MENU_EMPTY_AND_HARD_RELOAD_ITEM 10178
#define IDS_TAB_SHARING_INFOBAR_SHARING_CURRENT_TAB_LABEL 10179
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_UNTITLED_TAB_LABEL 10180
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_LABEL 10181
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_TO_THIS_TAB_LABEL 10182
#define IDS_TAB_SHARING_INFOBAR_SHARE_BUTTON 10183
#define IDS_TAB_SHARING_INFOBAR_STOP_BUTTON 10184
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_BUTTON 10185
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURER_BUTTON 10186
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURED_BUTTON 10187
#define IDS_TAB_SHARING_INFOBAR_CAPTURED_SURFACE_CONTROL_PERMISSION_BUTTON 10188
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_LABEL 10189
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_NO_DEVICE_NAME_LABEL 10190
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_LABEL 10191
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_NO_DEVICE_NAME_LABEL 10192
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_LABEL 10193
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_NO_DEVICE_NAME_LABEL 10194
#define IDS_TAB_CASTING_INFOBAR_CAST_BUTTON 10195
#define IDS_TAB_CASTING_INFOBAR_STOP_BUTTON 10196
#define IDS_TASK_MANAGER_KILL 10197
#define IDS_TASK_MANAGER_KILL_V2 10198
#define IDS_TASK_MANAGER_PROCESS_ID_COLUMN 10199
#define IDS_TASK_MANAGER_GDI_HANDLES_COLUMN 10200
#define IDS_TASK_MANAGER_USER_HANDLES_COLUMN 10201
#define IDS_TASK_MANAGER_TASK_COLUMN 10202
#define IDS_TASK_MANAGER_NET_COLUMN 10203
#define IDS_TASK_MANAGER_CPU_COLUMN 10204
#define IDS_TASK_MANAGER_START_TIME_COLUMN 10205
#define IDS_TASK_MANAGER_CPU_TIME_COLUMN 10206
#define IDS_TASK_MANAGER_MEM_FOOTPRINT_COLUMN 10207
#define IDS_TASK_MANAGER_SWAPPED_MEM_COLUMN 10208
#define IDS_TASK_MANAGER_PROFILE_NAME_COLUMN 10209
#define IDS_TASK_MANAGER_IDLE_WAKEUPS_COLUMN 10210
#define IDS_TASK_MANAGER_HARD_FAULTS_COLUMN 10211
#define IDS_TASK_MANAGER_OPEN_FD_COUNT_COLUMN 10212
#define IDS_TASK_MANAGER_PROCESS_PRIORITY_COLUMN 10213
#define IDS_TASK_MANAGER_WEBCORE_IMAGE_CACHE_COLUMN 10214
#define IDS_TASK_MANAGER_WEBCORE_SCRIPTS_CACHE_COLUMN 10215
#define IDS_TASK_MANAGER_WEBCORE_CSS_CACHE_COLUMN 10216
#define IDS_TASK_MANAGER_VIDEO_MEMORY_COLUMN 10217
#define IDS_TASK_MANAGER_SQLITE_MEMORY_USED_COLUMN 10218
#define IDS_TASK_MANAGER_JAVASCRIPT_MEMORY_ALLOCATED_COLUMN 10219
#define IDS_TASK_MANAGER_KEEPALIVE_COUNT_COLUMN 10220
#define IDS_TASK_MANAGER_MEM_CELL_TEXT 10221
#define IDS_TASK_MANAGER_CACHE_SIZE_CELL_TEXT 10222
#define IDS_TASK_MANAGER_NA_CELL_TEXT 10223
#define IDS_TASK_MANAGER_BACKGROUNDED_TEXT 10224
#define IDS_TASK_MANAGER_FOREGROUNDED_TEXT 10225
#define IDS_TASK_MANAGER_HANDLES_CELL_TEXT 10226
#define IDS_TASK_MANAGER_TASK_GROUP_CONNECT_TEXT 10227
#define IDS_TASK_MANAGER_WEB_BROWSER_CELL_TEXT 10228
#define IDS_TASK_MANAGER_EXTENSION_PREFIX 10229
#define IDS_TASK_MANAGER_EXTENSION_INCOGNITO_PREFIX 10230
#define IDS_TASK_MANAGER_APP_PREFIX 10231
#define IDS_TASK_MANAGER_APP_INCOGNITO_PREFIX 10232
#define IDS_TASK_MANAGER_TAB_PREFIX 10233
#define IDS_TASK_MANAGER_TAB_INCOGNITO_PREFIX 10234
#define IDS_TASK_MANAGER_BACKGROUND_APP_PREFIX 10235
#define IDS_TASK_MANAGER_BACKGROUND_PREFIX 10236
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_PREFIX 10237
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_PREFIX 10238
#define IDS_TASK_MANAGER_PRELOADED_RENDERER_FOR_UI 10239
#define IDS_TASK_MANAGER_NO_STATE_PREFETCH_PREFIX 10240
#define IDS_TASK_MANAGER_PRERENDER_PREFIX 10241
#define IDS_TASK_MANAGER_SPARE_RENDERER_PREFIX 10242
#define IDS_TASK_MANAGER_UNKNOWN_RENDERER_PREFIX 10243
#define IDS_TASK_MANAGER_DEDICATED_WORKER_PREFIX 10244
#define IDS_TASK_MANAGER_SHARED_WORKER_PREFIX 10245
#define IDS_TASK_MANAGER_SERVICE_WORKER_PREFIX 10246
#define IDS_TASK_MANAGER_UTILITY_PREFIX 10247
#define IDS_TASK_MANAGER_GPU_PREFIX 10248
#define IDS_TASK_MANAGER_PRINT_PREFIX 10249
#define IDS_TASK_MANAGER_SUBFRAME_PREFIX 10250
#define IDS_TASK_MANAGER_SUBFRAME_INCOGNITO_PREFIX 10251
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_SUBFRAME_PREFIX 10252
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_SUBFRAME_PREFIX 10253
#define IDS_TASK_MANAGER_PDF_SUBFRAME_PREFIX 10254
#define IDS_TASK_MANAGER_PDF_SUBFRAME_INCOGNITO_PREFIX 10255
#define IDS_TASK_MANAGER_PORTAL_PREFIX 10256
#define IDS_TASK_MANAGER_PORTAL_INCOGNITO_PREFIX 10257
#define IDS_TASK_MANAGER_FENCED_FRAME_PREFIX 10258
#define IDS_TASK_MANAGER_FENCED_FRAME_INCOGNITO_PREFIX 10259
#define IDS_TASK_MANAGER_ARC_PREFIX 10260
#define IDS_TASK_MANAGER_TOOL_PREFIX 10261
#define IDS_TASK_MANAGER_ARC_PREFIX_BACKGROUND_SERVICE 10262
#define IDS_TASK_MANAGER_ARC_PREFIX_RECEIVER 10263
#define IDS_TASK_MANAGER_ARC_SYSTEM 10264
#define IDS_TASK_MANAGER_LINUX_VM_PREFIX 10265
#define IDS_TASK_MANAGER_PLUGIN_VM_PREFIX 10266
#define IDS_TASK_MANAGER_OMNIBOX 10267
#define IDS_UTILITY_PROCESS_FILE_UTILITY_NAME 10268
#define IDS_UTILITY_PROCESS_PROFILE_IMPORTER_NAME 10269
#define IDS_UTILITY_PROCESS_QRCODE_GENERATOR_SERVICE_NAME 10270
#define IDS_UTILITY_PROCESS_IMAGE_WRITER_NAME 10272
#define IDS_UTILITY_PROCESS_MEDIA_GALLERY_UTILITY_NAME 10273
#define IDS_UTILITY_PROCESS_NOOP_SERVICE_NAME 10274
#define IDS_SERVICE_PROCESS_DOCUMENT_ANALYSIS_NAME 10275
#define IDS_THEME_INSTALL_INFOBAR_LABEL 10276
#define IDS_THEME_INSTALL_INFOBAR_UNDO_BUTTON 10277
#define IDS_CRITICAL_NOTIFICATION_RESTART 10278
#define IDS_EXTENSION_DISABLED_ERROR_LABEL 10279
#define IDS_EXTENSION_DISABLED_REMOTE_INSTALL_ERROR_TITLE 10280
#define IDS_EXTENSION_DISABLED_ERROR_TITLE 10281
#define IDS_EXTENSION_SITE_RELOAD_PAGE_BUBBLE_HEADING 10282
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_OK_BUTTON 10283
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_SINGLE_EXTENSION_TITLE 10284
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_MULTIPLE_EXTENSIONS_TITLE 10285
#define IDS_APP_UNINSTALL_PROMPT_TITLE 10286
#define IDS_ARC_APP_UNINSTALL_PROMPT_DATA_REMOVAL_WARNING 10287
#define IDS_EXTENSION_UNINSTALL_PROMPT_TITLE 10288
#define IDS_EXTENSION_CONFIRM_PERMISSIONS 10289
#define IDS_EXTENSION_INSTALL_PROMPT_TITLE 10290
#define IDS_EXTENSION_REQUEST_PROMPT_TITLE 10291
#define IDS_EXTENSION_PENDING_REQUEST_PROMPT_TITLE 10292
#define IDS_EXTENSION_BLOCKED_BY_POLICY_PROMPT_TITLE 10293
#define IDS_EXTENSION_RE_ENABLE_PROMPT_TITLE 10294
#define IDS_EXTENSION_PERMISSIONS_PROMPT_TITLE 10295
#define IDS_EXTENSION_REMOTE_INSTALL_PROMPT_TITLE 10296
#define IDS_EXTENSION_REPAIR_PROMPT_TITLE 10297
#define IDS_EXTENSION_ASK_PARENT_PROMPT_TITLE 10298
#define IDS_EXTENSION_ASK_PARENT_PROMPT_BODY 10299
#define IDS_EXTENSION_ASK_PARENT_PROMPT_ASK_IN_PERSON_BUTTON 10300
#define IDS_EXTENSION_PARENT_APPROVAL_PROMPT_TITLE 10301
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 10302
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_APP 10303
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 10304
#define IDS_EXTENSION_ALERT_TITLE 10305
#define IDS_APP_ALERT_TITLE 10306
#define IDS_EXTENSION_AND_APP_ALERT_TITLE 10307
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_TITLE 10308
#define IDS_POLICY_BLOCKED_EXTENSIONS_ALERT_ITEM_TITLE 10309
#define IDS_BLOCKLISTED_EXTENSIONS_ALERT_ITEM 10310
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_ITEM_DETAIL 10311
#define IDS_EXTENSION_ALERT_ITEM_OK 10312
#define IDS_EXTENSION_ALERT_ITEM_DETAILS 10313
#define IDS_EXTENSION_PROMPT_APP_CONNECT_FROM_INCOGNITO 10314
#define IDS_EXTENSION_PROMPT_EXTENSION_CONNECT_FROM_INCOGNITO 10315
#define IDS_EXTENSION_PROMPT_WILL_HAVE_ACCESS_TO 10316
#define IDS_EXTENSION_PROMPT_WILL_NOW_HAVE_ACCESS_TO 10317
#define IDS_EXTENSION_PROMPT_WANTS_ACCESS_TO 10318
#define IDS_EXTENSION_PROMPT_CAN_ACCESS 10319
#define IDS_EXTENSION_PROMPT_REQUESTS_PERMISSIONS 10320
#define IDS_EXTENSION_PROMPT_GRANT_PERMISSIONS_CHECKBOX 10321
#define IDS_EXTENSION_PERMISSION_LINE 10322
#define IDS_EXTENSION_RATING_COUNT 10323
#define IDS_EXTENSION_PROMPT_RATING_ACCESSIBLE_TEXT 10324
#define IDS_EXTENSION_PROMPT_NO_RATINGS_ACCESSIBLE_TEXT 10325
#define IDS_EXTENSION_USER_COUNT 10326
#define IDS_EXTENSION_PROMPT_STORE_LINK 10327
#define IDS_EXTENSION_PROMPT_WARNING_FULL_ACCESS 10328
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS 10329
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS_READ_ONLY 10330
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_CAPTURE 10331
#define IDS_EXTENSION_PROMPT_WARNING_VIDEO_CAPTURE 10332
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_AND_VIDEO_CAPTURE 10333
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH 10334
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_DEVICES 10335
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_PRIVATE 10336
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_SERIAL 10337
#define IDS_EXTENSION_PROMPT_WARNING_BOOKMARKS 10338
#define IDS_EXTENSION_PROMPT_WARNING_READING_LIST 10339
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD 10340
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_READWRITE 10341
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_WRITE 10342
#define IDS_EXTENSION_PROMPT_WARNING_DEBUGGER 10343
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_WEB_REQUEST 10344
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_NET_REQUEST 10345
#define IDS_EXTENSION_PROMPT_WARNING_DOCUMENT_SCAN 10346
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_HARDWARE_PLATFORM 10347
#define IDS_EXTENSION_PROMPT_WARNING_FAVICON 10348
#define IDS_EXTENSION_PROMPT_WARNING_GEOLOCATION 10349
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ 10350
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ_ON_ALL_DEVICES 10351
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_WRITE_ON_ALL_DEVICES 10352
#define IDS_EXTENSION_PROMPT_WARNING_HOME_PAGE_SETTING_OVERRIDE 10353
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST 10354
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST_READ_ONLY 10355
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS 10356
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS_READ_ONLY 10357
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS 10358
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS_READ_ONLY 10359
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST 10360
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST_READ_ONLY 10361
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN 10362
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN_LIST 10363
#define IDS_EXTENSION_PROMPT_WARNING_INPUT 10364
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN 10365
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_LOGIN 10366
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_UI 10367
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_STORAGE 10368
#define IDS_EXTENSION_PROMPT_WARNING_MANAGEMENT 10369
#define IDS_EXTENSION_PROMPT_WARNING_MDNS 10370
#define IDS_EXTENSION_PROMPT_WARNING_NETWORK_STATE 10371
#define IDS_EXTENSION_PROMPT_WARNING_NETWORKING_PRIVATE 10372
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING 10373
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING_METRICS 10374
#define IDS_EXTENSION_PROMPT_WARNING_SEARCH_SETTINGS_OVERRIDE 10375
#define IDS_EXTENSION_PROMPT_WARNING_SERIAL 10376
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_ANY_HOST 10377
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAIN 10378
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAINS 10379
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOST 10380
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOSTS 10381
#define IDS_EXTENSION_PROMPT_WARNING_SPEECH_RECOGNITION 10382
#define IDS_EXTENSION_PROMPT_WARNING_START_PAGE_SETTING_OVERRIDE 10383
#define IDS_EXTENSION_PROMPT_WARNING_SYSTEM_STORAGE 10384
#define IDS_EXTENSION_PROMPT_WARNING_TAB_GROUPS 10385
#define IDS_EXTENSION_PROMPT_WARNING_TOPSITES 10386
#define IDS_EXTENSION_PROMPT_WARNING_TTS_ENGINE 10387
#define IDS_EXTENSION_PROMPT_WARNING_U2F_DEVICES 10388
#define IDS_EXTENSION_PROMPT_WARNING_NOTIFICATIONS 10389
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE 10390
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST 10391
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_PRODUCT 10392
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_VENDOR 10393
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_PRODUCT 10394
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_VENDOR 10395
#define IDS_EXTENSION_PROMPT_WARNING_VPN 10396
#define IDS_EXTENSION_PROMPT_WARNING_CONTENT_SETTINGS 10397
#define IDS_EXTENSION_PROMPT_WARNING_PRIVACY 10398
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS 10399
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS_OPEN 10400
#define IDS_EXTENSION_PROMPT_WARNING_IDENTITY_EMAIL 10401
#define IDS_EXTENSION_PROMPT_WARNING_WALLPAPER 10402
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_DIRECTORY 10403
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_WRITE_DIRECTORY 10404
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ 10405
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE 10406
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_DELETE 10407
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE_DELETE 10408
#define IDS_EXTENSION_PROMPT_WARNING_SYNCFILESYSTEM 10409
#define IDS_EXTENSION_PROMPT_WARNING_NATIVE_MESSAGING 10410
#define IDS_EXTENSION_PROMPT_WARNING_SCREENLOCK_PRIVATE 10411
#define IDS_EXTENSION_PROMPT_WARNING_ACTIVITY_LOG_PRIVATE 10412
#define IDS_EXTENSION_PROMPT_WARNING_DESKTOP_CAPTURE 10413
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_MODIFY 10414
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ 10415
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ_MODIFY 10416
#define IDS_EXTENSION_PROMPT_WARNING_PLATFORMKEYS 10417
#define IDS_EXTENSION_PROMPT_WARNING_CERTIFICATEPROVIDER 10418
#define IDS_EXTENSION_PROMPT_WARNING_SETTINGS_PRIVATE 10419
#define IDS_EXTENSION_PROMPT_WARNING_AUTOFILL_PRIVATE 10420
#define IDS_EXTENSION_PROMPT_WARNING_PASSWORDS_PRIVATE 10421
#define IDS_EXTENSION_PROMPT_WARNING_USERS_PRIVATE 10422
#define IDS_EXTENSION_PROMPT_WARNING_NEW_TAB_PAGE_OVERRIDE 10423
#define IDS_EXTENSION_PROMPT_WARNING_TRANSIENT_BACKGROUND 10424
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_DEVICE_ATTRIBUTES 10425
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_KIOSK_INPUT 10426
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_NETWORKING_ATTRIBUTES 10427
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_PLATFORMKEYS 10428
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE_ENABLED_LINUX_AND_MACOS 10430
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE 10431
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REMOTE_APPS 10432
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_ATTACHED_DEVICE_INFO 10433
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_BLUETOOTH_PERIPHERALS_INFO 10434
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS 10435
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS_NETWORK_INFO_FOR_MLAB 10436
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_EVENTS 10437
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_MANAGEMENT_AUDIO 10438
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY 10439
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_SERIAL_NUMBER 10440
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_NETWORK_INFORMATION 10441
#define IDS_EXTENSION_PROMPT_WARNING_OMNIBOX_DIRECT_INPUT 10442
#define IDS_EXTENSION_INVALID_IMAGE_PATH 10445
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_2 10447
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO 10449
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO_WITH_SHORTCUT 10450
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO 10451
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO_WITH_SHORTCUT 10452
#define IDS_EXTENSION_INSTALLED_OMNIBOX_KEYWORD_INFO 10453
#define IDS_EXTENSION_INSTALLED_MANAGE_INFO 10454
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS 10456
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS_LINK_TEXT 10457
#define IDS_EXTENSION_LAUNCH_WEB_AUTH_FLOW_TAB_INFO_BAR_TEXT 10458
#define IDS_EXTENSION_INSTALLED_DICE_PROMO_SYNC_MESSAGE 10459
#define IDS_EXTENSION_VERIFY_PROMO_SUBTITLE 10460
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_TITLE 10461
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_READ_ONLY 10462
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_WRITABLE 10463
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_TITLE_LABEL 10464
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_ADDRESS_LABEL 10465
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_PORT_LABEL 10466
#define IDS_EXTENSIONS_WANTS_ACCESS_TO_SITE 10467
#define IDS_EXTENSIONS_HAS_ACCESS_TO_SITE 10468
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_SINGLE_EXTENSION 10469
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_HAS_ACCESS 10470
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_BLOCKED_ACCESS 10471
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_REQUESTS_ACCESS 10472
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_ALLOWED_ACCESS 10473
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_BLOCKED_ACCESS 10474
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_HAS_ACCESS 10475
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_REQUESTS_ACCESS 10476
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_PINNED_TEXT 10477
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_INSTALLED_TEXT 10478
#define IDS_EXTENSIONS_CONTEXT_MENU_SITE_PERMISSIONS 10479
#define IDS_EXTENSIONS_CONTEXT_MENU_CANT_ACCESS_PAGE 10480
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS 10481
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_GRANTED 10482
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_BLOCKED 10483
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK_V2 10484
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE_V2 10485
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES_V2 10486
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_PERMISSIONS_PAGE 10487
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK 10488
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE 10489
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES 10490
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_LEARN_MORE 10491
#define IDS_EXTENSIONS_CONTEXT_MENU_PIN_TO_TOOLBAR 10492
#define IDS_EXTENSIONS_CONTEXT_MENU_UNPIN_FROM_TOOLBAR 10493
#define IDS_EXTENSIONS_OPTIONS_MENU_ITEM 10494
#define IDS_EXTENSIONS_INSTALLED_BY_ADMIN 10495
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR 10496
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR 10497
#define IDS_EXTENSIONS_PINNED_BY_ADMIN 10498
#define IDS_MANAGE_EXTENSION 10499
#define IDS_MANAGE_EXTENSIONS 10500
#define IDS_VIEW_WEB_PERMISSIONS 10501
#define IDS_EXTENSION_ACTION_INSPECT_POPUP 10502
#define IDS_EXTENSIONS_DISABLE 10503
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR_ACCESSIBLE_NAME 10504
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR_ACCESSIBLE_NAME 10505
#define IDS_EXTENSIONS_PINNED_BY_ADMIN_ACCESSIBLE_NAME 10506
#define IDS_EXTENSIONS_SUBMENU_OPEN_SIDE_PANEL_ITEM 10507
#define IDS_EXTENSIONS_SUBMENU_CLOSE_SIDE_PANEL_ITEM 10508
#define IDS_EXTENSIONS_LOCKED_SUPERVISED_USER 10512
#define IDS_EXTENSION_LOAD_FROM_DIRECTORY 10513
#define IDS_EXTENSION_COMMANDS_GENERIC_ACTIVATE 10514
#define IDS_EXTENSION_PACK_DIALOG_HEADING 10515
#define IDS_EXTENSION_PACK_DIALOG_SELECT_KEY 10516
#define IDS_EXTENSION_PACK_DIALOG_KEY_FILE_TYPE_DESCRIPTION 10517
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_REQUIRED 10518
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_INVALID 10519
#define IDS_EXTENSION_PACK_DIALOG_ERROR_KEY_INVALID 10520
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_NEW 10521
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_UPDATE 10522
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_CONTINUE_BUTTON 10523
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_TITLE 10524
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_WARNING_TEXT 10525
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 10526
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_APP 10527
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 10528
#define IDS_EXTENSION_INSTALL_PROMPT_ASK_A_PARENT_BUTTON 10529
#define IDS_EXTENSION_INSTALL_BLOCKED_BY_PARENT_PROMPT_TITLE 10530
#define IDS_EXTENSION_ENABLE_BLOCKED_BY_PARENT_PROMPT_TITLE 10531
#define IDS_PARENT_PERMISSION_PROMPT_GO_GET_A_PARENT_FOR_EXTENSION_LABEL 10532
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_EXTENSION 10533
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_APP 10534
#define IDS_PARENT_PERMISSION_PROMPT_CHILD_WANTS_TO_INSTALL_LABEL 10535
#define IDS_PARENT_PERMISSION_PROMPT_APPROVE_BUTTON 10536
#define IDS_PARENT_PERMISSION_PROMPT_CANCEL_BUTTON 10537
#define IDS_PARENT_PERMISSION_PROMPT_SELECT_PARENT_LABEL 10538
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_LABEL 10539
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_VERIFY_LABEL 10540
#define IDS_PARENT_PROMPT_ENTER_PASSWORD_TO_ALLOW_EXTENSION_LABEL 10541
#define IDS_SKIP_PARENT_PERMISSION_EXTENSION_INFORMATION 10542
#define IDS_PARENT_PERMISSION_PROMPT_ENTER_PASSWORD_LABEL 10543
#define IDS_PARENT_PERMISSION_PROMPT_PASSWORD_INCORRECT_LABEL 10544
#define IDS_EXTENSION_INSTALL_PROMPT_REQUEST_BUTTON 10545
#define IDS_EXTENSION_PROMPT_UNINSTALL_BUTTON 10546
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE 10547
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE_FROM_EXTENSION 10548
#define IDS_EXTENSION_PROMPT_UNINSTALL_TITLE 10549
#define IDS_EXTENSION_PROMPT_UNINSTALL_APP_BUTTON 10550
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_NAME_BULLET_POINT 10551
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_TITLE 10552
#define IDS_EXTENSION_PROMPT_UNINSTALL_TRIGGERED_BY_EXTENSION 10553
#define IDS_EXTENSION_PROMPT_RE_ENABLE_BUTTON 10554
#define IDS_EXTENSION_PROMPT_PERMISSIONS_BUTTON 10555
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ACCEPT_BUTTON 10556
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ABORT_BUTTON 10557
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_EXTENSION 10558
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_APP 10559
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_EXTENSION 10560
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_APP 10561
#define IDS_EXTENSION_WEB_STORE_TITLE_SHORT 10562
#define IDS_EXTENSIONS_SHOW_DETAILS 10563
#define IDS_EXTENSIONS_HIDE_DETAILS 10564
#define IDS_EXTENSION_WARNINGS_WRENCH_MENU_ITEM 10565
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_EXTENSION 10566
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_APP 10567
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_THEME 10568
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_TITLE 10569
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_APP 10570
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_EXTENSION 10571
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_THEME 10572
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE 10573
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE_LEARN_MORE 10574
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_CHANGE_IT_BACK 10575
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_KEEP_IT 10576
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_GENERIC 10577
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 10578
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_BODY_GENERIC 10579
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_GENERIC 10580
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 10581
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_OTHER 10582
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_EXPLICIT_CHOICE 10583
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_GENERIC 10584
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_EXPLICIT_CHOICE 10585
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_RECENT_CHANGE 10586
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_PREVIOUS_CHOICE 10587
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_DEFAULT_SEARCH_ENGINE 10588
#define IDS_FORCE_INSTALLED_DEPRECATED_APPS_CONTENT 10589
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_TITLE 10590
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_CONTENT 10591
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_GO_TO_SITE_BUTTON 10592
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_PLURAL 10593
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_WITH_APP_NAME 10594
#define IDS_DEPRECATED_APPS_MONITOR_RENDERER 10595
#define IDS_DEPRECATED_APPS_LEARN_MORE 10596
#define IDS_DEPRECATED_APPS_LEARN_MORE_AX_LABEL 10597
#define IDS_DEPRECATED_APPS_DELETION_LINK 10598
#define IDS_DEPRECATED_APPS_OK_LABEL 10599
#define IDS_DEPRECATED_APPS_CANCEL_LABEL 10600
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON 10601
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_ACCESSIBLE_NAME 10602
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_DISMISSED_TEXT 10603
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_MULTIPLE_EXTENSIONS 10604
#define IDS_EXTENSIONS_MENU_TITLE 10605
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP 10606
#define IDS_EXTENSIONS_MENU_ZERO_STATE_HEADER 10607
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP_ACCESSIBLE_NAME 10608
#define IDS_EXTENSIONS_MENU_PIN_BUTTON_TOOLTIP 10609
#define IDS_EXTENSIONS_MENU_UNPIN_BUTTON_TOOLTIP 10610
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA_SHORT 10611
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA 10612
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA_SHORT 10613
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA 10614
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA_SHORT 10615
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA 10616
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_LABEL 10617
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_NOT_ALLOWED_LABEL 10618
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ON_TOOLTIP 10619
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_OFF_TOOLTIP 10620
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ACCESSIBLE_NAME 10621
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_ENTERPRISE_TOOLTIP_ICON_TEXT 10622
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_DESCRIPTION_TEXT 10623
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TEXT 10624
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TOOLTIP 10625
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_TITLE 10626
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TEXT 10627
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TOOLTIP 10628
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_ACCESSIBLE_NAME 10629
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TEXT 10630
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TOOLTIP 10631
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_ACCESSIBLE_NAME 10632
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ON_TOOLTIP 10633
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_OFF_TOOLTIP 10634
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ACCESSIBLE_NAME 10635
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_TOOLTIP 10636
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_ACCESSIBLE_NAME 10637
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_PINNED_ACCESSIBLE_NAME 10638
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_NONE 10639
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_DISCOVER_EXTENSIONS 10640
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_TOOLTIP 10641
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_TOOLTIP 10642
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 10643
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 10644
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_HAS_ACCESS_TOOLTIP 10645
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_BLOCKED_ACCESS_TOOLTIP 10646
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_REQUESTS_TOOLTIP 10647
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_CLICK 10648
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_SITE 10649
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_ALL_SITES 10650
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON 10651
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON_TOOLTIP 10652
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_LABEL 10653
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_ON 10654
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_OFF 10655
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_LABEL 10656
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_TEXT 10657
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_TEXT 10658
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_TEXT 10659
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_DESCRIPTION 10660
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_DESCRIPTION 10661
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_DESCRIPTION 10662
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_TITLE 10663
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_DESCRIPTION 10664
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_LEARN_MORE_LINK 10665
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_SEARCH_ENGINE 10666
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_TITLE 10667
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_HEADING 10668
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_ALLOW 10669
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_DENY 10670
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_TITLE 10671
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_HEADING 10672
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_ALLOW 10673
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_DENY 10674
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_TITLE 10675
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_HEADING 10676
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_ALLOW 10677
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_DENY 10678
#define IDS_EXTENSIONS_NTP_CONTROLLED_FIRST_LINE 10679
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE 10680
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE_EXTENSION_SPECIFIC 10681
#define IDS_EXTENSIONS_SETTINGS_API_THIRD_LINE_CONFIRMATION 10682
#define IDS_EXTENSION_CONTROLLED_RESTORE_SETTINGS 10683
#define IDS_EXTENSION_CONTROLLED_KEEP_CHANGES 10684
#define IDS_SUB_APPS_INSTALL_DIALOG_TITLE 10685
#define IDS_SUB_APPS_INSTALL_DIALOG_DESCRIPTION 10686
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_DESCRIPTION 10687
#define IDS_SUB_APPS_INSTALL_DIALOG_MANAGE_PERMISSIONS_LINK 10688
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_BUTTON 10689
#define IDS_SUB_APPS_INSTALL_DIALOG_CANCEL_BUTTON 10690
#define IDS_WEB_APP_UNINSTALL_BUTTON_FRAME_TOOLTIP 10691
#define IDS_WEB_APP_UNINSTALL_BUTTON_FRAME 10692
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP 10693
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP_UPDATE_AVAILABLE 10694
#define IDS_WEB_APP_MENU_BUTTON_UPDATE 10695
#define IDS_WEB_APP_BLOCKED_MIGRATION_MESSAGE 10696
#define IDS_WEB_APP_ENABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 10697
#define IDS_WEB_APP_DISABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 10698
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_ENABLED_ALERT 10699
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_DISABLED_ALERT 10700
#define IDS_APP_HOME_TITLE 10701
#define IDS_APP_HOME_OPEN_IN_WINDOW 10702
#define IDS_APP_HOME_LAUNCH_AT_STARTUP 10703
#define IDS_APP_HOME_CREATE_SHORTCUT 10704
#define IDS_APP_HOME_INSTALL_LOCALLY 10705
#define IDS_APP_HOME_UNINSTALL_APP 10706
#define IDS_APP_HOME_REMOVE_APP 10707
#define IDS_APP_HOME_APP_SETTINGS 10708
#define IDS_ACCNAME_APP_HOME_NOT_INSTALLED 10709
#define IDS_APP_HOME_APP_NO_APPS 10710
#define IDS_APP_HOME_APP_LEARN_INSTALL 10711
#define IDS_WEB_APP_SETTINGS_TITLE 10712
#define IDS_WEB_APP_SETTINGS_LINK 10713
#define IDS_WEB_APP_SETTINGS_LINK_TOOLTIP 10714
#define IDS_COMPONENTS_TITLE 10715
#define IDS_COMPONENTS_VERSION 10716
#define IDS_COMPONENTS_NONE_INSTALLED 10717
#define IDS_COMPONENTS_NO_COMPONENTS 10718
#define IDS_COMPONENTS_CHECK_FOR_UPDATE 10719
#define IDS_COMPONENTS_STATUS_LABEL 10720
#define IDS_COMPONENTS_CHECKING_LABEL 10721
#define IDS_COMPONENTS_SVC_STATUS_NEW 10722
#define IDS_COMPONENTS_SVC_STATUS_CHECKING 10723
#define IDS_COMPONENTS_SVC_STATUS_UPDATE 10724
#define IDS_COMPONENTS_SVC_STATUS_DNL 10725
#define IDS_COMPONENTS_SVC_STATUS_DECOMPRESSING 10726
#define IDS_COMPONENTS_SVC_STATUS_PATCHING 10727
#define IDS_COMPONENTS_SVC_STATUS_UPDATING 10728
#define IDS_COMPONENTS_SVC_STATUS_UPDATED 10729
#define IDS_COMPONENTS_SVC_STATUS_UPTODATE 10730
#define IDS_COMPONENTS_SVC_STATUS_UPDATE_ERROR 10731
#define IDS_COMPONENTS_UNKNOWN 10732
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_TITLE 10733
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM 10734
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM_WITHOUT_STRONG 10735
#define IDS_PASSWORD_GENERATION_NUDGE_CANCEL_BUTTON 10736
#define IDS_PASSWORD_MANAGER_CONFIRM_SAVED_TITLE 10737
#define IDS_PASSWORD_MANAGER_CONFIRM_UPDATE_TITLE 10738
#define IDS_PASSWORD_GENERATION_EDITING_SUGGESTION 10739
#define IDS_SAVE_PASSWORD 10740
#define IDS_SAVE_ACCOUNT 10741
#define IDS_ADD_USERNAME_TITLE 10742
#define IDS_ADD_USERNAME 10743
#define IDS_ADD_USERNAME_BODY 10744
#define IDS_UPDATE_PASSWORD 10745
#define IDS_VERIFY_IT_IS_YOU 10746
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_IN 10747
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_UP 10748
#define IDS_PASSWORD_ERROR_VERIFY_BUTTON_TITLE 10749
#define IDS_SAVE_PASSWORD_DIFFERENT_DOMAINS_TITLE 10751
#define IDS_UPDATE_PASSWORD_DIFFERENT_DOMAINS_TITLE 10752
#define IDS_SAVE_PASSWORD_FOOTER 10753
#define IDS_PASSWORD_BUBBLES_PASSWORD_MANAGER_LINK_TEXT_SYNCED_TO_ACCOUNT 10754
#define IDS_PASSWORD_BUBBLES_FOOTER_SYNCED_TO_ACCOUNT 10755
#define IDS_PASSWORD_BUBBLES_FOOTER_TRUSTED_VAULT_ERROR 10756
#define IDS_PASSWORD_BUBBLES_SUBTITLE_TRUSTED_VAULT_ERROR 10757
#define IDS_PASSWORD_BUBBLES_FOOTER_SAVING_ON_DEVICE 10758
#define IDS_PASSWORD_GENERATION_PROMPT_GOOGLE_PASSWORD_MANAGER 10759
#define IDS_PASSWORD_GENERATION_NUDGE_TITLE 10760
#define IDS_PASSWORD_MANAGEMENT_BUBBLE_FOOTER_ACCOUNT_STORE_USERS 10761
#define IDS_PASSWORD_MANAGER_GENERATED_PASSWORD_SAVED_MESSAGE_DESCRIPTION 10762
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 10763
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 10764
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_TITLE 10765
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_DESCRIPTION 10766
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_CONFIRM_BUTTON_LABEL 10767
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_WARNING_DESCRIPTION 10768
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_SIGN_IN 10769
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_BUTTON 10770
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORD_BUTTON 10771
#define IDS_SETTINGS_PASSWORDS_ANDROID_APP 10772
#define IDS_SHARED_PASSWORDS_NOTIFICATION_GOT_IT_BUTTON 10773
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_SINGLE_PASSWORD 10774
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_MULTIPLE_PASSWORD 10775
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TITLE 10776
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_A 10777
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_B 10778
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_C 10779
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_A 10780
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_B 10781
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SIGNIN_MESSAGE 10782
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SYNC_MESSAGE 10783
#define IDS_WEBRTC_LOGS_TITLE 10784
#define IDS_WEBRTC_TEXT_LOGS_LOG_COUNT_BANNER_FORMAT 10785
#define IDS_WEBRTC_EVENT_LOGS_LOG_COUNT_BANNER_FORMAT 10786
#define IDS_WEBRTC_LOGS_LOG_HEADER_FORMAT 10787
#define IDS_WEBRTC_LOGS_LOG_LOCAL_FILE_LABEL_FORMAT 10788
#define IDS_WEBRTC_LOGS_NO_LOCAL_LOG_FILE_MESSAGE 10789
#define IDS_WEBRTC_LOGS_LOG_UPLOAD_TIME_FORMAT 10790
#define IDS_WEBRTC_LOGS_LOG_FAILED_UPLOAD_TIME_FORMAT 10791
#define IDS_WEBRTC_LOGS_LOG_REPORT_ID_FORMAT 10792
#define IDS_WEBRTC_LOGS_BUG_LINK_LABEL 10793
#define IDS_WEBRTC_LOGS_LOG_PENDING_MESSAGE 10794
#define IDS_WEBRTC_LOGS_LOG_ACTIVELY_UPLOADED_MESSAGE 10795
#define IDS_WEBRTC_LOGS_LOG_NOT_UPLOADED_MESSAGE 10796
#define IDS_WEBRTC_LOGS_EVENT_LOG_LOCAL_LOG_ID 10797
#define IDS_WEBRTC_LOGS_NO_TEXT_LOGS_MESSAGE 10798
#define IDS_WEBRTC_LOGS_NO_EVENT_LOGS_MESSAGE 10799
#define IDS_PLUGIN_HIDE 10800
#define IDS_PLUGIN_BLOCKED 10801
#define IDS_PLUGIN_BLOCKED_BY_POLICY 10802
#define IDS_PLUGIN_NOT_AUTHORIZED 10803
#define IDS_PLUGIN_DISABLED 10804
#define IDS_PLUGIN_DEPRECATED 10805
#define IDS_SESSION_CRASHED_BUBBLE_TITLE 10806
#define IDS_SESSION_CRASHED_BUBBLE_UMA_LINK_TEXT 10807
#define IDS_IDLE_BUBBLE_TITLE_CLEAR 10808
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_TITLE 10809
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_MESSAGE 10810
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_BUTTON_LABEL 10811
#define IDS_BAD_FLAGS_WARNING_MESSAGE 10812
#define IDS_BAD_FEATURES_WARNING_MESSAGE 10813
#define IDS_BAD_FLAGS_FROM_FILE_WARNING_MESSAGE 10814
#define IDS_BAD_ENVIRONMENT_VARIABLES_WARNING_MESSAGE 10815
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT_TITLE 10816
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT 10817
#define IDS_ALLOW_INSECURE_CONTENT_BUTTON 10818
#define IDS_ADD_TO_SHELF_INFOBAR_TITLE 10819
#define IDS_ADD_TO_SHELF_INFOBAR_ADD_BUTTON 10820
#define IDS_ABOUT_SYS_TITLE 10821
#define IDS_ABOUT_SYS_DESC 10822
#define IDS_ABOUT_SYS_TABLE_TITLE 10823
#define IDS_ABOUT_SYS_LOG_FILE_TABLE_TITLE 10824
#define IDS_ABOUT_SYS_EXPAND_ALL 10825
#define IDS_ABOUT_SYS_COLLAPSE_ALL 10826
#define IDS_ABOUT_SYS_EXPAND 10827
#define IDS_ABOUT_SYS_COLLAPSE 10828
#define IDS_ABOUT_SYS_PARSE_ERROR 10829
#define IDS_ABOUT_BROWSER_SWITCH_TITLE 10830
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_UNKNOWN_BROWSER 10831
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_KNOWN_BROWSER 10832
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_UNKNOWN_BROWSER 10833
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_KNOWN_BROWSER 10834
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_UNKNOWN_BROWSER 10835
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_KNOWN_BROWSER 10836
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_UNKNOWN_BROWSER 10837
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_KNOWN_BROWSER 10838
#define IDS_ABOUT_BROWSER_SWITCH_PROTOCOL_ERROR 10839
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_DESC 10840
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_TITLE 10841
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_NOTHING_SHOWN 10842
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_LBS_DISABLED 10843
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_TITLE 10844
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_DESC 10845
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER 10846
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_PROTOCOL_REASON 10847
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_RULE_REASON 10848
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_INVERT_RULE_REASON 10849
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_DEFAULT_REASON 10850
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_INVALID_URL 10851
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_TITLE 10852
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_DESC 10853
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SOURCE 10854
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_NOT_CONFIGURED 10855
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NOT_FETCHED 10856
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_DOWNLOAD_BUTTON 10857
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_LAST_DOWNLOAD_DATE 10858
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NEXT_DOWNLOAD_DATE 10859
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_TITLE 10860
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_DESCRIPTION 10861
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_FIRST_PARAGRAPH 10862
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_SECOND_PARAGRAPH 10863
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_RULE 10864
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_OPENS_IN 10865
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_SOURCE 10866
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TITLE 10867
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_DESCRIPTION 10868
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_FIRST_PARAGRAPH 10869
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_SECOND_PARAGRAPH 10870
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_RULE 10871
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_SOURCE 10872
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_POLICIES_DOWNLOAD_BUTTON 10873
#define IDS_OMNIBOX_PLACEHOLDER_TEXT 10878
#define IDS_PASTE_AND_GO 10879
#define IDS_PASTE_AND_SEARCH 10880
#define IDS_PASTE_AND_GO_EMPTY 10881
#define IDS_OMNIBOX_KEYWORD_TEXT 10882
#define IDS_OMNIBOX_CLEAR_ALL 10883
#define IDS_OMNIBOX_WHY_THIS_SUGGESTION 10884
#define IDS_OMNIBOX_CLOSE_IPH_SUGGESTION 10885
#define IDS_OMNIBOX_THUMBS_UP_SUGGESTION 10886
#define IDS_OMNIBOX_THUMBS_DOWN_SUGGESTION 10887
#define IDS_OMNIBOX_REMOVE_SUGGESTION 10888
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_TITLE 10889
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_DESCRIPTION 10890
#define IDS_CONTEXT_MENU_SHOW_FULL_URLS 10891
#define IDS_CONTEXT_MENU_SHOW_SEARCH_TOOLS 10892
#define IDS_WEBUI_OMNIBOX_PLACEHOLDER_TEXT 10895
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE 10896
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 10897
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_YOUR_TABS 10898
#define IDS_NTP_DRIVE_CONNECT_TITLE 10899
#define IDS_NTP_DRIVE_DISCLAIMER_BODY 10900
#define IDS_NTP_DRIVE_DISCLAIMER_CANCEL 10901
#define IDS_NTP_DRIVE_DISCLAIMER_CONNECT 10902
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MD 10903
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_SHORT 10904
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MULTIMODAL 10905
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL 10906
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL_PDF 10907
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY 10908
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_PDF 10909
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_SECONDARY 10910
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_ERROR_TEXT 10911
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_ALT 10912
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_NO_SUGGEST_TEXT 10913
#define IDS_GOOGLE_SEARCH_BOX_MULTIMODAL_IMAGE_THUMBNAIL 10914
#define IDS_GOOGLE_LENS_SEARCH_BOX_EMPTY_HINT 10915
#define IDS_NTP_SEARCH_BOX_PLACEHOLDER_ASK_OR_TYPE 10916
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_ASK_GOOGLE 10917
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_PLAN 10918
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_COMPARE 10919
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_RESEARCH 10920
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TEACH 10921
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_WRITE 10922
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TAB 10923
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_IMAGE 10924
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_CANVAS 10925
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TOOLTIP 10926
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TITLE 10927
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT_TOOLTIP 10928
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT 10929
#define IDS_NTP_CUSTOM_LINKS_SHORTCUT_DETAILS_TITLE 10930
#define IDS_NTP_CUSTOM_LINKS_MORE_ACTIONS 10931
#define IDS_NTP_ENTERPRISE_SHORTCUT_SUBTITLE 10932
#define IDS_UPLOAD_IMAGE_FORMAT 10933
#define IDS_NTP_CUSTOM_LINKS_NAME 10934
#define IDS_NTP_CUSTOM_LINKS_URL 10935
#define IDS_NTP_CUSTOM_LINKS_REMOVE 10936
#define IDS_NTP_MOST_VISITED_SITES_REMOVE 10937
#define IDS_NTP_CUSTOM_LINKS_CANCEL 10938
#define IDS_NTP_CUSTOM_LINKS_DONE 10939
#define IDS_NTP_CUSTOM_LINKS_DETAILS 10940
#define IDS_NTP_CUSTOM_LINKS_INVALID_URL 10941
#define IDS_NTP_CUSTOM_LINKS_CANT_CREATE 10942
#define IDS_NTP_CUSTOM_LINKS_CANT_EDIT 10943
#define IDS_NTP_CUSTOM_LINKS_CANT_REMOVE 10944
#define IDS_NTP_CUSTOM_LINKS_HELP_PIN 10945
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_REMOVED 10946
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_EDITED 10947
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_ADDED 10948
#define IDS_NTP_CUSTOM_LINKS_ALREADY_EXISTS 10949
#define IDS_NTP_CONFIRM_MSG_RESTORE_DEFAULTS 10950
#define IDS_NTP_CONFIRM_MSG_RESTORE_ENTERPRISE_DEFAULTS 10951
#define IDS_NTP_CUSTOM_BG_UPLOAD_AN_IMAGE 10952
#define IDS_NTP_CUSTOM_BG_SELECT_A_COLLECTION 10953
#define IDS_NTP_CUSTOM_BG_DAILY_REFRESH 10954
#define IDS_NTP_CUSTOM_BG_RESTORE_DEFAULT 10955
#define IDS_NTP_CUSTOM_BG_CANCEL 10956
#define IDS_NTP_CONNECTION_ERROR_NO_PERIOD 10957
#define IDS_NTP_CONNECTION_ERROR 10958
#define IDS_NTP_ERROR_MORE_INFO 10959
#define IDS_NTP_CUSTOM_BG_BACKGROUNDS_UNAVAILABLE 10960
#define IDS_NTP_CUSTOM_BG_BACK_LABEL 10961
#define IDS_NTP_CUSTOM_BG_IMAGE_SELECTED 10962
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_LABEL 10963
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_WALLPAPER_SEARCH_LABEL 10964
#define IDS_NTP_CLOSE 10965
#define IDS_NTP_DISMISS 10966
#define IDS_NTP_DISMISS_PROMO 10967
#define IDS_NTP_DOODLE_SHARE_LABEL 10968
#define IDS_NTP_DOODLE_SHARE_DIALOG_CLOSE_LABEL 10969
#define IDS_NTP_DOODLE_SHARE_DIALOG_FACEBOOK_LABEL 10970
#define IDS_NTP_DOODLE_SHARE_DIALOG_TWITTER_LABEL 10971
#define IDS_NTP_DOODLE_SHARE_DIALOG_MAIL_LABEL 10972
#define IDS_NTP_DOODLE_SHARE_DIALOG_COPY_LABEL 10973
#define IDS_NTP_DOODLE_SHARE_DIALOG_LINK_LABEL 10974
#define IDS_NTP_CUSTOMIZE_APPEARANCE_LABEL 10975
#define IDS_NTP_CUSTOMIZE_THEMES_HEADER 10976
#define IDS_NTP_CUSTOMIZE_MENU_SHORTCUTS_LABEL 10977
#define IDS_NTP_CUSTOMIZE_MENU_TOOLBAR_LABEL 10978
#define IDS_NTP_CUSTOMIZE_MENU_EXTENSIONS_LABEL 10979
#define IDS_NTP_CUSTOMIZE_MENU_MODULES_LABEL 10980
#define IDS_NTP_CUSTOMIZE_NO_BACKGROUND_LABEL 10981
#define IDS_NTP_CUSTOMIZE_CHROME_CHANGE_THEME_LABEL 10982
#define IDS_NTP_CUSTOMIZE_FOOTER_HEADER 10983
#define IDS_NTP_CUSTOMIZE_TOOLS_HEADER 10984
#define IDS_NTP_MANAGED_BY_SEARCH_ENGINE 10985
#define IDS_NTP_MANAGED_BY_EXTENSION 10986
#define IDS_NTP_CUSTOMIZE_CHROME_MANAGED_NEW_TAB_PAGE_ACCESSIBILITY 10987
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_COMPLETE 10988
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_UPLOADED_IMAGE_COMPLETE 10989
#define IDS_NTP_CUSTOMIZE_CHROME_FOLLOW_THEME_LABEL 10990
#define IDS_NTP_CUSTOMIZE_UPLOADED_IMAGE_LABEL 10991
#define IDS_NTP_CUSTOMIZE_YOUR_UPLOADED_IMAGE_LABEL 10992
#define IDS_NTP_CUSTOMIZE_YOUR_SEARCHED_IMAGE_LABEL 10993
#define IDS_NTP_CUSTOMIZE_CHROME_CURRENT_THEME_LABEL 10994
#define IDS_NTP_CUSTOMIZE_SHOW_CARDS_LABEL 10995
#define IDS_NTP_CUSTOMIZE_SHOW_FOOTER_LABEL 10996
#define IDS_NTP_CUSTOMIZE_SHOW_CHIPS_LABEL 10997
#define IDS_NTP_CUSTOMIZE_SHOW_SUGGESTIONS_CHIPS_LABEL 10998
#define IDS_NTP_CUSTOMIZE_SHOW_SHORTCUTS_LABEL 10999
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_LABEL 11000
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_DESC 11001
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_LABEL 11002
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_LABEL 11003
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_LABEL 11004
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_DESC 11005
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_DESC 11006
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_DESC 11007
#define IDS_NTP_CUSTOMIZE_COLOR_PICKER_LABEL 11008
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_TITLE 11009
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_ARIA_LABEL 11010
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_TITLE 11011
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_A11Y_LABEL 11012
#define IDS_NTP_THEME_MANAGED_DIALOG_TITLE 11013
#define IDS_NTP_THEME_MANAGED_DIALOG_BODY 11014
#define IDS_NTP_THEMES_CONTAINER_LABEL 11015
#define IDS_NTP_CUSTOMIZE_DEFAULT_LABEL 11016
#define IDS_NTP_CUSTOMIZE_GREY_DEFAULT_LABEL 11017
#define IDS_NTP_COLORS_WARM_GREY 11018
#define IDS_NTP_COLORS_COOL_GREY 11019
#define IDS_NTP_COLORS_MIDNIGHT_BLUE 11020
#define IDS_NTP_COLORS_BLACK 11021
#define IDS_NTP_COLORS_BEIGE_AND_WHITE 11022
#define IDS_NTP_COLORS_YELLOW_AND_WHITE 11023
#define IDS_NTP_COLORS_GREEN_AND_WHITE 11024
#define IDS_NTP_COLORS_LIGHT_TEAL_AND_WHITE 11025
#define IDS_NTP_COLORS_LIGHT_PURPLE_AND_WHITE 11026
#define IDS_NTP_COLORS_PINK_AND_WHITE 11027
#define IDS_NTP_COLORS_BEIGE 11028
#define IDS_NTP_COLORS_ORANGE 11029
#define IDS_NTP_COLORS_LIGHT_GREEN 11030
#define IDS_NTP_COLORS_LIGHT_TEAL 11031
#define IDS_NTP_COLORS_LIGHT_BLUE 11032
#define IDS_NTP_COLORS_PINK 11033
#define IDS_NTP_COLORS_DARK_PINK_AND_RED 11034
#define IDS_NTP_COLORS_DARK_RED_AND_ORANGE 11035
#define IDS_NTP_COLORS_DARK_GREEN 11036
#define IDS_NTP_COLORS_DARK_TEAL 11037
#define IDS_NTP_COLORS_DARK_BLUE 11038
#define IDS_NTP_COLORS_DARK_PURPLE 11039
#define IDS_NTP_COLORS_BLUE 11040
#define IDS_NTP_COLORS_GREY 11041
#define IDS_NTP_COLORS_AQUA 11042
#define IDS_NTP_COLORS_GREEN 11043
#define IDS_NTP_COLORS_VIRIDIAN 11044
#define IDS_NTP_COLORS_CITRON 11045
#define IDS_NTP_COLORS_APRICOT 11046
#define IDS_NTP_COLORS_ROSE 11047
#define IDS_NTP_COLORS_FUCHSIA 11048
#define IDS_NTP_COLORS_VIOLET 11049
#define IDS_NTP_COLORS_BATCH_UPLOAD_DESCRIPTION 11050
#define IDS_NTP_UNDO_DISMISS_PROMO_BUTTON_TOAST 11051
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_GROUP_LABEL 11052
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_LIGHT_LABEL 11053
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_DARK_LABEL 11054
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_SYSTEM_LABEL 11055
#define IDS_NTP_CUSTOMIZE_CHROME_WEBSTORE_LABEL 11056
#define IDS_NTP_SHOW_MORE_BUTTON_LABEL 11057
#define IDS_NTP_SHOW_LESS_BUTTON_LABEL 11058
#define IDS_NTP_THREADS_HISTORY_LABEL 11059
#define IDS_NTP_THREADS_NEW_SEARCH_LABEL 11060
#define IDS_NTP_WEBSTORE_SHOPPING_CATEOGRY_LABEL 11061
#define IDS_NTP_WEBSTORE_WRITTING_HELP_COLLECTION_LABEL 11062
#define IDS_NTP_WEBSTORE_PRODUCTIVITY_CATEOGRY_LABEL 11063
#define IDS_NTP_WEBSTORE_TOAST_MESSAGE 11064
#define IDS_NTP_WEBSTORE_TOAST_BUTTON_TEXT 11065
#define IDS_NTP_WALLPAPER_SEARCH_FEEDBACK_PLACEHOLDER 11066
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION 11067
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY 11068
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_INSPIRATION 11069
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY_AND_INSPIRATION 11070
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_TITLE 11071
#define IDS_NTP_WALLPAPER_SEARCH_TILE_LABEL 11072
#define IDS_NTP_WALLPAPER_SEARCH_PAGE_HEADER 11073
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_HEADER 11074
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION 11075
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION_WITH_HISTORY 11076
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_TITLE 11077
#define IDS_NTP_WALLPAPER_SEARCH_OPTIONAL_DETAILS_LABEL 11078
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_RED_LABEL 11079
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLUE_LABEL 11080
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_YELLOW_LABEL 11081
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_GREEN_LABEL 11082
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLACK_LABEL 11083
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_DESCRIPTION 11084
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_TITLE 11085
#define IDS_NTP_WALLPAPER_SEARCH_SUBMIT_BTN_TEXT 11086
#define IDS_NTP_WALLPAPER_SEARCH_TRY_AGAIN_CTA 11087
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_NO_DESCRIPTOR 11088
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL 11089
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_B 11090
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_C 11091
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 11092
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL 11093
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_B 11094
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_C 11095
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 11096
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LABEL 11097
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DEFAULT_OPTION_LABEL 11098
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_LABEL 11099
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DEFAULT_OPTION_LABEL 11100
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_LABEL 11101
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DEFAULT_OPTION_LABEL 11102
#define IDS_LEARN_MORE_ABOUT_FEATURE_A11Y_LABEL 11103
#define IDS_THUMBS_DOWN_OPENS_FEEDBACK_FORM_A11Y_LABEL 11104
#define IDS_THUMBS_UP_RESULTS_A11Y_LABEL 11105
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_HEADER 11106
#define IDS_NTP_WALLPAPER_SEARCH_LOADING_A11Y_MESSAGE 11107
#define IDS_NTP_WALLPAPER_SEARCH_SUCCESS_A11Y_MESSAGE 11108
#define IDS_NTP_WALLPAPER_SEARCH_DISCLAIMER 11109
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_CARD_TOGGLE_TITLE 11110
#define IDS_NTP_WALLPAPER_SEARCH_DESCRIPTORS_CHANGED_A11Y_MESSAGE 11111
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_DESCRIPTION 11112
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_TITLE 11113
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_DESSERTS 11114
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_INTERIORS 11115
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_LANDSCAPE 11116
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_NATURE 11117
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_OUTER_SPACE 11118
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_PLACES 11119
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_STRUCTURES 11120
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CAKE_POPS 11121
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEESECAKE 11122
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FRUIT_TART 11123
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ICE_CREAM 11124
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MACARON 11125
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PANNA_COTTA 11126
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEMISTRY_LAB 11127
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HALLWAY 11128
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_KITCHEN 11129
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIVING_ROOM 11130
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_READING_NOOK 11131
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DESERT 11132
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FOREST 11133
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHLANDS 11134
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MEADOW 11135
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOUNTAIN 11136
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_OCEAN 11137
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINFOREST 11138
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RICE_PADDY 11139
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SALT_FLAT 11140
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SHORELINE 11141
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_TUNDRA 11142
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_WATERFALL 11143
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_AURORA_BOREALIS 11144
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CLIFF 11145
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CRASHING_WAVES 11146
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CREEK 11147
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ECLIPSES 11148
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FLOWERS 11149
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTNING 11150
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NIGHT_SKY 11151
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PALM_TREE 11152
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINBOW 11153
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RIVER 11154
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SLOT_CANYON 11155
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SUNSET 11156
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ASTEROID 11157
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_COMET 11158
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOON 11159
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NEBULA 11160
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PLANET 11161
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SPACE_STATION 11162
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_STARS 11163
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHICHEN_ITZA 11164
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_CANYON 11165
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_TETON_NATIONAL_PARK 11166
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GREAT_PYRAMID_OF_GIZA 11167
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ROCKY_MOUNTAINS_NATIONAL_PARK 11168
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_THE_COLOSSEUM 11169
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ZION_NATIONAL_PARK 11170
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_BRICK_BUILDING 11171
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CASTLE 11172
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHWAY 11173
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HOUSE 11174
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTHOUSE 11175
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PIER 11176
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ANIMATED 11177
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_COLORED_PENCIL 11178
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_CYBERPUNK 11179
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DREAM 11180
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_EXPRESSIONISM 11181
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_FANTASY 11182
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_IMPRESSIONISM 11183
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_OIL_PAINTING 11184
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ORGANIC 11185
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_PHOTOGRAPHY 11186
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_SPLATTER 11187
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_STEAMPUNK 11188
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_WATERCOLOR 11189
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CHAOTIC 11190
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CREATIVE 11191
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DARK 11192
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DREAMY 11193
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_EXCITED 11194
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_HAPPY 11195
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_INTELLECTUAL 11196
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ORDERLY 11197
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ROMANTIC 11198
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SERENE 11199
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SNOWY 11200
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUBDUED 11201
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUNNY 11202
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_THOUGHTFUL 11203
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WHIMSICAL 11204
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WILD 11205
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_1 11206
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_2 11207
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_3 11208
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_4 11209
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_5 11210
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_6 11211
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_7 11212
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_8 11213
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_9 11214
#define IDS_NTP_WALLPAPER_SEARCH_SEPARATOR 11215
#define IDS_NTP_CUSTOMIZE_TOOLBAR_BUTTON_A11Y_LABEL 11216
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CHOOSE_ICONS_LABEL 11217
#define IDS_NTP_CUSTOMIZE_TOOLBAR_ENTERPRISE_ENABLED_LABEL 11218
#define IDS_NTP_CUSTOMIZE_TOOLBAR_REORDER_TIP_LABEL 11219
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_ANNOUNCEMENT 11220
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_NAVIGATION 11221
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_SIDE_PANELS 11222
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_TOOLS_AND_ACTIONS 11223
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_BUTTON_LABEL 11224
#define IDS_NTP_COMPOSE_ENTRYPOINT 11225
#define IDS_NTP_COMPOSE_ENTRYPOINT_A11Y_LABEL 11226
#define IDS_NTP_COMPOSE_PLACEHOLDER_TEXT 11227
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL 11228
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL_INPUT 11229
#define IDS_NTP_COMPOSE_IMAGE_UPLOAD_BUTTON_A11Y_LABEL 11230
#define IDS_NTP_COMPOSE_PDF_UPLOAD_BUTTON_A11Y_LABEL 11231
#define IDS_NTP_COMPOSE_SUBMIT_BUTTON_A11Y_LABEL 11232
#define IDS_NTP_COMPOSE_DELETE_FILE_A11Y_LABEL 11233
#define IDS_NTP_COMPOSE_FILE_UPLOAD_STARTED_A11Y_TEXT 11234
#define IDS_NTP_COMPOSE_FILE_UPLOAD_COMPLETE_A11Y_TEXT 11235
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_EMPTY_SIZE 11236
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_TOO_LARGE 11237
#define IDS_NTP_COMPOSE_FILE_UPLOAD_IMAGE_PROCESSING_ERROR 11238
#define IDS_NTP_COMPOSE_FILE_UPLOAD_VALIDATION_FAILED 11239
#define IDS_NTP_COMPOSE_DRAG_AND_DROP_HINT 11240
#define IDS_NTP_COMPOSE_MAX_FILES_REACHED_ERROR 11241
#define IDS_NTP_COMPOSE_MAX_IMAGES_REACHED_ERROR 11242
#define IDS_NTP_COMPOSE_MAX_PDFS_REACHED_ERROR 11243
#define IDS_NTP_COMPOSE_FILE_TYPE_NOT_ALLOWED_ERROR 11244
#define IDS_NTP_COMPOSE_FILE_UPLOAD_NOT_ALLOWED 11245
#define IDS_NTP_COMPOSE_FILE_UPLOAD_FAILED 11246
#define IDS_NTP_COMPOSE_FILE_UPLOAD_EXPIRED 11247
#define IDS_NTP_COMPOSE_MOST_RECENT_TABS 11248
#define IDS_NTP_COMPOSEBOX_TAB_PICKER_ADD_TABS_TITLE 11249
#define IDS_NTP_COMPOSEBOX_SHARE_TABS 11250
#define IDS_NTP_COMPOSEBOX_RECENT_TAB_SUFFIX 11251
#define IDS_NTP_COMPOSE_ADD_IMAGE 11252
#define IDS_NTP_COMPOSE_ADD_FILE 11253
#define IDS_NTP_COMPOSE_ADD_DRIVE 11254
#define IDS_NTP_COMPOSE_ADD_CONTEXT 11255
#define IDS_NTP_COMPOSE_ADD_CONTEXTS 11256
#define IDS_NTP_COMPOSE_ADD_CONTEXT_TITLE 11257
#define IDS_NTP_COMPOSE_SUGGESTIONS_INFO 11258
#define IDS_NTP_COMPOSE_SMART_COMPOSE_A11Y_LABEL 11259
#define IDS_NTP_COMPOSE_SMART_COMPOSE_TAB 11260
#define IDS_NTP_COMPOSE_DEEP_SEARCH 11261
#define IDS_NTP_COMPOSE_CREATE_IMAGES 11262
#define IDS_NTP_COMPOSE_CANVAS 11263
#define IDS_NTP_COMPOSE_MODELS_LABEL 11264
#define IDS_NTP_COMPOSE_AUTO_MODEL 11265
#define IDS_NTP_COMPOSE_THINKING_3_PRO 11266
#define IDS_COMPOSE_DEEP_SEARCH_PLACEHOLDER 11267
#define IDS_COMPOSE_CREATE_IMAGE_IPH 11268
#define IDS_COMPOSE_DEEP_SEARCH_IPH 11269
#define IDS_COMPOSE_CREATE_IMAGE_PLACEHOLDER 11270
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THESE 11271
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_IMAGE 11272
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_TAB 11273
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_DOC 11274
#define IDS_COMPOSE_SHARING_TABS 11275
#define IDS_COMPOSE_SHARING_TABS_WITH_GOOGLE 11276
#define IDS_COMPOSE_ADD_TABS 11277
#define IDS_COMPOSE_CURRENT_TAB 11278
#define IDS_COMPOSE_MAX_FILE_UPLOAD_ERROR 11279
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_1 11280
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_2 11281
#define IDS_NTP_ACTION_CHIP_TAB_BODY_1 11282
#define IDS_NTP_ACTION_CHIP_TAB_BODY_2 11283
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_HEADING 11284
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_1 11285
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_2 11286
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_HEADING 11287
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_BODY 11288
#define IDS_NTP_ACTION_CHIP_CANVAS_HEADING 11289
#define IDS_NTP_ACTION_CHIP_CANVAS_BODY 11290
#define IDS_NTP_ACTION_CHIP_STARTER_HEADING 11291
#define IDS_NTP_ACTION_CHIP_STARTER_BODY 11292
#define IDS_NTP_ACTION_CHIP_DISABLE_TEXT 11293
#define IDS_NTP_ACTION_CHIPS_UNDO_DISABLEMENT_TOAST_MESSAGE 11294
#define IDS_COMPOSE_REMOVE_TOOL_CHIP_A11Y_LABEL 11295
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB 11296
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB_ARIA_LABEL 11297
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE 11298
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 11299
#define IDS_NTP_MODULES_SETUP_LIST_DISABLE_TOAST_MESSAGE 11300
#define IDS_NTP_MODULES_SETUP_LIST_DISMISS_TOAST_MESSAGE 11301
#define IDS_NTP_MODULES_SETUP_LIST_INFO 11302
#define IDS_NTP_MODULES_INFO_BUTTON_TITLE 11303
#define IDS_NTP_MODULES_DISMISS_TOAST_MESSAGE 11304
#define IDS_NTP_MODULES_DISABLE_TOAST_MESSAGE 11305
#define IDS_NTP_MODULE_INACTIVITY_REMOVAL 11306
#define IDS_NTP_MODULES_INACTIVITY_REMOVAL 11307
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_MESSAGE 11308
#define IDS_NTP_MODULES_DISMISS_BUTTON_TEXT 11309
#define IDS_NTP_MODULES_DRIVE_MORE_ACTIONS_BUTTON_TEXT 11310
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT 11311
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT_V2 11312
#define IDS_NTP_MODULES_MORE_ACTIONS 11313
#define IDS_NTP_MODULE_HEADER_MORE_ACTIONS_MENU 11314
#define IDS_NTP_MODULES_CUSTOMIZE_BUTTON_TEXT 11315
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_TODAY 11316
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_YESTERDAY 11317
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_WEEK 11318
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_MONTH 11319
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PREVIOUSLY 11320
#define IDS_NTP_MODULES_SHOPPING_TASKS_SENTENCE 11321
#define IDS_NTP_MODULES_SHOPPING_TASKS_LOWER 11322
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT 11323
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT_V2 11324
#define IDS_NTP_MODULES_DRIVE_NAME 11325
#define IDS_NTP_MODULES_FILES_SENTENCE 11326
#define IDS_NTP_MODULES_DUMMY_LOWER 11327
#define IDS_NTP_MODULES_DUMMY_TITLE 11328
#define IDS_NTP_MODULES_DRIVE_INFO 11329
#define IDS_NTP_MODULES_MICROSOFT_FILES_NAME 11330
#define IDS_NTP_MODULES_MICROSOFT_FILES_INFO 11331
#define IDS_NTP_MODULES_MICROSOFT_FILES_DISABLE_BUTTON_TEXT 11332
#define IDS_NTP_MODULES_MICROSOFT_FILES_TRENDING_JUSTIFICATION_TEXT 11333
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_TODAY_JUSTIFICATION_TEXT 11334
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_YESTERDAY_JUSTIFICATION_TEXT 11335
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_PAST_WEEK_JUSTIFICATION_TEXT 11336
#define IDS_NTP_MODULES_MICROSOFT_FILES_SHARED_BY_JUSTIFICATION_TEXT 11337
#define IDS_NTP_MODULES_DISMISS_FOR_HOURS_BUTTON_TEXT 11338
#define IDS_NTP_MODULES_DISMISS_FOR_DAYS_BUTTON_TEXT 11339
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISMISS_TOAST_MESSAGE 11340
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_TOAST_MESSAGE 11341
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_INFO 11342
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_MORE_ACTIONS 11343
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_TITLE 11344
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_BUTTON_TEXT 11345
#define IDS_NTP_MODULES_MICROSOFT_SIGN_OUT_BUTTON_TEXT 11346
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_TITLE 11347
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISABLE_BUTTON_TEXT 11348
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISMISS_TOAST_MESSAGE 11349
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_INFO 11350
#define IDS_NTP_MODULES_CALENDAR_DOUBLE_BOOKED 11351
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_TEXT 11352
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_ACCNAME 11353
#define IDS_NTP_MODULES_CALENDAR_IN_PROGRESS 11354
#define IDS_NTP_MODULES_CALENDAR_IN_X_MIN 11355
#define IDS_NTP_MODULES_CALENDAR_IN_X_HR 11356
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE 11357
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE_ACCNAME 11358
#define IDS_NTP_MODULES_KALEIDOSCOPE_TITLE 11359
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_TITLE 11360
#define IDS_NTP_MODULES_TASKS_INFO 11361
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_CLOSE 11362
#define IDS_NTP_MODULES_SHOPPING_TASKS_RELATED 11363
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_AMOUNT 11364
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_UP_TO_AMOUNT 11365
#define IDS_NTP_MODULES_CUSTOMIZE_IPH 11366
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING 11367
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING_FOR 11368
#define IDS_NTP_MODULES_SHOW_ALL 11369
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_BOOKMARKED 11370
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_INFO 11371
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_WITH_DISCOUNT_INFO 11372
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SENTENCE2 11373
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_NAME 11374
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISMISS_BUTTON 11375
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_DROPDOWN_TEXT 11376
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DONE_BUTTON 11377
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_OPEN_ALL_IN_NEW_TAB_GROUP_BUTTON_TEXT 11378
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SHOW_ALL_BUTTON 11379
#define IDS_ACCNAME_SHOW_ALL 11380
#define IDS_ACCNAME_SEARCH_SUGG 11381
#define IDS_NTP_MODULES_TAB_RESUMPTION_DISMISS_BUTTON 11382
#define IDS_NTP_MODULES_TAB_RESUMPTION_INFO 11383
#define IDS_NTP_MODULES_TAB_RESUMPTION_MULTI_DISMISS 11384
#define IDS_NTP_MODULES_TAB_RESUMPTION_SINGLE_DISMISS 11385
#define IDS_NTP_MODULES_TAB_RESUMPTION_RECENTLY_OPENED 11386
#define IDS_NTP_MODULES_TAB_RESUMPTION_DEVICE_PREFIX 11387
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_DISMISS_BUTTON 11388
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_TITLE 11389
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_SEE_MORE 11390
#define IDS_NTP_MODULES_MICROSOFT_AUTHENTICATION_NAME 11391
#define IDS_NTP_MODULES_TAB_GROUPS_DISMISS_TOAST_MESSAGE 11392
#define IDS_NTP_MODULES_TAB_GROUPS_DISABLE_TOAST_MESSAGE 11393
#define IDS_NTP_MODULES_TAB_GROUPS_INFO 11394
#define IDS_NTP_MODULES_TAB_GROUPS_TITLE 11395
#define IDS_NTP_MODULES_TAB_GROUPS_TIME_DELTA 11396
#define IDS_NTP_MODULES_TAB_GROUPS_RECENTLY_USED 11397
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TITLE 11398
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TEXT 11399
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISABLE_BUTTON_TEXT 11400
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISMISS_BUTTON_TEXT 11401
#define IDS_NTP_MICROSOFT_AUTHENTICATION_HEADING 11402
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SUBHEADING 11403
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIGN_IN_BUTTON_TEXT 11404
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIDE_PANEL_DESCRIPTION 11405
#define IDS_NTP_MOBILE_PROMO_HEADER 11406
#define IDS_NTP_MOBILE_PROMO_DESCRIPTION 11407
#define IDS_NTP_MOBILE_PROMO_QR_CODE_LABEL 11408
#define IDS_NTP_MOST_VISITED_SHORTCUTS_INACTIVITY_REMOVAL 11409
#define IDS_EXTENSIONS_PROMO_PERFORMANCE 11410
#define IDS_EXTENSIONS_PROMO_PRIVACY 11411
#define IDS_EXTENSIONS_PROMO_NEUTRAL 11412
#define IDS_NEW_TAB_FOOTER_NAME 11413
#define IDS_OPENS_MANAGEMENT_PAGE 11414
#define IDS_HIDE_NEW_TAB_FOOTER 11415
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_ARIA_DESC 11416
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_TEXT 11417
#define IDS_STAR_VIEW_MENU_ADD_BOOKMARK 11418
#define IDS_STAR_VIEW_MENU_EDIT_BOOKMARK 11419
#define IDS_STAR_VIEW_MENU_MOVE_TO_READ_LATER 11420
#define IDS_STAR_VIEW_MENU_MARK_AS_READ 11421
#define IDS_READ_LATER_TITLE 11422
#define IDS_READ_LATER_EXPAND_BUTTON_ARIA_LABEL 11423
#define IDS_READ_LATER_COLLAPSE_BUTTON_ARIA_LABEL 11424
#define IDS_READ_LATER_MENU_UNREAD_HEADER 11425
#define IDS_READ_LATER_MENU_READ_HEADER 11426
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_READ 11427
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_UNREAD 11428
#define IDS_READ_LATER_MENU_EMPTY_STATE_ADD_FROM_DIALOG_SUBHEADER 11429
#define IDS_READ_LATER_MENU_EMPTY_STATE_HEADER 11430
#define IDS_READ_LATER_MENU_EMPTY_STATE_SUBHEADER 11431
#define IDS_READ_LATER_ADD_CURRENT_TAB 11432
#define IDS_READ_LATER_CANT_ADD_CURRENT_TAB 11433
#define IDS_READ_LATER_MARK_CURRENT_TAB_READ 11434
#define IDS_READ_LATER_REMOVE_CURRENT_TAB 11435
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_UNREAD 11436
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_READ 11437
#define IDS_READ_LATER_CONTEXT_MENU_DELETE 11438
#define IDS_READING_LIST_MENU 11439
#define IDS_READING_LIST_MENU_ADD_TAB 11440
#define IDS_READING_LIST_MENU_SHOW_UI 11441
#define IDS_ACCNAME_SIDE_PANEL_RESIZE 11442
#define IDS_ACCNAME_SIDE_PANEL_CLOSE 11443
#define IDS_SIDE_PANEL_RESIZE_ACCESSIBLE_ALERT 11444
#define IDS_SIDE_PANEL_RESIZE_LEFT_SIDE_ACCESSIBLE_ALERT 11445
#define IDS_SIDE_PANEL_RESIZE_RIGHT_SIDE_ACCESSIBLE_ALERT 11446
#define IDS_ACCNAME_SIDE_PANEL_SELECTOR 11447
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_SHOW 11448
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_HIDE 11449
#define IDS_SIDE_PANEL_COMPANION_TITLE 11450
#define IDS_SIDE_PANEL_COMPANION_TOOLBAR_TOOLTIP 11451
#define IDS_SIDE_PANEL_COMPANION_PROMO 11452
#define IDS_SIDE_PANEL_COMPANION_PROMO_PINNING 11453
#define IDS_SIDE_PANEL_COMPANION_PROMO_SCREEN_READER 11454
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_FIRST_LINE 11455
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_SECOND_LINE 11456
#define IDS_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL 11457
#define IDS_SHOW_CUSTOMIZE_CHROME_TOOLBAR 11458
#define IDS_SIDE_PANEL_SHOW_TABS_FROM_OTHER_DEVICES 11459
#define IDS_SIDE_PANEL_TABS_FROM_OTHER_DEVICES_TITLE 11460
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_UNPIN 11461
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_PIN 11462
#define IDS_SIDE_PANEL_HEADER_UNPIN_BUTTON_TOOLTIP 11463
#define IDS_SIDE_PANEL_HEADER_PIN_BUTTON_TOOLTIP 11464
#define IDS_SIDE_PANEL_UNPINNED 11465
#define IDS_SIDE_PANEL_PINNED 11466
#define IDS_PINNED_ACTION_BUTTON_ACCESSIBLE_TITLE 11467
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH 11468
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH_SCREENREADER 11469
#define IDS_SIDE_PANEL_HEADER_MORE_INFO_BUTTON_TOOLTIP 11470
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_TITLE 11471
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 11472
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_FOLDER_SUBTITLE 11473
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 11474
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_TITLE 11475
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_SUBTITLE 11476
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_FOLDER_SUBTITLE 11477
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_OK_BUTTON_LABEL 11478
#define IDS_BOOKMARKS_SORT_BY_TYPE 11479
#define IDS_BOOKMARKS_ALL_BOOKMARKS 11480
#define IDS_BOOKMARKS_ALL_BOOKMARKS_OPEN_SIDE_PANEL 11481
#define IDS_BOOKMARKS_ACCOUNT_BOOKMARKS 11482
#define IDS_BOOKMARKS_DEVICE_BOOKMARKS 11483
#define IDS_BOOKMARKS_LABEL_TRACKED_PRODUCTS 11484
#define IDS_BOOKMARKS_SORT_NEWEST 11485
#define IDS_BOOKMARKS_SORT_NEWEST_LOWER 11486
#define IDS_BOOKMARKS_SORT_OLDEST 11487
#define IDS_BOOKMARKS_SORT_OLDEST_LOWER 11488
#define IDS_BOOKMARKS_SORT_ALPHABETICALLY 11489
#define IDS_BOOKMARKS_SORT_REVERSE_ALPHABETICALLY 11490
#define IDS_BOOKMARKS_SORT_LAST_OPENED 11491
#define IDS_BOOKMARKS_SORT_LAST_OPENED_LOWER 11492
#define IDS_BOOKMARKS_VISUAL_VIEW 11493
#define IDS_BOOKMARKS_COMPACT_VIEW 11494
#define IDS_BOOKMARKS_SWITCH_TO_COMPACT_VIEW 11495
#define IDS_BOOKMARKS_SWITCH_TO_VISUAL_VIEW 11496
#define IDS_BOOKMARKS_SORT_MENU_A11Y_LABEL 11497
#define IDS_BOOKMARKS_CREATE_NEW_FOLDER_A11Y_LABEL 11498
#define IDS_BOOKMARKS_NEW_FOLDER_TOOLTIP 11499
#define IDS_BOOKMARKS_EDIT_BOOKMARK_LIST_A11Y_LABEL 11500
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE 11501
#define IDS_BOOKMARKS_EMPTY_STATE_BODY 11502
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_FOLDER 11503
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_FOLDER 11504
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_GUEST 11505
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_GUEST 11506
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_SEARCH 11507
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_SEARCH 11508
#define IDS_BOOKMARK_FOLDER_CHILD_COUNT 11509
#define IDS_BOOKMARKS_EDIT_BOOKMARK 11510
#define IDS_BOOKMARKS_EDIT_MOVE_TO_ANOTHER_FOLDER 11511
#define IDS_BOOKMARKS_EDIT_MORE 11512
#define IDS_BOOKMARKS_EDIT_MOVE_TO 11513
#define IDS_BOOKMARKS_EDIT_NEW_FOLDER 11514
#define IDS_BOOKMARKS_EDIT_CANCEL 11515
#define IDS_BOOKMARKS_EDIT_SAVE 11516
#define IDS_BOOKMARKS_EDIT_NAME 11517
#define IDS_BOOKMARKS_EDIT_URL 11518
#define IDS_BOOKMARK_DELETION_COUNT 11519
#define IDS_UNDO_BOOKMARK_DELETION 11520
#define IDS_BOOKMARKS_MOVE_TO_BOOKMARKS_BAR 11521
#define IDS_BOOKMARKS_MOVE_TO_ALL_BOOKMARKS 11522
#define IDS_BOOKMARKS_EDIT 11523
#define IDS_BOOKMARKS_RENAME 11524
#define IDS_BOOKMARKS_URL_FOLDER_DESCRIPTION 11525
#define IDS_BOOKMARKS_DISABLED_FEATURE 11526
#define IDS_BOOKMARKS_BACK_BUTTON_LABEL 11527
#define IDS_BOOKMARKS_BACK_BUTTON_TOOLTIP 11528
#define IDS_BOOKMARKS_FORWARD_BUTTON_LABEL 11529
#define IDS_BOOKMARK_OPTIONS_LABEL 11530
#define IDS_FOLDER_OPTIONS_LABEL 11531
#define IDS_BOOKMARKS_OPEN_FOLDER_LABEL 11532
#define IDS_BOOKMARKS_OPEN_BOOKMARK_LABEL 11533
#define IDS_BOOKMARKS_SELECT_FOLDER_LABEL 11534
#define IDS_BOOKMARKS_SELECT_BOOKMARK_LABEL 11535
#define IDS_BOOKMARKS_DESELECT_FOLDER_LABEL 11536
#define IDS_BOOKMARKS_DESELECT_BOOKMARK_LABEL 11537
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_TRACKING 11538
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_CHANGE 11539
#define IDS_BOOKMARKS_CHECKBOX_LABEL 11540
#define IDS_BOOKMARKS_PRIMARY_FILTER_HEADING 11541
#define IDS_BOOKMARKS_SECONDARY_FILTER_HEADING 11542
#define IDS_SHOW_READING_MODE_SIDE_PANEL 11543
#define IDS_READING_MODE_TITLE 11544
#define IDS_IMMERSIVE_READING_MODE_OPENED_ANNOUNCEMENT 11545
#define IDS_READING_MODE_TOOLTIP 11546
#define IDS_READING_MODE_NOT_SELECTABLE_HEADER 11547
#define IDS_READING_MODE_EMPTY_STATE_HEADER 11548
#define IDS_READING_MODE_EMPTY_STATE_SUBHEADER 11549
#define IDS_READING_MODE_TOOLBAR_LABEL 11550
#define IDS_READING_MODE_READ_ALOUD_TOOLBAR_LABEL 11551
#define IDS_READING_MODE_FONT_SIZE 11552
#define IDS_READING_MODE_FONT_NAME_COMBOBOX_LABEL 11553
#define IDS_READING_MODE_DECREASE_FONT_SIZE_BUTTON_LABEL 11554
#define IDS_READING_MODE_INCREASE_FONT_SIZE_BUTTON_LABEL 11555
#define IDS_READING_MODE_INCREASE_FONT_SIZE_ANNOUNCEMENT 11556
#define IDS_READING_MODE_DECREASE_FONT_SIZE_ANNOUNCEMENT 11557
#define IDS_READING_MODE_DISABLE_LINKS_BUTTON_LABEL 11558
#define IDS_READING_MODE_ENABLE_LINKS_BUTTON_LABEL 11559
#define IDS_READING_MODE_IMAGES_LABEL 11560
#define IDS_READING_MODE_DISABLE_IMAGES_BUTTON_LABEL 11561
#define IDS_READING_MODE_ENABLE_IMAGES_BUTTON_LABEL 11562
#define IDS_READING_MODE_PIN_LABEL 11563
#define IDS_READING_MODE_DISABLE_PIN_BUTTON_LABEL 11564
#define IDS_READING_MODE_ENABLE_PIN_BUTTON_LABEL 11565
#define IDS_READING_MODE_COLORS_COMBOBOX_LABEL 11566
#define IDS_READING_MODE_LINE_SPACING_COMBOBOX_LABEL 11567
#define IDS_READING_MODE_LETTER_SPACING_COMBOBOX_LABEL 11568
#define IDS_READING_MODE_SPACING_COMBOBOX_STANDARD 11569
#define IDS_READING_MODE_SPACING_COMBOBOX_LOOSE 11570
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_LOOSE 11571
#define IDS_READING_MODE_SPACING_COMBOBOX_WIDE 11572
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_WIDE 11573
#define IDS_READING_MODE_DEFAULT_COLOR_LABEL 11574
#define IDS_READING_MODE_LIGHT_COLOR_LABEL 11575
#define IDS_READING_MODE_DARK_COLOR_LABEL 11576
#define IDS_READING_MODE_YELLOW_COLOR_LABEL 11577
#define IDS_READING_MODE_HIGH_CONTRAST_COLOR_LABEL 11578
#define IDS_READING_MODE_LOW_CONTRAST_LIGHT_COLOR_LABEL 11579
#define IDS_READING_MODE_LOW_CONTRAST_DARK_COLOR_LABEL 11580
#define IDS_READING_MODE_BLUE_COLOR_LABEL 11581
#define IDS_READING_MODE_VOICE_HIGHLIGHT 11582
#define IDS_READING_MODE_AUTO_HIGHLIGHT_LABEL 11583
#define IDS_READING_MODE_WORD_HIGHLIGHT_LABEL 11584
#define IDS_READING_MODE_PHRASE_HIGHLIGHT_LABEL 11585
#define IDS_READING_MODE_SENTENCE_HIGHLIGHT_LABEL 11586
#define IDS_READING_MODE_OFF_HIGHLIGHT_LABEL 11587
#define IDS_READING_MODE_LINE_FOCUS_WINDOW_HEADING 11588
#define IDS_READING_MODE_LINE_FOCUS_STYLE_HEADING 11589
#define IDS_READING_MODE_LINE_FOCUS_SMALL_FOCUS_LABEL 11590
#define IDS_READING_MODE_LINE_FOCUS_MEDIUM_FOCUS_LABEL 11591
#define IDS_READING_MODE_LINE_FOCUS_LARGE_FOCUS_LABEL 11592
#define IDS_READING_MODE_LINE_FOCUS_UNDERLINE_LABEL 11593
#define IDS_READING_MODE_LINE_FOCUS_LINE_HEADING 11594
#define IDS_READING_MODE_LINE_FOCUS_MOVEMENT_HEADING 11595
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LABEL 11596
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LINE_LABEL 11597
#define IDS_READING_MODE_LINE_FOCUS_CURSOR_LINE_LABEL 11598
#define IDS_READING_MODE_LINE_FOCUS_OFF_LABEL 11599
#define IDS_READING_MODE_LINE_FOCUS_SMALL_FOCUS_LABEL_SCREENREADER 11600
#define IDS_READING_MODE_LINE_FOCUS_MEDIUM_FOCUS_LABEL_SCREENREADER 11601
#define IDS_READING_MODE_LINE_FOCUS_LARGE_FOCUS_LABEL_SCREENREADER 11602
#define IDS_READING_MODE_LINE_FOCUS_UNDERLINE_LABEL_SCREENREADER 11603
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LABEL_SCREENREADER 11604
#define IDS_READING_MODE_LINE_FOCUS_CURSOR_LINE_LABEL_SCREENREADER 11605
#define IDS_READING_MODE_LINE_FOCUS_OFF_LABEL_SCREENREADER 11606
#define IDS_READING_MODE_KEYBOARD_SHORTCUT_IPH_BODY 11607
#define IDS_READING_MODE_KEYBOARD_SHORTCUT_IPH_SCREENREADER 11608
#define IDS_READ_ANYTHING_LOADING 11609
#define IDS_READING_MODE_FONT_RESET 11610
#define IDS_READING_MODE_FONT_RESET_TOOLTIP 11611
#define IDS_READING_MODE_TURN_HIGHLIGHT_OFF 11612
#define IDS_READING_MODE_TURN_HIGHLIGHT_ON 11613
#define IDS_READING_MODE_PLAY_DESCRIPTION 11614
#define IDS_READING_MODE_PLAY_SPEECH 11615
#define IDS_READING_MODE_PLAY_TOOLTIP 11616
#define IDS_READING_MODE_PREVIEW_TOOLTIP 11617
#define IDS_READING_MODE_PAUSE_TOOLTIP 11618
#define IDS_READING_MODE_STOP_SPEECH 11619
#define IDS_READING_MODE_NAVIGATE_PREVIOUS_SENTENCE 11620
#define IDS_READING_MODE_NAVIGATE_NEXT_SENTENCE 11621
#define IDS_READING_MODE_MORE_OPTIONS 11622
#define IDS_READING_MODE_SETTINGS 11623
#define IDS_READING_MODE_VOICE_SPEED 11624
#define IDS_READING_MODE_VOICE_SPEED_WITH_RATE 11625
#define IDS_READING_MODE_VOICE_SPEED_OPTION_TITLE 11626
#define IDS_READING_MODE_VOICE_SELECTION 11627
#define IDS_READING_MODE_SYSTEM_VOICE 11628
#define IDS_READING_MODE_ITEM_SELECTED 11629
#define IDS_READING_MODE_LANGUAGE_MENU 11630
#define IDS_READING_MODE_LANGUAGE_MENU_TITLE 11631
#define IDS_READING_MODE_LANGUAGE_MENU_CLOSE 11632
#define IDS_READING_MODE_CLOSE 11633
#define IDS_READING_MODE_LANGUAGE_MENU_NO_RESULTS 11634
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_LABEL 11635
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_CLEAR 11636
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOADING 11637
#define IDS_READING_MODE_VOICE_MENU_DOWNLOADING 11638
#define IDS_READING_MODE_LANGUAGE_MENU_VOICES_UNAVAILABLE 11639
#define IDS_READING_MODE_LANGUAGE_MENU_NO_INTERNET 11640
#define IDS_READING_MODE_CANT_USE_READ_ALOUD 11641
#define IDS_READING_MODE_VOICE_MENU_NO_INTERNET 11642
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOAD_FAILED 11643
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE 11644
#define IDS_READING_MODE_TOAST_NO_SPACE 11645
#define IDS_READING_MODE_VOICE_MENU_NO_SPACE 11646
#define IDS_READING_MODE_VOICE_MENU_PREVIEW_LANGUAGE 11647
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE_BUT_VOICES_EXIST 11648
#define IDS_READING_MODE_LANGUAGE_MENU_ITEM_LABEL 11649
#define IDS_READING_MODE_VOICE_DOWNLOADED_TITLE 11650
#define IDS_READING_MODE_VOICE_DOWNLOADED_MESSAGE 11651
#define IDS_READING_MODE_SIDE_PANEL_PROMO 11652
#define IDS_READING_MODE_SIDE_PANEL_PROMO_PINNING 11653
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO 11654
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO_SCREEN_READER 11655
#define IDS_READING_MODE_VOICE_PREVIEW_STRING 11656
#define IDS_READING_MODE_FONT_LOADING_STRING 11657
#define IDS_READING_MODE_LINE_FOCUS_LABEL 11658
#define IDS_READING_MODE_SIDE_PANEL_LABEL 11659
#define IDS_READING_MODE_VIEW_FULL_PAGE_LABEL 11660
#define IDS_READING_MODE_FULL_SCREEN_LABEL 11661
#define IDS_READING_MODE_VIEW_LABEL 11662
#define IDS_READING_MODE_LINKS_LABEL 11663
#define IDS_READING_MODE_PRESENTATION_MODE_IPH_BODY 11664
#define IDS_READING_MODE_PRESENTATION_MODE_IPH_SCREENREADER 11665
#define IDS_GOOGLE_LENS_TITLE 11666
#define IDS_LENS_DEFAULT_TITLE 11667
#define IDS_LENS_COBROWSE_IPH_HEADER 11668
#define IDS_LENS_COBROWSE_IPH_DESCRIPTION 11669
#define IDS_TOOLTIP_BACK 11670
#define IDS_ACCDESCRIPTION_BACK 11671
#define IDS_TOOLTIP_CHROMELABS_BUTTON 11672
#define IDS_TOOLTIP_LEFT_ALIGNED_SIDE_PANEL_BUTTON 11673
#define IDS_TOOLTIP_CHROMELABS_COMBOBOX 11674
#define IDS_TOOLTIP_CHROMELABS_FEEDBACK_BUTTON 11675
#define IDS_TOOLTIP_FORWARD 11676
#define IDS_ACCDESCRIPTION_FORWARD 11677
#define IDS_TOOLTIP_DOWNLOAD_ICON 11678
#define IDS_TOOLTIP_DOWNLOAD_ICON_NEW_DOWNLOAD 11679
#define IDS_TOOLTIP_HOME 11680
#define IDS_TOOLTIP_RELOAD 11681
#define IDS_TOOLTIP_RELOAD_WITH_MENU 11682
#define IDS_TOOLTIP_STOP 11683
#define IDS_TOOLTIP_EXTENSIONS_BUTTON 11684
#define IDS_TOOLTIP_OVERFLOW_BUTTON 11685
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 11686
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 11687
#define IDS_ACC_NAME_EXTENSIONS_BUTTON 11688
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 11689
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 11690
#define IDS_TOOLTIP_EXTENSIONS_SITE_ACCESS_BUTTON 11691
#define IDS_TOOLTIP_SIDE_PANEL_SHOW 11692
#define IDS_TOOLTIP_SIDE_PANEL_HIDE 11693
#define IDS_TOOLTIP_SIDE_PANEL 11694
#define IDS_TOOLTIP_LOCATION_ICON 11696
#define IDS_TOOLTIP_NEW_TAB 11697
#define IDS_TOOLTIP_TAB_SCROLL_LEADING 11698
#define IDS_TOOLTIP_TAB_SCROLL_TRAILING 11699
#define IDS_TOOLTIP_MIC_SEARCH 11700
#define IDS_TOOLTIP_LENS_SEARCH 11701
#define IDS_TOOLTIP_LENS_REINVOKE_VISUAL_SELECTION_A11Y_LABEL 11702
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_CLOSE_BUTTON_LABEL 11703
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE 11704
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE_SHORT 11705
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_TITLE 11706
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_UPLOAD_FILE_TITLE 11707
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OR_TEXT 11708
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TEXT_PLACEHOLDER 11709
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_SEARCH_BUTTON_LABEL 11710
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_DROP_TITLE 11711
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_LOADING_TEXT 11712
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_TEXT 11713
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_SUBTITLE_TEXT 11714
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_BUTTON_LABEL 11715
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_TYPE 11716
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_SIZE 11717
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_FILES 11718
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_SCHEME 11719
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_CONFORMANCE 11720
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_URLS 11721
#define IDS_TOOLTIP_SAVE_CREDIT_CARD 11722
#define IDS_TOOLTIP_SAVE_CREDIT_CARD_PENDING 11723
#define IDS_TOOLTIP_SAVE_CVC 11724
#define IDS_TOOLTIP_SAVE_IBAN 11725
#define IDS_TOOLTIP_MIGRATE_LOCAL_CARD 11726
#define IDS_TOOLTIP_TRANSLATE 11727
#define IDS_TOOLTIP_ZOOM 11728
#define IDS_TOOLTIP_ZOOM_EXTENSION_ICON 11729
#define IDS_ZOOM_SET_DEFAULT 11730
#define IDS_TOOLTIP_FIND 11731
#define IDS_TOOLTIP_TAB_SEARCH 11732
#define IDS_SPLIT_VIEW_NTP_EMPTY_TITLE 11733
#define IDS_SPLIT_VIEW_NTP_EMPTY_BODY 11734
#define IDS_SPLIT_VIEW_NTP_TITLE 11735
#define IDS_SPLIT_VIEW_NTP_TAB_TITLE 11736
#define IDS_ACCNAME_SPLIT_VIEW_MINI_TOOLBAR_MENU_BUTTON 11737
#define IDS_SPLIT_VIEW_NTP_CLOSE_BUTTON_ARIA_LABEL 11738
#define IDS_SPLIT_VIEW_TITLE_IPH 11739
#define IDS_SPLIT_VIEW_BODY_IPH 11740
#define IDS_SPLIT_VIEW_PIN_ACTION_2_IPH 11741
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_TITLE 11742
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_BODY 11743
#define IDS_SPLIT_VIEW_TAB_SWITCH_STEP_IPH_BODY 11744
#define IDS_SPLIT_VIEW_TAB_SWITCH_COMPLETION_IPH_BODY 11745
#define IDS_SPLIT_VIEW_TOOLBAR_BUTTON_STEP_IPH_BODY 11746
#define IDS_SPLIT_VIEW_DRAG_ENTRYPOINT_LABEL 11747
#define IDS_SPLIT_VIEW_RESIZE_ACCESSIBLE_ALERT 11748
#define IDS_SPLIT_VIEW_RESIZE_ACCESSIBLE_ALERT_STACKED 11749
#define IDS_SPLIT_VIEW_RESIZE_LEFT_SIDE_ACCESSIBLE_ALERT 11750
#define IDS_SPLIT_VIEW_RESIZE_RIGHT_SIDE_ACCESSIBLE_ALERT 11751
#define IDS_SPLIT_VIEW_RESIZE_TOP_SIDE_ACCESSIBLE_ALERT 11752
#define IDS_SPLIT_VIEW_RESIZE_BOTTOM_SIDE_ACCESSIBLE_ALERT 11753
#define IDS_SWITCH_TO_VERTICAL_TAB 11754
#define IDS_SWITCH_TO_HORIZONTAL_TAB 11755
#define IDS_COLLAPSE_VERTICAL_TABS 11756
#define IDS_EXPAND_VERTICAL_TABS 11757
#define IDS_VERTICAL_TABS_SEND_FEEDBACK 11758
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_SHOW_VERTICAL 11759
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_COLLAPSE 11760
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_END 11761
#define IDS_VERTICAL_TABS_ENABLE_EXPAND_ON_HOVER 11762
#define IDS_VERTICAL_TABS_DISABLE_EXPAND_ON_HOVER 11763
#define IDS_VERTICAL_TABS_COLLAPSE_BUTTON_TOGGLE_EXPAND_ON_HOVER 11764
#define IDS_VERTICAL_TABS_IPH_TITLE 11765
#define IDS_VERTICAL_TABS_IPH_BODY 11766
#define IDS_VERTICAL_TABS_EXPAND_ON_HOVER_DEFAULT_ENABLED_IPH_BODY 11767
#define IDS_VERTICAL_TABS_EXPAND_ON_HOVER_DEFAULT_DISABLED_IPH_BODY 11768
#define IDS_VERTICAL_RESIZE_AREA 11769
#define IDS_VERTICAL_TAB_RESIZE_ACCESSIBLE_ALERT 11770
#define IDS_VERTICAL_TAB_GROUP_MORE_OPTIONS 11771
#define IDS_VERTICAL_TABS_VIEW_MENU_TOGGLE_COLLAPSE 11772
#define IDS_VIEW_PROJECTS_PANEL 11773
#define IDS_HIDE_PROJECTS_PANEL 11774
#define IDS_TAB_GROUPS_TITLE 11775
#define IDS_RECENT_CHATS_TITLE 11776
#define IDS_TAB_GROUP_MORE_OPTIONS 11777
#define IDS_THREADS_SHOW_MORE 11778
#define IDS_THREADS_SHOW_LESS 11779
#define IDS_PROJECTS_PANEL 11780
#define IDS_PROJECTS_PANEL_GEMINI_ACTIVITY 11781
#define IDS_PROJECTS_PANEL_AI_MODE_ACTIVITY 11782
#define IDS_TAB_GROUPS_NO_TAB_GROUPS 11783
#define IDS_OPEN_GEMINI_THREAD_TOOLTIP 11784
#define IDS_OPEN_AI_MODE_THREAD_TOOLTIP 11785
#define IDS_OPEN_GEMINI_THREAD_ACCESSIBILITY_LABEL 11786
#define IDS_OPEN_AI_MODE_THREAD_ACCESSIBILITY_LABEL 11787
#define IDS_TAB_STRIP_UNPIN_TAB_SEARCH 11788
#define IDS_TAB_STRIP_PIN_TAB_SEARCH 11789
#define IDS_TAB_SEARCH_BUTTON_CXMENU_UNPIN 11790
#define IDS_TAB_SEARCH_BUTTON_CXMENU_PIN 11791
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_UNPIN 11792
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_PIN 11793
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_UNPIN 11794
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_PIN 11795
#define IDS_TOOLTIP_INTENT_PICKER_ICON 11796
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_WITH 11797
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_IN_APP 11798
#define IDS_INTENT_PICKER_BUBBLE_VIEW_REMEMBER_SELECTION 11799
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN 11800
#define IDS_INTENT_PICKER_BUBBLE_VIEW_STAY_IN_CHROME 11801
#define IDS_INTENT_PICKER_BUBBLE_VIEW_INITIATING_ORIGIN 11802
#define IDS_INTENT_CHIP_OPEN_IN_APP 11803
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_MESSAGE 11804
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_OK_LABEL 11805
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_REMINDER 11812
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_DECLINE 11813
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_BUTTON 11814
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_TITLE 11815
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_LENS_FEATURE_NAME 11816
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_ENHANCED_BROWSING_FEATURE_NAME 11817
#define IDS_IOS_DEVICE_TYPE_IPHONE 11818
#define IDS_IOS_DEVICE_TYPE_IPAD 11819
#define IDS_NTP_MOBILE_PROMO_BODY 11820
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_BODY 11821
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_TITLE 11822
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE_REMINDER 11823
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_BUTTON_DECLINE 11824
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_SUBTITLE 11825
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_TITLE 11826
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_TITLE 11827
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_BUTTON_DECLINE 11828
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_SUBTITLE 11829
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 11830
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_TITLE 11831
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_TITLE 11832
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_BUTTON_DECLINE 11833
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_SUBTITLE 11834
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 11835
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_QR 11836
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_REMINDER 11837
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_QR 11838
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_REMINDER 11839
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_DESCRIPTION_REMINDER 11840
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_REMINDER 11841
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_REMINDER 11842
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_QR 11843
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_REMINDER 11844
#define IDS_IOS_DESKTOP_AI_PROMO_NOTIFICATION_TITLE 11845
#define IDS_IOS_DESKTOP_SHOPPING_PROMO_NOTIFICATION_TITLE 11846
#define IDS_IOS_DESKTOP_YOUR_CHROME_PROMO_NOTIFICATION_TITLE 11847
#define IDS_ACCESSIBLE_INCOGNITO_WINDOW_TITLE_FORMAT 11848
#define IDS_ACCESSIBLE_GUEST_WINDOW_TITLE_FORMAT 11849
#define IDS_ACCESSIBLE_WINDOW_TITLE_WITH_PROFILE_FORMAT 11850
#define IDS_ACCNAME_APP_UPGRADE_RECOMMENDED 11851
#define IDS_ACCNAME_FULLSCREEN 11852
#define IDS_ACCNAME_EXIT_FULLSCREEN 11853
#define IDS_ACCNAME_FULLSCREEN_DISABLED 11854
#define IDS_ACCNAME_HOME 11855
#define IDS_ACCNAME_RELOAD 11856
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_PINNED 11857
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED_LEFT_ACTIVE 11858
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED_RIGHT_ACTIVE 11859
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED_TOP_ACTIVE 11860
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED_BOTTOM_ACTIVE 11861
#define IDS_ACCNAME_FIND 11862
#define IDS_ACCNAME_BOOKMARKS 11863
#define IDS_ACCNAME_SAVED_TAB_GROUPS 11864
#define IDS_ACCNAME_SAVED_TAB_GROUPS_CHEVRON 11865
#define IDS_SAVED_TAB_GROUPS_OVERFLOW_BUTTON_TOOLTIP 11866
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_DISABLED 11867
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_ENABLED 11868
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_LEARN_MORE 11869
#define IDS_ACCNAME_TAB_GROUPS_EVERYTHING 11870
#define IDS_TAB_GROUPS_EVERYTHING_BUTTON_TOOLTIP 11871
#define IDS_ACCNAME_BOOKMARKS_CHEVRON 11872
#define IDS_ACCNAME_BOOKMARK_BUTTON_ROLE_DESCRIPTION 11873
#define IDS_ACCNAME_BOOKMARK_FOLDER_BUTTON_ROLE_DESCRIPTION 11874
#define IDS_ACCNAME_SAVED_TAB_GROUP_BUTTON_ROLE_DESCRIPTION 11875
#define IDS_ACCNAME_CHROMELABS_BUTTON 11876
#define IDS_ACCNAME_LEFT_ALIGNED_SIDE_PANEL_BUTTON 11877
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_ADDED_BY_ENTERPRISE_POLICY 11878
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_REMOVED_BY_ENTERPRISE_POLICY 11879
#define IDS_ACCNAME_CHROMELABS_COMBOBOX 11880
#define IDS_ACCNAME_CHROMELABS_COMBOBOX_MAC 11881
#define IDS_ACCNAME_SEPARATOR 11882
#define IDS_ACCNAME_EXTENSIONS 11883
#define IDS_ACCNAME_NEWTAB 11884
#define IDS_ACCNAME_MINIMIZE 11885
#define IDS_ACCNAME_MAXIMIZE 11886
#define IDS_ACCNAME_RESTORE 11887
#define IDS_ACCNAME_CLOSE_TAB 11888
#define IDS_ACCNAME_ZOOM_SET_DEFAULT 11889
#define IDS_ACCNAME_TAB_SEARCH 11890
#define IDS_ACCNAME_TAB_SCROLL_LEADING 11891
#define IDS_ACCNAME_TAB_SCROLL_TRAILING 11892
#define IDS_ACCNAME_MUTE_TAB 11893
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_LEADING_SCROLL_BUTTON 11894
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_TRAILING_SCROLL_BUTTON 11895
#define IDS_TOOLBAR_BUTTON_UNPINNED 11896
#define IDS_TOOLBAR_BUTTON_PINNED 11897
#define IDS_ALLOWED_CLIPBOARD_TITLE 11898
#define IDS_BLOCKED_CLIPBOARD_TITLE 11899
#define IDS_ALLOWED_CLIPBOARD_MESSAGE 11900
#define IDS_ALLOWED_CLIPBOARD_BLOCK 11901
#define IDS_ALLOWED_CLIPBOARD_NO_ACTION 11902
#define IDS_BLOCKED_CLIPBOARD_MESSAGE 11903
#define IDS_BLOCKED_CLIPBOARD_UNBLOCK 11904
#define IDS_BLOCKED_CLIPBOARD_NO_ACTION 11905
#define IDS_BACK_NAVIGATION_MENU_PROMO 11906
#define IDS_BACK_NAVIGATION_MENU_PROMO_ACCESSIBLE_TEXT 11907
#define IDS_BOOKMARK_PROMO_0 11908
#define IDS_BOOKMARK_PROMO_1 11909
#define IDS_BOOKMARK_PROMO_2 11910
#define IDS_CHROME_TIP 11911
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_TITLE 11912
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_BODY 11913
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_TITLE 11914
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_BODY 11915
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_IPH_TITLE 11916
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_DESCRIPTION 11917
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_ACCEPT 11918
#define IDS_GLOBAL_MEDIA_CONTROLS_PROMO 11919
#define IDS_INCOGNITOWINDOW_PROMO_0 11920
#define IDS_INCOGNITOWINDOW_PROMO_1 11921
#define IDS_INCOGNITOWINDOW_PROMO_2 11922
#define IDS_INCOGNITOWINDOW_PROMO_3 11923
#define IDS_NEWTAB_PROMO_0 11924
#define IDS_NEWTAB_PROMO_1 11925
#define IDS_NEWTAB_PROMO_2 11926
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO 11927
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO_PINNING 11928
#define IDS_READING_LIST_DISCOVERY_PROMO 11929
#define IDS_READING_LIST_DISCOVERY_PROMO_PINNING 11930
#define IDS_READING_LIST_ENTRY_POINT_PROMO 11931
#define IDS_DESKTOP_PWA_INSTALL_PROMO 11932
#define IDS_DESKTOP_PWA_LINK_CAPTURING_TEXT 11933
#define IDS_DESKTOP_PWA_LINK_CAPTURING_SETTINGS 11934
#define IDS_UPDATED_CONNECTION_SECURITY_INDICATORS_PROMO 11935
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO 11936
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO_PINNING 11937
#define IDS_TAB_GROUPS_UNNAMED_GROUP_TOOLTIP 11938
#define IDS_TAB_GROUPS_NAMED_GROUP_TOOLTIP 11939
#define IDS_SHARED_HIGHLIGHTING_PROMO 11940
#define IDS_TAB_AUDIO_MUTING_PROMO 11941
#define IDS_BATTERY_SAVER_MODE_PROMO_TITLE 11942
#define IDS_BATTERY_SAVER_MODE_PROMO_TEXT 11943
#define IDS_BATTERY_SAVER_MODE_PROMO_ACTION_TEXT 11944
#define IDS_MEMORY_SAVER_MODE_PROMO_TEXT 11945
#define IDS_MEMORY_SAVER_MODE_PROMO_ACTION_TEXT 11946
#define IDS_TAB_GROUPS_HOVER_CARD_HEADER 11947
#define IDS_TAB_GROUPS_UNNAMED_GROUP_HOVER_CARD_HEADER 11948
#define IDS_TAB_GROUPS_HOVER_CARD_FOOTER 11949
#define IDS_DISCARD_RING_PROMO_TITLE 11950
#define IDS_DISCARD_RING_PROMO_TEXT 11951
#define IDS_DISCARD_RING_PROMO_ACTION_TEXT 11952
#define IDS_DISCARD_RING_SETTINGS_TOAST 11953
#define IDS_TUTORIAL_GENERIC_SUCCESS_TITLE 11954
#define IDS_TUTORIAL_TAB_GROUP_ADD_TAB_TO_GROUP 11955
#define IDS_TUTORIAL_ADD_TAB_TO_GROUP_WITH_EXISTING_GROUP_IN_TAB_STRIP 11956
#define IDS_TUTORIAL_TAB_GROUP_EDIT_BUBBLE 11957
#define IDS_TUTORIAL_TAB_GROUP_DRAG_TAB 11958
#define IDS_TUTORIAL_TAB_GROUP_COLLAPSE 11959
#define IDS_TUTORIAL_TAB_GROUP_SUCCESS_DESCRIPTION 11960
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_START_TUTORIAL_IPH 11961
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_OPEN_SIDE_PANEL 11962
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CHANGE_THEME 11963
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SELECT_COLLECTION 11964
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_APPLY_THEME 11965
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CLICK_BACK_ARROW 11966
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SUCCESS_BODY 11967
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORDS_MENU 11968
#define IDS_TUTORIAL_PASSWORD_MANAGER_ADD_SHORTCUT 11969
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_INSTALL 11970
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_ADDRESS_BAR 11971
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_HEADER 11972
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_BODY 11973
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_CLICK_LENS 11974
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_SEARCH_BOX 11975
#define IDS_BROWSER_HANGMONITOR_RENDERER_TITLE 11977
#define IDS_BROWSER_HANGMONITOR_RENDERER 11978
#define IDS_BROWSER_HANGMONITOR_IFRAME_TITLE 11979
#define IDS_BROWSER_HANGMONITOR_RENDERER_WAIT 11980
#define IDS_BROWSER_HANGMONITOR_RENDERER_END 11981
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR 11982
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR_KILLBUTTON 11983
#define IDS_PASSWORDS_AUTO_SIGNIN_TITLE 11984
#define IDS_PASSWORDS_AUTO_SIGNIN_DESCRIPTION 11985
#define IDS_PASSWORDS_VIA_FEDERATION 11986
#define IDS_CONFIRM_MESSAGEBOX_YES_BUTTON_LABEL 11987
#define IDS_CONFIRM_MESSAGEBOX_NO_BUTTON_LABEL 11988
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_TITLE 11989
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_DESCRIPTION 11990
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_TITLE 11991
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_ACCEPT 11992
#define IDS_TAILORED_SECURITY_DISPLAY_SOURCE 11993
#define IDS_PASSWORD_MANAGER_CANCEL_BUTTON 11994
#define IDS_PASSWORD_MANAGER_USERNAME_LABEL 11995
#define IDS_PASSWORD_MANAGER_PASSWORD_LABEL 11996
#define IDS_PASSWORD_MANAGER_UPDATED_BUBBLE_TITLE 11997
#define IDS_PASSWORD_MANAGER_MORE_TO_FIX_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 11998
#define IDS_PASSWORD_MANAGER_SAFE_STATE_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 11999
#define IDS_PASSWORD_MANAGER_CHECK_REMAINING_BUTTON 12000
#define IDS_PASSWORD_MANAGER_SAVE_BUTTON 12001
#define IDS_PASSWORD_MANAGER_MOVE_BUBBLE_CANCEL_BUTTON 12002
#define IDS_PASSWORD_MANAGER_UPDATE_BUTTON 12003
#define IDS_PASSWORD_MANAGER_SHORT_UPDATE_BUTTON 12004
#define IDS_PASSWORD_MANAGER_BUBBLE_BLOCKLIST_BUTTON 12005
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_ACCESSIBLE_NAME 12006
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_ACCOUNT 12007
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_DEVICE 12008
#define IDS_PASSWORD_MANAGER_IPH_TITLE_SAVE_TO_ACCOUNT 12009
#define IDS_PASSWORD_MANAGER_IPH_BODY_SAVE_TO_ACCOUNT 12010
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_TEMPLATE 12011
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_SIGNED_IN 12012
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_NOT_SIGNED_IN 12013
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_SCREENREADER 12014
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_BODY 12015
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_SCREENREADER 12016
#define IDS_PASSWORD_MANAGER_TOOLTIP_BLOCKED 12017
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE 12018
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE_SCREENREADER 12019
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON 12020
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON_SCREENREADER 12021
#define IDS_PASSWORD_MANAGER_IPH_ACCOUNT_STORAGE_TOGGLE 12022
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_TITLE 12023
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN 12024
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN_SCREENREADER 12025
#define IDS_PASSWORD_MANAGER_TOOLTIP_SAVE 12026
#define IDS_PASSWORD_MANAGER_TOOLTIP_MANAGE 12027
#define IDS_PASSWORD_MANAGER_TOOLTIP_MOVE 12028
#define IDS_PASSWORD_MANAGER_TOOLTIP_PROTECT 12029
#define IDS_PASSWORD_MANAGER_TOOLTIP_SHARED_NOTIFICATION 12030
#define IDS_PASSWORD_MANAGER_TOOLTIP_KEYCHAIN_ERROR 12031
#define IDS_IMPORT_FROM_FIREFOX 12053
#define IDS_IMPORT_FROM_ICEWEASEL 12054
#define IDS_IMPORT_FROM_SAFARI 12055
#define IDS_IMPORT_FROM_BOOKMARKS_HTML_FILE 12056
#define IDS_IMPORTER_LOCK_TITLE 12060
#define IDS_IMPORTER_LOCK_TEXT 12061
#define IDS_IMPORTER_LOCK_OK 12062
#define IDS_FEEDBACK_REPORT_APP_TITLE 12063
#define IDS_FEEDBACK_REPORT_PAGE_TITLE 12064
#define IDS_FEEDBACK_REPORT_PAGE_TITLE_SAD_TAB_FLOW 12065
#define IDS_FEEDBACK_MINIMIZE_BUTTON_LABEL 12066
#define IDS_FEEDBACK_CLOSE_BUTTON_LABEL 12067
#define IDS_FEEDBACK_FREE_TEXT_LABEL 12068
#define IDS_FEEDBACK_FREE_TEXT_AI_LABEL 12069
#define IDS_FEEDBACK_REPORT_URL_LABEL 12070
#define IDS_FEEDBACK_USER_EMAIL_LABEL 12071
#define IDS_FEEDBACK_ANONYMOUS_EMAIL_OPTION 12072
#define IDS_FEEDBACK_CONSENT_CHECKBOX_LABEL 12073
#define IDS_FEEDBACK_SCREENSHOT_LABEL 12074
#define IDS_FEEDBACK_SCREENSHOT_A11Y_TEXT 12075
#define IDS_FEEDBACK_OFFLINE_DIALOG_TITLE 12076
#define IDS_FEEDBACK_OFFLINE_DIALOG_TEXT 12077
#define IDS_FEEDBACK_INCLUDE_SYSTEM_INFORMATION_CHKBOX 12078
#define IDS_FEEDBACK_ATTACH_FILE_NOTE 12081
#define IDS_FEEDBACK_ATTACH_FILE_LABEL 12082
#define IDS_FEEDBACK_ATTACH_FILE_TO_BIG 12083
#define IDS_FEEDBACK_INCLUDE_AUTOFILL_METADATA_CHECKBOX 12084
#define IDS_FEEDBACK_IWLWIFI_DEBUG_DUMP_EXPLAINER 12085
#define IDS_FEEDBACK_LOG_ID_CHECKBOX_LABEL 12086
#define IDS_FEEDBACK_PRIVACY_NOTE 12087
#define IDS_FEEDBACK_NO_DESCRIPTION 12088
#define IDS_FEEDBACK_OFFENSIVE_CHECKBOX_LABEL 12089
#define IDS_FEEDBACK_SEND_REPORT 12090
#define IDS_FEEDBACK_AUTOFILL_METADATA_PAGE_TITLE 12091
#define IDS_FEEDBACK_SYSINFO_PAGE_TITLE 12092
#define IDS_FEEDBACK_SYSINFO_PAGE_LOADING 12093
#define IDS_FEEDBACK_ADDITIONAL_INFO_LABEL 12094
#define IDS_CLEAR_BROWSING_DATA_TITLE 12095
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE 12096
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_TITLE 12097
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_OK 12098
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE 12099
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_TITLE 12100
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_OK 12101
#define IDS_MEDIA_SELECTED_MIC_LABEL 12102
#define IDS_MEDIA_SELECTED_CAMERA_LABEL 12103
#define IDS_MEDIA_MENU_NO_DEVICE_TITLE 12104
#define IDS_MEDIA_CONTROLS_TITLE_PLACEHOLDER_INCOGNITO 12105
#define IDS_ZOOMLEVELS_CHROME_ERROR_PAGES_LABEL 12106
#define IDS_STORAGE_ACCESS_MANAGE_TEXT 12107
#define IDS_STORAGE_ACCESS_MANAGE_TOOLTIP 12108
#define IDS_REPORT_AN_ISSUE 12119
#define IDS_REENABLE_UPDATES 12120
#define IDS_PICTURE_IN_PICTURE_TITLE_TEXT 12121
#define IDS_PICTURE_IN_PICTURE_PAUSE_CONTROL_TEXT 12122
#define IDS_PICTURE_IN_PICTURE_PLAY_CONTROL_TEXT 12123
#define IDS_PICTURE_IN_PICTURE_REPLAY_CONTROL_TEXT 12124
#define IDS_PICTURE_IN_PICTURE_BACK_TO_TAB_CONTROL_TEXT 12125
#define IDS_PICTURE_IN_PICTURE_SKIP_AD_CONTROL_TEXT 12126
#define IDS_PICTURE_IN_PICTURE_LIVE_STATUS_TEXT 12127
#define IDS_PICTURE_IN_PICTURE_MUTE_MICROPHONE_TEXT 12128
#define IDS_PICTURE_IN_PICTURE_UNMUTE_MICROPHONE_TEXT 12129
#define IDS_PICTURE_IN_PICTURE_MUTE_TEXT 12130
#define IDS_PICTURE_IN_PICTURE_UNMUTE_TEXT 12131
#define IDS_PICTURE_IN_PICTURE_TURN_ON_CAMERA_TEXT 12132
#define IDS_PICTURE_IN_PICTURE_TURN_OFF_CAMERA_TEXT 12133
#define IDS_PICTURE_IN_PICTURE_HANG_UP_TEXT 12134
#define IDS_PICTURE_IN_PICTURE_CLOSE_CONTROL_TEXT 12135
#define IDS_PICTURE_IN_PICTURE_MINIMIZE_CONTROL_TEXT 12136
#define IDS_PICTURE_IN_PICTURE_LIVE_CAPTION_CONTROL_TEXT 12137
#define IDS_PICTURE_IN_PICTURE_REPLAY_10_TEXT 12138
#define IDS_PICTURE_IN_PICTURE_FORWARD_10_TEXT 12139
#define IDS_PICTURE_IN_PICTURE_RESIZE_HANDLE_TEXT 12140
#define IDS_PICTURE_IN_PICTURE_PLAY_PAUSE_CONTROL_ACCESSIBLE_TEXT 12141
#define IDS_PICTURE_IN_PICTURE_NEXT_TRACK_CONTROL_ACCESSIBLE_TEXT 12142
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_TRACK_CONTROL_ACCESSIBLE_TEXT 12143
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_SLIDE_CONTROL_ACCESSIBLE_TEXT 12144
#define IDS_PICTURE_IN_PICTURE_NEXT_SLIDE_CONTROL_ACCESSIBLE_TEXT 12145
#define IDS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 12146
#define IDS_LOAD_STATE_WAITING_FOR_SOCKET_SLOT 12147
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE 12148
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE_GENERIC 12149
#define IDS_LOAD_STATE_WAITING_FOR_CACHE 12150
#define IDS_LOAD_STATE_ESTABLISHING_PROXY_TUNNEL 12151
#define IDS_LOAD_STATE_RESOLVING_PROXY_FOR_URL 12152
#define IDS_LOAD_STATE_RESOLVING_HOST_IN_PAC_FILE 12153
#define IDS_LOAD_STATE_DOWNLOADING_PAC_FILE 12154
#define IDS_LOAD_STATE_RESOLVING_HOST 12155
#define IDS_LOAD_STATE_CONNECTING 12156
#define IDS_LOAD_STATE_SSL_HANDSHAKE 12157
#define IDS_LOAD_STATE_SENDING_REQUEST 12158
#define IDS_LOAD_STATE_SENDING_REQUEST_WITH_PROGRESS 12159
#define IDS_LOAD_STATE_WAITING_FOR_RESPONSE 12160
#define IDS_TAB_CXMENU_NEWTABTORIGHT 12161
#define IDS_TAB_CXMENU_NEWTABTOLEFT 12162
#define IDS_TAB_CXMENU_NEWTABBELOW 12163
#define IDS_TAB_CXMENU_RELOAD 12164
#define IDS_TAB_CXMENU_DUPLICATE 12165
#define IDS_TAB_CXMENU_CLOSETAB 12166
#define IDS_TAB_CXMENU_CLOSEOTHERTABS 12167
#define IDS_TAB_CXMENU_CLOSETABSTORIGHT 12168
#define IDS_TAB_CXMENU_CLOSETABSTOLEFT 12169
#define IDS_TAB_CXMENU_CLOSETABSBELOW 12170
#define IDS_TAB_CXMENU_CLOSEALLTABS 12171
#define IDS_TAB_CXMENU_FOCUS_THIS_TAB 12172
#define IDS_TAB_CXMENU_PIN_TAB 12173
#define IDS_TAB_CXMENU_UNPIN_TAB 12174
#define IDS_TAB_CXMENU_SOUND_MUTE_SITE 12175
#define IDS_TAB_CXMENU_SOUND_UNMUTE_SITE 12176
#define IDS_TAB_CXMENU_READ_LATER 12177
#define IDS_TAB_CXMENU_ADD_TAB_TO_GROUP 12178
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_GROUP 12179
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_SPLIT 12180
#define IDS_TAB_CXMENU_NEW_SPLIT_WITH_CURRENT 12181
#define IDS_TAB_CXMENU_ARRANGE_SPLIT 12182
#define IDS_TAB_CXMENU_SWAP_WITH_ACTIVE_SPLIT 12183
#define IDS_TAB_CXMENU_SUBMENU_NEW_GROUP 12184
#define IDS_TAB_CXMENU_REMOVE_TAB_FROM_GROUP 12185
#define IDS_TAB_CXMENU_PLACEHOLDER_GROUP_TITLE 12186
#define IDS_TAB_CXMENU_MOVE_TABS_TO_NEW_WINDOW 12187
#define IDS_TAB_CXMENU_MOVETOANOTHERWINDOW 12188
#define IDS_TAB_CXMENU_MOVETOANOTHERNEWWINDOW 12189
#define IDS_TAB_CXMENU_COMMERCE_PRODUCT_SPEC 12190
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_COMPARISON_TABLE 12191
#define IDS_ACCNAME_SPLIT_TABS_RESIZE 12195
#define IDS_PIN_SPLIT_TAB_TOGGLE 12196
#define IDS_SPLIT_TAB_REVERSE_VIEWS 12197
#define IDS_SPLIT_TAB_CLOSE 12198
#define IDS_SPLIT_TAB_CLOSE_LEFT_VIEW 12199
#define IDS_SPLIT_TAB_CLOSE_RIGHT_VIEW 12200
#define IDS_SPLIT_TAB_CLOSE_TOP_VIEW 12201
#define IDS_SPLIT_TAB_CLOSE_BOTTOM_VIEW 12202
#define IDS_SPLIT_TAB_SEPARATE_VIEWS 12203
#define IDS_SPLIT_TAB_SWAP_LEFT_VIEW 12204
#define IDS_SPLIT_TAB_SWAP_RIGHT_VIEW 12205
#define IDS_SPLIT_TAB_SWAP_TOP_VIEW 12206
#define IDS_SPLIT_TAB_SWAP_BOTTOM_VIEW 12207
#define IDS_SPLIT_TAB_NEW_VERTICAL 12208
#define IDS_SPLIT_TAB_NEW_HORIZONTAL 12209
#define IDS_SPLIT_TAB_SHOW_STACKED 12210
#define IDS_SPLIT_TAB_SHOW_SIDE_BY_SIDE 12211
#define IDS_SPLIT_TAB_SEND_FEEDBACK 12212
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_TITLE 12213
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_BODY 12214
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_SCREENREADER 12215
#define IDS_TAB_SEARCH_SEARCH_TABS 12216
#define IDS_TAB_SEARCH_NO_RESULTS_FOUND 12217
#define IDS_TAB_SEARCH_CLOSE_TAB 12218
#define IDS_TAB_SEARCH_SUBMIT_FEEDBACK 12219
#define IDS_TAB_SEARCH_A11Y_TAB_CLOSED 12220
#define IDS_TAB_SEARCH_A11Y_SPLIT_VIEW_CLOSED 12221
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB 12222
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS 12223
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB_FOR 12224
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS_FOR 12225
#define IDS_TAB_SEARCH_A11Y_OPEN_TAB 12226
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB 12227
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB_GROUP 12228
#define IDS_TAB_SEARCH_MEDIA_TABS 12229
#define IDS_TAB_SEARCH_OPEN_TABS 12230
#define IDS_TAB_SEARCH_RECENTLY_CLOSED 12231
#define IDS_TAB_SEARCH_RECENTLY_CLOSED_TABS 12232
#define IDS_TAB_SEARCH_ONE_TAB 12233
#define IDS_TAB_SEARCH_TAB_COUNT 12234
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED_ITEMS 12235
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED 12236
#define IDS_TAB_SEARCH_COLLAPSE_RECENTLY_CLOSED 12237
#define IDS_TAB_SEARCH_TAB_NAME 12238
#define IDS_TAB_SEARCH_MENU 12239
#define IDS_BROWSER_WINDOW_TITLE_MENU_ENTRY 12240
#define IDS_TABS_TITLE_CXMENU 12241
#define IDS_SAVED_TAB_GROUP_TABS_COUNT 12242
#define IDS_CREATE_NEW_TAB_GROUP 12243
#define IDS_GROUP_UNGROUPED_TABS 12244
#define IDS_SAVED_TAB_GROUPS_MENU 12245
#define IDS_OPEN_GROUP_IN_BROWSER_MENU 12246
#define IDS_NEW_TAB_IN_GROUP 12247
#define IDS_NEW_TAB_IN_GROUP_NO_GROUPS 12248
#define IDS_NEW_TAB_IN_GROUP_NO_NAME 12249
#define IDS_NEW_TAB_GROUP 12250
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_SYNCED_BODY 12251
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_DEFAULT_BODY_A11Y 12252
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_NOT_SYNCED_BODY 12253
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_SYNCED_BODY 12254
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_NOT_SYNCED_BODY 12255
#define IDS_RESUMPTION_RAIL_IPH_TITLE 12256
#define IDS_RESUMPTION_RAIL_IPH_BODY 12257
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_GEMINI 12258
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_AI_MODE 12259
#define IDS_RESUMPTION_RAIL_IPH_BODY_NO_THREADS 12260
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE 12261
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_GEMINI 12262
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_AI_MODE 12263
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY 12264
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_GEMINI 12265
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_AI_MODE 12266
#define IDS_RESUMPTION_RAIL_IPH_OK_BUTTON 12267
#define IDS_SAVED_TAB_GROUPS_UNSUPPORTED_ERROR 12268
#define IDS_TAB_GROUP_DELETION_DIALOG_MISSING_EMAIL 12269
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_DELETE 12270
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_UNGROUP 12271
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_DELETE 12272
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_UNGROUP 12273
#define IDS_TAB_GROUP_DELETION_DIALOG_DONT_ASK 12274
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_DELETE 12275
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_UNGROUP 12276
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_CLOSE_TAB_AND_DELETE 12277
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_REMOVE_TAB_AND_DELETE 12278
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_DELETE 12279
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_UNGROUP 12280
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_TITLE_ACCESSIBLE_NAME 12281
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_FACE_PILE_ACCESSIBLE_NAME 12282
#define IDS_TAB_GROUP_HEADER_CXMENU_NEW_TAB_IN_GROUP 12283
#define IDS_TAB_GROUP_HEADER_CXMENU_UNGROUP 12284
#define IDS_TAB_GROUP_HEADER_CXMENU_FOCUS_GROUP 12285
#define IDS_TAB_GROUP_HEADER_CXMENU_UNFOCUS_GROUP 12286
#define IDS_TAB_GROUP_HEADER_CXMENU_SHARE_GROUP 12287
#define IDS_TAB_GROUP_HEADER_CXMENU_RECENT_ACTIVITY 12288
#define IDS_TAB_GROUP_HEADER_CXMENU_MANAGE_GROUP 12289
#define IDS_TAB_GROUP_HEADER_CXMENU_CLOSE_GROUP 12290
#define IDS_TAB_GROUP_HEADER_CXMENU_HIDE_GROUP 12291
#define IDS_TAB_GROUP_HEADER_CXMENU_DELETE_GROUP 12292
#define IDS_TAB_GROUP_HEADER_CXMENU_MOVE_GROUP_TO_NEW_WINDOW 12293
#define IDS_TAB_GROUP_HEADER_CXMENU_OPEN_GROUP_IN_NEW_WINDOW 12294
#define IDS_TAB_GROUP_HEADER_CXMENU_PIN_GROUP 12295
#define IDS_TAB_GROUP_HEADER_CXMENU_UNPIN_GROUP 12296
#define IDS_TAB_GROUP_HEADER_CXMENU_CONVERT_GROUP_TO_BOOKMARK_FOLDER 12297
#define IDS_TAB_GROUP_HEADER_CXMENU_SEND_FEEDBACK 12298
#define IDS_TAB_GROUP_HEADER_BUBBLE_TITLE_PLACEHOLDER 12299
#define IDS_DATA_SHARING_SHARE_GROUP_TITLE 12300
#define IDS_DATA_SHARING_COPY_LINK 12301
#define IDS_DATA_SHARING_COPY_LINK_SUCCESS 12302
#define IDS_DATA_SHARING_MANAGE_GROUP_TITLE 12303
#define IDS_DATA_SHARING_MANAGE_STOP_SHARING_OPTION 12304
#define IDS_DATA_SHARING_MANAGE_ACTIVITY_LOG_OPTION 12305
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_TITLE 12306
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_TITLE 12307
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_CONFIRM 12308
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_TITLE 12309
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_CONFIRM 12310
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE 12311
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_ZERO 12312
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_SINGULAR 12313
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_PLURAL 12314
#define IDS_DATA_SHARING_PREVIEW_DIALOG_CONFIRM 12315
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TITLE 12316
#define IDS_DATA_SHARING_LINK_FAILED_TITLE 12317
#define IDS_DATA_SHARING_LEAVE_DIALOG_TITLE 12318
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_TITLE 12319
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_CONFIRM 12320
#define IDS_DATA_SHARING_NEED_SIGN_IN 12321
#define IDS_DATA_SHARING_NEED_SYNC 12322
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS 12323
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT 12324
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BUTTON 12325
#define IDS_DATA_SHARING_GOT_IT 12326
#define IDS_DATA_SHARING_SOMETHING_WRONG 12327
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN 12328
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE 12329
#define IDS_DATA_SHARING_SIGNED_OUT 12330
#define IDS_DATA_SHARING_GROUP_FULL 12331
#define IDS_DATA_SHARING_DELETE_LAST_TAB_TITLE 12332
#define IDS_DATA_SHARING_DELETE_LAST_TAB_CONFIRM 12333
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_CANCEL 12334
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_CANCEL 12335
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TITLE 12336
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_TAB 12337
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_GROUP 12338
#define IDS_DATA_SHARING_SHARE_GROUP_BODY 12339
#define IDS_DATA_SHARING_SHARE_GROUP_SHARE_AS 12340
#define IDS_DATA_SHARING_MANAGE_SHARE_WISELY 12341
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_BODY 12342
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_BODY 12343
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY 12344
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY_NO_GROUP_TITLE 12345
#define IDS_DATA_SHARING_PREVIEW_DIALOG_BODY 12346
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TABS_IN_GROUP 12347
#define IDS_DATA_SHARING_LINK_FAILED_BODY 12348
#define IDS_DATA_SHARING_JOIN_GROUP_JOIN_AS 12349
#define IDS_DATA_SHARING_GET_GROUP_PREVIEW_ARIA_LABEL 12350
#define IDS_DATA_SHARING_PREVIEW_A11Y_NAME 12351
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY 12352
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY_NO_GROUP_TITLE 12353
#define IDS_DATA_SHARING_LEAVE_DIALOG_CONFIRM 12354
#define IDS_DATA_SHARING_BLOCK_DIALOG_TITLE 12355
#define IDS_DATA_SHARING_BLOCK_DIALOG_BODY 12356
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_BODY 12357
#define IDS_DATA_SHARING_BLOCK_LEAVE_LEARN_MORE 12358
#define IDS_DATA_SHARING_NEED_SIGN_IN_BODY 12359
#define IDS_DATA_SHARING_NEED_SIGN_IN_CONTINUE_BUTTON 12360
#define IDS_DATA_SHARING_NEED_SYNC_BODY 12361
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS_BODY 12362
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BODY 12363
#define IDS_SYNC_HISTORY_TITLE 12364
#define IDS_DATA_SHARING_NEED_SIGN_IN_AND_SYNC_HISTORY_BODY 12365
#define IDS_DATA_SHARING_NEED_SYNC_HISTORY_BODY 12366
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_SYNC_HISTORY_BODY 12367
#define IDS_SYNC_HISTORY_BUTTON 12368
#define IDS_SYNC_HISTORY_FOOTER 12369
#define IDS_DATA_SHARING_SOMETHING_WRONG_BODY 12370
#define IDS_DATA_SHARING_SHARE_ERROR_BODY 12371
#define IDS_DATA_SHARING_JOIN_WARNING 12372
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN_BODY 12373
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE_BODY 12374
#define IDS_DATA_SHARING_SIGNED_OUT_BODY 12375
#define IDS_DATA_SHARING_SETTINGS 12376
#define IDS_DATA_SHARING_GROUP_FULL_BODY 12377
#define IDS_DATA_SHARING_OWNER_CANNOT_SHARE 12378
#define IDS_DATA_SHARING_DELETE_LAST_DIALOG_HEADER 12379
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY 12380
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_SINGULAR 12381
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_2 12382
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY 12383
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY_SINGULAR 12384
#define IDS_DATA_SHARING_RECENT_ACTIVITY_NO_UPDATES 12385
#define IDS_DATA_SHARING_PAGE_ACTION_ADDED_NEW_TAB 12386
#define IDS_DATA_SHARING_PAGE_ACTION_CHANGED_TAB 12387
#define IDS_ANCHORED_MESSAGE_EXPAND_BUTTON_TOOLTIP 12388
#define IDS_ANCHORED_MESSAGE_COLLAPSE_BUTTON_TOOLTIP 12389
#define IDS_DATA_SHARING_USER_ED_FIRST_TAB_CHANGE 12390
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK 12391
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH 12392
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH_SCREENREADER 12393
#define IDS_DATA_SHARING_LEARN_ABOUT_SHARED_GROUPS 12394
#define IDS_DATA_SHARING_PEOPLE_WITH_ACCESS 12395
#define IDS_DATA_SHARING_LINK_EDIT_ACCESS 12396
#define IDS_DATA_SHARING_LINK_JOIN_TOGGLE 12397
#define IDS_DATA_SHARING_CANCEL 12398
#define IDS_DATA_SHARING_CLOSE 12399
#define IDS_DATA_SHARING_BACK 12400
#define IDS_DATA_SHARING_BLOCK 12401
#define IDS_DATA_SHARING_REMOVE 12402
#define IDS_DATA_SHARING_LEAVE_GROUP 12403
#define IDS_DATA_SHARING_KEEP_GROUP 12404
#define IDS_DATA_SHARING_DELETE_GROUP 12405
#define IDS_DATA_SHARING_LOADING 12406
#define IDS_DATA_SHARING_COPY_LINK_FAILED 12407
#define IDS_DATA_SHARING_YOU 12408
#define IDS_DATA_SHARING_OWNER 12409
#define IDS_DATA_SHARING_MEMBER_COUNT_SINGULAR 12410
#define IDS_DATA_SHARING_MEMBER_COUNT_PLURAL 12411
#define IDS_DATA_SHARING_TAB_COUNT_SINGULAR 12412
#define IDS_DATA_SHARING_TAB_COUNT_PLURAL 12413
#define IDS_DATA_SHARING_MORE_OPTIONS 12414
#define IDS_DATA_SHARING_MORE_OPTIONS_DESCRIPTION 12415
#define IDS_APP_MENU_RELOAD 12416
#define IDS_APP_MENU_NEW_WEB_PAGE 12417
#define IDS_APP_MENU_COPY_LINK 12418
#define IDS_APP_MENU_CREATE_QR_CODE 12419
#define IDS_APP_MENU_BUTTON_UPDATE 12420
#define IDS_APP_MENU_BUTTON_UPDATE_ALT1 12421
#define IDS_APP_MENU_BUTTON_UPDATE_ALT2 12422
#define IDS_APP_MENU_BUTTON_UPDATE_ALT3 12423
#define IDS_APP_MENU_BUTTON_ERROR 12424
#define IDS_APP_MENU_BUTTON_ACTION_REQUIRED 12425
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TITLE 12426
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TEXT 12427
#define IDS_MEDIA_SCREEN_AND_AUDIO_CAPTURE_CONFIRMATION_TEXT 12428
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_TEXT 12429
#define IDS_MEDIA_SCREEN_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 12430
#define IDS_MEDIA_WINDOW_CAPTURE_NOTIFICATION_TEXT 12431
#define IDS_MEDIA_WINDOW_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 12432
#define IDS_MEDIA_TAB_CAPTURE_NOTIFICATION_TEXT 12433
#define IDS_MEDIA_TAB_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 12434
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_HIDE 12435
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_SOURCE 12436
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_STOP 12437
#define IDS_PLATFORM_KEYS_SELECT_CERT_DIALOG_TEXT 12438
#define IDS_UNSAFE_FRAME_MESSAGE 12439
#define IDS_CLIENT_CERT_DIALOG_TITLE 12440
#define IDS_CLIENT_CERT_DIALOG_TEXT 12441
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TITLE 12442
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_ENROLLMENT 12443
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CLIENT_AUTH 12444
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_LIST_CERTS 12445
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_IMPORT 12446
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_EXPORT 12447
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_PASSWORD_FIELD 12448
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_OK_BUTTON_LABEL 12449
#define IDS_FR_ENABLE_LOGGING 12451
#define IDS_CRASHED_TAB_FEEDBACK_MESSAGE 12455
#define IDS_CRASHED_TAB_FEEDBACK_LINK 12456
#define IDS_KILLED_TAB_FEEDBACK_MESSAGE 12458
#define IDS_DEFAULT_BROWSER_CHANGED_TITLE 12460
#define IDS_DEFAULT_BROWSER_CHANGED_YES_BUTTON 12461
#define IDS_DEFAULT_BROWSER_CHANGED_NO_THANKS_BUTTON 12462
#define IDS_DEFAULT_BROWSER_MODAL_CONFIRM_BUTTON 12463
#define IDS_DEFAULT_BROWSER_MODAL_CANCEL_BUTTON 12464
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_COMBINED 12465
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_OPEN_SETTINGS_LABEL 12466
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_DEFAULT_LABEL 12467
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_YES_LABEL 12468
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_LATER_LABEL 12469
#define IDS_RELAUNCH_BUTTON 12470
#define IDS_HELP_MANAGED_BY_YOUR_PARENT 12471
#define IDS_CONTROLLED_SETTING_POLICY 12474
#define IDS_TOOLBAR_INFORM_SET_HOME_PAGE 12475
#define IDS_MANAGE_EXTENSIONS_SETTING_WINDOWS_TITLE 12476
#define IDS_CONTROLLED_SETTING_EXTENSION 12477
#define IDS_CONTROLLED_SETTING_EXTENSION_WITHOUT_NAME 12478
#define IDS_CONTROLLED_SETTING_RECOMMENDED 12479
#define IDS_CONTROLLED_SETTING_HAS_RECOMMENDATION 12480
#define IDS_CONTROLLED_SETTING_CHILD_RESTRICTION 12481
#define IDS_CONTROLLED_SETTING_PARENT 12482
#define IDS_EXTENSIONS_INSTALL_LOCATION_UNKNOWN 12483
#define IDS_EXTENSIONS_INSTALL_LOCATION_3RD_PARTY 12484
#define IDS_EXTENSIONS_INSTALL_LOCATION_ENTERPRISE 12485
#define IDS_EXTENSIONS_INSTALL_LOCATION_SHARED_MODULE 12486
#define IDS_EXTENSIONS_BLOCKLISTED_MALWARE 12487
#define IDS_EXTENSIONS_BLOCKLISTED_SECURITY_VULNERABILITY 12488
#define IDS_EXTENSIONS_BLOCKLISTED_CWS_POLICY_VIOLATION 12489
#define IDS_EXTENSIONS_BLOCKLISTED_POTENTIALLY_UNWANTED 12490
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING 12491
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING_LEARN_MORE 12492
#define IDS_EXTENSIONS_ACCESS_REQUESTS_LEARN_MORE 12493
#define IDS_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_TITLE 12494
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 12495
#define IDS_BOOKMARK_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 12496
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 12497
#define IDS_BOOKMARK_MOVE_TO_ACCOUNT_ICON_TOOLTIP 12498
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_TITLE 12499
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_EXPLANATION 12500
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_DEFAULT_TOOL_NAME 12501
#define IDS_RESET_PROFILE_SETTINGS_LOCALE 12502
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_URLS 12503
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_TYPE 12504
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE 12505
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE_IS_NTP 12506
#define IDS_RESET_PROFILE_SETTINGS_YES 12507
#define IDS_RESET_PROFILE_SETTINGS_NO 12508
#define IDS_RESET_PROFILE_SETTINGS_SHOW_HOME_BUTTON 12509
#define IDS_RESET_PROFILE_SETTINGS_DSE 12510
#define IDS_RESET_PROFILE_SETTINGS_EXTENSIONS 12511
#define IDS_RESET_PROFILE_SETTINGS_SHORTCUTS 12512
#define IDS_RESET_PROFILE_SETTINGS_PROCESSING_SHORTCUTS 12513
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_MONTH 12515
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_YEAR 12516
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT 12517
#define IDS_SHOW_WINDOW_DECORATIONS 12518
#define IDS_SEND_TAB_TO_SELF_SEND_BUTTON_LABEL 12519
#define IDS_OMNIBOX_TOOLTIP_SEND_TAB_TO_SELF 12520
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_FROM_DEVICE 12521
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_TITLE 12522
#define IDS_SEND_TAB_TO_SELF_DEVICE_PICKER_TITLE 12523
#define IDS_SEND_TAB_TO_SELF_DEVICE_PICKER_SUBTITLE 12524
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_LABEL 12525
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_A11Y_NAME 12526
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_HINT_TEXT 12527
#define IDS_MENU_SEND_TAB_TO_SELF 12528
#define IDS_SEND_TAB_TO_SELF 12529
#define IDS_SEND_TAB_TO_SELF_DEVICE_LABEL 12530
#define IDS_SEND_TAB_TO_SELF_MANAGE_DEVICES 12531
#define IDS_SEND_TAB_TO_SELF_SENDING_ANNOUNCE 12532
#define IDS_SEND_TAB_TO_SELF_MANAGE_DEVICES_LINK 12533
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_LABEL 12534
#define IDS_SEND_TAB_TO_SELF_NO_TARGET_DEVICE_LABEL 12535
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_BODY 12536
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_PAGE 12537
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_IMAGE 12538
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_LINK 12539
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_LABEL 12540
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_TOOLTIP 12541
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TITLE 12542
#define IDS_SHARING_HUB_GENERATE_QR_CODE_LABEL 12543
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_URL_TEXTFIELD_ACCESSIBLE_NAME 12544
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TOOLTIP 12545
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_DOWNLOAD_BUTTON_LABEL 12546
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_COPY_BUTTON_LABEL 12547
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_TOO_LONG 12548
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_UNKNOWN 12549
#define IDS_SHARING_HUB_TITLE 12550
#define IDS_SHARING_HUB_TOOLTIP 12551
#define IDS_SHARING_HUB_SCREENSHOT_LABEL 12552
#define IDS_SHARING_HUB_COPY_LINK_LABEL 12553
#define IDS_SHARING_HUB_SAVE_PAGE_LABEL 12554
#define IDS_SHARING_HUB_MEDIA_ROUTER_LABEL 12555
#define IDS_SHARING_HUB_SHARE_LABEL 12556
#define IDS_BROWSER_SHARING_SCREENSHOT_POST_CAPTURE_TITLE 12557
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_DOWNLOAD_BUTTON_LABEL 12558
#define IDS_CONTEXT_MENU_PASTE_FROM_CLIPBOARD 12559
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT_UNKNOWN_DEVICE 12560
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT 12561
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT_UNKNOWN_DEVICE 12562
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT 12563
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_DESCRIPTION 12564
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_MULTIPLE_DEVICES 12565
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_SINGLE_DEVICE 12566
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_MULTIPLE_DEVICES 12567
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_SINGLE_DEVICE 12568
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE_UNKNOWN_DEVICE 12569
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE 12570
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_DESCRIPTION 12571
#define IDS_OMNIBOX_TOOLTIP_SHARED_CLIPBOARD 12572
#define IDS_COLLECTED_COOKIES_DIALOG_TITLE 12573
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_LABEL 12574
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_LABEL 12575
#define IDS_COLLECTED_COOKIES_BLOCKED_THIRD_PARTY_BLOCKING_ENABLED 12576
#define IDS_COLLECTED_COOKIES_ALLOW_BUTTON 12577
#define IDS_COLLECTED_COOKIES_SESSION_ONLY_BUTTON 12578
#define IDS_COLLECTED_COOKIES_BLOCK_BUTTON 12579
#define IDS_COLLECTED_COOKIES_ALLOW_RULE_CREATED 12580
#define IDS_COLLECTED_COOKIES_BLOCK_RULE_CREATED 12581
#define IDS_COLLECTED_COOKIES_SESSION_RULE_CREATED 12582
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_TAB_LABEL 12583
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_TAB_LABEL 12584
#define IDS_COLLECTED_COOKIES_ALLOWED_AUX_TEXT 12585
#define IDS_COLLECTED_COOKIES_BLOCKED_AUX_TEXT 12586
#define IDS_COLLECTED_COOKIES_CLEAR_ON_EXIT_AUX_TEXT 12587
#define IDS_COLLECTED_COOKIES_INFOBAR_MESSAGE 12588
#define IDS_COLLECTED_COOKIES_INFOBAR_BUTTON 12589
#define IDS_COLLECTED_COOKIES_PARTITIONED_COOKIE 12590
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_TITLE 12591
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SUBTITLE 12592
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SETTINGS_LINK 12593
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_TITLE 12594
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_SUBTITLE 12595
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_TITLE 12596
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_SUBTITLE 12597
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_EMPTY_STATE_LABEL 12598
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_TITLE 12599
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SUBTITLE 12600
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SETTINGS_LINK_TOOLTIP 12601
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_MENU_ITEM 12602
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_THIRD_PARTY_MENU_ITEM 12603
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCK_MENU_ITEM 12604
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_MENU_ITEM 12605
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOWED_STATE_SUBTITLE 12606
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCKED_STATE_SUBTITLE 12607
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_STATE_SUBTITLE 12608
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_STATE_SUBTITLE 12609
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_SESSION_ONLY_STATE_SUBTITLE 12610
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_CONTEXT_MENU_TOOLTIP 12611
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_DELETE_BUTTON_TOOLTIP 12612
#define IDS_ACCNAME_INFOBAR_CONTAINER 12613
#define IDS_ACCNAME_INFOBAR 12614
#define IDS_ONE_CLICK_BUBBLE_UNDO 12615
#define IDS_ENTERPRISE_SIGNIN_CANCEL 12616
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_PROFILE 12617
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_WORK_PROFILE 12618
#define IDS_ENTERPRISE_SIGNIN_CONTINUE 12619
#define IDS_ENTERPRISE_SIGNIN_ALERT 12620
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_TITLE 12621
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_DESCRIPTION 12622
#define IDS_MANAGED_WITH_HYPERLINK 12625
#define IDS_MANAGED_BY_WITH_HYPERLINK 12626
#define IDS_PROFILE_MANAGED_BY_WITH_HYPERLINK 12627
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_WITH_HYPERLINK 12628
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_WITH_HYPERLINK 12629
#define IDS_BROWSER_AND_PROFILE_SAME_MANAGED_BY_WITH_HYPERLINK 12630
#define IDS_MANAGED_BY_PARENT_WITH_HYPERLINK 12631
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_TOOLTIP 12632
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_TOOLTIP 12633
#define IDS_COOKIES_COOKIE_EXPIRES_SESSION 12634
#define IDS_COOKIES_COOKIE_SENDFOR_ANY 12635
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE 12636
#define IDS_COOKIES_COOKIE_SENDFOR_SAME_SITE 12637
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE_SAME_SITE 12638
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_YES 12639
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_NO 12640
#define IDS_COOKIES_COOKIES 12641
#define IDS_COOKIES_WEB_DATABASES 12642
#define IDS_COOKIES_LOCAL_STORAGE 12643
#define IDS_COOKIES_SESSION_STORAGE 12644
#define IDS_COOKIES_INDEXED_DBS 12645
#define IDS_COOKIES_FILE_SYSTEMS 12646
#define IDS_COOKIES_FILE_SYSTEM_USAGE_NONE 12647
#define IDS_COOKIES_SERVICE_WORKER 12648
#define IDS_COOKIES_SERVICE_WORKERS 12649
#define IDS_COOKIES_SHARED_WORKERS 12650
#define IDS_COOKIES_CACHE_STORAGE 12651
#define IDS_APP_DEFAULT_PAGE_NAME 12652
#define IDS_APP_LAUNCHER_TAB_TITLE 12653
#define IDS_NEW_TAB_GUEST_SESSION_HEADING 12654
#define IDS_NEW_TAB_GUEST_SESSION_DESCRIPTION 12655
#define IDS_NEW_TAB_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 12656
#define IDS_NEW_TAB_ENTERPRISE_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 12657
#define IDS_NEW_TAB_TILE_GRID_ACCESSIBLE_DESCRIPTION 12658
#define IDS_NEW_TAB_APP_INSTALL_HINT_LABEL 12659
#define IDS_NEW_TAB_MOST_VISITED 12660
#define IDS_NEW_TAB_RESTORE_THUMBNAILS_SHORT_LINK 12661
#define IDS_NEW_TAB_ATTRIBUTION_INTRO 12662
#define IDS_NEW_TAB_THUMBNAIL_REMOVED_NOTIFICATION 12663
#define IDS_NEW_TAB_REMOVE_THUMBNAIL_TOOLTIP 12664
#define IDS_NEW_TAB_PAGE_SWITCHER_CHANGE_TITLE 12665
#define IDS_NEW_TAB_PAGE_SWITCHER_SAME_TITLE 12666
#define IDS_NEW_TAB_VOICE_AUDIO_ERROR 12667
#define IDS_NEW_TAB_VOICE_CLOSE_TOOLTIP 12668
#define IDS_NEW_TAB_VOICE_DETAILS 12669
#define IDS_NEW_TAB_VOICE_LANGUAGE_ERROR 12670
#define IDS_NEW_TAB_VOICE_LISTENING 12671
#define IDS_NEW_TAB_VOICE_NETWORK_ERROR 12672
#define IDS_NEW_TAB_VOICE_NO_TRANSLATION 12673
#define IDS_NEW_TAB_VOICE_NO_VOICE 12674
#define IDS_NEW_TAB_VOICE_OTHER_ERROR 12675
#define IDS_NEW_TAB_VOICE_PERMISSION_ERROR 12676
#define IDS_NEW_TAB_VOICE_LEARN_MORE_ACCESSIBILITY_LABEL 12677
#define IDS_NEW_TAB_VOICE_READY 12678
#define IDS_NEW_TAB_VOICE_TRY_AGAIN 12679
#define IDS_NEW_TAB_VOICE_WAITING 12680
#define IDS_NEW_TAB_VOICE_SEARCH_CLOSED 12681
#define IDS_FUSEBOX_VOICE_SEARCH_TRANSCRIBING 12682
#define IDS_FUSEBOX_VOICE_SEARCH_STOP_TITLE 12683
#define IDS_NEW_TAB_APP_OPTIONS 12684
#define IDS_NEW_TAB_APP_DETAILS 12685
#define IDS_NEW_TAB_APP_CREATE_SHORTCUT 12686
#define IDS_NEW_TAB_APP_INSTALL_LOCALLY 12687
#define IDS_APP_CONTEXT_MENU_SHOW_INFO 12688
#define IDS_APP_CONTEXT_MENU_OPEN_PINNED 12689
#define IDS_APP_CONTEXT_MENU_OPEN_REGULAR 12690
#define IDS_APP_CONTEXT_MENU_OPEN_WINDOW 12691
#define IDS_APP_CONTEXT_MENU_OPEN_FULLSCREEN 12692
#define IDS_APP_CONTEXT_MENU_OPEN_MAXIMIZED 12693
#define IDS_APP_CONTEXT_MENU_OPEN_TAB 12694
#define IDS_APP_CONTEXT_MENU_RUN_ON_OS_LOGIN 12699
#define IDS_APPS_PAGE_DEPRECATED_APP_TITLE 12702
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_TITLE 12703
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_PROCEED_BUTTON 12704
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_CANCEL_BUTTON 12705
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_BODY_TEXT 12706
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_DEFAULT_BODY_TEXT 12707
#define IDS_SYNC_CONFIRMATION_SETTINGS_INFO 12708
#define IDS_SYNC_CONFIRMATION_CONFIRM_BUTTON_LABEL 12709
#define IDS_SYNC_CONFIRMATION_SETTINGS_BUTTON_LABEL 12710
#define IDS_SYNC_CONFIRMATION_REFRESHED_SETTINGS_BUTTON_LABEL 12711
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_TITLE 12712
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE 12713
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE_SIGNIN_INTERCEPT_V2 12714
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_BOOKMARKS 12715
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_READING_LIST 12716
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_AUTOFILL 12717
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_EXTENSIONS 12718
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_HISTORY_AND_MORE 12719
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_DESC 12720
#define IDS_SYNC_CONFIRMATION_WELCOME_TITLE_SIGNIN_INTERCEPT 12721
#define IDS_SYNC_CONFIRMATION_TURN_ON_SYNC_BUTTON_LABEL 12722
#define IDS_SYNC_DISABLED_CONFIRMATION_CHROME_SYNC_TITLE 12723
#define IDS_SYNC_DISABLED_CONFIRMATION_DETAILS 12724
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_LABEL 12725
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_MANAGED_ACCOUNT_SIGNOUT_DISALLOWED_LABEL 12726
#define IDS_SYNC_DISABLED_CONFIRMATION_UNDO_BUTTON_LABEL 12727
#define IDS_SYNC_LOADING_CONFIRMATION_TITLE 12728
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_NEW_PROFILE_BUTTON_LABEL 12729
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SEPARATE_BROWSING_TEXT 12730
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SWITCH_PROFILE_TEXT 12731
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CREATE_PROFILE_BUTTON_LABEL 12732
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_STAY_HERE_BUTTON_LABEL 12733
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE_SUPERVISED 12734
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_BUTTON_LABEL 12735
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_SWITCH_BUTTON_LABEL 12736
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC_SUPERVISED 12737
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_CONTINUE_BUTTON_LABEL 12738
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCEPT_TEXT 12739
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_BUBBLE_DESC_MANAGED_BY_TOKEN 12740
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_DISCLAIMER 12741
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_BY_DISCLAIMER 12742
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TITLE_SIGNIN_REMINDER 12743
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_OK_BUTTON 12744
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TITLE 12745
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_DELETE_AND_SIGNOUT_BUTTON 12746
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT_LINK 12747
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_CLOSE 12748
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK 12749
#define IDS_SYNC_PASSPHRASE_DIALOG_TITLE 12750
#define IDS_SYNC_PASSPHRASE_DIALOG_OK_BUTTON 12751
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_PROFILE_NAME 12752
#define IDS_SIGNIN_ERROR_TITLE 12753
#define IDS_SIGNIN_ERROR_EMAIL_TITLE 12754
#define IDS_SIGNIN_ERROR_CLOSE_BUTTON_LABEL 12755
#define IDS_SIGNIN_ERROR_OK_BUTTON_LABEL 12756
#define IDS_SIGNIN_ERROR_SWITCH_BUTTON_LABEL 12757
#define IDS_SIGNIN_ACCESSIBLE_CLOSE_BUTTON 12758
#define IDS_SIGNIN_ACCESSIBLE_BACK_BUTTON 12759
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_TITLE 12760
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_SUBTITLE 12761
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_TITLE 12762
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_SUBTITLE 12763
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CLOSE_BUTTON_LABEL 12764
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CONFIRM_BUTTON_LABEL 12765
#define IDS_PLUGIN_CRASHED_PROMPT 12766
#define IDS_RELOAD_PAGE_WITH_PLUGIN 12767
#define IDS_EXTERNAL_PROTOCOL_TITLE 12768
#define IDS_EXTERNAL_PROTOCOL_MESSAGE_WITH_INITIATING_ORIGIN 12769
#define IDS_EXTERNAL_PROTOCOL_MESSAGE 12770
#define IDS_EXTERNAL_PROTOCOL_OK_BUTTON_TEXT 12771
#define IDS_EXTERNAL_PROTOCOL_CANCEL_BUTTON_TEXT 12772
#define IDS_EXTERNAL_PROTOCOL_CHECKBOX_PER_ORIGIN_TEXT 12773
#define IDS_DIRECTORY_LISTING_HEADER 12775
#define IDS_DIRECTORY_LISTING_PARENT 12776
#define IDS_DIRECTORY_LISTING_NAME 12777
#define IDS_DIRECTORY_LISTING_SIZE 12778
#define IDS_DIRECTORY_LISTING_DATE_MODIFIED 12779
#define IDS_SAVE_PAGE_DESC_HTML_ONLY 12780
#define IDS_SAVE_PAGE_DESC_SINGLE_FILE 12781
#define IDS_SAVE_PAGE_DESC_COMPLETE 12782
#define IDS_PROFILE_ERROR_DIALOG_TITLE 12783
#define IDS_COULDNT_OPEN_PROFILE_ERROR 12784
#define IDS_OPEN_PROFILE_DATA_LOSS 12785
#define IDS_PROFILE_ERROR_DIALOG_CHECKBOX 12786
#define IDS_PROFILE_ERROR_FEEDBACK_DESCRIPTION 12787
#define IDS_REFUSE_TO_RUN_AS_ROOT 12788
#define IDS_REFUSE_TO_RUN_AS_ROOT_2 12789
#define IDS_CANT_WRITE_USER_DIRECTORY_TITLE 12791
#define IDS_RECENT_TABS_MENU 12792
#define IDS_RECENTLY_CLOSED_WINDOW 12793
#define IDS_RECENTLY_CLOSED_GROUP 12794
#define IDS_RECENTLY_CLOSED_GROUP_UNNAMED 12795
#define IDS_RECENTLY_CLOSED_SPLIT 12796
#define IDS_RECENT_TABS_NO_DEVICE_TABS 12797
#define IDS_RECENT_TABS_LOGIN_FOR_DEVICE_TABS 12798
#define IDS_RECENT_TABS_SEE_DEVICE_TABS 12799
#define IDS_HISTORY_MENU 12800
#define IDS_DEFAULT_DOWNLOAD_FILENAME 12801
#define IDS_DEFAULT_BROWSER_INFOBAR_OK_BUTTON_LABEL 12803
#define IDS_MINIMIZE_WINDOW_MENU 12811
#define IDS_MAXIMIZE_WINDOW_MENU 12812
#define IDS_RESTORE_WINDOW_MENU 12813
#define IDS_CLOSE_WINDOW_MENU 12814
#define IDS_SHOW_WINDOW_DECORATIONS_MENU 12815
#define IDS_USED_EXISTING_BROWSER 12816
#define IDS_DECLINE_RECOVERY 12817
#define IDS_SYNC_ACCOUNT_SYNCING 12818
#define IDS_SYNC_ACCOUNT_SYNCING_CUSTOM_DATA_TYPES 12819
#define IDS_SIGNIN_ERROR_DISPLAY_SOURCE 12820
#define IDS_SIGNIN_ERROR_BUBBLE_VIEW_TITLE 12821
#define IDS_SYNC_ERROR_BUBBLE_VIEW_TITLE 12822
#define IDS_SYNC_ERROR_BUBBLE_VIEW_TITLE_2 12823
#define IDS_SYNC_ERROR_PASSWORDS_BUBBLE_VIEW_TITLE 12824
#define IDS_SYNC_ERROR_USER_MENU_TITLE 12825
#define IDS_SYNC_ERROR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 12826
#define IDS_SYNC_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 12827
#define IDS_SYNC_NEEDS_VERIFICATION_BUBBLE_VIEW_TITLE 12828
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON 12829
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON 12830
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON_MAYBE_TITLE_CASE 12831
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON_MAYBE_TITLE_CASE 12832
#define IDS_SYNC_EMPTY_STRING 12842
#define IDS_SYNC_OVERVIEW 12843
#define IDS_SYNC_START_SYNC_BUTTON_LABEL 12844
#define IDS_SIGNED_IN_WITH_SYNC_DISABLED_BY_POLICY 12845
#define IDS_SYNC_SETTINGS_NOT_CONFIRMED 12847
#define IDS_SYNC_SETUP_IN_PROGRESS 12848
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR 12849
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR_NEEDS_SIGNOUT 12850
#define IDS_SYNC_STATUS_NEEDS_PASSWORD 12851
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON 12852
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON 12853
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON_MAYBE_TITLE_CASE 12854
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON_MAYBE_TITLE_CASE 12855
#define IDS_SYNC_RELOGIN_ERROR 12856
#define IDS_SYNC_RELOGIN_BUTTON 12857
#define IDS_SYNC_RELOGIN_BUTTON_MAYBE_TITLE_CASE 12858
#define IDS_SYNC_ADVANCED_OPTIONS 12860
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM 12862
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM_WITH_DATE 12863
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM 12864
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM_WITH_DATE 12865
#define IDS_PARTIAL_TRANSLATE_BUBBLE_WAITING_TITLE 12866
#define IDS_TRANSLATE_BUBBLE_BEFORE_TRANSLATE_TITLE 12867
#define IDS_TRANSLATE_BUBBLE_TRANSLATED_TITLE 12868
#define IDS_PARTIAL_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 12869
#define IDS_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 12870
#define IDS_TRANSLATE_BUBBLE_SOURCE_LANG_COMBOBOX_ACCNAME 12871
#define IDS_TRANSLATE_BUBBLE_TARGET_LANG_COMBOBOX_ACCNAME 12872
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_COMPLETE_ANNOUNCEMENT 12873
#define IDS_TRANSLATE_BUBBLE_ADVANCED_BUTTON 12874
#define IDS_TRANSLATE_BUBBLE_ADVANCED_MENU_BUTTON 12875
#define IDS_TRANSLATE_BUBBLE_CHANGE_TARGET_LANGUAGE 12876
#define IDS_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 12877
#define IDS_TRANSLATE_BUBBLE_OPEN_LANGUAGE_SETTINGS 12878
#define IDS_PARTIAL_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 12879
#define IDS_TRANSLATE_BUBBLE_ACCEPT 12880
#define IDS_TRANSLATE_BUBBLE_DENY 12881
#define IDS_TRANSLATE_BUBBLE_ALWAYS_TRANSLATE_LANG 12882
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_LANG 12883
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_SITE 12884
#define IDS_TRANSLATE_BUBBLE_TRANSLATING 12885
#define IDS_TRANSLATE_BUBBLE_REVERT 12886
#define IDS_TRANSLATE_BUBBLE_TRY_AGAIN 12887
#define IDS_TRANSLATE_BUBBLE_ALWAYS 12888
#define IDS_TRANSLATE_BUBBLE_OPTIONS_MENU_BUTTON 12889
#define IDS_TRANSLATE_BUBBLE_PAGE_LANGUAGE 12890
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_LANGUAGE 12891
#define IDS_TRANSLATE_BUBBLE_ADVANCED_TARGET 12892
#define IDS_TRANSLATE_BUBBLE_ADVANCED_SOURCE 12893
#define IDS_PARTIAL_TRANSLATE_BUBBLE_ADVANCED_SOURCE 12894
#define IDS_PARTIAL_TRANSLATE_BUBBLE_TRANSLATE_FULL_PAGE 12895
#define IDS_TRANSLATE_BUBBLE_RESET 12896
#define IDS_NOTIFICATION_BUTTON_SETTINGS 12897
#define IDS_NOTIFICATION_BUTTON_CLOSE 12898
#define IDS_NOTIFICATION_BUTTON_MORE 12899
#define IDS_NOTIFICATION_REPLY_PLACEHOLDER 12900
#define IDS_NOTIFICATION_MUTED_MESSAGE 12901
#define IDS_NOTIFICATION_MUTED_TITLE 12902
#define IDS_NOTIFICATION_MUTED_ACTION_SHOW 12903
#define IDS_NOTIFICATION_MUTED_ACTION_SNOOZE 12904
#define IDS_FILE_MENU_LINUX 13028
#define IDS_EDIT_MENU_LINUX 13029
#define IDS_VIEW_MENU_LINUX 13030
#define IDS_HISTORY_MENU_LINUX 13031
#define IDS_TOOLS_MENU_LINUX 13032
#define IDS_HELP_MENU_LINUX 13033
#define IDS_REOPEN_CLOSED_TABS_LINUX 13034
#define IDS_OPEN_FILE_LINUX 13035
#define IDS_OPEN_LOCATION_LINUX 13036
#define IDS_CLOSE_WINDOW_LINUX 13037
#define IDS_CLOSE_TAB_LINUX 13038
#define IDS_STOP_MENU_LINUX 13039
#define IDS_RELOAD_MENU_LINUX 13040
#define IDS_TEXT_DEFAULT_LINUX 13041
#define IDS_TEXT_BIGGER_LINUX 13042
#define IDS_TEXT_SMALLER_LINUX 13043
#define IDS_HISTORY_HOME_LINUX 13044
#define IDS_HISTORY_BACK_LINUX 13045
#define IDS_HISTORY_FORWARD_LINUX 13046
#define IDS_HISTORY_VISITED_LINUX 13047
#define IDS_HISTORY_CLOSED_LINUX 13048
#define IDS_HISTORY_CLOSED_RESTORE_WINDOW_LINUX 13049
#define IDS_HISTORY_CLOSED_RESTORE_GROUP_LINUX 13050
#define IDS_HISTORY_CLOSED_RESTORE_SPLIT_LINUX 13051
#define IDS_ALLOWED_GEOLOCATION_TITLE 13052
#define IDS_BLOCKED_GEOLOCATION_TITLE 13053
#define IDS_ALLOWED_GEOLOCATION_MESSAGE 13054
#define IDS_ALLOWED_GEOLOCATION_BLOCK 13055
#define IDS_ALLOWED_GEOLOCATION_NO_ACTION 13056
#define IDS_BLOCKED_GEOLOCATION_MESSAGE 13057
#define IDS_BLOCKED_GEOLOCATION_UNBLOCK 13058
#define IDS_BLOCKED_GEOLOCATION_NO_ACTION 13059
#define IDS_GEOLOCATION 13060
#define IDS_GEOLOCATION_WILL_ASK_AGAIN 13061
#define IDS_GEOLOCATION_TURNED_OFF 13063
#define IDS_ALLOWED_MIDI_SYSEX_TITLE 13064
#define IDS_BLOCKED_MIDI_SYSEX_TITLE 13065
#define IDS_ALLOWED_MIDI_SYSEX_MESSAGE 13066
#define IDS_ALLOWED_MIDI_SYSEX_BLOCK 13067
#define IDS_ALLOWED_MIDI_SYSEX_NO_ACTION 13068
#define IDS_BLOCKED_MIDI_SYSEX_MESSAGE 13069
#define IDS_BLOCKED_MIDI_SYSEX_UNBLOCK 13070
#define IDS_BLOCKED_MIDI_SYSEX_NO_ACTION 13071
#define IDS_MICROPHONE_CAMERA_ALLOWED 13072
#define IDS_MICROPHONE_CAMERA_BLOCKED 13073
#define IDS_MICROPHONE_ACCESSED 13074
#define IDS_CAMERA_ACCESSED 13075
#define IDS_MICROPHONE_BLOCKED 13076
#define IDS_CAMERA_BLOCKED 13077
#define IDS_MICROPHONE_CAMERA_ALLOWED_TITLE 13078
#define IDS_MICROPHONE_CAMERA_BLOCKED_TITLE 13079
#define IDS_MICROPHONE_ACCESSED_TITLE 13080
#define IDS_CAMERA_ACCESSED_TITLE 13081
#define IDS_MICROPHONE_BLOCKED_TITLE 13082
#define IDS_CAMERA_BLOCKED_TITLE 13083
#define IDS_MEDIASTREAM_SETTING_CHANGED_MESSAGE 13084
#define IDS_A11Y_OMNIBOX_CHIP_HINT 13094
#define IDS_A11Y_INDICATORS_ANNOUNCEMENT 13095
#define IDS_MICROPHONE_CAMERA_IN_USE 13096
#define IDS_MICROPHONE_CAMERA_NOT_ALLOWED 13097
#define IDS_SENSORS_IN_USE 13098
#define IDS_SENSORS_BLOCKED 13099
#define IDS_MICROPHONE_IN_USE 13100
#define IDS_CAMERA_IN_USE 13101
#define IDS_MICROPHONE_NOT_ALLOWED 13102
#define IDS_CAMERA_NOT_ALLOWED 13103
#define IDS_CAMERA_CANNOT_ACCESS 13104
#define IDS_MICROPHONE_CANNOT_ACCESS 13105
#define IDS_CAMERA_MICROPHONE_CANNOT_ACCESS 13106
#define IDS_MANAGE_PASSWORDS_CONFIRM_GENERATED_TEXT 13107
#define IDS_PASSWORDS_WEB_LINK 13108
#define IDS_MANAGE_PASSWORDS_LINK 13110
#define IDS_MANAGE_PASSWORDS_TITLE 13111
#define IDS_MANAGE_PASSWORDS_NO_PASSWORDS_TITLE 13112
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_TITLE 13113
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_NO_PASSWORDS_TITLE 13114
#define IDS_MANAGE_PASSWORDS_SHOW_PASSWORD 13115
#define IDS_MANAGE_PASSWORDS_HIDE_PASSWORD 13116
#define IDS_MANAGE_PASSWORDS_EMPTY_NOTE 13117
#define IDS_MANAGE_PASSWORDS_EDIT_USERNAME_TOOLTIP 13118
#define IDS_MANAGE_PASSWORDS_EDIT_NOTE_TOOLTIP 13119
#define IDS_MANAGE_PASSWORDS_NOTE_ACCESSIBLE_NAME 13120
#define IDS_MANAGE_PASSWORDS_NOTE_TEXTFIELD 13121
#define IDS_MANAGE_PASSWORDS_UPDATE 13122
#define IDS_MANAGE_PASSWORDS_USERNAME_ACCESSIBLE_NAME 13123
#define IDS_MANAGE_PASSWORDS_USERNAME_TEXTFIELD 13124
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE_MD 13125
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TOAST_BODY 13126
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_MANY_DEVICES 13127
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_LOCAL_DEVICE 13128
#define IDS_AUTO_SIGNIN_FIRST_RUN_TEXT 13129
#define IDS_AUTO_SIGNIN_FIRST_RUN_OK 13130
#define IDS_FILE_SELECTION_DIALOG_INFOBAR 13139
#define IDS_ABOUT_LINUX_PROXY_CONFIG_TITLE 13140
#define IDS_ABOUT_LINUX_PROXY_CONFIG_BODY 13141
#define IDS_IMAGE_FILES 13142
#define IDS_AUDIO_FILES 13143
#define IDS_VIDEO_FILES 13144
#define IDS_CUSTOM_FILES 13145
#define IDS_SENSORS_ALLOWED_TOOLTIP 13146
#define IDS_MOTION_SENSORS_ALLOWED_TOOLTIP 13147
#define IDS_SENSORS_BLOCKED_TOOLTIP 13148
#define IDS_MOTION_SENSORS_BLOCKED_TOOLTIP 13149
#define IDS_BLOCKED_SENSORS_UNBLOCK 13150
#define IDS_BLOCKED_SENSORS_NO_ACTION 13151
#define IDS_ALLOWED_SENSORS_TITLE 13152
#define IDS_BLOCKED_SENSORS_TITLE 13153
#define IDS_ALLOWED_SENSORS_MESSAGE 13154
#define IDS_ALLOWED_MOTION_SENSORS_MESSAGE 13155
#define IDS_BLOCKED_SENSORS_MESSAGE 13156
#define IDS_BLOCKED_MOTION_SENSORS_MESSAGE 13157
#define IDS_ALLOWED_SENSORS_NO_ACTION 13158
#define IDS_ALLOWED_SENSORS_BLOCK 13159
#define IDS_LIVE_CAPTION_PROMO 13166
#define IDS_LIVE_CAPTION_PROMO_SCREENREADER 13167
#define IDS_ENABLE_CARET_BROWSING_INFO 13168
#define IDS_CARET_BROWSING_DO_NOT_ASK 13175
#define IDS_ENABLE_CARET_BROWSING_TITLE 13176
#define IDS_ENABLE_CARET_BROWSING_TURN_ON 13177
#define IDS_MEDIA_GALLERIES_DIALOG_HEADER 13178
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_WRITE 13179
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_DELETE 13180
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_ONLY 13181
#define IDS_MEDIA_GALLERIES_PERMISSION_SUGGESTIONS 13182
#define IDS_MEDIA_GALLERIES_LAST_ATTACHED 13183
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY 13184
#define IDS_MEDIA_GALLERIES_DIALOG_CONFIRM 13185
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY_TITLE 13186
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_ATTACHED 13187
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_NOT_ATTACHED 13188
#define IDS_MEDIA_GALLERIES_DIALOG_DELETE 13189
#define IDS_CHROME_SHORTCUT_DESCRIPTION 13191
#define IDS_WEBSTORE_NAME_STORE 13192
#define IDS_DESKTOP_MEDIA_PICKER_TITLE 13193
#define IDS_DISPLAY_MEDIA_PICKER_TITLE 13194
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_SCREEN_ONLY 13195
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WINDOW_ONLY 13196
#define IDS_DESKTOP_MEDIA_PICKER_TEXT 13197
#define IDS_DISPLAY_MEDIA_PICKER_TEXT 13198
#define IDS_DESKTOP_MEDIA_PICKER_TEXT_DELEGATED 13199
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_SCREEN_WITH_MUTE_WARNING 13200
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_SYSTEM_AUDIO 13201
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_APPLICATION_AUDIO 13202
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_ALL_AUDIO_OUTPUT 13203
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_TAB_AUDIO 13204
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB 13205
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_SCREEN 13206
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_WINDOW 13207
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_SCREEN 13208
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_WINDOW 13209
#define IDS_DESKTOP_MEDIA_PICKER_SINGLE_SCREEN_NAME 13210
#define IDS_DESKTOP_MEDIA_PICKER_MULTIPLE_SCREEN_NAME 13211
#define IDS_DESKTOP_MEDIA_PICKER_MANAGED 13212
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_BUTTON_MAC 13213
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_SCREEN 13214
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_WINDOW 13215
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_THIS_TAB 13216
#define IDS_DESKTOP_MEDIA_PICKER_EMPTY_PREVIEW 13217
#define IDS_DESKTOP_MEDIA_PICKER_PREVIEW_ACCESSIBLE_NAME 13218
#define IDS_DESKTOP_MEDIA_SOURCE_EMPTY_ACCESSIBLE_NAME 13219
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_TEXT 13220
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_BUTTON 13221
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_TEXT 13222
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_BUTTON 13223
#define IDS_SHARE_THIS_TAB_DIALOG_TITLE 13224
#define IDS_SHARE_THIS_TAB_DIALOG_TEXT 13225
#define IDS_SHARE_THIS_TAB_DIALOG_ALLOW 13226
#define IDS_SHARE_THIS_TAB_AUDIO_SHARE 13227
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TITLE 13228
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TEXT 13229
#define IDS_TOOLTIP_TAB_ALERT_STATE_MEDIA_RECORDING 13230
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_RECORDING 13231
#define IDS_TOOLTIP_TAB_ALERT_STATE_VIDEO_RECORDING 13232
#define IDS_TOOLTIP_TAB_ALERT_STATE_TAB_CAPTURING 13233
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_PLAYING 13234
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_MUTING 13235
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_CONNECTED 13236
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_SCAN_ACTIVE 13237
#define IDS_TOOLTIP_TAB_ALERT_STATE_USB_CONNECTED 13238
#define IDS_TOOLTIP_TAB_ALERT_STATE_HID_CONNECTED 13239
#define IDS_TOOLTIP_TAB_ALERT_STATE_SERIAL_CONNECTED 13240
#define IDS_TOOLTIP_TAB_ALERT_STATE_PIP_PLAYING 13241
#define IDS_TOOLTIP_TAB_ALERT_STATE_DESKTOP_CAPTURING 13242
#define IDS_TOOLTIP_TAB_ALERT_STATE_VR_PRESENTING 13243
#define IDS_TAB_AX_LABEL_MEDIA_RECORDING_FORMAT 13244
#define IDS_TAB_AX_LABEL_AUDIO_RECORDING_FORMAT 13245
#define IDS_TAB_AX_LABEL_VIDEO_RECORDING_FORMAT 13246
#define IDS_TAB_AX_LABEL_TAB_CAPTURING_FORMAT 13247
#define IDS_TAB_AX_LABEL_PIP_PLAYING_FORMAT 13248
#define IDS_TAB_AX_LABEL_AUDIO_PLAYING_FORMAT 13249
#define IDS_TAB_AX_LABEL_AUDIO_MUTING_FORMAT 13250
#define IDS_TAB_AX_LABEL_BLUETOOTH_CONNECTED_FORMAT 13251
#define IDS_TAB_AX_LABEL_BLUETOOTH_SCAN_ACTIVE_FORMAT 13252
#define IDS_TAB_AX_LABEL_USB_CONNECTED_FORMAT 13253
#define IDS_TAB_AX_LABEL_HID_CONNECTED_FORMAT 13254
#define IDS_TAB_AX_LABEL_SERIAL_CONNECTED_FORMAT 13255
#define IDS_TAB_AX_LABEL_NETWORK_ERROR_FORMAT 13256
#define IDS_TAB_AX_LABEL_CRASHED_FORMAT 13257
#define IDS_TAB_AX_LABEL_DESKTOP_CAPTURING_FORMAT 13258
#define IDS_TAB_AX_LABEL_VR_PRESENTING 13259
#define IDS_TAB_AX_LABEL_SPLIT_TAB_LEFT_VIEW_FORMAT 13260
#define IDS_TAB_AX_LABEL_SPLIT_TAB_RIGHT_VIEW_FORMAT 13261
#define IDS_TAB_AX_LABEL_SPLIT_TAB_TOP_VIEW_FORMAT 13262
#define IDS_TAB_AX_LABEL_SPLIT_TAB_BOTTOM_VIEW_FORMAT 13263
#define IDS_TAB_AX_LABEL_UNNAMED_GROUP_FORMAT 13264
#define IDS_TAB_AX_LABEL_NAMED_GROUP_FORMAT 13265
#define IDS_TAB_AX_LABEL_PINNED_FORMAT 13266
#define IDS_TAB_AX_LABEL_PERMISSION_REQUESTED_FORMAT 13267
#define IDS_GROUP_AX_LABEL_UNNAMED_GROUP_FORMAT 13268
#define IDS_GROUP_AX_LABEL_NAMED_GROUP_FORMAT 13269
#define IDS_GROUP_AX_LABEL_COLLAPSED 13270
#define IDS_GROUP_AX_LABEL_EXPANDED 13271
#define IDS_GROUP_AX_LABEL_UNNAMED_SAVED_GROUP_FORMAT 13272
#define IDS_GROUP_AX_LABEL_NAMED_SAVED_GROUP_FORMAT 13273
#define IDS_GROUP_AX_LABEL_GROUP_MENU_ITEM_FORMAT 13274
#define IDS_SAVED_GROUP_AX_LABEL_OPENED 13275
#define IDS_SAVED_GROUP_AX_LABEL_CLOSED 13276
#define IDS_SAVED_GROUP_AX_LABEL_SHARED 13277
#define IDS_TAB_AX_ANNOUNCE_MOVED_RIGHT 13278
#define IDS_TAB_AX_ANNOUNCE_MOVED_LEFT 13279
#define IDS_TAB_AX_ANNOUNCE_MOVED_UP 13280
#define IDS_TAB_AX_ANNOUNCE_MOVED_DOWN 13281
#define IDS_TAB_AX_ANNOUNCE_MOVED_FIRST 13282
#define IDS_TAB_AX_ANNOUNCE_MOVED_LAST 13283
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_UNNAMED_GROUP 13284
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_NAMED_GROUP 13285
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_UNNAMED_GROUP 13286
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_NAMED_GROUP 13287
#define IDS_PAGE_LOADING_AX_TITLE_FORMAT 13288
#define IDS_TAB_AX_INACTIVE_TAB 13289
#define IDS_TAB_AX_MEMORY_SAVINGS 13290
#define IDS_TAB_AX_MEMORY_USAGE 13291
#define IDS_TAB_AX_HIGH_MEMORY_USAGE 13292
#define IDS_PROFILE_IN_USE_LINUX_QUIT 13293
#define IDS_PROFILE_IN_USE_LINUX_RELAUNCH 13294
#define IDS_DESKTOP_MEDIA_PICKER_SHARE 13312
#define IDS_PUSH_MESSAGING_GENERIC_NOTIFICATION_BODY 13313
#define IDS_DEVICE_PERMISSIONS_DIALOG_SELECT 13314
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL 13315
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL_TOOLTIP 13316
#define IDS_DEVICE_LOG_TITLE 13317
#define IDS_DEVICE_AUTO_REFRESH 13318
#define IDS_DEVICE_SELECT_TYPES 13319
#define IDS_DEVICE_LOG_REFRESH 13320
#define IDS_DEVICE_LOG_CLEAR 13321
#define IDS_DEVICE_LOG_CLEAR_TYPES 13322
#define IDS_DEVICE_LOG_NO_ENTRIES 13323
#define IDS_DEVICE_LOG_LEVEL_LABEL 13324
#define IDS_DEVICE_LOG_LEVEL_ERROR 13325
#define IDS_DEVICE_LOG_LEVEL_USER 13326
#define IDS_DEVICE_LOG_LEVEL_EVENT 13327
#define IDS_DEVICE_LOG_LEVEL_DEBUG 13328
#define IDS_DEVICE_LOG_TYPE_LOGIN 13329
#define IDS_DEVICE_LOG_TYPE_MEMORY 13330
#define IDS_DEVICE_LOG_TYPE_NETWORK 13331
#define IDS_DEVICE_LOG_TYPE_POWER 13332
#define IDS_DEVICE_LOG_TYPE_BLUETOOTH 13333
#define IDS_DEVICE_LOG_TYPE_USB 13334
#define IDS_DEVICE_LOG_TYPE_HID 13335
#define IDS_DEVICE_LOG_TYPE_PRINTER 13336
#define IDS_DEVICE_LOG_TYPE_FIDO 13337
#define IDS_DEVICE_LOG_TYPE_SERIAL 13338
#define IDS_DEVICE_LOG_TYPE_CAMERA 13339
#define IDS_DEVICE_LOG_TYPE_GEOLOCATION 13340
#define IDS_DEVICE_LOG_TYPE_EXTENSIONS 13341
#define IDS_DEVICE_LOG_TYPE_DISPLAY 13342
#define IDS_DEVICE_LOG_TYPE_FIRMWARE 13343
#define IDS_DEVICE_LOG_FILEINFO 13344
#define IDS_DEVICE_LOG_TIME_DETAIL 13345
#define IDS_DEVICE_LOG_ENTRY 13346
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION 13347
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION_TITLE 13348
#define IDS_WEBHID_SYSTEM_TRAY_ICON_HID_SETTINGS 13349
#define IDS_WEBHID_SYSTEM_TRAY_ICON_ABOUT_HID_DEVICE 13350
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_USB_SETTINGS 13351
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_ABOUT_USB_DEVICE 13352
#define IDS_DEVICE_CONNECTED_BY_EXTENSION 13355
#define IDS_DEFAULT_AUDIO_DEVICE_NAME 13364
#define IDS_SERIAL_DEVICE_CHOOSER_ADAPTER_OFF 13373
#define IDS_SERIAL_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 13374
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 13375
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN 13376
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN_TOOLTIP 13377
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_SCANNING_STATUS 13378
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_RE_SCAN_LINK 13379
#define IDS_DEVICE_CHOOSER_PAIRED_STATUS_TEXT 13380
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_AND_PAIRED_STATUS_TEXT 13381
#define IDS_DEVICE_CHOOSER_ACCNAME_COMPATIBLE_DEVICES_LIST 13382
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_NAME 13383
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_ID_AND_PRODUCT_ID 13384
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_NAME 13385
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_ID 13386
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_ID 13387
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_NAME 13388
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_ANY_VENDOR 13389
#define IDS_SERIAL_PORT_CHOOSER_PROMPT 13390
#define IDS_SERIAL_PORT_CHOOSER_CONNECT_BUTTON_TEXT 13391
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL 13392
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL_TOOLTIP 13393
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_NAME 13394
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_NAME 13395
#define IDS_SERIAL_PORT_CHOOSER_NAME_WITH_PATH 13396
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_ID 13397
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_ID 13398
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_ANY_PORT 13399
#define IDS_HID_CHOOSER_PROMPT 13400
#define IDS_HID_CHOOSER_ITEM_WITHOUT_NAME 13401
#define IDS_HID_CHOOSER_LOADING_LABEL 13402
#define IDS_HID_CHOOSER_LOADING_LABEL_TOOLTIP 13403
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID_AND_PRODUCT_ID 13404
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID 13405
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_AND_USAGE_PAGE 13406
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_PAGE 13407
#define IDS_HID_POLICY_DESCRIPTION_FOR_ANY_DEVICE 13408
#define IDS_WEB_APP_FILE_HANDLING_LIST_SEPARATOR 13409
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION 13410
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION_MULTIPLE 13411
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_STICKY_CHOICE 13412
#define IDS_WEB_APP_FILE_HANDLING_POSITIVE_BUTTON 13413
#define IDS_WEB_APP_FILE_HANDLING_NEGATIVE_BUTTON 13414
#define IDS_WEB_APP_PERMISSION_NEGATIVE_BUTTON 13415
#define IDS_PROTOCOL_HANDLER_INTENT_PICKER_QUESTION 13416
#define IDS_FONT_ACCESS_CHOOSER_PROMPT_ORIGIN 13417
#define IDS_FONT_ACCESS_CHOOSER_NO_FONTS_FOUND_PROMPT 13418
#define IDS_FONT_ACCESS_CHOOSER_IMPORT_BUTTON_TEXT 13419
#define IDS_FONT_ACCESS_CHOOSER_CANCEL_BUTTON_TEXT 13420
#define IDS_FONT_ACCESS_CHOOSER_SELECT_ALL_CHECKBOX_TEXT 13421
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL 13422
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL_TOOLTIP 13423
#define IDS_IME_API_ACTIVATED_WARNING 13424
#define IDS_IME_API_NEVER_SHOW 13425
#define IDS_BLOCKED_ADS_PROMPT_TOOLTIP 13426
#define IDS_REDIRECT_BLOCKED_MESSAGE 13429
#define IDS_REDIRECT_BLOCKED_TITLE 13430
#define IDS_REDIRECT_BLOCKED_TOOLTIP 13431
#define IDS_ALWAYS_ALLOW_REDIRECTS 13432
#define IDS_OPEN_REDIRECT 13433
#define IDS_UTILITY_PROCESS_SYSTEM_SIGNALS_NAME 13434
#define IDS_CONTROLLED_BY_AUTOMATION 13437
#define IDS_CHROME_FOR_TESTING_DISCLAIMER 13438
#define IDS_DOWNLOAD_CHROME 13439
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_TITLE 13441
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_MESSAGE 13442
#define IDS_CONFIRM_FILE_UPLOAD_TITLE 13443
#define IDS_CONFIRM_FILE_UPLOAD_TEXT 13444
#define IDS_CONFIRM_FILE_UPLOAD_OK_BUTTON 13445
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_TITLE 13446
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_ALLOW_TEXT 13447
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_FILE_TEXT 13448
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_DIRECTORY_TEXT 13449
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_FILE_TEXT 13450
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_DIRECTORY_TEXT 13451
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_FILE_TEXT 13452
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_DIRECTORY_TEXT 13453
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_FILE_TEXT 13454
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_DIRECTORY_TEXT 13455
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_TITLE 13456
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_TITLE 13457
#define IDS_FILE_SYSTEM_ACCESS_READ_FILE_PERMISSION_TITLE 13458
#define IDS_FILE_SYSTEM_ACCESS_READ_DIRECTORY_PERMISSION_TITLE 13459
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_ALLOW_TEXT 13460
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_ALLOW_TEXT 13461
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_ALLOW_TEXT 13462
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_ALLOW_TEXT 13463
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_CANCEL_TEXT 13464
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_CANCEL_TEXT 13465
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_CANCEL_TEXT 13466
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_CANCEL_TEXT 13467
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_CANCEL_TEXT 13468
#define IDS_FILE_SYSTEM_ACCESS_RESTORE_PERMISSION_DESCRIPTION 13469
#define IDS_FILE_SYSTEM_ACCESS_WRITE_USAGE_TOOLTIP 13470
#define IDS_FILE_SYSTEM_ACCESS_DIRECTORY_USAGE_TOOLTIP 13471
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_FILE_TEXT 13472
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_TEXT 13473
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_DIRECTORY_TEXT 13474
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_DIRECTORIES_TEXT 13475
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_AND_DIRECTORIES_TEXT 13476
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_FILE_TEXT 13477
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_TEXT 13478
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_DIRECTORY_TEXT 13479
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_DIRECTORIES_TEXT 13480
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_AND_DIRECTORIES_TEXT 13481
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READ_AND_WRITE 13482
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SAVE_CHANGES 13483
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_VIEW_CHANGES 13484
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_FILES_TEXT 13485
#define IDS_FILE_SYSTEM_ACCESS_USAGE_EXPAND 13486
#define IDS_FILE_SYSTEM_ACCESS_USAGE_COLLAPSE 13487
#define IDS_FILE_SYSTEM_ACCESS_USAGE_REMOVE_ACCESS 13488
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_DIRECTORY_TITLE 13489
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_WRITABLE_DIRECTORY_TITLE 13490
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_SAVE_FILE_TITLE 13491
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILE_TITLE 13492
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILES_TITLE 13493
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TITLE 13494
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TEXT 13495
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_BUTTON 13496
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TITLE 13497
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TEXT 13498
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_BUTTON 13499
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TITLE 13500
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TEXT 13501
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_DONT_SAVE 13502
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_SAVE 13503
#define IDS_RELAUNCH_ACCEPT_BUTTON 13504
#define IDS_RELAUNCH_REQUIRED_CANCEL_BUTTON 13505
#define IDS_IDLE_TIMEOUT_INCOGNITO 13506
#define IDS_IDLE_TIMEOUT_CLOSE_COUNTDOWN 13507
#define IDS_IDLE_TIMEOUT_CLEAR_COUNTDOWN 13508
#define IDS_WEBAUTHN_GENERIC_TITLE 13509
#define IDS_WEBAUTHN_CONTINUE 13510
#define IDS_WEBAUTHN_TRANSPORT_USB 13511
#define IDS_WEBAUTHN_TRANSPORT_INTERNAL 13513
#define IDS_WEBAUTHN_TRANSPORT_CABLE 13514
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO_OR_SECURITY_KEY 13515
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO 13516
#define IDS_WEBAUTHN_TRANSPORT_ICLOUD_KEYCHAIN 13517
#define IDS_WEBAUTHN_TRANSPORT_EXTERNAL_SECURITY_KEY 13518
#define IDS_WEBAUTHN_USB_ACTIVATE_DESCRIPTION 13519
#define IDS_WEBAUTHN_ERROR_GENERIC_TITLE 13520
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_TITLE 13521
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_TITLE 13522
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_REGISTER_DESCRIPTION 13523
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_SIGN_DESCRIPTION 13524
#define IDS_WEBAUTHN_ERROR_TIMEOUT_DESCRIPTION 13525
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_TITLE 13526
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_DESCRIPTION 13527
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_TITLE 13528
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_DESCRIPTION 13529
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_TITLE 13530
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_DESCRIPTION 13531
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_TITLE 13532
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_DESCRIPTION 13533
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_TITLE 13534
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_DESCRIPTION 13535
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_NEXT 13536
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_TITLE 13537
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 13538
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_NEXT 13539
#define IDS_WEBAUTHN_LOADING 13540
#define IDS_WEBAUTHN_CABLEV2_CONNECTING_TITLE 13542
#define IDS_WEBAUTHN_CABLEV2_CONNECTED_DESCRIPTION 13543
#define IDS_WEBAUTHN_CABLEV2_ERROR_DESCRIPTION 13544
#define IDS_WEBAUTHN_CABLEV2_ERROR_CLOSE 13545
#define IDS_WEBAUTHN_PASSKEY_PHONE_OR_TABLET_LABEL 13546
#define IDS_WEBAUTHN_PASSKEY_PHONE_TABLET_OR_SECURITY_KEY_LABEL 13547
#define IDS_WEBAUTHN_PIN_ENTRY_TITLE 13548
#define IDS_WEBAUTHN_PIN_ENTRY_DESCRIPTION 13549
#define IDS_WEBAUTHN_PIN_ENTRY_PIN_LABEL 13550
#define IDS_WEBAUTHN_PIN_ENTRY_NEXT 13551
#define IDS_WEBAUTHN_PIN_SETUP_DESCRIPTION 13552
#define IDS_WEBAUTHN_PIN_SETUP_CONFIRMATION_LABEL 13553
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_INVALID_CHARACTERS 13554
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_TOO_SHORT 13555
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED_RETRIES 13556
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED 13557
#define IDS_WEBAUTHN_PIN_TAP_AGAIN_DESCRIPTION 13558
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_MISMATCH 13559
#define IDS_WEBAUTHN_CLIENT_PIN_SOFT_BLOCK_DESCRIPTION 13560
#define IDS_WEBAUTHN_CLIENT_PIN_HARD_BLOCK_DESCRIPTION 13561
#define IDS_WEBAUTHN_CLIENT_PIN_AUTHENTICATOR_REMOVED_DESCRIPTION 13562
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_SAME_AS_CURRENT 13563
#define IDS_WEBAUTHN_INLINE_ENROLLMENT_CANCEL_LABEL 13564
#define IDS_WEBAUTHN_UV_RETRY_TITLE 13565
#define IDS_WEBAUTHN_UV_RETRY_DESCRIPTION 13566
#define IDS_WEBAUTHN_UV_RETRY_ERROR_FAILED_RETRIES 13567
#define IDS_WEBAUTHN_UV_ERROR_LOCKED 13568
#define IDS_WEBAUTHN_FORCE_PIN_CHANGE 13569
#define IDS_WEBAUTHN_UNKNOWN_ACCOUNT 13570
#define IDS_WEBAUTHN_RESIDENT_KEY_PRIVACY 13571
#define IDS_WEBAUTHN_RESIDENT_KEY_PREFERRED_PRIVACY 13572
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_TITLE 13573
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_DESC 13574
#define IDS_WEBAUTHN_STORAGE_FULL_DESC 13575
#define IDS_WEBAUTHN_ATTESTATION_WARNING 13576
#define IDS_WEBAUTHN_ENTERPRISE_ATTESTATION_WARNING 13577
#define IDS_WEBAUTHN_RETRY 13578
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_TITLE 13579
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DESCRIPTION 13580
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DENY 13581
#define IDS_WEBAUTHN_CREATE_PASSKEY_TITLE 13582
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA 13583
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA_INCOGNITO 13584
#define IDS_WEBAUTHN_CREATE_PASSKEY_CHOOSE_DEVICE_TITLE 13585
#define IDS_WEBAUTHN_USE_PASSKEY_TITLE 13586
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_TITLE 13587
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_BODY 13588
#define IDS_WEBAUTHN_QR_CODE_ALT_TEXT 13589
#define IDS_WEBAUTHN_USE_A_DIFFERENT_PASSKEY 13590
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_FOR_RP_TITLE 13591
#define IDS_WEBAUTHN_THIS_DEVICE_LABEL 13592
#define IDS_WEBAUTHN_OTHER_DEVICES_LABEL 13593
#define IDS_WEBAUTHN_SOURCE_CHROME_PROFILE 13594
#define IDS_WEBAUTHN_SOURCE_ICLOUD_KEYCHAIN 13595
#define IDS_WEBAUTHN_SOURCE_WINDOWS_HELLO 13596
#define IDS_WEBAUTHN_SOURCE_GOOGLE_PASSWORD_MANAGER 13597
#define IDS_WEBAUTHN_SOURCE_USB_SECURITY_KEY 13598
#define IDS_WEBAUTHN_PASSKEYS_AND_SECURITY_KEYS 13599
#define IDS_WEBAUTHN_PASSKEYS 13600
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET 13601
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_CREATE_DESCRIPTION 13602
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_SIGN_IN_DESCRIPTION 13603
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY 13604
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_CREATE_DESCRIPTION 13605
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_SIGN_IN_DESCRIPTION 13606
#define IDS_WEBAUTHN_CREATE 13607
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_TITLE 13608
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_DESC 13609
#define IDS_WEBAUTHN_SAVE_ANOTHER_WAY 13610
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_TITLE 13611
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_DESC 13612
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_TITLE 13613
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_DESC 13614
#define IDS_WEBAUTHN_USE_A_DIFFERENT_DEVICE 13615
#define IDS_WEBAUTHN_TOUCH_ID_ASSERTION_DESC 13616
#define IDS_WEBAUTHN_TOUCH_ID_CONTINUE 13617
#define IDS_WEBAUTHN_TOUCH_ID_LOCKED 13618
#define IDS_WEBAUTHN_TOUCH_ID_ENTER_PASSWORD 13619
#define IDS_WEBAUTHN_GPM_ERROR_TITLE 13620
#define IDS_WEBAUTHN_GPM_ERROR_DESC 13621
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_TITLE 13622
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_DESCRIPTION 13623
#define IDS_WEBAUTHN_GPM_PIN_OPTION_NUMBERS 13624
#define IDS_WEBAUTHN_GPM_PIN_OPTION_ALPHANUMERIC 13625
#define IDS_WEBAUTHN_GPM_CREATE_PIN_TITLE 13626
#define IDS_WEBAUTHN_GPM_CREATE_ALPHANUMERIC_PIN_ACCESSIBILITY 13627
#define IDS_WEBAUTHN_GPM_CREATE_PIN_DESC 13628
#define IDS_WEBAUTHN_GPM_ENTER_PIN_TITLE 13629
#define IDS_WEBAUTHN_GPM_ENTER_ALPHANUMERIC_PIN_ACCESSIBILITY_WITH_WEBSITE 13630
#define IDS_WEBAUTHN_GPM_ENTER_PIN_DESC 13631
#define IDS_WEBAUTHN_GPM_SIX_DIGIT_PIN_ACCESSIBILITY_LABEL 13632
#define IDS_WEBAUTHN_FORGOT_GPM_PIN_BUTTON 13633
#define IDS_WEBAUTHN_GPM_PIN_OPTIONS_BUTTON 13634
#define IDS_WEBAUTHN_GPM_WRONG_PIN_ERROR 13635
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_TITLE 13636
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_PIN_CREATED_TITLE 13637
#define IDS_WEBAUTHN_SHOW_PIN 13638
#define IDS_WEBAUTHN_HIDE_PIN 13639
#define IDS_WEBAUTHN_CHANGE_PIN 13640
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_TITLE 13641
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_DESCRIPTION 13642
#define IDS_WEBAUTHN_GPM_PIN_DIGIT_HINT 13643
#define IDS_WEBAUTHN_GPM_PIN_LENGTH_HINT 13644
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LABEL 13645
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LINK 13646
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_TITLE 13647
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_LABEL 13648
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_TITLE 13649
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LABEL 13650
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LINK 13651
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_TITLE 13652
#define IDS_WEBAUTHN_GPM_PASSKEY_DOESNT_WORK_LABEL 13653
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_LINK 13654
#define IDS_WEBAUTHN_GPM_SETTINGS 13655
#define IDS_WEBAUTHN_SIGN_IN_TO_WEBSITE_DIALOG_TITLE 13656
#define IDS_WEBAUTHN_SIGN_IN_AS_PROMPT 13657
#define IDS_PASSKEY_UPGRADE_BUBBLE_TITLE 13658
#define IDS_PASSKEY_UPGRADE_BUBBLE_DESCRIPTION 13659
#define IDS_PASSKEY_UPGRADE_BUBBLE_LEARN_MORE 13660
#define IDS_PASSKEY_UPGRADE_BUBBLE_MANAGE_BUTTON 13661
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_TITLE 13662
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 13663
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_NEXT 13664
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_TITLE 13665
#define IDS_WEB_DIGITAL_CREDENTIALS_PRESENTATION_QR_BODY 13666
#define IDS_WEB_DIGITAL_CREDENTIALS_ISSUANCE_QR_BODY 13667
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_CODE_ALT_TEXT 13668
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTING_TITLE 13669
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTED_TITLE 13670
#define IDS_WEB_DIGITAL_CREDENTIALS_FLOW_CANCEL_BUTTON_TEXT 13671
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_DIALOG_TITLE 13672
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_DIALOG_TEXT 13673
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_NEGATIVE_BUTTON_TEXT 13674
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_DIALOG_TEXT 13675
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_NEGATIVE_BUTTON_TEXT 13676
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_POSITIVE_BUTTON_TEXT 13677
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_REQUEST_ABORTED_DIALOG_TEXT 13678
#define IDS_INCOGNITO_PROFILE_MENU_TITLE 13679
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_BUTTON 13680
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_PRIMARY_TEXT 13681
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_SECONDARY_TEXT 13682
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_CLOSE_WINDOWS_BUTTON 13683
#define IDS_INCOGNITO_HISTORY_BUBBLE_PRIMARY_TEXT 13684
#define IDS_INCOGNITO_HISTORY_BUBBLE_SECONDARY_TEXT 13685
#define IDS_INCOGNITO_HISTORY_BUBBLE_CLOSE_INCOGNITO_BUTTON_TEXT 13686
#define IDS_INCOGNITO_HISTORY_BUBBLE_CANCEL_BUTTON_TEXT 13687
#define IDS_NOTIFICATION_DEFAULT_HELPFUL_BUTTON_TEXT 13688
#define IDS_NOTIFICATION_DEFAULT_UNHELPFUL_BUTTON_TEXT 13689
#define IDS_DEEP_SCANNING_DIALOG_TITLE 13690
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_PENDING_MESSAGE 13691
#define IDS_DEEP_SCANNING_DIALOG_PRINT_PENDING_MESSAGE 13692
#define IDS_DEEP_SCANNING_DIALOG_SUCCESS_MESSAGE 13693
#define IDS_DEEP_SCANNING_DIALOG_PRINT_SUCCESS_MESSAGE 13694
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAILURE_MESSAGE 13695
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAIL_CLOSED_MESSAGE 13696
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_WARNING_MESSAGE 13697
#define IDS_DEEP_SCANNING_DIALOG_PRINT_WARNING_MESSAGE 13698
#define IDS_DEEP_SCANNING_DIALOG_TIMEOUT_MESSAGE 13699
#define IDS_DEEP_SCANNING_DIALOG_PROCEED_BUTTON 13700
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_WARNING_BUTTON 13701
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_UPLOAD_BUTTON 13702
#define IDS_DEEP_SCANNING_DIALOG_LARGE_FILE_FAILURE_MESSAGE 13703
#define IDS_DEEP_SCANNING_DIALOG_LARGE_PRINT_FAILURE_MESSAGE 13704
#define IDS_DEEP_SCANNING_DIALOG_ENCRYPTED_FILE_FAILURE_MESSAGE 13705
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE 13706
#define IDS_DEEP_SCANNING_DIALOG_COMBINED_CUSTOM_MESSAGE 13707
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_SENSITIVE_DATA 13708
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE_LEARN_MORE_LINK 13709
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_DISCARD_FILE_BUTTON 13710
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_BYPASS_JUSTIFICATION_LABEL 13711
#define IDS_DEEP_SCANNING_DIALOG_PASTE_BYPASS_JUSTIFICATION_LABEL 13712
#define IDS_DEEP_SCANNING_DIALOG_PRINT_BYPASS_JUSTIFICATION_LABEL 13713
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOAD_BYPASS_JUSTIFICATION_LABEL 13714
#define IDS_DEEP_SCANNING_DIALOG_BYPASS_JUSTIFICATION_TEXT_LIMIT_LABEL 13715
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_LABEL 13716
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_FILENAME_PLACEHOLDER 13717
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_MESSAGE 13718
#define IDS_DATA_SHARING_BUBBLE_DIALOG_TITLE 13719
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_TEXT 13720
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_CLOSE_BUTTON_ARIA_LABEL_TEXT 13721
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_TITLE 13722
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_TITLE 13723
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_MAIN_TEXT 13724
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_MAIN_TEXT 13725
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_ACCEPT_BUTTON 13726
#define IDS_TAILORED_SECURITY_DIALOG_SETTINGS_BUTTON 13727
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_TITLE 13728
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_BODY 13729
#define IDS_TAILORED_SECURITY_UNCONSENTED_ACCEPT_BUTTON 13730
#define IDS_TAILORED_SECURITY_UNCONSENTED_CANCEL_BUTTON 13731
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_TITLE 13732
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_DESCRIPTION 13733
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_TITLE 13734
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_DESCRIPTION 13735
#define IDS_TAILORED_SECURITY_CONSENTED_MESSAGE_OK_BUTTON 13736
#define IDS_TAILORED_SECURITY_CONSENTED_ENHANCED_PROTECTION_ENABLE_MESSAGE_TITLE 13737
#define IDS_PROMPT_APP_UNINSTALL_TITLE 13738
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_NON_GOOGLE 13739
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_GOOGLE 13740
#define IDS_APP_UNINSTALL_PROMPT_LEARN_MORE 13741
#define IDS_APP_UNINSTALL_PROMPT_ADDITIONAL_UNINSTALLS_MESSAGE 13742
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_TITLE 13743
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_DESCRIPTION 13744
#define IDS_UTILITY_PROCESS_SPEECH_RECOGNITION_SERVICE_NAME 13745
#define IDS_APP_PAUSE_PROMPT_TITLE 13746
#define IDS_APP_PAUSE_HEADING 13747
#define IDS_APP_PAUSE_HEADING_FOR_WEB_APPS 13748
#define IDS_APP_BLOCK_PROMPT_TITLE 13749
#define IDS_APP_BLOCK_HEADING_FOR_CHILD 13750
#define IDS_APP_BLOCK_HEADING 13751
#define IDS_APP_LOCAL_BLOCK_PROMPT_TITLE 13752
#define IDS_APP_LOCAL_BLOCK_PROMPT_MULTIPLE_TITLE 13753
#define IDS_APP_LOCAL_BLOCK_HEADING 13754
#define IDS_ENTERPRISE_EXTENSION_REQUEST_APPROVED_TITLE 13755
#define IDS_ENTERPRISE_EXTENSION_REQUEST_REJECTED_TITLE 13756
#define IDS_ENTERPRISE_EXTENSION_REQUEST_FORCE_INSTALLED_TITLE 13757
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_INSTALL 13758
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_VIEW 13759
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION 13760
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_PLACEHOLDER 13761
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_LENGTH_LIMIT 13762
#define IDS_NAME_WINDOW_PROMPT_TITLE 13763
#define IDS_NAME_WINDOW_PROMPT_FIELD_LABEL 13764
#define IDS_CHROMELABS_RELAUNCH_BUTTON_LABEL 13765
#define IDS_WINDOW_TITLE_EXPERIMENTS 13766
#define IDS_CHROMELABS_SEND_FEEDBACK 13767
#define IDS_CHROMELABS_SEND_FEEDBACK_DESCRIPTION_PLACEHOLDER 13768
#define IDS_CHROMELABS_DEFAULT 13769
#define IDS_CHROMELABS_ENABLED 13770
#define IDS_CHROMELABS_DISABLED 13771
#define IDS_CHROMELABS_ENABLED_WITH_VARIATION_NAME 13772
#define IDS_LENS_REGION_SEARCH_BUBBLE_TEXT 13773
#define IDS_CAPTURE_REGION_BUBBLE_TEXT 13774
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_NAME 13775
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_DESCRIPTION 13776
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_DESCRIPTION 13779
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_ACCEPT 13780
#define IDS_TAILORED_SECURITY_CONSENTED_PROMOTION_MESSAGE_TURN_ON 13781
#define IDS_TAILORED_SECURITY_CONSENTED_ESB_OFF_MESSAGE_TITLE 13782
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_IN 13783
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_UP 13784
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_USE 13785
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_CONTINUE 13786
#define IDS_ACCOUNT_SELECTION_SHEET_SUBTITLE_FOR_EMBED 13787
#define IDS_ACCOUNT_SELECTION_CONTINUE 13788
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT 13789
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT_BUTTON 13790
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_NAME 13791
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_EMAIL 13792
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PICTURE 13793
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PHONE 13794
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_USERNAME 13795
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP_OR_TOS 13796
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP 13797
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_TOS 13798
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT 13799
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT 13800
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT_MULTI_IDP 13801
#define IDS_ACCOUNT_SELECTION_OPENS_IN_NEW_TAB 13802
#define IDS_ACCOUNT_SELECTION_BACK 13803
#define IDS_SIGNIN_CONTINUE 13804
#define IDS_IDP_SIGNIN_STATUS_MISMATCH_DIALOG_BODY 13805
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_SUMMARY 13806
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_DESCRIPTION 13807
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_SUMMARY 13808
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_DESCRIPTION 13809
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_SUMMARY 13810
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_DESCRIPTION 13811
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_SUMMARY 13812
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_DESCRIPTION 13813
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_SUMMARY 13814
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_DESCRIPTION 13815
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_SUMMARY 13816
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_DESCRIPTION 13817
#define IDS_SIGNIN_ERROR_DIALOG_GOT_IT_BUTTON 13818
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_BUTTON 13819
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_PROMPT 13820
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_PROMPT 13821
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_RETRY_PROMPT 13822
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_RETRY_PROMPT 13823
#define IDS_MULTI_IDP_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT 13824
#define IDS_MULTI_IDP_ACCOUNT_ORIGIN_AND_LAST_USED 13825
#define IDS_USED_ON_THIS_SITE 13826
#define IDS_VERIFY_SHEET_TITLE 13827
#define IDS_VERIFY_SHEET_TITLE_AUTO_REAUTHN 13828
#define IDS_AUTO_REAUTHN_OPTOUT_CHECKBOX 13829
#define IDS_FILTERED_ACCOUNT_MESSAGE 13830
#define IDS_FEDERATION_SIGN_IN_TITLE 13831
#define IDS_FEDERATION_SIGNING_IN_TITLE 13832
#define IDS_FEDERATION_SIGN_UP_TITLE 13833
#define IDS_BATTERY_SAVER_BUTTON_TOOLTIP 13836
#define IDS_BATTERY_SAVER_BUTTON_ACCNAME 13837
#define IDS_BATTERY_SAVER_BUBBLE_TITLE 13838
#define IDS_BATTERY_SAVER_BUBBLE_DESCRIPTION 13839
#define IDS_BATTERY_SAVER_SESSION_TURN_OFF 13840
#define IDS_MEMORY_SAVER_CHIP_LABEL 13841
#define IDS_MEMORY_SAVER_CHIP_ACCNAME 13842
#define IDS_MEMORY_SAVER_CHIP_WITH_SAVINGS_ACCNAME 13843
#define IDS_MEMORY_SAVER_CHIP_SAVINGS_LABEL 13844
#define IDS_MEMORY_SAVER_DIALOG_TITLE 13845
#define IDS_MEMORY_SAVER_DIALOG_SETTINGS_BUTTON 13846
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_ACCNAME 13847
#define IDS_MEMORY_SAVER_DIALOG_BUTTON_ADD_TO_EXCLUSION_LIST 13848
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_LABEL 13849
#define IDS_MEMORY_SAVER_DIALOG_SMALL_SAVINGS_LABEL 13850
#define IDS_MEMORY_SAVER_DIALOG_MEDIUM_SAVINGS_LABEL 13851
#define IDS_MEMORY_SAVER_DIALOG_LARGE_SAVINGS_LABEL 13852
#define IDS_MEMORY_SAVER_DIALOG_VERY_LARGE_SAVINGS_LABEL 13853
#define IDS_HOVERCARD_TAB_MEMORY_USAGE 13854
#define IDS_HOVERCARD_TAB_HIGH_MEMORY_USAGE 13855
#define IDS_HOVERCARD_INACTIVE_TAB_MEMORY_SAVINGS 13856
#define IDS_HOVERCARD_INACTIVE_TAB 13857
#define IDS_PERFORMANCE_INTERVENTION_CLOSE_BUTTON_ACCNAME 13858
#define IDS_PERFORMANCE_INTERVENTION_SINGLE_SUGGESTED_ROW_ACCNAME 13859
#define IDS_PERFORMANCE_INTERVENTION_TAB_LIST_ACCNAME 13860
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_V1 13861
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V1 13862
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V2 13863
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_V1 13864
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V1 13865
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V2 13866
#define IDS_PERFORMANCE_INTERVENTION_DISMISS_BUTTON 13867
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_TOOLTIP 13868
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_ACCNAME 13869
#define IDS_TOAST_MENU_BUTTON_NAME 13870
#define IDS_TRANSLATE_TOAST_BODY 13871
#define IDS_TRANSLATE_TOAST_UNDO_BUTTON 13872
#define IDS_MULTISTEP_FILTER_CUE_ACTION_TEXT 13873
#define IDS_MULTISTEP_FILTER_CUE_DISMISS 13874
#define IDS_MULTISTEP_FILTER_CUE_SETTINGS 13875
#define IDS_MULTISTEP_FILTER_CUE_EXPANDABLE_CONTENT_HEADING 13876
#define IDS_MULTISTEP_FILTER_IPH_BODY 13877
#define IDS_MULTISTEP_FILTER_IPH_BODY_SCREENREADER 13878
#define IDS_LINK_COPIED_TOAST_BODY 13879
#define IDS_IMAGE_COPIED_TOAST_BODY 13880
#define IDS_VIDEO_FRAME_COPIED_TOAST_BODY 13881
#define IDS_LINK_COPIED_TO_HIGHLIGHT_TOAST_BODY 13882
#define IDS_DICTATION_ERROR_TOAST 13883
#define IDS_DICTATION_STOPPED_TOAST 13884
#define IDS_READING_LIST_TOAST_BODY 13885
#define IDS_READING_LIST_TOAST_BUTTON 13886
#define IDS_CLOSE_PINNED_TAB_TOAST_BODY 13887
#define IDS_TOAST_CLOSE_TOOLTIP 13888
#define IDS_NON_MILESTONE_UPDATE_TOAST_BODY 13889
#define IDS_GLIC_SHARE_IMAGE_FAILED_TOAST_BODY 13890
#define IDS_GLIC_SELECTION_OVERLAY_RENDERER_LABEL 13891
#define IDS_GLIC_SELECTION_OVERLAY_PRESELECTION_BUBBLE_TEXT 13892
#define IDS_COPIED_TO_CLIPBOARD_TOAST_BODY 13893
#define IDS_SPLIT_VIEW_CREATED_TOAST_BODY 13894
#define IDS_SPLIT_VIEW_SEPARATE_VIEWS_ACTION_BUTTON 13895
#define IDS_SPLIT_VIEW_UNDO_SPLIT_ACTION_BUTTON 13896
#define IDS_TAB_STRIP_SWITCH_DELAYED_TO_HORIZONTAL_TOAST_BODY 13897
#define IDS_TAB_STRIP_SWITCH_DELAYED_TO_VERTICAL_TOAST_BODY 13898
#define IDS_TAB_STRIP_SWITCH_DELAYED_EXIT_FULLSCREEN_ACTION 13899
#define IDS_DICTATION_ONBOARDING_BULLET_DATA_SHARING 13900
#define IDS_DICTATION_ONBOARDING_BUTTON_ACCEPT 13901
#define IDS_DICTATION_BUTTON_START 13902
#define IDS_PROTECTED_AUDIENCE_DEBUGGING_DISCLAIMER 13906
#define IDS_OVERFLOW_MENU_ITEM_TEXT_PROFILE 13907
#define IDS_OVERFLOW_MENU_ITEM_TEXT_DOWNLOADS 13908
#define IDS_OVERFLOW_MENU_ITEM_TEXT_EXTENSIONS 13909
#define IDS_OVERFLOW_MENU_ITEM_TEXT_FORWARD 13910
#define IDS_OVERFLOW_MENU_ITEM_TEXT_HOME 13911
#define IDS_OVERFLOW_MENU_ITEM_TEXT_LABS 13912
#define IDS_OVERFLOW_MENU_ITEM_TEXT_MEDIA_CONTROLS 13913
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SIDE_PANEL 13914
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SPLIT_VIEW 13915
#define IDS_OVERFLOW_MENU_ITEM_TEXT_CONTEXTUAL_TASKS 13916
#define IDS_OVERFLOW_MENU_ITEM_TEXT_ENERGY_SAVER 13917
#define IDS_PROMISE_STATUS_WAITING 13918
#define IDS_PROMISE_STATUS_INSTALLING 13919
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_WAITING 13920
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_INSTALLING 13921
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_WAITING 13922
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_INSTALLING 13923
#define IDS_IWA_INSTALLER_DISABLED_TITLE 13924
#define IDS_IWA_INSTALLER_DISABLED_CHANGE_PREFERENCE 13925
#define IDS_IWA_INSTALLER_DISABLED_SUBTITLE 13926
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_TITLE 13927
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_SUBTITLE 13928
#define IDS_IWA_INSTALLER_BODY_SCREENREADER_NAME 13929
#define IDS_IWA_INSTALLER_DETAILS_SCREENREADER_NAME 13930
#define IDS_IWA_INSTALLER_PROGRESS_SCREENREADER_NAME 13931
#define IDS_IWA_INSTALLER_INSTALL_SUBTITLE 13932
#define IDS_IWA_INSTALLER_INSTALL_PROGRESS 13933
#define IDS_IWA_INSTALLER_SHOW_METADATA_SUBTITLE 13934
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_NAME_LABEL 13935
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_VERSION_LABEL 13936
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_ENTERPRISE_NAME_LABEL 13937
#define IDS_IWA_INSTALLER_UPDATE_SETTINGS 13938
#define IDS_IWA_INSTALLER_UPDATE_CHANNEL 13939
#define IDS_IWA_INSTALLER_CONFIRM_TITLE 13940
#define IDS_IWA_INSTALLER_CONFIRM_SUBTITLE 13941
#define IDS_IWA_INSTALLER_CONFIRM_CONTINUE 13942
#define IDS_IWA_INSTALLER_INSTALL_FAILED_TITLE 13943
#define IDS_IWA_INSTALLER_INSTALL_FAILED_SUBTITLE 13944
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_BLOCKED_USER_INSTALL_ALLOWLIST_BLOCKLIST_TITLE 13945
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_NOT_ON_USER_INSTALL_ALLOWLIST_MESSAGE 13946
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_BLOCKLISTED_MESSAGE 13947
#define IDS_IWA_INSTALLER_INSTALL_FAILED_RETRY 13948
#define IDS_IWA_INSTALLER_SUCCESS_SUBTITLE 13949
#define IDS_IWA_INSTALLER_SUCCESS_FINISH 13950
#define IDS_IWA_INSTALLER_SUCCESS_LAUNCH_APPLICATION 13951
#define IDS_IWA_INSTALLER_VERIFICATION_TITLE 13952
#define IDS_IWA_INSTALLER_VERIFICATION_SUBTITLE 13953
#define IDS_IWA_INSTALLER_VERIFICATION_STATUS 13954
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_TITLE 13955
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_SUBTITLE 13956
#define IDS_IWA_SUB_APPS_INSTALLER_PARENT_APP_NAME 13957
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_TITLE 13959
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_MESSAGE 13960
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_BUTTON_SETTINGS 13961
#define IDS_THUMBS_DOWN 13968
#define IDS_THUMBS_UP 13969
#define IDS_EXPERIMENTAL_FEATURE_DISCLAIMER 13970
#define IDS_PDF_INK_SIGNATURES_IPH_BODY 13971
#define IDS_PDF_TEXT_ANNOTATIONS_IPH_BODY 13972
#define IDS_PDF_SEARCHIFY_IPH_TITLE 13973
#define IDS_PDF_SEARCHIFY_IPH_BODY 13974
#define IDS_PDF_SEARCHIFY_IPH_BODY_SCREEN_READER 13975
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_TITLE 13976
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_CHOOSE_DEVICE 13977
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE 13993
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY 13994
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE_NEW 13995
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY_NEW 13996
#define IDS_PDF_GLIC_SUMMARIZE 14001
#define IDS_PDF_GLIC_SUMMARIZE_WITH_GEMINI 14002
#define IDS_PDF_GLIC_SUMMARIZE_TOOLTIP 14003
#define IDS_PDF_GLIC_SUMMARIZE_PROMPT 14004
#define IDS_PDF_GLIC_SUMMARIZE_IPH_TITLE 14005
#define IDS_PDF_GLIC_SUMMARIZE_IPH_GOT_IT 14006
#define IDS_NTP_PROMO_DISMISS 14015
#define IDS_NTP_PROMO_MENU_TOOLTIP 14016
#define IDS_NTP_PROMO_MENU_A11Y_LABEL 14017
#define IDS_NTP_EXTENSIONS_PROMO 14018
#define IDS_ACCOUNT_CHOOSER_SINGLE_ACCOUNT_TITLE 14019
#define IDS_ACCOUNT_CHOOSER_MULTI_ACCOUNT_TITLE 14020
#define IDS_ACCOUNT_CHOOSER_SUBTITLE 14021
#define IDS_SAVE_TO_DRIVE_FOLDER_NAME 14022
#define IDS_ACCOUNT_CHOOSER_DRIVE 14023
#define IDS_ACCOUNT_CHOOSER_ADD_ACCOUNT 14024
#define IDS_ACCOUNT_CHOOSER_RADIO_GROUP_ACCESSIBILITY_LABEL 14025
#define IDS_ACCOUNT_CHOOSER_HEADER_ACCESSIBILITY_LABEL 14026
#define IDS_TIPS_NOTIFICATIONS_HELPFUL_BUTTON_TEXT 14027
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_TITLE 14028
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_SUBTITLE 14029
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_TITLE 14030
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_SUBTITLE 14031
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_TITLE 14032
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_SUBTITLE 14033
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_TITLE 14034
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_SUBTITLE 14035
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_TITLE 14036
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_SUBTITLE 14037
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_TITLE 14038
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_SUBTITLE 14039
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_TITLE 14040
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_SUBTITLE 14041
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_TITLE 14042
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_SUBTITLE 14043
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_TITLE 14044
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_SUBTITLE 14045
#define IDS_UPDATER_ACTIVATION_FAILED 14046
#define IDS_UPDATER_ACTIVATION_SUCCEEDED 14047
#define IDS_UPDATER_ADD_FILTER 14048
#define IDS_UPDATER_APP 14049
#define IDS_UPDATER_APP_COLUMN 14050
#define IDS_UPDATER_APPLY 14051
#define IDS_UPDATER_APP_NAME_OR_ID 14052
#define IDS_UPDATER_APP_POLICIES 14053
#define IDS_UPDATER_APP_STATES_QUERY_FAILED 14054
#define IDS_UPDATER_CANCEL 14055
#define IDS_UPDATER_CLEAR_ALL_FILTERS 14056
#define IDS_UPDATER_COLLAPSE_ALL 14057
#define IDS_UPDATER_COMMAND_LINE 14058
#define IDS_UPDATER_COMMAND_OUTCOME 14059
#define IDS_UPDATER_COMMON 14060
#define IDS_UPDATER_DATE 14061
#define IDS_UPDATER_DATE_FILTER_AFTER 14062
#define IDS_UPDATER_DATE_FILTER_BEFORE 14063
#define IDS_UPDATER_DATE_FILTER_RANGE 14064
#define IDS_UPDATER_DISPLAYED_EVENTS_COUNT 14065
#define IDS_UPDATER_DURATION 14066
#define IDS_UPDATER_EFFECTIVE_POLICY_SET 14067
#define IDS_UPDATER_END_DATE 14068
#define IDS_UPDATER_ERROR_ACCESS_DENIED 14069
#define IDS_UPDATER_ERROR_CORRUPT 14070
#define IDS_UPDATER_ERROR_DISABLED 14071
#define IDS_UPDATER_ERROR_DISK_FULL 14072
#define IDS_UPDATER_ERROR_DOWNLOAD 14073
#define IDS_UPDATER_ERROR_INSTALL 14074
#define IDS_UPDATER_ERROR_INSTALLER_FAILED 14075
#define IDS_UPDATER_ERROR_NETWORK 14076
#define IDS_UPDATER_ERROR_RESTRICTED 14077
#define IDS_UPDATER_ERROR_UNPACK 14078
#define IDS_UPDATER_ERROR_UPDATE_CHECK 14079
#define IDS_UPDATER_ERROR_UNKNOWN 14080
#define IDS_UPDATER_EVENT_LIST_TITLE 14081
#define IDS_UPDATER_EVENT_TYPE 14082
#define IDS_UPDATER_EVENT_TYPE_ACTIVATE 14083
#define IDS_UPDATER_EVENT_TYPE_APP_COMMAND 14084
#define IDS_UPDATER_EVENT_TYPE_INSTALL 14085
#define IDS_UPDATER_EVENT_TYPE_LOAD_POLICY 14086
#define IDS_UPDATER_EVENT_TYPE_PERSISTED_DATA 14087
#define IDS_UPDATER_EVENT_TYPE_POST_REQUEST 14088
#define IDS_UPDATER_EVENT_TYPE_QUALIFY 14089
#define IDS_UPDATER_EVENT_TYPE_UNINSTALL 14090
#define IDS_UPDATER_EVENT_TYPE_UPDATE 14091
#define IDS_UPDATER_EVENT_TYPE_UPDATER_PROCESS 14092
#define IDS_UPDATER_EXPAND_ALL 14093
#define IDS_UPDATER_EXPORT_HISTORY_FILE 14094
#define IDS_UPDATER_FILTER_CHIP_APP 14095
#define IDS_UPDATER_FILTER_CHIP_DATE 14096
#define IDS_UPDATER_FILTER_CHIP_EVENT_TYPE 14097
#define IDS_UPDATER_FILTER_CHIP_UPDATE_OUTCOME 14098
#define IDS_UPDATER_FILTER_CHIP_UPDATER_SCOPE 14099
#define IDS_UPDATER_HELP_CENTER_TOOLTIP 14100
#define IDS_UPDATER_INACTIVE_VERSIONS_LABEL 14101
#define IDS_UPDATER_INSTALL_PATH_LABEL 14102
#define IDS_UPDATER_INSTALL_SUMMARY 14103
#define IDS_UPDATER_INSTALLED_APPS_TITLE 14104
#define IDS_UPDATER_INTERNAL 14105
#define IDS_UPDATER_LAST_CHECKED_LABEL 14106
#define IDS_UPDATER_LAST_STARTED_LABEL 14107
#define IDS_UPDATER_LEARN_MORE 14108
#define IDS_UPDATER_LOAD_HISTORY_FILE 14109
#define IDS_UPDATER_LOAD_HISTORY_FILE_ERROR 14110
#define IDS_UPDATER_NO_APPS_FOUND 14111
#define IDS_UPDATER_NO_POLICIES 14112
#define IDS_UPDATER_NO_UPDATER_FOUND 14113
#define IDS_UPDATER_NEVER 14114
#define IDS_UPDATER_NEXT_VERSION 14115
#define IDS_UPDATER_NO_UPDATE 14116
#define IDS_UPDATER_OMAHA_REQUEST 14117
#define IDS_UPDATER_OMAHA_RESPONSE 14118
#define IDS_UPDATER_OTHER 14119
#define IDS_UPDATER_OUTCOME 14120
#define IDS_UPDATER_OUTCOME_UNKNOWN 14121
#define IDS_UPDATER_PAGE_TITLE 14122
#define IDS_UPDATER_PARSE_ERROR_EVENTS 14123
#define IDS_UPDATER_PERSISTED_DATA_SUMMARY 14124
#define IDS_UPDATER_POLICY_CONFLICT_WARNING 14125
#define IDS_UPDATER_POLICY_IGNORED 14126
#define IDS_UPDATER_POLICY_NAME 14127
#define IDS_UPDATER_POLICY_OK 14128
#define IDS_UPDATER_POLICY_SOURCE 14129
#define IDS_UPDATER_POLICY_STATUS 14130
#define IDS_UPDATER_POLICY_VALUE 14131
#define IDS_UPDATER_PROCESS_SUMMARY 14132
#define IDS_UPDATER_QUALIFICATION_FAILED 14133
#define IDS_UPDATER_QUALIFICATION_SUCCEEDED 14134
#define IDS_UPDATER_QUERY_FAILED 14135
#define IDS_UPDATER_REMOVE_FILTER 14136
#define IDS_UPDATER_RETURN_TO_LOCAL 14137
#define IDS_UPDATER_SCOPE 14138
#define IDS_UPDATER_SCOPE_SYSTEM 14139
#define IDS_UPDATER_SCOPE_USER 14140
#define IDS_UPDATER_START_DATE 14141
#define IDS_UPDATER_STATE_TITLE 14142
#define IDS_UPDATER_UNDATED_EVENTS 14143
#define IDS_UPDATER_UNINSTALL_SUMMARY 14144
#define IDS_UPDATER_UPDATED_TO 14145
#define IDS_UPDATER_UPDATER_POLICIES 14146
#define IDS_UPDATER_UPDATER_VERSION 14147
#define IDS_UPDATER_VERSION_COLUMN 14148
#define IDS_UPDATER_VERSION_LABEL 14149
#define IDS_UPDATER_VIEWING_HISTORY_FILES 14150
#define IDS_UPDATER_UPDATE_ERROR 14151
#define IDS_UPDATER_UPDATE_OUTCOME 14152
#define IDS_UPDATER_UPDATE_OUTCOME_NO_UPDATE 14153
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATED 14154
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATE_ERROR 14155
#define IDS_UPDATER_VIEW_ALL_CHROME_POLICIES 14156
#define IDS_UPDATER_VIEW_RAW_DETAILS 14157
#define IDS_REPORT_UNSAFE_SITE_DIALOG_INCLUDE_SCREENSHOT_CHECKBOX_LABEL 14158
#define IDS_REPORT_UNSAFE_SITE_DIALOG_SEND_BUTTON_LABEL 14159
#define IDS_REPORT_UNSAFE_SITE_DIALOG_URL_LABEL 14160
#define IDS_REPORT_UNSAFE_SITE_DIALOG_SENDING_BUTTON_LABEL 14161
#define IDS_REPORT_UNSAFE_SITE_CONFIRMATION_TOAST 14162
#define IDS_REPORT_UNSAFE_SITE_A11Y_IMAGE_TEXT 14163
#define IDS_CHROME_FINDS_NOTIFICATIONS_HELPFUL_BUTTON_TEXT 14164
#define IDS_CHROME_FINDS_NOTIFICATIONS_UNHELPFUL_BUTTON_TEXT 14165
#define IDS_OSCRYPTASYNC_AVAILABILITY_INFOBAR_MESSAGE 14166
#define IDS_OSCRYPTASYNC_AVAILABILITY_INFOBAR_BUTTON 14167

// ---------------------------------------------------------------------------
// From locale_settings.h:

#define IDS_SPELLCHECK_DICTIONARY 15000
#define IDS_EDITBOOKMARK_DIALOG_WIDTH_CHARS 15001
#define IDS_EDITBOOKMARK_DIALOG_HEIGHT_LINES 15002
#define IDS_WEBSTORE_URL 15003
#define IDS_MEDIA_GALLERIES_DIALOG_CONTENT_WIDTH_CHARS 15004

// ---------------------------------------------------------------------------
// From omnibox_pedal_synonyms.h:

#define IDS_OMNIBOX_PEDALS_IGNORE_GROUP 40240
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_CLEAR_BROWSER_CACHE 40241
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_OPTIONAL_GOOGLE_CHROME 40242
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_DELETE 40243
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_INFORMATION 40244
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_MANAGE_CHROME_PASSWORDS 40245
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_GOOGLE_CHROME 40246
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_MANAGER 40247
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_PASSWORDS 40248
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_MANAGE_PAYMENT_METHODS 40249
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_OPTIONAL_GOOGLE_CHROME 40250
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CHANGE 40251
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CREDIT_CARD_INFORMATION 40252
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_ENTER_INCOGNITO_MODE 40253
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_GOOGLE_CHROME 40254
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_CREATE 40255
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_INCOGNITO_WINDOW 40256
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_TRANSLATE_THIS_PAGE 40257
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_OPTIONAL_GOOGLE_CHROME 40258
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_CHANGE_LANGUAGE 40259
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_THIS_PAGE 40260
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_UPDATE_CHROME 40261
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_GOOGLE_CHROME 40262
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_INSTALL 40263
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_RUN_CHROME_SAFETY_CHECK 40264
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_ACTIVATE 40265
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_GOOGLE_CHROME 40266
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_CHECKUP 40267
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_PASSWORDS 40268
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_MANAGE_SECURITY_SETTINGS 40269
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ANY_OPTIONAL_GOOGLE_CHROME 40270
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_ENHANCED_PROTECTION 40271
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_OPTIONAL_ALTER 40272
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_CHROME_COOKIE_SETTINGS 40273
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_COOKIE_SETTINGS 40274
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_REQUIRED_GOOGLE_CHROME 40275
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_OPTIONAL_THIRD_PARTY 40276
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_ADD_ADDRESS 40277
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_CONTROL 40278
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_SHIPPING_ADDRESSES 40279
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_OPTIONAL_GOOGLE_CHROME 40280
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_CHANGE_CHROME_BROWSER_SYNC_SETTINGS 40281
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS 40282
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS_UPDATED 40283
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ANY_REQUIRED_GOOGLE_CHROME 40284
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_UPDATED 40285
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_ADJUST_SITE_PERMISSIONS 40286
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_SITE_PERMISSIONS 40287
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ANY_REQUIRED_GOOGLE_CHROME 40288
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_CREATE_GOOGLE_DOC 40289
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_GOOGLE_WORKSPACE 40290
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ANY_REQUIRED_CREATE 40291
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_DOCUMENT 40292
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_CREATE_GOOGLE_SHEET 40293
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ANY_REQUIRED_CREATE 40294
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_GOOGLE_WORKSPACE 40295
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_SPREADSHEET 40296
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE_GOOGLE_SLIDE 40297
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE 40298
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_PRESENTATION 40299
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ANY_REQUIRED_WORKSPACE 40300
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_CREATE_GOOGLE_CAL_INVITE 40301
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_SCHEDULE 40302
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_WORKSPACE 40303
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_MEETING 40304
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_CREATE_GOOGLE_SITE 40305
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_CREATE 40306
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_WORKSPACE 40307
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_WEBSITE 40308
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_CREATE_GOOGLE_KEEP_NOTE 40309
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_CREATE 40310
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_WORKSPACE 40311
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_NOTES 40312
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_CREATE_GOOGLE_FORM 40313
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_CREATE 40314
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_WORKSPACE 40315
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_SURVEY 40316
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_CHROME_FEATURES 40317
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_OPTIONAL_MAKE_THE_MOST_OF 40318
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ANY_OPTIONAL_BROWSER 40319
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_NEW_CHROME_FEATURES 40320
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL_MY_GOOGLE_ACCOUNT 40321
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_GOOGLE_ACCOUNT 40322
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ANY_OPTIONAL_BROWSER 40323
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL 40324
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE_GMAIL_PASSWORD 40325
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_GOOGLE_ACCOUNT_PASSWORD 40326
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ANY_OPTIONAL_BROWSER 40327
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE 40328
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_CLOSE_INCOGNITO_WINDOW 40329
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_DELETE 40330
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_INCOGNITO_WINDOW 40331
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_CHROME_DINO 40332
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_PLAY_CHROME_DINO_GAME 40333
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_FIND_LOST_PHONE 40334
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_HELP_ME_LOCATE 40335
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_LOST_DEVICE 40336
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_CHANGE_GOOGLE_PRIVACY_SETTINGS 40337
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_MANAGE_GOOGLE_PRIVACY_SETTINGS 40338
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHANGE_CHROME_SETTINGS 40339
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_OPTIONAL_CONTROL 40340
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHROME_BROWSER_SETTINGS 40341
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_MANAGE_CHROME_DOWNLOADS 40342
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CONTROL 40343
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CHROME_BROWSER_DOWNLOADS 40344
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_SEE_CHROME_HISTORY 40345
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_REVISIT 40346
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_GOOGLE_CHROME_BROWSING_HISTORY 40347
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_THIS_PAGE 40348
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_LINK_WITH_QR_CODE 40349
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROME_ACCESSIBILITY 40350
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 40351
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 40352
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_CHANGE_BROWSER_FONT 40353
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_OPTIONAL_CUSTOMIZE 40354
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_GOOGLE_CHROME 40355
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_FONT_SIZING 40356
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CUSTOMIZE_CHROME_APPEARANCE 40357
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_OPTIONAL_CUSTOMIZE 40358
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CHROME_BACKGROUNDS 40359
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_ADD_CUSTOM_SEARCH 40360
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_CUSTOMIZE 40361
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_CUSTOM_SEARCH_ENGINES 40362
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_GOOGLE_CHROME 40363
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROMEOS_ACCESSIBILITY 40364
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 40365
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 40366
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_ALWAYS_OPEN_LINKS_IN_CHROME 40367
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_HOW_TO_MAKE_CHROME_MY_DEFAULT_BROWSER 40368
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_SELECT 40369
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_DEFAULT_BROWSER 40370

// ---------------------------------------------------------------------------
// From permission_element_generated_strings.h:

#define IDS_PERMISSION_REQUEST_LAUNCH_af 56270
#define IDS_PERMISSION_REQUEST_CAMERA_af 56271
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_af 56272
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_af 56273
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_af 56274
#define IDS_PERMISSION_REQUEST_INSTALL_af 56275
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_af 56276
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_af 56277
#define IDS_PERMISSION_REQUEST_MICROPHONE_af 56278
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_af 56279
#define IDS_PERMISSION_REQUEST_GEOLOCATION_af 56280
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_af 56281
#define IDS_PERMISSION_REQUEST_USING_LOCATION_af 56282
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_af 56283
#define IDS_PERMISSION_REQUEST_LAUNCH_am 56284
#define IDS_PERMISSION_REQUEST_CAMERA_am 56285
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_am 56286
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_am 56287
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_am 56288
#define IDS_PERMISSION_REQUEST_INSTALL_am 56289
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_am 56290
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_am 56291
#define IDS_PERMISSION_REQUEST_MICROPHONE_am 56292
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_am 56293
#define IDS_PERMISSION_REQUEST_GEOLOCATION_am 56294
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_am 56295
#define IDS_PERMISSION_REQUEST_USING_LOCATION_am 56296
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_am 56297
#define IDS_PERMISSION_REQUEST_LAUNCH_ar 56298
#define IDS_PERMISSION_REQUEST_CAMERA_ar 56299
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ar 56300
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ar 56301
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ar 56302
#define IDS_PERMISSION_REQUEST_INSTALL_ar 56303
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ar 56304
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ar 56305
#define IDS_PERMISSION_REQUEST_MICROPHONE_ar 56306
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ar 56307
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ar 56308
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ar 56309
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ar 56310
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ar 56311
#define IDS_PERMISSION_REQUEST_LAUNCH_as 56312
#define IDS_PERMISSION_REQUEST_CAMERA_as 56313
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_as 56314
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_as 56315
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_as 56316
#define IDS_PERMISSION_REQUEST_INSTALL_as 56317
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_as 56318
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_as 56319
#define IDS_PERMISSION_REQUEST_MICROPHONE_as 56320
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_as 56321
#define IDS_PERMISSION_REQUEST_GEOLOCATION_as 56322
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_as 56323
#define IDS_PERMISSION_REQUEST_USING_LOCATION_as 56324
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_as 56325
#define IDS_PERMISSION_REQUEST_LAUNCH_az 56326
#define IDS_PERMISSION_REQUEST_CAMERA_az 56327
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_az 56328
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_az 56329
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_az 56330
#define IDS_PERMISSION_REQUEST_INSTALL_az 56331
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_az 56332
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_az 56333
#define IDS_PERMISSION_REQUEST_MICROPHONE_az 56334
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_az 56335
#define IDS_PERMISSION_REQUEST_GEOLOCATION_az 56336
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_az 56337
#define IDS_PERMISSION_REQUEST_USING_LOCATION_az 56338
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_az 56339
#define IDS_PERMISSION_REQUEST_LAUNCH_be 56340
#define IDS_PERMISSION_REQUEST_CAMERA_be 56341
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_be 56342
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_be 56343
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_be 56344
#define IDS_PERMISSION_REQUEST_INSTALL_be 56345
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_be 56346
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_be 56347
#define IDS_PERMISSION_REQUEST_MICROPHONE_be 56348
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_be 56349
#define IDS_PERMISSION_REQUEST_GEOLOCATION_be 56350
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_be 56351
#define IDS_PERMISSION_REQUEST_USING_LOCATION_be 56352
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_be 56353
#define IDS_PERMISSION_REQUEST_LAUNCH_bg 56354
#define IDS_PERMISSION_REQUEST_CAMERA_bg 56355
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bg 56356
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bg 56357
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bg 56358
#define IDS_PERMISSION_REQUEST_INSTALL_bg 56359
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bg 56360
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bg 56361
#define IDS_PERMISSION_REQUEST_MICROPHONE_bg 56362
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bg 56363
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bg 56364
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bg 56365
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bg 56366
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bg 56367
#define IDS_PERMISSION_REQUEST_LAUNCH_bn 56368
#define IDS_PERMISSION_REQUEST_CAMERA_bn 56369
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bn 56370
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bn 56371
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bn 56372
#define IDS_PERMISSION_REQUEST_INSTALL_bn 56373
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bn 56374
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bn 56375
#define IDS_PERMISSION_REQUEST_MICROPHONE_bn 56376
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bn 56377
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bn 56378
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bn 56379
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bn 56380
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bn 56381
#define IDS_PERMISSION_REQUEST_LAUNCH_bs 56382
#define IDS_PERMISSION_REQUEST_CAMERA_bs 56383
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bs 56384
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bs 56385
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bs 56386
#define IDS_PERMISSION_REQUEST_INSTALL_bs 56387
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bs 56388
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bs 56389
#define IDS_PERMISSION_REQUEST_MICROPHONE_bs 56390
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bs 56391
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bs 56392
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bs 56393
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bs 56394
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bs 56395
#define IDS_PERMISSION_REQUEST_LAUNCH_ca 56396
#define IDS_PERMISSION_REQUEST_CAMERA_ca 56397
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ca 56398
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ca 56399
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ca 56400
#define IDS_PERMISSION_REQUEST_INSTALL_ca 56401
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ca 56402
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ca 56403
#define IDS_PERMISSION_REQUEST_MICROPHONE_ca 56404
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ca 56405
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ca 56406
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ca 56407
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ca 56408
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ca 56409
#define IDS_PERMISSION_REQUEST_LAUNCH_cs 56410
#define IDS_PERMISSION_REQUEST_CAMERA_cs 56411
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cs 56412
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cs 56413
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cs 56414
#define IDS_PERMISSION_REQUEST_INSTALL_cs 56415
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cs 56416
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cs 56417
#define IDS_PERMISSION_REQUEST_MICROPHONE_cs 56418
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cs 56419
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cs 56420
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cs 56421
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cs 56422
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cs 56423
#define IDS_PERMISSION_REQUEST_LAUNCH_cy 56424
#define IDS_PERMISSION_REQUEST_CAMERA_cy 56425
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cy 56426
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cy 56427
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cy 56428
#define IDS_PERMISSION_REQUEST_INSTALL_cy 56429
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cy 56430
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cy 56431
#define IDS_PERMISSION_REQUEST_MICROPHONE_cy 56432
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cy 56433
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cy 56434
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cy 56435
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cy 56436
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cy 56437
#define IDS_PERMISSION_REQUEST_LAUNCH_da 56438
#define IDS_PERMISSION_REQUEST_CAMERA_da 56439
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_da 56440
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_da 56441
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_da 56442
#define IDS_PERMISSION_REQUEST_INSTALL_da 56443
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_da 56444
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_da 56445
#define IDS_PERMISSION_REQUEST_MICROPHONE_da 56446
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_da 56447
#define IDS_PERMISSION_REQUEST_GEOLOCATION_da 56448
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_da 56449
#define IDS_PERMISSION_REQUEST_USING_LOCATION_da 56450
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_da 56451
#define IDS_PERMISSION_REQUEST_LAUNCH_de 56452
#define IDS_PERMISSION_REQUEST_CAMERA_de 56453
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_de 56454
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_de 56455
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_de 56456
#define IDS_PERMISSION_REQUEST_INSTALL_de 56457
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_de 56458
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_de 56459
#define IDS_PERMISSION_REQUEST_MICROPHONE_de 56460
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_de 56461
#define IDS_PERMISSION_REQUEST_GEOLOCATION_de 56462
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_de 56463
#define IDS_PERMISSION_REQUEST_USING_LOCATION_de 56464
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_de 56465
#define IDS_PERMISSION_REQUEST_LAUNCH_el 56466
#define IDS_PERMISSION_REQUEST_CAMERA_el 56467
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_el 56468
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_el 56469
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_el 56470
#define IDS_PERMISSION_REQUEST_INSTALL_el 56471
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_el 56472
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_el 56473
#define IDS_PERMISSION_REQUEST_MICROPHONE_el 56474
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_el 56475
#define IDS_PERMISSION_REQUEST_GEOLOCATION_el 56476
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_el 56477
#define IDS_PERMISSION_REQUEST_USING_LOCATION_el 56478
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_el 56479
#define IDS_PERMISSION_REQUEST_LAUNCH_en_GB 56480
#define IDS_PERMISSION_REQUEST_CAMERA_en_GB 56481
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_en_GB 56482
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_en_GB 56483
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_en_GB 56484
#define IDS_PERMISSION_REQUEST_INSTALL_en_GB 56485
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_en_GB 56486
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_en_GB 56487
#define IDS_PERMISSION_REQUEST_MICROPHONE_en_GB 56488
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_en_GB 56489
#define IDS_PERMISSION_REQUEST_GEOLOCATION_en_GB 56490
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_en_GB 56491
#define IDS_PERMISSION_REQUEST_USING_LOCATION_en_GB 56492
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_en_GB 56493
#define IDS_PERMISSION_REQUEST_LAUNCH_es_419 56494
#define IDS_PERMISSION_REQUEST_CAMERA_es_419 56495
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es_419 56496
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es_419 56497
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es_419 56498
#define IDS_PERMISSION_REQUEST_INSTALL_es_419 56499
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es_419 56500
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es_419 56501
#define IDS_PERMISSION_REQUEST_MICROPHONE_es_419 56502
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es_419 56503
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es_419 56504
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es_419 56505
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es_419 56506
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es_419 56507
#define IDS_PERMISSION_REQUEST_LAUNCH_es 56508
#define IDS_PERMISSION_REQUEST_CAMERA_es 56509
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es 56510
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es 56511
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es 56512
#define IDS_PERMISSION_REQUEST_INSTALL_es 56513
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es 56514
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es 56515
#define IDS_PERMISSION_REQUEST_MICROPHONE_es 56516
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es 56517
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es 56518
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es 56519
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es 56520
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es 56521
#define IDS_PERMISSION_REQUEST_LAUNCH_et 56522
#define IDS_PERMISSION_REQUEST_CAMERA_et 56523
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_et 56524
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_et 56525
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_et 56526
#define IDS_PERMISSION_REQUEST_INSTALL_et 56527
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_et 56528
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_et 56529
#define IDS_PERMISSION_REQUEST_MICROPHONE_et 56530
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_et 56531
#define IDS_PERMISSION_REQUEST_GEOLOCATION_et 56532
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_et 56533
#define IDS_PERMISSION_REQUEST_USING_LOCATION_et 56534
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_et 56535
#define IDS_PERMISSION_REQUEST_LAUNCH_eu 56536
#define IDS_PERMISSION_REQUEST_CAMERA_eu 56537
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_eu 56538
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_eu 56539
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_eu 56540
#define IDS_PERMISSION_REQUEST_INSTALL_eu 56541
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_eu 56542
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_eu 56543
#define IDS_PERMISSION_REQUEST_MICROPHONE_eu 56544
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_eu 56545
#define IDS_PERMISSION_REQUEST_GEOLOCATION_eu 56546
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_eu 56547
#define IDS_PERMISSION_REQUEST_USING_LOCATION_eu 56548
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_eu 56549
#define IDS_PERMISSION_REQUEST_LAUNCH_fa 56550
#define IDS_PERMISSION_REQUEST_CAMERA_fa 56551
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fa 56552
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fa 56553
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fa 56554
#define IDS_PERMISSION_REQUEST_INSTALL_fa 56555
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fa 56556
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fa 56557
#define IDS_PERMISSION_REQUEST_MICROPHONE_fa 56558
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fa 56559
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fa 56560
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fa 56561
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fa 56562
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fa 56563
#define IDS_PERMISSION_REQUEST_LAUNCH_fi 56564
#define IDS_PERMISSION_REQUEST_CAMERA_fi 56565
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fi 56566
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fi 56567
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fi 56568
#define IDS_PERMISSION_REQUEST_INSTALL_fi 56569
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fi 56570
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fi 56571
#define IDS_PERMISSION_REQUEST_MICROPHONE_fi 56572
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fi 56573
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fi 56574
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fi 56575
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fi 56576
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fi 56577
#define IDS_PERMISSION_REQUEST_LAUNCH_fil 56578
#define IDS_PERMISSION_REQUEST_CAMERA_fil 56579
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fil 56580
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fil 56581
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fil 56582
#define IDS_PERMISSION_REQUEST_INSTALL_fil 56583
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fil 56584
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fil 56585
#define IDS_PERMISSION_REQUEST_MICROPHONE_fil 56586
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fil 56587
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fil 56588
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fil 56589
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fil 56590
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fil 56591
#define IDS_PERMISSION_REQUEST_LAUNCH_fr_CA 56592
#define IDS_PERMISSION_REQUEST_CAMERA_fr_CA 56593
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr_CA 56594
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr_CA 56595
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr_CA 56596
#define IDS_PERMISSION_REQUEST_INSTALL_fr_CA 56597
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr_CA 56598
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr_CA 56599
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr_CA 56600
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr_CA 56601
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr_CA 56602
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr_CA 56603
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr_CA 56604
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr_CA 56605
#define IDS_PERMISSION_REQUEST_LAUNCH_fr 56606
#define IDS_PERMISSION_REQUEST_CAMERA_fr 56607
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr 56608
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr 56609
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr 56610
#define IDS_PERMISSION_REQUEST_INSTALL_fr 56611
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr 56612
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr 56613
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr 56614
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr 56615
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr 56616
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr 56617
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr 56618
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr 56619
#define IDS_PERMISSION_REQUEST_LAUNCH_gl 56620
#define IDS_PERMISSION_REQUEST_CAMERA_gl 56621
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gl 56622
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gl 56623
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gl 56624
#define IDS_PERMISSION_REQUEST_INSTALL_gl 56625
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gl 56626
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gl 56627
#define IDS_PERMISSION_REQUEST_MICROPHONE_gl 56628
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gl 56629
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gl 56630
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gl 56631
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gl 56632
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gl 56633
#define IDS_PERMISSION_REQUEST_LAUNCH_gu 56634
#define IDS_PERMISSION_REQUEST_CAMERA_gu 56635
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gu 56636
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gu 56637
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gu 56638
#define IDS_PERMISSION_REQUEST_INSTALL_gu 56639
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gu 56640
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gu 56641
#define IDS_PERMISSION_REQUEST_MICROPHONE_gu 56642
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gu 56643
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gu 56644
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gu 56645
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gu 56646
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gu 56647
#define IDS_PERMISSION_REQUEST_LAUNCH_hi 56648
#define IDS_PERMISSION_REQUEST_CAMERA_hi 56649
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hi 56650
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hi 56651
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hi 56652
#define IDS_PERMISSION_REQUEST_INSTALL_hi 56653
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hi 56654
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hi 56655
#define IDS_PERMISSION_REQUEST_MICROPHONE_hi 56656
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hi 56657
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hi 56658
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hi 56659
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hi 56660
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hi 56661
#define IDS_PERMISSION_REQUEST_LAUNCH_hr 56662
#define IDS_PERMISSION_REQUEST_CAMERA_hr 56663
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hr 56664
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hr 56665
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hr 56666
#define IDS_PERMISSION_REQUEST_INSTALL_hr 56667
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hr 56668
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hr 56669
#define IDS_PERMISSION_REQUEST_MICROPHONE_hr 56670
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hr 56671
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hr 56672
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hr 56673
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hr 56674
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hr 56675
#define IDS_PERMISSION_REQUEST_LAUNCH_hu 56676
#define IDS_PERMISSION_REQUEST_CAMERA_hu 56677
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hu 56678
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hu 56679
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hu 56680
#define IDS_PERMISSION_REQUEST_INSTALL_hu 56681
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hu 56682
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hu 56683
#define IDS_PERMISSION_REQUEST_MICROPHONE_hu 56684
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hu 56685
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hu 56686
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hu 56687
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hu 56688
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hu 56689
#define IDS_PERMISSION_REQUEST_LAUNCH_hy 56690
#define IDS_PERMISSION_REQUEST_CAMERA_hy 56691
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hy 56692
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hy 56693
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hy 56694
#define IDS_PERMISSION_REQUEST_INSTALL_hy 56695
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hy 56696
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hy 56697
#define IDS_PERMISSION_REQUEST_MICROPHONE_hy 56698
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hy 56699
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hy 56700
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hy 56701
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hy 56702
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hy 56703
#define IDS_PERMISSION_REQUEST_LAUNCH_id 56704
#define IDS_PERMISSION_REQUEST_CAMERA_id 56705
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_id 56706
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_id 56707
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_id 56708
#define IDS_PERMISSION_REQUEST_INSTALL_id 56709
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_id 56710
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_id 56711
#define IDS_PERMISSION_REQUEST_MICROPHONE_id 56712
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_id 56713
#define IDS_PERMISSION_REQUEST_GEOLOCATION_id 56714
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_id 56715
#define IDS_PERMISSION_REQUEST_USING_LOCATION_id 56716
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_id 56717
#define IDS_PERMISSION_REQUEST_LAUNCH_is 56718
#define IDS_PERMISSION_REQUEST_CAMERA_is 56719
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_is 56720
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_is 56721
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_is 56722
#define IDS_PERMISSION_REQUEST_INSTALL_is 56723
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_is 56724
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_is 56725
#define IDS_PERMISSION_REQUEST_MICROPHONE_is 56726
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_is 56727
#define IDS_PERMISSION_REQUEST_GEOLOCATION_is 56728
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_is 56729
#define IDS_PERMISSION_REQUEST_USING_LOCATION_is 56730
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_is 56731
#define IDS_PERMISSION_REQUEST_LAUNCH_it 56732
#define IDS_PERMISSION_REQUEST_CAMERA_it 56733
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_it 56734
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_it 56735
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_it 56736
#define IDS_PERMISSION_REQUEST_INSTALL_it 56737
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_it 56738
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_it 56739
#define IDS_PERMISSION_REQUEST_MICROPHONE_it 56740
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_it 56741
#define IDS_PERMISSION_REQUEST_GEOLOCATION_it 56742
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_it 56743
#define IDS_PERMISSION_REQUEST_USING_LOCATION_it 56744
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_it 56745
#define IDS_PERMISSION_REQUEST_LAUNCH_iw 56746
#define IDS_PERMISSION_REQUEST_CAMERA_iw 56747
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_iw 56748
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_iw 56749
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_iw 56750
#define IDS_PERMISSION_REQUEST_INSTALL_iw 56751
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_iw 56752
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_iw 56753
#define IDS_PERMISSION_REQUEST_MICROPHONE_iw 56754
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_iw 56755
#define IDS_PERMISSION_REQUEST_GEOLOCATION_iw 56756
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_iw 56757
#define IDS_PERMISSION_REQUEST_USING_LOCATION_iw 56758
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_iw 56759
#define IDS_PERMISSION_REQUEST_LAUNCH_ja 56760
#define IDS_PERMISSION_REQUEST_CAMERA_ja 56761
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ja 56762
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ja 56763
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ja 56764
#define IDS_PERMISSION_REQUEST_INSTALL_ja 56765
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ja 56766
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ja 56767
#define IDS_PERMISSION_REQUEST_MICROPHONE_ja 56768
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ja 56769
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ja 56770
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ja 56771
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ja 56772
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ja 56773
#define IDS_PERMISSION_REQUEST_LAUNCH_ka 56774
#define IDS_PERMISSION_REQUEST_CAMERA_ka 56775
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ka 56776
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ka 56777
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ka 56778
#define IDS_PERMISSION_REQUEST_INSTALL_ka 56779
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ka 56780
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ka 56781
#define IDS_PERMISSION_REQUEST_MICROPHONE_ka 56782
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ka 56783
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ka 56784
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ka 56785
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ka 56786
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ka 56787
#define IDS_PERMISSION_REQUEST_LAUNCH_kk 56788
#define IDS_PERMISSION_REQUEST_CAMERA_kk 56789
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kk 56790
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kk 56791
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kk 56792
#define IDS_PERMISSION_REQUEST_INSTALL_kk 56793
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kk 56794
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kk 56795
#define IDS_PERMISSION_REQUEST_MICROPHONE_kk 56796
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kk 56797
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kk 56798
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kk 56799
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kk 56800
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kk 56801
#define IDS_PERMISSION_REQUEST_LAUNCH_km 56802
#define IDS_PERMISSION_REQUEST_CAMERA_km 56803
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_km 56804
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_km 56805
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_km 56806
#define IDS_PERMISSION_REQUEST_INSTALL_km 56807
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_km 56808
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_km 56809
#define IDS_PERMISSION_REQUEST_MICROPHONE_km 56810
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_km 56811
#define IDS_PERMISSION_REQUEST_GEOLOCATION_km 56812
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_km 56813
#define IDS_PERMISSION_REQUEST_USING_LOCATION_km 56814
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_km 56815
#define IDS_PERMISSION_REQUEST_LAUNCH_kn 56816
#define IDS_PERMISSION_REQUEST_CAMERA_kn 56817
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kn 56818
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kn 56819
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kn 56820
#define IDS_PERMISSION_REQUEST_INSTALL_kn 56821
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kn 56822
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kn 56823
#define IDS_PERMISSION_REQUEST_MICROPHONE_kn 56824
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kn 56825
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kn 56826
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kn 56827
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kn 56828
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kn 56829
#define IDS_PERMISSION_REQUEST_LAUNCH_ko 56830
#define IDS_PERMISSION_REQUEST_CAMERA_ko 56831
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ko 56832
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ko 56833
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ko 56834
#define IDS_PERMISSION_REQUEST_INSTALL_ko 56835
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ko 56836
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ko 56837
#define IDS_PERMISSION_REQUEST_MICROPHONE_ko 56838
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ko 56839
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ko 56840
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ko 56841
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ko 56842
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ko 56843
#define IDS_PERMISSION_REQUEST_LAUNCH_ky 56844
#define IDS_PERMISSION_REQUEST_CAMERA_ky 56845
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ky 56846
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ky 56847
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ky 56848
#define IDS_PERMISSION_REQUEST_INSTALL_ky 56849
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ky 56850
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ky 56851
#define IDS_PERMISSION_REQUEST_MICROPHONE_ky 56852
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ky 56853
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ky 56854
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ky 56855
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ky 56856
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ky 56857
#define IDS_PERMISSION_REQUEST_LAUNCH_lo 56858
#define IDS_PERMISSION_REQUEST_CAMERA_lo 56859
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lo 56860
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lo 56861
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lo 56862
#define IDS_PERMISSION_REQUEST_INSTALL_lo 56863
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lo 56864
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lo 56865
#define IDS_PERMISSION_REQUEST_MICROPHONE_lo 56866
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lo 56867
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lo 56868
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lo 56869
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lo 56870
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lo 56871
#define IDS_PERMISSION_REQUEST_LAUNCH_lt 56872
#define IDS_PERMISSION_REQUEST_CAMERA_lt 56873
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lt 56874
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lt 56875
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lt 56876
#define IDS_PERMISSION_REQUEST_INSTALL_lt 56877
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lt 56878
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lt 56879
#define IDS_PERMISSION_REQUEST_MICROPHONE_lt 56880
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lt 56881
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lt 56882
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lt 56883
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lt 56884
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lt 56885
#define IDS_PERMISSION_REQUEST_LAUNCH_lv 56886
#define IDS_PERMISSION_REQUEST_CAMERA_lv 56887
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lv 56888
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lv 56889
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lv 56890
#define IDS_PERMISSION_REQUEST_INSTALL_lv 56891
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lv 56892
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lv 56893
#define IDS_PERMISSION_REQUEST_MICROPHONE_lv 56894
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lv 56895
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lv 56896
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lv 56897
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lv 56898
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lv 56899
#define IDS_PERMISSION_REQUEST_LAUNCH_mk 56900
#define IDS_PERMISSION_REQUEST_CAMERA_mk 56901
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mk 56902
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mk 56903
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mk 56904
#define IDS_PERMISSION_REQUEST_INSTALL_mk 56905
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mk 56906
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mk 56907
#define IDS_PERMISSION_REQUEST_MICROPHONE_mk 56908
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mk 56909
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mk 56910
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mk 56911
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mk 56912
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mk 56913
#define IDS_PERMISSION_REQUEST_LAUNCH_ml 56914
#define IDS_PERMISSION_REQUEST_CAMERA_ml 56915
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ml 56916
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ml 56917
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ml 56918
#define IDS_PERMISSION_REQUEST_INSTALL_ml 56919
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ml 56920
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ml 56921
#define IDS_PERMISSION_REQUEST_MICROPHONE_ml 56922
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ml 56923
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ml 56924
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ml 56925
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ml 56926
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ml 56927
#define IDS_PERMISSION_REQUEST_LAUNCH_mn 56928
#define IDS_PERMISSION_REQUEST_CAMERA_mn 56929
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mn 56930
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mn 56931
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mn 56932
#define IDS_PERMISSION_REQUEST_INSTALL_mn 56933
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mn 56934
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mn 56935
#define IDS_PERMISSION_REQUEST_MICROPHONE_mn 56936
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mn 56937
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mn 56938
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mn 56939
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mn 56940
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mn 56941
#define IDS_PERMISSION_REQUEST_LAUNCH_mr 56942
#define IDS_PERMISSION_REQUEST_CAMERA_mr 56943
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mr 56944
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mr 56945
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mr 56946
#define IDS_PERMISSION_REQUEST_INSTALL_mr 56947
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mr 56948
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mr 56949
#define IDS_PERMISSION_REQUEST_MICROPHONE_mr 56950
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mr 56951
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mr 56952
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mr 56953
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mr 56954
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mr 56955
#define IDS_PERMISSION_REQUEST_LAUNCH_ms 56956
#define IDS_PERMISSION_REQUEST_CAMERA_ms 56957
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ms 56958
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ms 56959
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ms 56960
#define IDS_PERMISSION_REQUEST_INSTALL_ms 56961
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ms 56962
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ms 56963
#define IDS_PERMISSION_REQUEST_MICROPHONE_ms 56964
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ms 56965
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ms 56966
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ms 56967
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ms 56968
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ms 56969
#define IDS_PERMISSION_REQUEST_LAUNCH_my 56970
#define IDS_PERMISSION_REQUEST_CAMERA_my 56971
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_my 56972
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_my 56973
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_my 56974
#define IDS_PERMISSION_REQUEST_INSTALL_my 56975
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_my 56976
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_my 56977
#define IDS_PERMISSION_REQUEST_MICROPHONE_my 56978
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_my 56979
#define IDS_PERMISSION_REQUEST_GEOLOCATION_my 56980
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_my 56981
#define IDS_PERMISSION_REQUEST_USING_LOCATION_my 56982
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_my 56983
#define IDS_PERMISSION_REQUEST_LAUNCH_ne 56984
#define IDS_PERMISSION_REQUEST_CAMERA_ne 56985
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ne 56986
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ne 56987
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ne 56988
#define IDS_PERMISSION_REQUEST_INSTALL_ne 56989
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ne 56990
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ne 56991
#define IDS_PERMISSION_REQUEST_MICROPHONE_ne 56992
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ne 56993
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ne 56994
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ne 56995
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ne 56996
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ne 56997
#define IDS_PERMISSION_REQUEST_LAUNCH_nl 56998
#define IDS_PERMISSION_REQUEST_CAMERA_nl 56999
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_nl 57000
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_nl 57001
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_nl 57002
#define IDS_PERMISSION_REQUEST_INSTALL_nl 57003
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_nl 57004
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_nl 57005
#define IDS_PERMISSION_REQUEST_MICROPHONE_nl 57006
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_nl 57007
#define IDS_PERMISSION_REQUEST_GEOLOCATION_nl 57008
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_nl 57009
#define IDS_PERMISSION_REQUEST_USING_LOCATION_nl 57010
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_nl 57011
#define IDS_PERMISSION_REQUEST_LAUNCH_no 57012
#define IDS_PERMISSION_REQUEST_CAMERA_no 57013
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_no 57014
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_no 57015
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_no 57016
#define IDS_PERMISSION_REQUEST_INSTALL_no 57017
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_no 57018
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_no 57019
#define IDS_PERMISSION_REQUEST_MICROPHONE_no 57020
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_no 57021
#define IDS_PERMISSION_REQUEST_GEOLOCATION_no 57022
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_no 57023
#define IDS_PERMISSION_REQUEST_USING_LOCATION_no 57024
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_no 57025
#define IDS_PERMISSION_REQUEST_LAUNCH_or 57026
#define IDS_PERMISSION_REQUEST_CAMERA_or 57027
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_or 57028
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_or 57029
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_or 57030
#define IDS_PERMISSION_REQUEST_INSTALL_or 57031
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_or 57032
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_or 57033
#define IDS_PERMISSION_REQUEST_MICROPHONE_or 57034
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_or 57035
#define IDS_PERMISSION_REQUEST_GEOLOCATION_or 57036
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_or 57037
#define IDS_PERMISSION_REQUEST_USING_LOCATION_or 57038
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_or 57039
#define IDS_PERMISSION_REQUEST_LAUNCH_pa 57040
#define IDS_PERMISSION_REQUEST_CAMERA_pa 57041
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pa 57042
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pa 57043
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pa 57044
#define IDS_PERMISSION_REQUEST_INSTALL_pa 57045
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pa 57046
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pa 57047
#define IDS_PERMISSION_REQUEST_MICROPHONE_pa 57048
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pa 57049
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pa 57050
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pa 57051
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pa 57052
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pa 57053
#define IDS_PERMISSION_REQUEST_LAUNCH_pl 57054
#define IDS_PERMISSION_REQUEST_CAMERA_pl 57055
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pl 57056
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pl 57057
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pl 57058
#define IDS_PERMISSION_REQUEST_INSTALL_pl 57059
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pl 57060
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pl 57061
#define IDS_PERMISSION_REQUEST_MICROPHONE_pl 57062
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pl 57063
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pl 57064
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pl 57065
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pl 57066
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pl 57067
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_BR 57068
#define IDS_PERMISSION_REQUEST_CAMERA_pt_BR 57069
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_BR 57070
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_BR 57071
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_BR 57072
#define IDS_PERMISSION_REQUEST_INSTALL_pt_BR 57073
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_BR 57074
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_BR 57075
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_BR 57076
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_BR 57077
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_BR 57078
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_BR 57079
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_BR 57080
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_BR 57081
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_PT 57082
#define IDS_PERMISSION_REQUEST_CAMERA_pt_PT 57083
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_PT 57084
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_PT 57085
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_PT 57086
#define IDS_PERMISSION_REQUEST_INSTALL_pt_PT 57087
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_PT 57088
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_PT 57089
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_PT 57090
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_PT 57091
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_PT 57092
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_PT 57093
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_PT 57094
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_PT 57095
#define IDS_PERMISSION_REQUEST_LAUNCH_ro 57096
#define IDS_PERMISSION_REQUEST_CAMERA_ro 57097
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ro 57098
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ro 57099
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ro 57100
#define IDS_PERMISSION_REQUEST_INSTALL_ro 57101
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ro 57102
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ro 57103
#define IDS_PERMISSION_REQUEST_MICROPHONE_ro 57104
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ro 57105
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ro 57106
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ro 57107
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ro 57108
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ro 57109
#define IDS_PERMISSION_REQUEST_LAUNCH_ru 57110
#define IDS_PERMISSION_REQUEST_CAMERA_ru 57111
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ru 57112
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ru 57113
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ru 57114
#define IDS_PERMISSION_REQUEST_INSTALL_ru 57115
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ru 57116
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ru 57117
#define IDS_PERMISSION_REQUEST_MICROPHONE_ru 57118
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ru 57119
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ru 57120
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ru 57121
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ru 57122
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ru 57123
#define IDS_PERMISSION_REQUEST_LAUNCH_si 57124
#define IDS_PERMISSION_REQUEST_CAMERA_si 57125
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_si 57126
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_si 57127
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_si 57128
#define IDS_PERMISSION_REQUEST_INSTALL_si 57129
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_si 57130
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_si 57131
#define IDS_PERMISSION_REQUEST_MICROPHONE_si 57132
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_si 57133
#define IDS_PERMISSION_REQUEST_GEOLOCATION_si 57134
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_si 57135
#define IDS_PERMISSION_REQUEST_USING_LOCATION_si 57136
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_si 57137
#define IDS_PERMISSION_REQUEST_LAUNCH_sk 57138
#define IDS_PERMISSION_REQUEST_CAMERA_sk 57139
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sk 57140
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sk 57141
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sk 57142
#define IDS_PERMISSION_REQUEST_INSTALL_sk 57143
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sk 57144
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sk 57145
#define IDS_PERMISSION_REQUEST_MICROPHONE_sk 57146
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sk 57147
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sk 57148
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sk 57149
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sk 57150
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sk 57151
#define IDS_PERMISSION_REQUEST_LAUNCH_sl 57152
#define IDS_PERMISSION_REQUEST_CAMERA_sl 57153
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sl 57154
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sl 57155
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sl 57156
#define IDS_PERMISSION_REQUEST_INSTALL_sl 57157
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sl 57158
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sl 57159
#define IDS_PERMISSION_REQUEST_MICROPHONE_sl 57160
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sl 57161
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sl 57162
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sl 57163
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sl 57164
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sl 57165
#define IDS_PERMISSION_REQUEST_LAUNCH_sq 57166
#define IDS_PERMISSION_REQUEST_CAMERA_sq 57167
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sq 57168
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sq 57169
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sq 57170
#define IDS_PERMISSION_REQUEST_INSTALL_sq 57171
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sq 57172
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sq 57173
#define IDS_PERMISSION_REQUEST_MICROPHONE_sq 57174
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sq 57175
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sq 57176
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sq 57177
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sq 57178
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sq 57179
#define IDS_PERMISSION_REQUEST_LAUNCH_sr_Latn 57180
#define IDS_PERMISSION_REQUEST_CAMERA_sr_Latn 57181
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr_Latn 57182
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr_Latn 57183
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr_Latn 57184
#define IDS_PERMISSION_REQUEST_INSTALL_sr_Latn 57185
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr_Latn 57186
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr_Latn 57187
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr_Latn 57188
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr_Latn 57189
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr_Latn 57190
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr_Latn 57191
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr_Latn 57192
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr_Latn 57193
#define IDS_PERMISSION_REQUEST_LAUNCH_sr 57194
#define IDS_PERMISSION_REQUEST_CAMERA_sr 57195
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr 57196
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr 57197
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr 57198
#define IDS_PERMISSION_REQUEST_INSTALL_sr 57199
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr 57200
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr 57201
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr 57202
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr 57203
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr 57204
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr 57205
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr 57206
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr 57207
#define IDS_PERMISSION_REQUEST_LAUNCH_sv 57208
#define IDS_PERMISSION_REQUEST_CAMERA_sv 57209
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sv 57210
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sv 57211
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sv 57212
#define IDS_PERMISSION_REQUEST_INSTALL_sv 57213
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sv 57214
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sv 57215
#define IDS_PERMISSION_REQUEST_MICROPHONE_sv 57216
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sv 57217
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sv 57218
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sv 57219
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sv 57220
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sv 57221
#define IDS_PERMISSION_REQUEST_LAUNCH_sw 57222
#define IDS_PERMISSION_REQUEST_CAMERA_sw 57223
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sw 57224
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sw 57225
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sw 57226
#define IDS_PERMISSION_REQUEST_INSTALL_sw 57227
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sw 57228
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sw 57229
#define IDS_PERMISSION_REQUEST_MICROPHONE_sw 57230
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sw 57231
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sw 57232
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sw 57233
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sw 57234
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sw 57235
#define IDS_PERMISSION_REQUEST_LAUNCH_ta 57236
#define IDS_PERMISSION_REQUEST_CAMERA_ta 57237
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ta 57238
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ta 57239
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ta 57240
#define IDS_PERMISSION_REQUEST_INSTALL_ta 57241
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ta 57242
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ta 57243
#define IDS_PERMISSION_REQUEST_MICROPHONE_ta 57244
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ta 57245
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ta 57246
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ta 57247
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ta 57248
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ta 57249
#define IDS_PERMISSION_REQUEST_LAUNCH_te 57250
#define IDS_PERMISSION_REQUEST_CAMERA_te 57251
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_te 57252
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_te 57253
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_te 57254
#define IDS_PERMISSION_REQUEST_INSTALL_te 57255
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_te 57256
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_te 57257
#define IDS_PERMISSION_REQUEST_MICROPHONE_te 57258
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_te 57259
#define IDS_PERMISSION_REQUEST_GEOLOCATION_te 57260
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_te 57261
#define IDS_PERMISSION_REQUEST_USING_LOCATION_te 57262
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_te 57263
#define IDS_PERMISSION_REQUEST_LAUNCH_th 57264
#define IDS_PERMISSION_REQUEST_CAMERA_th 57265
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_th 57266
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_th 57267
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_th 57268
#define IDS_PERMISSION_REQUEST_INSTALL_th 57269
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_th 57270
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_th 57271
#define IDS_PERMISSION_REQUEST_MICROPHONE_th 57272
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_th 57273
#define IDS_PERMISSION_REQUEST_GEOLOCATION_th 57274
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_th 57275
#define IDS_PERMISSION_REQUEST_USING_LOCATION_th 57276
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_th 57277
#define IDS_PERMISSION_REQUEST_LAUNCH_tr 57278
#define IDS_PERMISSION_REQUEST_CAMERA_tr 57279
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_tr 57280
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_tr 57281
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_tr 57282
#define IDS_PERMISSION_REQUEST_INSTALL_tr 57283
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_tr 57284
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_tr 57285
#define IDS_PERMISSION_REQUEST_MICROPHONE_tr 57286
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_tr 57287
#define IDS_PERMISSION_REQUEST_GEOLOCATION_tr 57288
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_tr 57289
#define IDS_PERMISSION_REQUEST_USING_LOCATION_tr 57290
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_tr 57291
#define IDS_PERMISSION_REQUEST_LAUNCH_uk 57292
#define IDS_PERMISSION_REQUEST_CAMERA_uk 57293
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uk 57294
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uk 57295
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uk 57296
#define IDS_PERMISSION_REQUEST_INSTALL_uk 57297
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uk 57298
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uk 57299
#define IDS_PERMISSION_REQUEST_MICROPHONE_uk 57300
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uk 57301
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uk 57302
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uk 57303
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uk 57304
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uk 57305
#define IDS_PERMISSION_REQUEST_LAUNCH_ur 57306
#define IDS_PERMISSION_REQUEST_CAMERA_ur 57307
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ur 57308
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ur 57309
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ur 57310
#define IDS_PERMISSION_REQUEST_INSTALL_ur 57311
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ur 57312
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ur 57313
#define IDS_PERMISSION_REQUEST_MICROPHONE_ur 57314
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ur 57315
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ur 57316
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ur 57317
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ur 57318
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ur 57319
#define IDS_PERMISSION_REQUEST_LAUNCH_uz 57320
#define IDS_PERMISSION_REQUEST_CAMERA_uz 57321
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uz 57322
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uz 57323
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uz 57324
#define IDS_PERMISSION_REQUEST_INSTALL_uz 57325
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uz 57326
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uz 57327
#define IDS_PERMISSION_REQUEST_MICROPHONE_uz 57328
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uz 57329
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uz 57330
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uz 57331
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uz 57332
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uz 57333
#define IDS_PERMISSION_REQUEST_LAUNCH_vi 57334
#define IDS_PERMISSION_REQUEST_CAMERA_vi 57335
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_vi 57336
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_vi 57337
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_vi 57338
#define IDS_PERMISSION_REQUEST_INSTALL_vi 57339
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_vi 57340
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_vi 57341
#define IDS_PERMISSION_REQUEST_MICROPHONE_vi 57342
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_vi 57343
#define IDS_PERMISSION_REQUEST_GEOLOCATION_vi 57344
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_vi 57345
#define IDS_PERMISSION_REQUEST_USING_LOCATION_vi 57346
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_vi 57347
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_CN 57348
#define IDS_PERMISSION_REQUEST_CAMERA_zh_CN 57349
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_CN 57350
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_CN 57351
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_CN 57352
#define IDS_PERMISSION_REQUEST_INSTALL_zh_CN 57353
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_CN 57354
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_CN 57355
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_CN 57356
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_CN 57357
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_CN 57358
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_CN 57359
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_CN 57360
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_CN 57361
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_HK 57362
#define IDS_PERMISSION_REQUEST_CAMERA_zh_HK 57363
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_HK 57364
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_HK 57365
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_HK 57366
#define IDS_PERMISSION_REQUEST_INSTALL_zh_HK 57367
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_HK 57368
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_HK 57369
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_HK 57370
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_HK 57371
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_HK 57372
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_HK 57373
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_HK 57374
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_HK 57375
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_TW 57376
#define IDS_PERMISSION_REQUEST_CAMERA_zh_TW 57377
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_TW 57378
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_TW 57379
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_TW 57380
#define IDS_PERMISSION_REQUEST_INSTALL_zh_TW 57381
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_TW 57382
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_TW 57383
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_TW 57384
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_TW 57385
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_TW 57386
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_TW 57387
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_TW 57388
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_TW 57389
#define IDS_PERMISSION_REQUEST_LAUNCH_zu 57390
#define IDS_PERMISSION_REQUEST_CAMERA_zu 57391
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zu 57392
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zu 57393
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zu 57394
#define IDS_PERMISSION_REQUEST_INSTALL_zu 57395
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zu 57396
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zu 57397
#define IDS_PERMISSION_REQUEST_MICROPHONE_zu 57398
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zu 57399
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zu 57400
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zu 57401
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zu 57402
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zu 57403

// ---------------------------------------------------------------------------
// From permission_element_strings.h:

#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED 46560
#define IDS_PERMISSION_REQUEST_CAMERA 46561
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED 46562
#define IDS_PERMISSION_REQUEST_MICROPHONE 46563
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED 46564
#define IDS_PERMISSION_REQUEST_GEOLOCATION 46565
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED 46566
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE 46567
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED 46568
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION 46569
#define IDS_PERMISSION_REQUEST_USING_LOCATION 46570
#define IDS_PERMISSION_REQUEST_INSTALL 46571
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST 46572
#define IDS_PERMISSION_REQUEST_LAUNCH 46573

// ---------------------------------------------------------------------------
// From platform_locale_settings.h:

#define IDS_STANDARD_FONT_FAMILY 15100
#define IDS_FIXED_FONT_FAMILY 15101
#define IDS_SERIF_FONT_FAMILY 15102
#define IDS_SANS_SERIF_FONT_FAMILY 15103
#define IDS_NTP_FONT_FAMILY 15104
#define IDS_CURSIVE_FONT_FAMILY 15105
#define IDS_FANTASY_FONT_FAMILY 15106
#define IDS_MATH_FONT_FAMILY 15107
#define IDS_FIXED_FONT_FAMILY_JAPANESE 15108
#define IDS_STANDARD_FONT_FAMILY_JAPANESE 15109
#define IDS_SERIF_FONT_FAMILY_JAPANESE 15110
#define IDS_SANS_SERIF_FONT_FAMILY_JAPANESE 15111
#define IDS_STANDARD_FONT_FAMILY_KOREAN 15112
#define IDS_SERIF_FONT_FAMILY_KOREAN 15113
#define IDS_SANS_SERIF_FONT_FAMILY_KOREAN 15114
#define IDS_STANDARD_FONT_FAMILY_SIMPLIFIED_HAN 15115
#define IDS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 15116
#define IDS_SANS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 15117
#define IDS_STANDARD_FONT_FAMILY_TRADITIONAL_HAN 15118
#define IDS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 15119
#define IDS_SANS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 15120
#define IDS_STANDARD_FONT_FAMILY_DEVANAGARI 15121
#define IDS_FIXED_FONT_FAMILY_DEVANAGARI 15122
#define IDS_SERIF_FONT_FAMILY_DEVANAGARI 15123
#define IDS_SANS_SERIF_FONT_FAMILY_DEVANAGARI 15124
#define IDS_MINIMUM_FONT_SIZE 15125
#define IDS_MINIMUM_LOGICAL_FONT_SIZE 15126

// ---------------------------------------------------------------------------
// From services_strings.h:

#define IDS_PROXY_RESOLVER_DISPLAY_NAME 46380
#define IDS_WINDOWS_SYSTEM_PROXY_RESOLVER_DISPLAY_NAME 46381
#define IDS_MAC_SYSTEM_PROXY_RESOLVER_DISPLAY_NAME 46382
#define IDS_PDF_OCR_RESULT_BEGIN 46383
#define IDS_PDF_OCR_RESULT_END 46384

// ---------------------------------------------------------------------------
// From ui_strings.h:

#define IDS_TIME_SECS 50350
#define IDS_TIME_LONG_SECS 50351
#define IDS_TIME_LONG_SECS_2ND 50352
#define IDS_TIME_MINS 50353
#define IDS_TIME_LONG_MINS 50354
#define IDS_TIME_LONG_MINS_1ST 50355
#define IDS_TIME_LONG_MINS_2ND 50356
#define IDS_TIME_HOURS 50357
#define IDS_TIME_HOURS_1ST 50358
#define IDS_TIME_HOURS_2ND 50359
#define IDS_TIME_DAYS 50360
#define IDS_TIME_DAYS_1ST 50361
#define IDS_TIME_MONTHS 50362
#define IDS_TIME_YEARS 50363
#define IDS_TIME_REMAINING_SECS 50364
#define IDS_TIME_REMAINING_LONG_SECS 50365
#define IDS_TIME_REMAINING_MINS 50366
#define IDS_TIME_REMAINING_LONG_MINS 50367
#define IDS_TIME_REMAINING_HOURS 50368
#define IDS_TIME_REMAINING_DAYS 50369
#define IDS_TIME_REMAINING_MONTHS 50370
#define IDS_TIME_REMAINING_YEARS 50371
#define IDS_TIME_ELAPSED_SECS 50372
#define IDS_TIME_ELAPSED_LONG_SECS 50373
#define IDS_TIME_ELAPSED_MINS 50374
#define IDS_TIME_ELAPSED_LONG_MINS 50375
#define IDS_TIME_ELAPSED_HOURS 50376
#define IDS_TIME_ELAPSED_DAYS 50377
#define IDS_TIME_ELAPSED_MONTHS 50378
#define IDS_TIME_ELAPSED_YEARS 50379
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_SECS 50380
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_MINS 50381
#define IDS_TIME_TITLE_CASE_ELAPSED_HOURS 50382
#define IDS_TIME_TITLE_CASE_ELAPSED_DAYS 50383
#define IDS_TIME_TITLE_CASE_ELAPSED_MONTHS 50384
#define IDS_TIME_TITLE_CASE_ELAPSED_YEARS 50385
#define IDS_PAST_TIME_TODAY 50386
#define IDS_PAST_TIME_YESTERDAY 50387
#define IDS_TIME_TOMORROW 50388
#define IDS_APP_MENU_EMPTY_SUBMENU 50389
#define IDS_APP_MENU_AX_ANNOUNCE_EMPTY_SUBMENU 50390
#define IDS_CLIPBOARD_MENU_HTML 50391
#define IDS_CLIPBOARD_MENU_IMAGE 50392
#define IDS_CLIPBOARD_MENU_RTF_CONTENT 50393
#define IDS_CLIPBOARD_MENU_WEB_SMART_PASTE 50394
#define IDS_CLIPBOARD_MENU_CLIPBOARD 50395
#define IDS_CLIPBOARD_MENU_DELETE_ALL 50396
#define IDS_EXTENSION_PINNED 50397
#define IDS_EXTENSION_UNPINNED 50398
#define IDS_NEW_BADGE 50399
#define IDS_NEW_BADGE_SCREEN_READER_MESSAGE 50400
#define IDS_PREVIEW_BADGE 50401
#define IDS_PREVIEW_BADGE_SCREEN_READER_MESSAGE 50402
#define IDS_SENTENCE_END 50403
#define IDS_CONCAT_TWO_STRINGS_WITH_COMMA 50404
#define IDS_CONCAT_THREE_STRINGS_WITH_COMMA 50405
#define IDS_CONCAT_TWO_STRINGS_WITH_PERIODS 50406
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_TITLE 50410
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_MENU 50418
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_DEFAULT 50419
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_LTR 50420
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_RTL 50421
#define IDS_SELECT_FOLDER_DIALOG_TITLE 50422
#define IDS_SAVE_AS_DIALOG_TITLE 50423
#define IDS_OPEN_FILE_DIALOG_TITLE 50424
#define IDS_OPEN_FILES_DIALOG_TITLE 50425
#define IDS_SAVEAS_ALL_FILES 50426
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_UPLOAD_BUTTON 50427
#define IDS_APP_ACCNAME_BACK 50428
#define IDS_APP_ACCNAME_CENTER 50429
#define IDS_APP_ACCNAME_CLOSE 50430
#define IDS_APP_ACCNAME_MINIMIZE 50431
#define IDS_APP_ACCNAME_MAXIMIZE 50432
#define IDS_APP_ACCNAME_RESTORE 50433
#define IDS_APP_ACCNAME_MENU 50434
#define IDS_APP_ACCNAME_COLOR_CHOOSER_HEX_INPUT 50435
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHERE 50436
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFTEDGE 50437
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHTEDGE 50438
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHOME 50439
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLEND 50440
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEUP 50441
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEDOWN 50442
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFT 50443
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHT 50444
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLUP 50445
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLDOWN 50446
#define IDS_APP_TABLE_COLUMN_NOT_SORTED_ACCNAME 50447
#define IDS_APP_TABLE_COLUMN_SORTED_ASC_ACCNAME 50448
#define IDS_APP_TABLE_COLUMN_SORTED_DESC_ACCNAME 50449
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME 50450
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME_MAC 50451
#define IDS_APP_TABLE_HEADER_SORTED_ASC_ACCNAME 50452
#define IDS_APP_TABLE_HEADER_SORTED_DESC_ACCNAME 50453
#define IDS_APP_UNDO 50454
#define IDS_APP_CUT 50455
#define IDS_APP_COPY 50456
#define IDS_APP_PASTE 50457
#define IDS_APP_DELETE 50458
#define IDS_APP_SELECT_ALL 50459
#define IDS_APP_SELECT 50460
#define IDS_CONTENT_CONTEXT_EMOJI 50461
#define IDS_APP_OK 50464
#define IDS_APP_CANCEL 50465
#define IDS_APP_CLOSE 50466
#define IDS_APP_CONTINUE 50467
#define IDS_APP_TURN_ON 50468
#define IDS_APP_ESC_KEY 50469
#define IDS_APP_TAB_KEY 50470
#define IDS_APP_INSERT_KEY 50471
#define IDS_APP_HOME_KEY 50472
#define IDS_APP_DELETE_KEY 50473
#define IDS_APP_END_KEY 50474
#define IDS_APP_PAGEUP_KEY 50475
#define IDS_APP_PAGEDOWN_KEY 50476
#define IDS_APP_LEFT_ARROW_KEY 50477
#define IDS_APP_RIGHT_ARROW_KEY 50478
#define IDS_APP_UP_ARROW_KEY 50479
#define IDS_APP_DOWN_ARROW_KEY 50480
#define IDS_APP_ENTER_KEY 50481
#define IDS_APP_SPACE_KEY 50482
#define IDS_APP_F1_KEY 50483
#define IDS_APP_F4_KEY 50484
#define IDS_APP_F5_KEY 50485
#define IDS_APP_F6_KEY 50486
#define IDS_APP_F11_KEY 50487
#define IDS_APP_BACKSPACE_KEY 50488
#define IDS_APP_COMMA_KEY 50489
#define IDS_APP_PERIOD_KEY 50490
#define IDS_APP_MEDIA_NEXT_TRACK_KEY 50491
#define IDS_APP_MEDIA_PLAY_PAUSE_KEY 50492
#define IDS_APP_MEDIA_PREV_TRACK_KEY 50493
#define IDS_APP_MEDIA_STOP_KEY 50494
#define IDS_APP_ALT_KEY 50495
#define IDS_APP_COMMAND_KEY 50496
#define IDS_APP_CTRL_KEY 50497
#define IDS_APP_SEARCH_KEY 50498
#define IDS_APP_SHIFT_KEY 50499
#define IDS_APP_SUPER_KEY 50501
#define IDS_APP_BYTES 50505
#define IDS_APP_KIBIBYTES 50506
#define IDS_APP_MEBIBYTES 50507
#define IDS_APP_GIBIBYTES 50508
#define IDS_APP_TEBIBYTES 50509
#define IDS_APP_PEBIBYTES 50510
#define IDS_APP_BYTES_PER_SECOND 50511
#define IDS_APP_KIBIBYTES_PER_SECOND 50512
#define IDS_APP_MEBIBYTES_PER_SECOND 50513
#define IDS_APP_GIBIBYTES_PER_SECOND 50514
#define IDS_APP_TEBIBYTES_PER_SECOND 50515
#define IDS_APP_PEBIBYTES_PER_SECOND 50516
#define IDS_MESSAGE_CENTER_ACCESSIBLE_NAME 50517
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME 50518
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME_PLURAL 50519
#define IDS_MESSAGE_CENTER_EXPAND_NOTIFICATION 50520
#define IDS_MESSAGE_CENTER_COLLAPSE_NOTIFICATION 50521
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_MESSAGE_WITH_DIVIDER 50522
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_HEADER_OVERFLOW_INDICATOR 50523
#define IDS_MESSAGE_CENTER_NOTIFICATION_PROGRESS_PERCENTAGE 50524
#define IDS_MESSAGE_CENTER_NOTIFICATION_CHROMEOS_SYSTEM 50525
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_PLACEHOLDER 50526
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_ACCESSIBLE_NAME 50527
#define IDS_MESSAGE_NOTIFICATION_NOW_STRING_SHORTEST 50528
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST 50529
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST 50530
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST 50531
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST 50532
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST_FUTURE 50533
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST_FUTURE 50534
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST_FUTURE 50535
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST_FUTURE 50536
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_SITE 50537
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_APP 50538
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS 50539
#define IDS_MESSAGE_CENTER_DONT_BLOCK_NOTIFICATIONS 50540
#define IDS_MESSAGE_CENTER_SETTINGS_DONE 50541
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_ACCESSIBLE_NAME 50542
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_TOOLTIP 50543
#define IDS_MESSAGE_CENTER_NOTIFICATION_SNOOZE_BUTTON_TOOLTIP 50544
#define IDS_MESSAGE_NOTIFICATION_SETTINGS_BUTTON_ACCESSIBLE_NAME 50545
#define IDS_MESSAGE_NOTIFICATION_ACCESSIBLE_NAME 50546
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_TITLE 50547
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_MESSAGE 50548
#define IDS_CLIPBOARD_HISTORY_MENU_PNG_IMAGE 50550
#define IDS_CLIPBOARD_HISTORY_MENU_HTML_IMAGE 50551
#define IDS_CLIPBOARD_HISTORY_MENU_TITLE 50552
#define IDS_CLIPBOARD_HISTORY_DELETE_ITEM_TEXT 50553
#define IDS_CLIPBOARD_HISTORY_DELETE_BUTTON_HOVER_TEXT 50554
#define IDS_CLIPBOARD_HISTORY_ITEM_DELETION 50555
#define IDS_DISPLAY_TOUCH_CALIBRATION_EXIT_LABEL 50556
#define IDS_DISPLAY_TOUCH_CALIBRATION_SECONDARY_SKIP_LABEL 50557
#define IDS_DISPLAY_TOUCH_CALIBRATION_PRIMARY_SKIP_LABEL 50558
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_LABEL_TEXT 50559
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_SUBLABEL_TEXT 50560
#define IDS_DISPLAY_TOUCH_CALIBRATION_TAP_HERE_LABEL 50561
#define IDS_DISPLAY_TOUCH_CALIBRATION_FINISH_LABEL 50562
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_TOP_RIGHT 50563
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_LEFT 50564
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_RIGHT 50565
#define IDS_DISPLAY_NAME_UNKNOWN 50566
#define IDS_DISPLAY_NAME_INTERNAL 50567
#define IDS_SATURATED_BADGE_CONTENT 50568
#define IDS_BADGE_UNREAD_NOTIFICATIONS_SATURATED 50569
#define IDS_BADGE_UNREAD_NOTIFICATIONS_UNSPECIFIED 50570
#define IDS_BADGE_UNREAD_NOTIFICATIONS 50571
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_LABEL 50572
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_NO_DEVICES 50573
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_CALL_BUTTON_LABEL 50574
#define IDS_BROWSER_SHARING_OMNIBOX_SENDING_LABEL 50575
#define IDS_BROWSER_SHARING_DIALOG_DEVICE_SUBTITLE_LAST_ACTIVE_DAYS 50576
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_INITIATING_ORIGIN 50577
#define IDS_BROWSER_SHARING_CONTENT_TYPE_TEXT 50578
#define IDS_BROWSER_SHARING_CONTENT_TYPE_NUMBER 50579
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_GENERIC_ERROR 50580
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_INTERNAL_ERROR 50581
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_NETWORK_ERROR 50582
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_ACK_TIMEOUT 50583
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_INTERNAL_ERROR 50584
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TITLE_PAYLOAD_TOO_LARGE 50585
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TEXT_PAYLOAD_TOO_LARGE 50586
#define IDS_SETTINGS_PASSWORD_SHOW 50590
#define IDS_SETTINGS_PASSWORD_HIDE 50591
#define IDS_TABLE_VIEW_AX_ANNOUNCE_ROW_SELECTED 50592
#define IDS_LINK_COPIED 50593
#define IDS_INCOGNITO_NAVIGATION_BLOCKED_PAGE_TITLE 50594
#define IDS_INCOGNITO_NAVIGATION_MESSAGE 50595
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS 50596
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_1 50597
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_2 50598
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_3 50599
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_4 50600
#define IDS_INCOGNITO_NAVIGATION_MISSING_TITLE 50601
#define IDS_INCOGNITO_NAVIGATION_MISSING_EXTENSIONS 50602

#endif  // CEF_INCLUDE_CEF_PACK_STRINGS_H_
